% Communications Toolbox MATLAB functions.
% Version 1.0 10-Apr-96
% 
% SIMULINK Block Library
%   commlib     - open the Communications Toolbox SIMULINK Block Library.
%
% Signal Sources and Display Functions
%   randint     - Random integer matrix generator.
%   randbit     - Binary noise generator.
%   biterr      - Bit error number and bit error rate computation.
%   symerr      - Symbol error number and symbol error rate computation.
%   eyescat     - Eye-pattern diagram or scatter plot.
%
% Source Coding
%   compand     - Source code mu-law or A-law compressor or expander.
%   dpcmdeco    - Differential pulse code modulation decode computation.
%   dpcmenco    - Differential pulse code modulation encode computation.
%   dpcmopt     - Differential pulse code modulation parameter optimization.
%   lloyds      - Scalar quantization optimization using training data.
%   quantiz     - Quantization index and quantized output value.
%
% Error-Control Encode/Decode
%   encode      - Encode computation for error-control coding methods.
%   decode      - Decode computation for error-control coding methods.
%   rsencof     - Encode a text file using Reed-Solomon code.
%   rsdecof     - Decode a Reed-Solomon code encoded text file.
%   
%   Support Functions:
%       bchpoly     - BCH code generator polynomial.
%       cyclgen     - Cyclic code generator and parity-check matrices.
%       cyclpoly    - Cyclic generator polynomial.
%       gen2par     - Generator matrix to parity-check matrix conversion.
%       hammgen     - Hamming code generator and parity-check matrices.
%       htruthtb    - Truth table from generator or parity check matrix.
%       oct2gen     - Convolution code octal form to binary form conversion.
%       sim2gen     - Convolution code binary from SIMULINK block diagram.
%
% Modulation/Demodulation
%   amod        - Modulation computation.
%   ademod      - Demodulation computation.
%   amodce      - Complex envelope of analog modulation.
%   ademodce    - Demodulate from a complex envelope of analog modulated signal.
%   dmodce      - Complex envelope of digital modulation.
%   ddemodce    - Demodulate from complex envelope of digital modulated signal.
%   modmap      - Digital modulation mapping.
%   demodmap    - Digital demodulation demapping.
%
%   Support Functions
%       apkconst    - Compute/plot ASK/PSK constellation from NIR, AIR, PIR.
%       qaskenco    - Encode a message to two-dimensional form for QASK use.
%       qaskdeco    - Decode a two-dimensional code to one dimension message.
%
% Filters
%   hank2sys    - Convert Hankel matrix to linear system.
%   hilbiir     - Hilbert transform IIR filter.
%   imp2sys     - FIR filter to IIR filter conversion.
%   rcosflt     - Filtering signal using raised cosine filter.
%   rcosine     - Design raised cosine filter.
%
%   
% Galois Field Computation
%   flxor       - Exclusive OR calculation.
%   gfadd       - GF additive computation.
%   gfconv      - GF polynomial convolution (multiply) computation.
%   gfcoset     - Cyclotomic cosets generator.
%   gfdeconv    - GF polynomial deconvolution (dividing) computation.
%   gfdiv       - GF dividing computation.
%   gffilter    - GF filtering computation.
%   gflineq     - Computer X in A X = B in GF(p) field.
%   gfminpol    - Find minimal polynomials.
%   gfmul       - GF multiplicative computation.
%   gfplus      - GF(2^p) additive computation.
%   gfpretty    - GF polynomial presentation.
%   gfprimck    - Test GF irreducible and primitive properties.
%   gfprimdf    - Output default primitive polynomial at a given degree.
%   gfprimfd    - Find GF primitive polynomial.
%   gfrank      - Find the rank of a matrix in Galois field.
%   gfrepcov    - GF polynomial conversion.
%   gfroots     - Find roots of a polynomial in GF(p^m) field.
%   gfsub       - GF substraction computation.
%   gftrunc     - GF polynomial truncation processing.
%   gftuple     - GF m-tuple representation and power representation.
%   isprime     - Verify whether an integer is a prime number.
%   primes      - Produce prime numbers.
%
% Utilities
%   callhelp    - Display help text section.
%   bi2de       - Binary to positive decimal integer conversion.
%   de2bi       - Positive decimal integer to binary conversion.
%   randint     - Uniform distribution random integer number generator.
%   checkinp    - Function default value check.
%   vec2mat     - Convert vector to matrix by a given column number.
%   blkdiag     - Constructs a block diagonal matrix using the input matrices.
%   
%   Graphical user interface example:
%   commgui     - Open the window for a error rate computation GUI example.
%

%   Lower-Level Functions for error-control coding:
%       bchcore     - The kernel computation part for BCH decode.
%       bchdeco     - BCH decode computation.
%       bchenco     - BCH code encode computation.
%       convenco    - Convolution code encode.
%       errlocp     - Error-location polynomial for BCH and RS code.
%       rspoly      - Produce Reed-Solomon code generator polynomial.
%       rscore      - Reed-Solomon decode core.
%       rsencode    - Encode Reed-Solomon code.
%       rsenco      - A user-interfaced Reed-Solomon encode calculation.
%       rsdecode    - Decode Reed-Solomon code.
%       rsdeco      - A user-interfaced Reed-Solomon decode calculation. 
%       viterbi     - Viterbi convolution code decode with limited memory.
%       viterbi2    - Viterbi convolution code decode with unlimited memory.
%
%   Lower Level Functions for utilities:
%       simsum      - Function recursively called by sim2gen.
%
%   Lower-Level Functions for special filters:
%       rcosfir     - Raised cosine FIR filter.
%       rcosiir     - Raised cosine IIR filter.
%
%   Lower level Functions for GUI example:
%       comempty    - Error message for empty entry.
%       comermn     - Parameter setting menu exchange.
%       comleng     - Making a same length vector.
%       comload     - Load file for COMFUN
%       commod      - Computation part for GUI example.
%       complot     - Curve fitting plot part for GUI example.
%       comrun      - Management file for GUI example.
%       comsave     - Save file for COMFUN.
%       combtnd     - Window button down function.
%       comwksp     - Load/Save to workspace.

%   Wes Wang 10/5/95
%   Copyright (c) 1995-96 by The MathWorks, Inc.
%   $Revision: 1.2 $  $Date: 1996/04/08 22:08:18 $
