function commlib
%COMMLIB Open the Communications Toolbox SIMULINK Block Library.
%       COMMLIB opens the top level of the Communications Toolbox
%       SIMULINK Block Library. When SIMULINK is not installed in
%       the MALTABPATH, this function displayes an error mesasge
%       at the MATLAB prompt.
%
%       The Communciaiton Toolbox SIMULINK Block Library has the
%       following tree structure:
%       COMMLIB-->COMMU ==> the Main Library
%           COM_SOUR ==> Source/Sink Library
%           COM_FRMT ==> Source Coding Library
%           COM_CODE ==> Error-Control-Coding Library
%               COMCDLIN-->Linear Block Code Sublibrary
%               COMCDHAM-->Hamming Code Sublibrary
%               COMCDCYC-->Cyclic Code Sublibrary
%               COMCDBCH-->BCH Code Sublibrary
%               COMCDRS -->Reed-Solomon Code Sublibrary
%               COMCDCON-->Convolution Code Sublibrary
%           COM_MODU ==> Modulation/Demodulation Library
%               COM_CDMO-->Passband Analog Modulation/Demodulation Sublibrary
%               COM_CEMO-->Baseband Analog Modulation/Demodulation Sublibrary
%               COM_DDMO-->Passband Digital Modulation/Demodulation Sublibrary
%               COM_MOCE-->Baseband Digital Modulation/Demodulation Sublibrary
%               COM_MOCD-->Passband Mapping/Demapping Sublibrary
%               COM_MOMP-->Baseband Mapping/Demapping Sublibrary
%           COM_MLAC ==> Multiple Access Library
%           COM_FILT ==> Special Filters Library
%           COM_CHAN ==> Communciation Channel Models Library
%           COM_SYNC ==> Synchronization Library
%           COM_UTIL ==> Utility Library
%           COM_CASE ==> Examples and Case Studies Library
%
%       See Also: COMMU.

%       Wes Wang 1996.
%       Copyright (c) 1995-96 by The MathWorks, Inc.
%       $Revision: 1.1 $  $Date: 1996/04/01 17:53:41 $

if exist('simulink')
    if exist('commu')
        open_system('commu');
    else
        error('You have not loaded the Communications Toolbox SIMULINK Block Library yet.'); 
    end;
else
    error('You need SIMULINK to open the Communications Toolbox SIMULINK Block Library.'); 
end;
