function wt = gfweight(g, gh_flag)
%GFWEIGHT Calculates Hamming weight based on generator or parity-check matrix.
%       WT = GFWEIGHT(G) outputs the Hamming weight of the given generator
%       matrix G.
%       WT = GFWEIGHT(G, GH_FLAG) outputs the Hamming weight, where GF_FLAG is
%       used to specify the feature of the first input parameter.
%       When GH_FLAG == 'gen', g is a generator matrix.
%       When GH_FLAG == 'par', g is a parity-check matrix.
%       When GH_FLAG == n, which represents the code word length, G is a
%       generator polynomial.
%
%       See also HAMMGEN, BCHPOLY.

%       Wes Wang 7/28/94, 10/7/95
%       Copyright (c) 1995-96 by The MathWorks, Inc.
%       $Revision: 1.1 $  $Date: 1996/04/01 18:00:29 $

if nargin < 1
    error('Not enough input parameters')
elseif nargin < 2 
    gh_flag = 'gen';        % default as generator matrix
end;

if ~isstr(gh_flag)
    [h, g] = cyclgen(gh_flag, g);
    clear h;
elseif lower(gh_flag(1:2)) == 'pa'
    g = gen2par(g);
end;

[n, m]= size(g);
if n < 10
    x = [1 : 2^n - 1]';
    x = de2bi(x, n);
    x = rem(x * g, 2);
    wt = min(sum(x'));
else
    wt = n;
    for i = 1 : 2^n -1
        wt = min(wt, sum(rem(de2bi(i, n) * g, 2)));
    end;
end;
%--- end of gfweight--
