function  [sys, x0, str, ts]  = sbiterr(t,x,u,flag, num_lin, K, TDelay, Sample)
%SBITERR S-function for symbol and bit error.
%
%  This M-file is designed to be used in a SIMULINK S-function block.
%
%    S-function Syntax (see SFUNC):
%       [SYS, X0, STR, TS]  = SBITERR(T,X,U,FLAG,NUM_LIN, K, TDelay, Sample)
%     where:
%       num_line: Number of lines on display.
%       K:        bit number. The input/output is in the range [0, M-1].
%       TDelay:   Time delay from input to output.
%       Sample:   Sample time of the input signal.
%
%       Set this M-file up in an S-function block.
%
%    See also PLOT, SFUNYST, SFUNXY, LORENZ2.

%       Wes Wang 1/14/95
%       Copyright (c) 1990-96 by The MathWorks, Inc.

if (flag == 2) | (flag == 9)
  % timing control.
  colormap = ['blu';'bla';'red'];
  posi_STnum = x(2) + 3;
  Sample1 = [x(posi_STnum+[1:2])];
  if x(posi_STnum) == 1
    Sample2 = Sample1;
  else
    Sample2 = [x(posi_STnum+[1;3])];
  end;
  rel_err = rem(t, Sample1(1)) / Sample1(1);
  test1 = abs(rel_err - Sample1(2) /Sample1(1));
  test2 = abs(rel_err - Sample1(2) /Sample1(1));
  % fprintf('\nCurrent time: %f Sender: %f, %f, %f',t,u(1),test1, test2)
  if (test1 < .0000001) | (abs(test1 - 1)< .0000001)
    % storage part
    if x(2) > 0
      x(3:2+x(2)) = [x(4:2+x(2)); u(1)];
    else
      x(3) = u(1);
    end;
    sys = x;
  % fprintf(' entered storage update.')
  end;
  if (test2 < .0000001) | (abs(test2 - 1)< .0000001)
    % plot part
	if t < TDelay
      sys = x;
      if (flag == 9)
        sys = [];
      end;
      return;
	end;
    % fprintf(' entered plot update.')
    if x(1) == 0
      % initialize graph.
      [sl_name, block] = get_param;
      [n_b, m_b] = size(block);
      if n_b < 1
        error('Cannot delete block during simulation.')
      elseif n_b > 1
        error('Something worng in get_param. You don''t have the current SIMULINK.')
      end;
      % find out if the graphics window exist
      ind = find(sl_name == setstr(10));
      dash = '_';
      sl_name(ind) = dash(ones(size(ind)));
          
      % in case of figure exists.
      %copy the lines over to reproduce it.
      new_figure = 1;
      old_figure = 0;
      % findout if the graphics window exist
      ind = find(sl_name == setstr(10));
      dash = '_';
      sl_name(ind)=dash(ones(size(ind)));

      % test if figure exists
      Figures = get(0,'Chil');
      new_figure = 1;
      i = 1;
      while ((new_figure) & (i <= length(Figures)))
        if strcmp(get(Figures(i), 'Type'), 'figure')
          if strcmp(get(Figures(i), 'Name'), sl_name)
            h_fig = Figures(i);
            handles = get(h_fig,'UserData');
            new_figure = 0;
            % refresh all handles.
            if (length(handles) == 1 + length(u) * (num_lin + 2) - ((K>1) + 1)*2)
              %use the old one.
              for ii = 3 : length(handles)
                set(handles(ii), 'String', ' ');
              end
              current_point = 0;
              if K == 1
                h_sym_bit = handles(2 : length(u)*2);
                h_record = handles(length(u)*2+1 : length(h_record));
                for i = 1 : 2: length(u) * 2
                  set(h_sym_bit(i) , 'UserData', 0);
                end;
              else
                h_sym_bit = handles(2 : length(u)*4-1);
                h_record = handles(length(u)*4 : length(h_record));
                t_tras(1) = get(h_sym_bit, 'UserData') + 1;
                t_tras(2) = get(h_sym_bit(length(u)*2), 'UserData') + K;
              end;
              set(h_fig, 'UserData', [current_point, h_sym_bit, h_record]);
            else
              delete(get(h_fig,'child'));
              old_figure = 1;
              new_figure = 1;
            end;
          end;
        end;
        i = i + 1;
      end;
 
      % exit early
      if new_figure & (flag == 9)
        sys = [];
        return;
      end;

      % the figure does not exist, create a new figure
      if new_figure
        if ~old_figure
          h_fig = figure('Unit','pixel','Pos',[10 10 300 400], ...
                         'Name',sl_name,'Number','off',...
                         'Color',[1 1 1]);
        else
          set(h_fig, 'Nextplot', 'add');
        end;
        set(0, 'CurrentF', h_fig);
        % number of input.
        len_u = length(u);
        if len_u < 2
          error('Source or destination is empty.');
        end;
        if K == 1;
          len_bit = 3;
          len_h_rec = 2 * length(u) - 1;
        else
          len_bit = 6;
          len_h_rec = 4 * length(u) - 2;
        end;

        % Input/Output
        if num_lin <= 0
          num_lin = 0;
        end;
        totlin = 1 + num_lin + len_bit + 1;

        h_axes = axes('position',[0 0 1 1],...
                      'visible','off',...
                      'next','add');
        tmp_x = [];
        tmp_y = [];
        for ii = 1 : totlin
            tmp_x = [tmp_x 0 1 NaN];
            tmp_y = [tmp_y ii/totlin ii/totlin NaN];
        end;
        h_plot = plot(tmp_x, tmp_y, 'k-');
        set(h_plot,'linewidth',1)
        len_u = length(u);
        for i = 1 : len_u
          % title
          if i == 1
            t_str = 'Sender';
          else
            t_str = ['Receiver',num2str(i-1, 8)];
            if len_u == 2
              t_str = 'Receiver';
            end
            if num_lin > 0
              set(h_plot, 'XData', [get(h_plot, 'XData') [1 1]*(i-1)/len_u NaN],...
                        'YData', [get(h_plot, 'YData') (totlin-num_lin-1)/totlin 1 NaN]);
            end;
          end;
          p_beg1 = (i - 1) / length(u) + .001;
          p_wid = 1 / length(u) - .002;
          uicontrol(h_fig, 'Style', 'text', 'Horiz', 'center',...
                    'Unit','norm',...
                    'pos', [p_beg1, (totlin - 1)/totlin+.001, p_wid, 1/totlin-.002], ...
                    'String', t_str);

          p_beg = (2*i - 1) / 2 / len_u;
          h_tmp = text(p_beg, (totlin - 1/2)/totlin, t_str);
          set(h_tmp, 'HorizontalA','Center',...
                     'FontSize', 9,...
                     'Color',[0 0 0],...
                     'VerticalA',  'Middle');
    
          %space for list of transfered number.
          if num_lin > 0
            for ii = 1 : num_lin
              h_record((ii-1)*length(u) + i) = ...
                text(p_beg, (2*totlin - 2*ii - 1)/2/totlin, ' ');
              set(h_record((ii-1)*length(u) + i), ...
                     'FontSize', 9,...
                     'Color',[0 0 0],...
                     'HorizontalA','Center',...
                     'VerticalA',  'Middle');
            end;
            set(h_record(1), 'UserData',1);
          end;
          % transfer error rate 
          if K > 1
            len_rate = 2;
          else
            len_rate = 1;
          end;
          kk = 0;
          for ii = 1 : len_rate
            if i == 1
              if ii == 1
                t_str = 'Symbol Transfered';
                trsf = 1;
                indx = 1;
              else
                t_str = 'Bit Transfered';
                trsf = K;
                indx = length(u) * 2;
              end;

              % Symbol/bit transfered title
              h_tmp = text(.25, ((len_rate-ii)*3+2.5+1)/totlin, t_str);
              set(h_tmp, 'HorizontalA','Center',...
                     'FontSize', 9,...
                     'Color',[0 0 0],...
                     'VerticalA',  'Middle');
              uicontrol(h_fig, 'Style', 'text', 'Units', 'norm',...
                        'Pos',[0, ((len_rate - ii) * 3 + 2 + 1)/totlin+.001, .499, 1/totlin-.002],...
                        'String',t_str, 'BackgroundColor','yellow');
              set(h_plot, 'XData', [get(h_plot, 'XData') .5 .5 NaN],...
                        'YData', [get(h_plot, 'YData') ((len_rate - ii)* 3 + 2 + 1)/totlin ((len_rate - ii)* 3 + 3 + 1)/totlin NaN]);
            
              % Symbol/bit transfered data
              h_sym_bit(indx) = text(.75, ((len_rate-ii)*3*2 + 5 + 2)/2/totlin, num2str(trsf, 8));
              set(h_sym_bit(indx),...
                     'FontSize', 9,...
                     'UserData', 0,...
                     'Color',[0 0 0],...
                     'HorizontalA','Center',...
                     'VerticalA',  'Middle');
              % title for error number
              uicontrol(h_fig, 'Style', 'text', 'Units', 'norm',...
                        'Pos', [p_beg1, ((len_rate - ii) * 3 + 1 + 1)/totlin+.001, p_wid, 1/totlin-.002],...
                        'String','Error Number'); 
              % title for error rate
              uicontrol(h_fig, 'Style', 'text', 'Units', 'norm',...
                        'Pos', [p_beg1, ((len_rate - ii) * 3 + 1)/totlin+.001, p_wid, 1/totlin-.002],...
                        'String','Error Rate'); 
              h_tmp = text(p_beg, ((len_rate - ii) * 3 + 3/2 + 1)/totlin, 'Error Number');
              set(h_tmp, 'HorizontalA','Center',...
                     'FontSize', 9,...
                     'Color',[0 0 0],...
                     'VerticalA',  'Middle');
              h_tmp = text(p_beg, ((len_rate - ii) * 3 + 1/2 + 1)/totlin, 'Error Rate');
              set(h_tmp, 'HorizontalA','Center',...
                     'FontSize', 9,...
                     'Color',[0 0 0],...
                     'VerticalA',  'Middle');
            else
              %error number
              kk = (i-1)*2 + (length(u) * 2 - 1)*(ii - 1);
              set(h_plot, 'XData', [get(h_plot, 'XData') [p_beg1 p_beg1]-.001 NaN],...
                        'YData', [get(h_plot, 'YData') ((len_rate - ii)* 3 + 1)/totlin ((len_rate - ii)* 3 + 2 + 1)/totlin NaN]);

              h_sym_bit(kk) = text(p_beg, ((len_rate-ii)*3*2 + 3 + 2)/2/totlin, '0');
              set(h_sym_bit(kk), ...
                     'UserData', 0,...
                     'FontSize', 9,...
                     'Color',[0 0 0],...
                     'HorizontalA','Center',...
                     'VerticalA',  'Middle');
              %error rate

              h_sym_bit(kk+1) = text(p_beg, ((len_rate-ii)*3*2 +1 + 2)/2/totlin, '0');
              set(h_sym_bit(kk+1), ...
                     'UserData', 0,...
                     'FontSize', 9,...
                     'Color',[0 0 0],...
                     'HorizontalA','Center',...
                     'VerticalA',  'Middle');
            end;
          end;
        end;
        set(h_axes, 'Xlim',[0 1], 'Ylim',[0 1])
        current_point = 0;
        set(h_fig, 'UserData', [current_point, h_sym_bit, h_record]);
        set(h_fig,'NextPlot','new');
      end;
      x(1) = h_fig;

      tmp1 = uicontrol(h_fig,...
             'Style', 'pushbutton',...
             'Unit', 'norm',...
             'Position', [0 0 .5 1/totlin], ...
             'String', 'Reset error count',...
             'Callback',['sbiterrs(gcf,',num2str(len_rate),',',num2str(len_u),')']);

      tmp1 = uicontrol(h_fig,...
             'Style', 'pushbutton',...
             'Unit', 'norm',...
             'Position', [.5 0 .5 1/totlin], ...
             'String', 'Close',...
             'Callback','close(gcf)');
    elseif x(1) < 0
      %figure has been closed
      return;
    end;

    plot_flag_test = get(0,'child');
    if isempty(plot_flag_test)
      return;
    elseif isempty(find(plot_flag_test == x(1)))
      x(1) = -1;
      return;
    end;

    handles = get(x(1), 'UserData');
    h_fig =  x(1);
    current_point = handles(1);
    if K == 1
      h_sym_bit = handles(2 : length(u)*2);
      h_record = handles(length(u)*2+1 : length(handles));
      t_tras = get(h_sym_bit(1), 'UserData') + 1;
      set(h_sym_bit(1), 'UserData', t_tras, 'String', num2str(t_tras, 8));
    else
      h_sym_bit = handles(2 : length(u)*4-1);
      h_record = handles(length(u)*4 : length(handles));
      t_tras(1) = get(h_sym_bit(1), 'UserData') + 1;
      t_tras(2) = get(h_sym_bit(length(u)*2), 'UserData') + K;
      set(h_sym_bit(1), 'UserData', t_tras(1), 'String', num2str(t_tras(1),  8));
      set(h_sym_bit(length(u)*2), 'UserData', t_tras(2), 'String', num2str(t_tras(2), 8));
    end;
    if num_lin > 0
      if current_point == 0
        set(h_record(1), 'UserData', rem(get(h_record(1), 'UserData') + 1, 2));
      end;
      col = colormap(get(h_record(1), 'UserData') + 1, :);
    end;
    next_point = rem(current_point + 1, num_lin);
    last_point = rem(current_point-1+num_lin, num_lin);
    for i = 1 : length(u)
      if i == 1
        if num_lin > 0
          set(h_record(current_point * length(u) + i), 'String', num2str(x(3), 8), 'Color',col);
        end;
      else
        if num_lin > 0
          if u(i) == x(3)
            set(h_record(current_point * length(u) + i), 'String', num2str(u(i), 8), 'Color',col);
          else
            set(h_record(current_point * length(u) + i), 'String', ...
                   num2str(u(i), 8), 'Color',colormap(3,:));
          end
        end;
        if u(i) ~= x(3)
          % in case of error
          % number of errors
          num = get(h_sym_bit((i-1)*2), 'UserData') + 1;
          set(h_sym_bit((i-1)*2), 'UserData', num, 'String', num2str(num, 8));
          % errors rate
          set(h_sym_bit((i-1)*2+1), 'String', num2str(num/t_tras(1), 8));
          if K > 1
            % number
            kk = (i-1)*2 + (length(u) * 2 - 1);
            num = get(h_sym_bit(kk), 'UserData');
            erb = sum(de2bi(flxor(x(3), u(i))));
            erb = erb + num;
            set(h_sym_bit(kk), 'UserData', erb, 'String', num2str(erb, 8));
            % rate
            set(h_sym_bit(kk+1), 'String', num2str(erb/t_tras(2),8));
          end;
        else
          tmp = get(h_sym_bit((i-1)*2), 'UserData');
          if tmp 
             set(h_sym_bit((i-1)*2 + 1), 'String', ...
                 num2str(tmp / t_tras(1), 8));
          end;
          if K > 1
            kk = (i-1)*2 + (length(u) * 2 - 1);
            tmp = get(h_sym_bit(kk), 'UserData');
            if tmp 
               set(h_sym_bit(kk + 1), 'String', ...
                 num2str(tmp / t_tras(2), 8));
            end
          end;
        end;
      end;
    end
    current_point = next_point;
    sys = [h_fig; x(2:length(x))];
    set(h_fig, 'UserData', [current_point, h_sym_bit, h_record]);
    % second in User data is the current position for the line of h_record.
  end;

  if flag == 9
    sys = [];
  end;
elseif flag  == 0,      % Initialization

    % Keep number of states.
    num_state = max(0, ceil(TDelay/Sample(1))) + 1;

    if TDelay < 0
        error('Time delay cannot be negative.');
    end;

    if length(Sample) < 1
        error('Sample time cannot be empty.');
    elseif length(Sample) == 1
        Sample  = [Sample, 0];
    else
        Sample = Sample(:)';
        Sample = Sample(1:2);
    end;
    if rem(TDelay+Sample(2), Sample(1)) == 0
        Sample2 = [];
        STnum = 1;
    else
        Sample2 = [Sample(1), rem(TDelay+Sample(2), Sample(1))];
        STnum = 2;
    end;    

    ts = [Sample; Sample2];
    if Sample <= 0
        error('Sample time for error rate meter has to be larger than zero.')
    end;

   % Return system sizes
   sys(1) = 0;                     % 0 continuous states
   sys(2) = num_state+6;           % discrete states
   sys(3) = 0;                     % 0 outputs
   sys(4) = -1;                    % autowidth number of inputs
   sys(5) = 0;                     % 0 roots
   sys(6) = 0;                     % no direct feedthrough
   sys(7) = STnum;                 % 2 sample time
   if isempty(Sample2)
        Sample2 = Sample;
   end;
   x0 = [0; num_state;     % figure number. 0 indicates the first
   zeros(num_state, 1);
   STnum; Sample(1); 
   Sample(2); Sample2(2)]; % number of state.
elseif (flag == 4)
    posi_STnum = x(2) + 3;
    rel_err = abs(rem(t, x(posi_STnum + 1)) / x(posi_STnum + 1));
    if x(posi_STnum) == 1
        if (rel_err < .0000001) & (x(posi_STnum+2) > eps)
            sys = t + x(posi_STnum + 2);
        else
            sys = t + x(posi_STnum + 1);
        end;
    else
        if (rel_err < .0000001) & (max(x(posi_STnum+[2:3]) > eps))
            ind = find(x(posi_STnum+[2:3]) > 0);
            sys = t + max(x(posi_STnum+1+ind));
        elseif (abs(rel_err - x(posi_STnum + 2)/x(posi_STnum+1)) < .0000001) & (x(posi_STnum + 2) > eps)
            if x(posi_STnum+2) > x(posi_STnum+3)
                sys = ceil(t / x(posi_STnum+1)) * x(posi_STnum+1) + x(posi_STnum+3);
            elseif x(posi_STnum+2) < x(posi_STnum+3)
                sys = floor(t / x(posi_STnum+1)) * x(posi_STnum+1) + x(posi_STnum+3);
            else
                sys = t + x(posi_STnum+1);
            end;
        elseif (abs(rel_err - x(posi_STnum + 3)/x(posi_STnum+1)) < .0000001)& (x(posi_STnum + 2) > eps)
            if x(posi_STnum+3) > x(posi_STnum+2)
                sys = ceil(t / x(posi_STnum+1)) * x(posi_STnum+1) + x(posi_STnum+2);
            elseif x(posi_STnum+3) < x(posi_STnum+2)
                sys = floor(t / x(posi_STnum+1)) * x(posi_STnum+1) + x(posi_STnum+2);
            else
                sys = t + x(posi_STnum+1);
            end;
        else
            sys = t + x(posi_STnum+1);
        end;
    end
else
  % Other flag options not defined.
    sys = [];
end
