function [ret,x0,str,ts,xts]=com_cdmo(t,x,u,flag);
%COM_CDMO	is the M-file description of the SIMULINK system named COM_CDMO.
%	The block-diagram can be displayed by typing: COM_CDMO.
%
%	SYS=COM_CDMO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_CDMO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_CDMO with a FLAG of zero:
%	[SIZES]=COM_CDMO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[82,154,523,684])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Demonstration blocks'.

new_system([sys,'/','Demonstration blocks'])
set_param([sys,'/','Demonstration blocks'],'Location',[175,552,335,697])
set_param([sys,'/','Demonstration blocks'],...
		'Mask Display','.')


%     Finished composite block 'Demonstration blocks'.

set_param([sys,'/','Demonstration blocks'],...
		'orientation',1,...
		'BackGround',7,...
		'position',[50,498,105,521])


%     Subsystem  ['SSB-AM',13,'passband'].

new_system([sys,'/',['SSB-AM',13,'passband']])
set_param([sys,'/',['SSB-AM',13,'passband']],'Location',[76,558,518,713])


%     Subsystem  ['SSB-AM',13,'passband/QAM discr-filt'].

new_system([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],'Location',[302,478,834,743])

add_block('built-in/Clock',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Clock']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Clock']],...
		'position',[80,85,100,105])

add_block('built-in/Gain',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Gain']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Gain']],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Inport',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/in_2']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/in_2']],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Inport',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/in_1']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/in_1']],...
		'position',[160,30,180,50])

add_block('built-in/Outport',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/out_1']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/out_1']],...
		'position',[490,90,510,110])

add_block('built-in/Sum',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Sum2']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Sum2']],...
		'position',[430,90,450,110])

add_block('built-in/Product',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Product1']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Product1']],...
		'position',[355,112,380,143])

add_block('built-in/Product',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Product']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Product']],...
		'position',[355,47,380,78])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[250,305,255,310])

add_block('built-in/Fcn',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Fcn1']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Fcn',[sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Fcn']])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])
add_line([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],[185,95;200,95;200,70;225,70])
add_line([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],[200,95;200,120;225,120])
add_line([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],[105,95;125,95])
add_line([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],[385,130;400,130;400,105;425,105])
add_line([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],[185,155;330,155;330,135;350,135])
add_line([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],[330,120;350,120])
add_line([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],[185,40;335,40;335,55;350,55])
add_line([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],[330,70;350,70])
add_line([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],[455,100;485,100])
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],...
		'Mask Display','QM DSB\nAM',...
		'Mask Type','Quadrature Multiplexed DSB-SC AM')
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],...
		'Mask Dialogue','Quadrature multiplexed double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency (Hz):|Initial phase (rad):|Sample time:')
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],...
		'Mask Translate','Am=@1;Fc=@2*2*pi;Ph=@3;ts=@4;')
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],...
		'Mask Help','The Quadratic Multiplexed Double-Sideband-Supressed-Carrier AM block causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. There are two input signal being modulated at the same time by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],...
		'Mask Entries','1\/Fc\/Ph\/ts\/')


%     Finished composite block ['SSB-AM',13,'passband/QAM discr-filt'].

set_param([sys,'/',['SSB-AM',13,'passband/QAM discr-filt']],...
		'ForeGround',3,...
		'position',[280,45,360,85])

add_block('built-in/Outport',[sys,'/',['SSB-AM',13,'passband/out_1']])
set_param([sys,'/',['SSB-AM',13,'passband/out_1']],...
		'position',[400,55,420,75])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp82']])
set_param([sys,'/',['SSB-AM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp82']],...
		'position',[355,290,360,295])

add_block('built-in/Inport',[sys,'/',['SSB-AM',13,'passband/in_1']])
set_param([sys,'/',['SSB-AM',13,'passband/in_1']],...
		'position',[30,20,50,40])

add_block('built-in/Filter',[sys,'/',['SSB-AM',13,'passband/Filter']])
set_param([sys,'/',['SSB-AM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[95,66,150,104])

add_block('built-in/Gain',[sys,'/',['SSB-AM',13,'passband/Gain']])
set_param([sys,'/',['SSB-AM',13,'passband/Gain']],...
		'Gain','k',...
		'position',[185,72,215,98])
add_line([sys,'/',['SSB-AM',13,'passband']],[365,65;395,65])
add_line([sys,'/',['SSB-AM',13,'passband']],[55,30;255,30;255,55;275,55])
add_line([sys,'/',['SSB-AM',13,'passband']],[55,30;65,30;65,85;90,85])
add_line([sys,'/',['SSB-AM',13,'passband']],[155,85;180,85])
add_line([sys,'/',['SSB-AM',13,'passband']],[220,85;240,85;240,75;275,75])
set_param([sys,'/',['SSB-AM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);SSB AM',...
		'Mask Type','Passband SSB-AM')
set_param([sys,'/',['SSB-AM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using \nsingle-sideband amplitude modulation\nmethod with Hilbert transform filter.|Carrier frequency (Hz):|Initial Phase (rad):|Bandwidth of the input signal (Hz):|Time delay for Hilbert transform filter (sec):|Sample time (sec):|"upper" sideband or "lower" sideband:')
set_param([sys,'/',['SSB-AM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2;ban=@3;dly=@4;ts=@5;sd=@6;if ban>1/ts, ban=1/ts-ts;end;[num,den]=hilbiir(ts,dly,ban);pi2=2*pi;pih=pi/2;k=-1;if sd(1)==''l'',k=1;end;[x,y]=moduicon(1);')
set_param([sys,'/',['SSB-AM',13,'passband']],...
		'Mask Help','This block modulates the input signal using the SSB-AM method. The block uses Hilbert transfer filter. Hilbert transform filter is a non-causal filter. A positive time delay is requested in the implementation. You can specify the modulation to be an USB or LSB modulation.')
set_param([sys,'/',['SSB-AM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/1/.01/10\/.01*10\/.01\/''upper''\/')


%     Finished composite block ['SSB-AM',13,'passband'].

set_param([sys,'/',['SSB-AM',13,'passband']],...
		'position',[50,348,130,392])


%     Subsystem  ['FDM',13,'passband'].

new_system([sys,'/',['FDM',13,'passband']])
set_param([sys,'/',['FDM',13,'passband']],'Location',[30,490,489,666])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Sensitivity']])
set_param([sys,'/',['FDM',13,'passband/Sensitivity']],...
		'Gain','2',...
		'position',[75,25,115,55])

add_block('built-in/Product',[sys,'/',['FDM',13,'passband/Multiplier',13,'phase detector']])
set_param([sys,'/',['FDM',13,'passband/Multiplier',13,'phase detector']],...
		'position',[190,35,215,55])

add_block('built-in/Filter',[sys,'/',['FDM',13,'passband/Filter']])
set_param([sys,'/',['FDM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[275,26,330,64])


%     Subsystem  ['FDM',13,'passband/Discrete-time',13,'VCO'].

new_system([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],'Location',[93,129,873,276])

add_block('built-in/Outport',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/out_1']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/out_1']],...
		'position',[690,35,710,55])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity3']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity3']],...
		'Gain','Ac',...
		'position',[605,30,655,60])

add_block('built-in/Fcn',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/sin']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/sin']],...
		'Expr','cos(u[1])',...
		'position',[510,32,585,58])

add_block('built-in/Constant',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Phase']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Phase']],...
		'Value','Ph',...
		'position',[400,100,420,120])

add_block('built-in/Sum',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum']],...
		'inputs','+++',...
		'position',[465,27,485,63])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity2']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity2']],...
		'Gain','Fc',...
		'position',[255,75,300,105])

add_block('built-in/Clock',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Clock']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Clock']],...
		'position',[180,80,200,100])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[105,15,155,45])

add_block('built-in/Sum',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum1']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum1']],...
		'position',[230,25,250,45])

add_block('built-in/Unit Delay',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Unit Delay']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Unit Delay']],...
		'Sample time','ts',...
		'position',[300,25,350,45])

add_block('built-in/Inport',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/in_1']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/in_1']],...
		'position',[35,20,55,40])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[660,45;685,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[590,45;600,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[425,110;435,110;435,55;460,55])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[355,35;460,35])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[370,35;370,70;205,70;205,40;225,40])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[305,90;425,90;425,45;460,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[205,90;250,90])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[490,45;505,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[255,35;295,35])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[160,30;225,30])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[60,30;100,30])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Display','Discrete\nVCO',...
		'Mask Type','VCO')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Dialogue','Voltage-Controlled Oscilator:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;ts=@5;Kc=Kc*pi2*ts(1);Fc=Fc*pi2;')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Help','The VCO block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Entries','1\/Fc\/1\/Ph\/ts\/')


%     Finished composite block ['FDM',13,'passband/Discrete-time',13,'VCO'].

set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'orientation',2,...
		'position',[240,95,300,135])

add_block('built-in/Outport',[sys,'/',['FDM',13,'passband/out_1']])
set_param([sys,'/',['FDM',13,'passband/out_1']],...
		'position',[420,35,440,55])

add_block('built-in/Inport',[sys,'/',['FDM',13,'passband/in_1']])
set_param([sys,'/',['FDM',13,'passband/in_1']],...
		'position',[25,30,45,50])
add_line([sys,'/',['FDM',13,'passband']],[235,115;135,115;135,50;185,50])
add_line([sys,'/',['FDM',13,'passband']],[220,45;270,45])
add_line([sys,'/',['FDM',13,'passband']],[335,45;415,45])
add_line([sys,'/',['FDM',13,'passband']],[385,45;385,115;305,115])
add_line([sys,'/',['FDM',13,'passband']],[50,40;70,40])
add_line([sys,'/',['FDM',13,'passband']],[120,40;185,40])
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);FDM',...
		'Mask Type','Passabnd FDM')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Dialogue','Demodulate an FM modulated signal\nusing phase-locked loop.|VCO frequency (Hz):|VCO initial phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2+pi/2;num=@3;den=@4;ts=@5;[x,y]=moduicon(4);')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Help','This block recovers a FM modulated signal using a phase-locked loop method. The phase detector used in this block is a multiplier.')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/.01\/')


%     Finished composite block ['FDM',13,'passband'].

set_param([sys,'/',['FDM',13,'passband']],...
		'position',[185,198,265,242])


%     Subsystem  ['PDM',13,'passband'].

new_system([sys,'/',['PDM',13,'passband']])
set_param([sys,'/',['PDM',13,'passband']],'Location',[232,541,802,708])

add_block('built-in/Inport',[sys,'/',['PDM',13,'passband/in_1']])
set_param([sys,'/',['PDM',13,'passband/in_1']],...
		'position',[20,30,40,50])

add_block('built-in/Outport',[sys,'/',['PDM',13,'passband/out_1']])
set_param([sys,'/',['PDM',13,'passband/out_1']],...
		'position',[545,40,565,60])

add_block('built-in/Unit Delay',[sys,'/',['PDM',13,'passband/Unit Delay1']])
set_param([sys,'/',['PDM',13,'passband/Unit Delay1']],...
		'orientation',2,...
		'Sample time','ts',...
		'position',[435,90,485,110])

add_block('built-in/Sum',[sys,'/',['PDM',13,'passband/Sum']])
set_param([sys,'/',['PDM',13,'passband/Sum']],...
		'position',[435,40,455,60])

add_block('built-in/Gain',[sys,'/',['PDM',13,'passband/Sensitivity']])
set_param([sys,'/',['PDM',13,'passband/Sensitivity']],...
		'Gain','ts*2*pi',...
		'position',[355,30,395,60])


%     Subsystem  ['PDM',13,'passband/Discrete-time',13,'VCO'].

new_system([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],'Location',[4,58,511,205])

add_block('built-in/Outport',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/out_1']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/out_1']],...
		'position',[425,30,445,50])

add_block('built-in/Constant',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Carrier',13,'frequency']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Carrier',13,'frequency']],...
		'Value','Fc*pi2',...
		'position',[60,85,115,105])

add_block('built-in/Fcn',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/sin']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/sin']],...
		'Expr','Ac*cos(u[1]+Ph)',...
		'position',[285,25,410,55])

add_block('built-in/Inport',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/in_1']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Gain',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Sensitivity']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Sensitivity']],...
		'Gain','Kc*pi2',...
		'position',[60,14,135,56])


%     Subsystem  ['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator'].

new_system([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],'Location',[402,373,908,481])

add_block('built-in/Outport',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/out_1']],...
		'position',[430,30,450,50])

add_block('built-in/Sum',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/module']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Inport',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Unit Delay',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Gain',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Sensitivity']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Sensitivity']],...
		'Gain','ts(1)',...
		'position',[80,16,135,54])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[40,35;75,35])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[400,40;425,40])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[410,40;410,90;175,90;175,45;190,45])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'Mask Entries','pi*100\/0\/ts\/')


%     Finished composite block ['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator'].

set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'position',[200,21,260,59])

add_block('built-in/Sum',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Sum']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Sum']],...
		'position',[155,30,175,50])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[415,40;420,40])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[40,35;55,35])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[120,95;125,95;125,45;150,45])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[265,40;280,40])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[180,40;195,40])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[140,35;150,35])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Display','Discrete\nVCO',...
		'Mask Type','VCO')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Dialogue','Voltage-Controlled Oscilator:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;ts=@5;')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Help','The VCO block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Entries','1\/Fc\/1\/Ph\/ts\/')


%     Finished composite block ['PDM',13,'passband/Discrete-time',13,'VCO'].

set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'orientation',2,...
		'position',[145,90,205,130])

add_block('built-in/Product',[sys,'/',['PDM',13,'passband/Multiplier',13,'phase detector']])
set_param([sys,'/',['PDM',13,'passband/Multiplier',13,'phase detector']],...
		'position',[155,35,180,55])

add_block('built-in/Filter',[sys,'/',['PDM',13,'passband/Filter']])
set_param([sys,'/',['PDM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[235,26,290,64])

add_block('built-in/Gain',[sys,'/',['PDM',13,'passband/Sensitivity1']])
set_param([sys,'/',['PDM',13,'passband/Sensitivity1']],...
		'Gain','2',...
		'position',[70,25,110,55])
add_line([sys,'/',['PDM',13,'passband']],[185,45;230,45])
add_line([sys,'/',['PDM',13,'passband']],[140,110;110,110;110,50;150,50])
add_line([sys,'/',['PDM',13,'passband']],[400,45;430,45])
add_line([sys,'/',['PDM',13,'passband']],[430,100;410,100;410,55;430,55])
add_line([sys,'/',['PDM',13,'passband']],[460,50;500,50;490,100])
add_line([sys,'/',['PDM',13,'passband']],[500,50;540,50])
add_line([sys,'/',['PDM',13,'passband']],[295,45;325,45;325,110;210,110])
add_line([sys,'/',['PDM',13,'passband']],[325,45;350,45])
add_line([sys,'/',['PDM',13,'passband']],[45,40;65,40])
add_line([sys,'/',['PDM',13,'passband']],[115,40;150,40])
set_param([sys,'/',['PDM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);PDM',...
		'Mask Type','Passband PDM')
set_param([sys,'/',['PDM',13,'passband']],...
		'Mask Dialogue','Demodulate a PM modulated signal\nusing phase locked loop.|VCO frequency (Hz):|VCO Phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['PDM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2+pi/2;num=@3;den=@4;ts=@5;[x,y]=moduicon(4);')
set_param([sys,'/',['PDM',13,'passband']],...
		'Mask Help','This block recovers a PM modulated signal. This block uses a multiplier phase detector in PLL. This block uses a discrete-time lowpass filter which passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['PDM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/.01\/')


%     Finished composite block ['PDM',13,'passband'].

set_param([sys,'/',['PDM',13,'passband']],...
		'position',[185,273,265,317])


%     Subsystem  ['ADM with carrier',13,'passband'].

new_system([sys,'/',['ADM with carrier',13,'passband']])
set_param([sys,'/',['ADM with carrier',13,'passband']],'Location',[67,574,402,724])


%     Subsystem  ['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas'].

new_system([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],'Location',[79,73,846,354])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/In-phase',13,'output']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/In-phase',13,'output']],...
		'position',[695,50,715,70])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/sin']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/in_1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/sin1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product2']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Sum1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Constant',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Gain',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Gain1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Sum']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter2']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Constant',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])


%     Subsystem  ['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator'].

new_system([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/module']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Unit Delay',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[410,40;440,40])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator'].

set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[400,60;690,60])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[655,60;645,115])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[260,130;215,130])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[315,185;300,185;290,135])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[305,125;290,125])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[360,125;345,125])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[485,225;655,225;645,125])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[155,225;420,225])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[70,55;120,55])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[90,55;90,230;120,230])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[605,120;600,120])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[435,125;430,125])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[155,60;335,60])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[530,120;465,120])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[240,130;240,180;225,180])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Display','Costas PL\nDSB ADM',...
		'Mask Type','DSB-SC ADM')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Dialogue','Double-sideband suppressed-carrier amplitude demodulation:|Carrier frequency:|Low-pass filter numerator (dis):|Low-pass filter denominator (dis):|Initial phase:|Sample time (sec):')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;pih=pi/2;ts=@5;')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Help','The DSB SC ADM demodulates a DSB-SC-AM signal using Costas Phase-Locked Loop method. The result of this ADM is phase sensitive. This block requires user to specify a lowpass filter which could filter the carrier freency and keep the message signal. Please refer Signal Processing Toolbox for design of the filters. ')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Entries','Fc\/num\/den\/Ph\/ts\/')


%     Finished composite block ['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas'].

set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'ForeGround',3,...
		'position',[100,15,180,55])

add_block('built-in/Constant',[sys,'/',['ADM with carrier',13,'passband/Constant']])
set_param([sys,'/',['ADM with carrier',13,'passband/Constant']],...
		'Value','Offset',...
		'position',[90,95,130,115])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'passband/out_1']])
set_param([sys,'/',['ADM with carrier',13,'passband/out_1']],...
		'position',[290,30,310,50])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'passband/Sum']])
set_param([sys,'/',['ADM with carrier',13,'passband/Sum']],...
		'inputs','+-',...
		'position',[240,30,260,50])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'passband/in_1']])
set_param([sys,'/',['ADM with carrier',13,'passband/in_1']],...
		'position',[40,25,60,45])
add_line([sys,'/',['ADM with carrier',13,'passband']],[135,105;220,105;220,45;235,45])
add_line([sys,'/',['ADM with carrier',13,'passband']],[265,40;285,40])
add_line([sys,'/',['ADM with carrier',13,'passband']],[185,35;235,35])
add_line([sys,'/',['ADM with carrier',13,'passband']],[65,35;95,35])
set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);ADM w TC',...
		'Mask Type','Passband ADM with carrier')
set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'Mask Dialogue','Demodulate an AM with carrier modulated signal.|Offset factor:|Carrier frequency (Hz):|Initial Phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'Mask Translate','Offset=@1;Fc=@2;Ph=@3;num=@4;den=@5;ts=@6;[x,y]=moduicon(2);')
set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'Mask Help','This block demodulates a DSB-AM with carrier modulated signal. In order to recover the original signal, the offset parameter should be the same as the parameter in the modulation. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'Mask Entries','1\/100/2/pi\/0\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/.01\/')


%     Finished composite block ['ADM with carrier',13,'passband'].

set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'position',[185,423,265,467])


%     Subsystem  ['AM with carrier',13,'passband'].

new_system([sys,'/',['AM with carrier',13,'passband']])
set_param([sys,'/',['AM with carrier',13,'passband']],'Location',[68,468,570,611])


%     Subsystem  ['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt'].

new_system([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],'Location',[51,135,503,309])

add_block('built-in/Filter',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/zero-hold',13,'for timing-control']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/zero-hold',13,'for timing-control']],...
		'Numerator','1',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[55,196,110,234])

add_block('built-in/Gain',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Gain']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Clock',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Clock']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Product',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Product']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Outport',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/out_1']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Inport',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/in_1']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Constant',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Constant1']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Fcn',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Fcn']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Sum',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Sum2']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Sum2']],...
		'position',[170,90,190,110])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[270,100;270,65;335,65])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[370,60;375,60])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[45,75;65,75])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[195,100;200,100])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'Mask Display','DSB-SC\nAM',...
		'Mask Type','DSB-SC AM')
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'Mask Dialogue','Double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'Mask Translate','Ac=@1;Fc=@2;Fc=Fc*2*pi;Ph=@3;ts=@4;')
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'Mask Help','The DSB-SC AM causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'Mask Entries','1\/Fc\/Ph\/ts\/')


%     Finished composite block ['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt'].

set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'ForeGround',3,...
		'position',[265,28,340,62])

add_block('built-in/Constant',[sys,'/',['AM with carrier',13,'passband/Constant']])
set_param([sys,'/',['AM with carrier',13,'passband/Constant']],...
		'Value','Offset',...
		'position',[60,75,110,95])

add_block('built-in/Inport',[sys,'/',['AM with carrier',13,'passband/in_1']])
set_param([sys,'/',['AM with carrier',13,'passband/in_1']],...
		'position',[50,30,70,50])

add_block('built-in/Sum',[sys,'/',['AM with carrier',13,'passband/Sum']])
set_param([sys,'/',['AM with carrier',13,'passband/Sum']],...
		'position',[160,35,180,55])

add_block('built-in/Outport',[sys,'/',['AM with carrier',13,'passband/out_1']])
set_param([sys,'/',['AM with carrier',13,'passband/out_1']],...
		'position',[395,35,415,55])

add_block('built-in/Note',[sys,'/',['AM with carrier',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp76']])
set_param([sys,'/',['AM with carrier',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp76']],...
		'position',[180,155,185,160])
add_line([sys,'/',['AM with carrier',13,'passband']],[115,85;130,85;130,50;155,50])
add_line([sys,'/',['AM with carrier',13,'passband']],[345,45;390,45])
add_line([sys,'/',['AM with carrier',13,'passband']],[185,45;260,45])
add_line([sys,'/',['AM with carrier',13,'passband']],[75,40;155,40])
set_param([sys,'/',['AM with carrier',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);AM w TC',...
		'Mask Type','Passband AM with carrier')
set_param([sys,'/',['AM with carrier',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using\namplitude modulation with transmission\ncarrier method.|Input signal offset:|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec)')
set_param([sys,'/',['AM with carrier',13,'passband']],...
		'Mask Translate','Offset=@1;Fc=@2;Ph=@3;ts=@4;[x,y]=moduicon(1);')
set_param([sys,'/',['AM with carrier',13,'passband']],...
		'Mask Help','This block shifts the amplitude of the input signal before the modulation. AM with carrier is a simple technique but not an energy-efficient one.')
set_param([sys,'/',['AM with carrier',13,'passband']],...
		'Mask Entries','1\/100/2/pi\/0\/.01\/')


%     Finished composite block ['AM with carrier',13,'passband'].

set_param([sys,'/',['AM with carrier',13,'passband']],...
		'position',[50,423,130,467])


%     Subsystem  ['SSB-ADM',13,'passband'].

new_system([sys,'/',['SSB-ADM',13,'passband']])
set_param([sys,'/',['SSB-ADM',13,'passband']],'Location',[234,472,778,662])

add_block('built-in/Gain',[sys,'/',['SSB-ADM',13,'passband/Gain1']])
set_param([sys,'/',['SSB-ADM',13,'passband/Gain1']],...
		'Gain','2',...
		'position',[250,108,275,132])

add_block('built-in/Inport',[sys,'/',['SSB-ADM',13,'passband/in_1']])
set_param([sys,'/',['SSB-ADM',13,'passband/in_1']],...
		'position',[210,110,230,130])

add_block('built-in/Gain',[sys,'/',['SSB-ADM',13,'passband/Gain']])
set_param([sys,'/',['SSB-ADM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[110,51,160,89])

add_block('built-in/Clock',[sys,'/',['SSB-ADM',13,'passband/Clock']])
set_param([sys,'/',['SSB-ADM',13,'passband/Clock']],...
		'position',[60,60,80,80])

add_block('built-in/Outport',[sys,'/',['SSB-ADM',13,'passband/out_1']])
set_param([sys,'/',['SSB-ADM',13,'passband/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Product',[sys,'/',['SSB-ADM',13,'passband/Product']])
set_param([sys,'/',['SSB-ADM',13,'passband/Product']],...
		'position',[330,62,355,93])

add_block('built-in/Fcn',[sys,'/',['SSB-ADM',13,'passband/Fcn']])
set_param([sys,'/',['SSB-ADM',13,'passband/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[205,55,300,85])

add_block('built-in/Note',[sys,'/',['SSB-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['SSB-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Filter',[sys,'/',['SSB-ADM',13,'passband/Filter']])
set_param([sys,'/',['SSB-ADM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])
add_line([sys,'/',['SSB-ADM',13,'passband']],[85,70;105,70])
add_line([sys,'/',['SSB-ADM',13,'passband']],[450,80;475,80])
add_line([sys,'/',['SSB-ADM',13,'passband']],[360,80;385,80])
add_line([sys,'/',['SSB-ADM',13,'passband']],[305,70;325,70])
add_line([sys,'/',['SSB-ADM',13,'passband']],[235,120;245,120])
add_line([sys,'/',['SSB-ADM',13,'passband']],[280,120;305,120;305,85;325,85])
add_line([sys,'/',['SSB-ADM',13,'passband']],[165,70;200,70])
set_param([sys,'/',['SSB-ADM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);SSB ADM',...
		'Mask Type','Passband SSB ADM')
set_param([sys,'/',['SSB-ADM',13,'passband']],...
		'Mask Dialogue','Demodulate a SSB-AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['SSB-ADM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;num=@2;den=@3;Ph=@4;ts=@5;Pg=Ph+pi/2;[x,y]=moduicon(2);')
set_param([sys,'/',['SSB-ADM',13,'passband']],...
		'Mask Help','This block demodulates the SSB-SC-AM modulated signal. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. You can specify the modulation to be a USB or LSB modulation.')
set_param([sys,'/',['SSB-ADM',13,'passband']],...
		'Mask Entries','100/2/pi\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/0\/.01\/')


%     Finished composite block ['SSB-ADM',13,'passband'].

set_param([sys,'/',['SSB-ADM',13,'passband']],...
		'position',[185,348,265,392])


%     Subsystem  'AM demo'.

new_system([sys,'/','AM demo'])
set_param([sys,'/','AM demo'],'Location',[175,552,335,697])
set_param([sys,'/','AM demo'],...
		'Mask Display','AM w carrier\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(2,100/pi/2*ts);testamc2'')')


%     Finished composite block 'AM demo'.

set_param([sys,'/','AM demo'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,423,395,467])


%     Subsystem  ['FM Mo//Dem',13,'demo'].

new_system([sys,'/',['FM Mo//Dem',13,'demo']])
set_param([sys,'/',['FM Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['FM Mo//Dem',13,'demo']],...
		'Mask Display','FM\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(2,100/pi/2*ts);test_fm2'')')


%     Finished composite block ['FM Mo//Dem',13,'demo'].

set_param([sys,'/',['FM Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,198,395,242])


%     Subsystem  ['SSB AM',13,'demo'].

new_system([sys,'/',['SSB AM',13,'demo']])
set_param([sys,'/',['SSB AM',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['SSB AM',13,'demo']],...
		'Mask Display','SSB AM\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(2,100/pi/2*ts);testssba'')')


%     Finished composite block ['SSB AM',13,'demo'].

set_param([sys,'/',['SSB AM',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,348,395,392])


%     Subsystem  ['PM Mo//Dem',13,'demo'].

new_system([sys,'/',['PM Mo//Dem',13,'demo']])
set_param([sys,'/',['PM Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['PM Mo//Dem',13,'demo']],...
		'Mask Display','PM\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(2,100/pi/2*ts);test_pm2'')')


%     Finished composite block ['PM Mo//Dem',13,'demo'].

set_param([sys,'/',['PM Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,273,395,317])


%     Subsystem  ['QAM Mo//Dem',13,'demo'].

new_system([sys,'/',['QAM Mo//Dem',13,'demo']])
set_param([sys,'/',['QAM Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['QAM Mo//Dem',13,'demo']],...
		'Mask Display','QAM\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(2,100/pi/2*ts);test_qa2'')')


%     Finished composite block ['QAM Mo//Dem',13,'demo'].

set_param([sys,'/',['QAM Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,123,395,167])


%     Subsystem  ['QADM',13,'passband'].

new_system([sys,'/',['QADM',13,'passband']])
set_param([sys,'/',['QADM',13,'passband']],'Location',[194,478,738,741])

add_block('built-in/Outport',[sys,'/',['QADM',13,'passband/out_1']])
set_param([sys,'/',['QADM',13,'passband/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Outport',[sys,'/',['QADM',13,'passband/out_2']])
set_param([sys,'/',['QADM',13,'passband/out_2']],...
		'Port','2',...
		'position',[480,175,500,195])

add_block('built-in/Product',[sys,'/',['QADM',13,'passband/Product1']])
set_param([sys,'/',['QADM',13,'passband/Product1']],...
		'position',[330,167,355,198])

add_block('built-in/Product',[sys,'/',['QADM',13,'passband/Product']])
set_param([sys,'/',['QADM',13,'passband/Product']],...
		'position',[330,62,355,93])

add_block('built-in/Fcn',[sys,'/',['QADM',13,'passband/Fcn1']])
set_param([sys,'/',['QADM',13,'passband/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[200,175,300,205])

add_block('built-in/Fcn',[sys,'/',['QADM',13,'passband/Fcn']])
set_param([sys,'/',['QADM',13,'passband/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[205,55,300,85])

add_block('built-in/Note',[sys,'/',['QADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Inport',[sys,'/',['QADM',13,'passband/in_1']])
set_param([sys,'/',['QADM',13,'passband/in_1']],...
		'position',[230,120,250,140])

add_block('built-in/Gain',[sys,'/',['QADM',13,'passband/Gain1']])
set_param([sys,'/',['QADM',13,'passband/Gain1']],...
		'Gain','2',...
		'position',[270,118,295,142])

add_block('built-in/Filter',[sys,'/',['QADM',13,'passband/Filter']])
set_param([sys,'/',['QADM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Filter',[sys,'/',['QADM',13,'passband/Filter1']])
set_param([sys,'/',['QADM',13,'passband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,166,445,204])

add_block('built-in/Gain',[sys,'/',['QADM',13,'passband/Gain']])
set_param([sys,'/',['QADM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[110,101,160,139])

add_block('built-in/Clock',[sys,'/',['QADM',13,'passband/Clock']])
set_param([sys,'/',['QADM',13,'passband/Clock']],...
		'position',[60,110,80,130])
add_line([sys,'/',['QADM',13,'passband']],[85,120;105,120])
add_line([sys,'/',['QADM',13,'passband']],[450,185;475,185])
add_line([sys,'/',['QADM',13,'passband']],[360,185;385,185])
add_line([sys,'/',['QADM',13,'passband']],[450,80;475,80])
add_line([sys,'/',['QADM',13,'passband']],[360,80;385,80])
add_line([sys,'/',['QADM',13,'passband']],[305,190;325,190])
add_line([sys,'/',['QADM',13,'passband']],[305,70;325,70])
add_line([sys,'/',['QADM',13,'passband']],[165,120;185,120;185,70;200,70])
add_line([sys,'/',['QADM',13,'passband']],[185,120;195,190])
add_line([sys,'/',['QADM',13,'passband']],[255,130;265,130])
add_line([sys,'/',['QADM',13,'passband']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['QADM',13,'passband']],[300,130;305,130;305,175;325,175])
set_param([sys,'/',['QADM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);QADM',...
		'Mask Type','Passband DSB-SC QADM')
set_param([sys,'/',['QADM',13,'passband']],...
		'Mask Dialogue','Demodulate a DSB-SC QAM modulated\nsignal into in-phase and quadrature\ncomponents.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QADM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;num=@2;den=@3;Ph=@4;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['QADM',13,'passband']],...
		'Mask Help','This block demodulates the QM-DSB-SC-AM modulated signal. The first output port outputs the in-phase component and the second port outputs the quadrature component. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['QADM',13,'passband']],...
		'Mask Entries','100/2/pi\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/0\/.01\/')


%     Finished composite block ['QADM',13,'passband'].

set_param([sys,'/',['QADM',13,'passband']],...
		'position',[185,123,265,167])


%     Subsystem  ['QAM',13,'passband'].

new_system([sys,'/',['QAM',13,'passband']])
set_param([sys,'/',['QAM',13,'passband']],'Location',[302,478,834,743])

add_block('built-in/Clock',[sys,'/',['QAM',13,'passband/Clock']])
set_param([sys,'/',['QAM',13,'passband/Clock']],...
		'position',[80,85,100,105])

add_block('built-in/Gain',[sys,'/',['QAM',13,'passband/Gain']])
set_param([sys,'/',['QAM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Inport',[sys,'/',['QAM',13,'passband/in_2']])
set_param([sys,'/',['QAM',13,'passband/in_2']],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Inport',[sys,'/',['QAM',13,'passband/in_1']])
set_param([sys,'/',['QAM',13,'passband/in_1']],...
		'position',[160,30,180,50])

add_block('built-in/Outport',[sys,'/',['QAM',13,'passband/out_1']])
set_param([sys,'/',['QAM',13,'passband/out_1']],...
		'position',[490,90,510,110])

add_block('built-in/Sum',[sys,'/',['QAM',13,'passband/Sum2']])
set_param([sys,'/',['QAM',13,'passband/Sum2']],...
		'position',[430,90,450,110])

add_block('built-in/Product',[sys,'/',['QAM',13,'passband/Product1']])
set_param([sys,'/',['QAM',13,'passband/Product1']],...
		'position',[355,112,380,143])

add_block('built-in/Product',[sys,'/',['QAM',13,'passband/Product']])
set_param([sys,'/',['QAM',13,'passband/Product']],...
		'position',[355,47,380,78])

add_block('built-in/Note',[sys,'/',['QAM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QAM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[250,305,255,310])

add_block('built-in/Fcn',[sys,'/',['QAM',13,'passband/Fcn1']])
set_param([sys,'/',['QAM',13,'passband/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Fcn',[sys,'/',['QAM',13,'passband/Fcn']])
set_param([sys,'/',['QAM',13,'passband/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])
add_line([sys,'/',['QAM',13,'passband']],[185,95;200,95;200,70;225,70])
add_line([sys,'/',['QAM',13,'passband']],[200,95;200,120;225,120])
add_line([sys,'/',['QAM',13,'passband']],[105,95;125,95])
add_line([sys,'/',['QAM',13,'passband']],[385,130;400,130;400,105;425,105])
add_line([sys,'/',['QAM',13,'passband']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['QAM',13,'passband']],[185,155;330,155;330,135;350,135])
add_line([sys,'/',['QAM',13,'passband']],[330,120;350,120])
add_line([sys,'/',['QAM',13,'passband']],[185,40;335,40;335,55;350,55])
add_line([sys,'/',['QAM',13,'passband']],[330,70;350,70])
add_line([sys,'/',['QAM',13,'passband']],[455,100;485,100])
set_param([sys,'/',['QAM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);QAM',...
		'Mask Type','Passband DSB-SC QAM')
set_param([sys,'/',['QAM',13,'passband']],...
		'Mask Dialogue','Modulate the in-phase signal from first input port and quadrature signal from\nthe second port using QAM.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QAM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['QAM',13,'passband']],...
		'Mask Help','This block modulates the in-phase component inputted from the first port and the quadrature component inputted from the second port by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['QAM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/.01\/')


%     Finished composite block ['QAM',13,'passband'].

set_param([sys,'/',['QAM',13,'passband']],...
		'position',[50,123,130,167])


%     Subsystem  ['DSB-SC AM',13,'passband'].

new_system([sys,'/',['DSB-SC AM',13,'passband']])
set_param([sys,'/',['DSB-SC AM',13,'passband']],'Location',[103,459,555,641])

add_block('built-in/Zero-Order Hold',[sys,'/',['DSB-SC AM',13,'passband/Zero-Order',13,'Hold',13,'timing control']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Zero-Order',13,'Hold',13,'timing control']],...
		'Sample time','ts',...
		'position',[50,219,85,251])

add_block('built-in/Gain',[sys,'/',['DSB-SC AM',13,'passband/Gain']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Clock',[sys,'/',['DSB-SC AM',13,'passband/Clock']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Product',[sys,'/',['DSB-SC AM',13,'passband/Product']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Outport',[sys,'/',['DSB-SC AM',13,'passband/out_1']])
set_param([sys,'/',['DSB-SC AM',13,'passband/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Inport',[sys,'/',['DSB-SC AM',13,'passband/in_1']])
set_param([sys,'/',['DSB-SC AM',13,'passband/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Constant',[sys,'/',['DSB-SC AM',13,'passband/Constant1']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Fcn',[sys,'/',['DSB-SC AM',13,'passband/Fcn']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Sum',[sys,'/',['DSB-SC AM',13,'passband/Sum2']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Sum2']],...
		'position',[170,90,190,110])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[270,100;270,65;335,65])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[370,60;375,60])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[45,75;65,75])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[195,100;200,100])
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB AM',...
		'Mask Type','Passband DSB-SC AM')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using\nDSB-SC AM method.|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Translate','Fc=@1;Fc=Fc*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Help','This block modulates the input signal using the double-sideband suppressed-carrier amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Entries','100/2/pi\/pi/2\/.01\/')


%     Finished composite block ['DSB-SC AM',13,'passband'].

set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'position',[50,48,130,92])


%     Subsystem  ['DSB-SC-ADM',13,'passband'].

new_system([sys,'/',['DSB-SC-ADM',13,'passband']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],'Location',[588,690,716,690])


%     Subsystem  ['DSB-SC-ADM',13,'passband/Dis module',13,'integrator'].

new_system([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])

add_block('built-in/Unit Delay',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/module']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[410,40;440,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[140,35;190,35])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['DSB-SC-ADM',13,'passband/Dis module',13,'integrator'].

set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband/Product1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband/Filter2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Gain',[sys,'/',['DSB-SC-ADM',13,'passband/Gain1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband/Sum1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband/Product2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/sin1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband/Product']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'passband/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Note',[sys,'/',['DSB-SC-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/sin']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband/Filter']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband/Filter1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'passband/In-phase',13,'output']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/In-phase',13,'output']],...
		'position',[695,50,715,70])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[260,130;215,130])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[240,130;240,180;225,180])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[530,120;465,120])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[155,60;335,60])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[435,125;430,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[605,120;600,120])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[70,55;120,55])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[90,55;90,230;120,230])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[155,225;420,225])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[485,225;655,225;645,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[360,125;345,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[305,125;290,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[315,185;300,185;290,135])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[400,60;690,60])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[655,60;645,115])
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB ADM',...
		'Mask Type','Passband DSB-SC ADM')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Dialogue','Demodulate a DSB-SC AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Help','This block demodulates a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Entries','100/2/pi\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/pi/2\/.01\/')


%     Finished composite block ['DSB-SC-ADM',13,'passband'].

set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'position',[185,48,265,92])


%     Subsystem  ['DSB AM',13,'Mo//Dem demo'].

new_system([sys,'/',['DSB AM',13,'Mo//Dem demo']])
set_param([sys,'/',['DSB AM',13,'Mo//Dem demo']],'Location',[175,552,335,697])
set_param([sys,'/',['DSB AM',13,'Mo//Dem demo']],...
		'Mask Display','AM\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(2,100/pi/2*ts);test_am2'')')


%     Finished composite block ['DSB AM',13,'Mo//Dem demo'].

set_param([sys,'/',['DSB AM',13,'Mo//Dem demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,48,395,92])

add_block('built-in/Note',[sys,'/','Analog Modulation//Demodulation Library'])
set_param([sys,'/','Analog Modulation//Demodulation Library'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[225,0,230,5])

add_block('built-in/Note',[sys,'/','passband simulation blocks'])
set_param([sys,'/','passband simulation blocks'],...
		'ForeGround',2,...
		'position',[215,20,220,25])


%     Subsystem  ['PM',13,'passband'].

new_system([sys,'/',['PM',13,'passband']])
set_param([sys,'/',['PM',13,'passband']],'Location',[358,506,869,673])

add_block('built-in/Constant',[sys,'/',['PM',13,'passband/Initial value']])
set_param([sys,'/',['PM',13,'passband/Initial value']],...
		'Value','Ph',...
		'position',[220,120,240,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['PM',13,'passband/Zero-Order',13,'Hold']])
set_param([sys,'/',['PM',13,'passband/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[150,94,185,126])

add_block('built-in/Gain',[sys,'/',['PM',13,'passband/Gain']])
set_param([sys,'/',['PM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[80,60,120,90])

add_block('built-in/Sum',[sys,'/',['PM',13,'passband/Sum1']])
set_param([sys,'/',['PM',13,'passband/Sum1']],...
		'inputs','+++',...
		'position',[280,57,300,93])

add_block('built-in/Fcn',[sys,'/',['PM',13,'passband/Fcn']])
set_param([sys,'/',['PM',13,'passband/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[325,60,400,90])

add_block('built-in/Inport',[sys,'/',['PM',13,'passband/in_1']])
set_param([sys,'/',['PM',13,'passband/in_1']],...
		'position',[150,10,170,30])

add_block('built-in/Outport',[sys,'/',['PM',13,'passband/out_1']])
set_param([sys,'/',['PM',13,'passband/out_1']],...
		'position',[445,65,465,85])

add_block('built-in/Sum',[sys,'/',['PM',13,'passband/Sum2']])
set_param([sys,'/',['PM',13,'passband/Sum2']],...
		'inputs','+-',...
		'position',[220,55,245,90])

add_block('built-in/Clock',[sys,'/',['PM',13,'passband/Clock']])
set_param([sys,'/',['PM',13,'passband/Clock']],...
		'position',[40,65,60,85])
add_line([sys,'/',['PM',13,'passband']],[125,75;130,75;130,110;145,110])
add_line([sys,'/',['PM',13,'passband']],[190,110;195,110;195,80;215,80])
add_line([sys,'/',['PM',13,'passband']],[125,75;165,75;165,65;215,65])
add_line([sys,'/',['PM',13,'passband']],[250,75;275,75])
add_line([sys,'/',['PM',13,'passband']],[65,75;75,75])
add_line([sys,'/',['PM',13,'passband']],[175,20;255,20;255,65;275,65])
add_line([sys,'/',['PM',13,'passband']],[305,75;320,75])
add_line([sys,'/',['PM',13,'passband']],[245,130;255,130;255,85;275,85])
add_line([sys,'/',['PM',13,'passband']],[405,75;440,75])
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);PM',...
		'Mask Type','Passband PM')
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using PM method.|Carrier frequency (Hz):|Initial phase (rad):|Symbol interval (sec, Use inf for analog case):')
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;td=@3;if isinf(td),td=inf;end;[x,y]=moduicon(3);',...
		'Mask Help','The PM block causes the change of the carrier signal depending on the input signal voltage.')
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/.1\/')


%     Finished composite block ['PM',13,'passband'].

set_param([sys,'/',['PM',13,'passband']],...
		'position',[50,273,130,317])


%     Subsystem  ['FM',13,'passband'].

new_system([sys,'/',['FM',13,'passband']])
set_param([sys,'/',['FM',13,'passband']],'Location',[451,587,939,737])

add_block('built-in/Inport',[sys,'/',['FM',13,'passband/in_1']])
set_param([sys,'/',['FM',13,'passband/in_1']],...
		'position',[60,40,80,60])

add_block('built-in/Outport',[sys,'/',['FM',13,'passband/out_1']])
set_param([sys,'/',['FM',13,'passband/out_1']],...
		'position',[465,50,485,70])

add_block('built-in/Fcn',[sys,'/',['FM',13,'passband/sin']])
set_param([sys,'/',['FM',13,'passband/sin']],...
		'Expr','cos(u[1]*pi2+Ph)',...
		'position',[290,45,430,75])

add_block('built-in/Constant',[sys,'/',['FM',13,'passband/Constant']])
set_param([sys,'/',['FM',13,'passband/Constant']],...
		'Value','Fc',...
		'position',[40,85,60,105])

add_block('built-in/S-Function',[sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']])
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf/2\/',...
		'position',[200,39,260,81])

add_block('built-in/Sum',[sys,'/',['FM',13,'passband/Sum']])
set_param([sys,'/',['FM',13,'passband/Sum']],...
		'position',[130,42,150,78])
add_line([sys,'/',['FM',13,'passband']],[435,60;460,60])
add_line([sys,'/',['FM',13,'passband']],[265,60;285,60])
add_line([sys,'/',['FM',13,'passband']],[155,60;195,60])
add_line([sys,'/',['FM',13,'passband']],[65,95;90,95;90,70;125,70])
add_line([sys,'/',['FM',13,'passband']],[85,50;125,50])
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);FM',...
		'Mask Type','Passband FM')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using FM method.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):|Symbol interval (sec; Use Inf for analog mod);')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2;pi2=2*pi;ts=@3;td=@4;if isinf(td),td=inf;end;[x,y]=moduicon(3);')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Help','This block modulates the input signal using frequency modulation method. The frequency of the output of the carrier signal depends on the amplitude of the input signal.')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/.01\/Inf\/')


%     Finished composite block ['FM',13,'passband'].

set_param([sys,'/',['FM',13,'passband']],...
		'position',[50,198,130,242])
add_line(sys,[135,370;180,370])
add_line(sys,[135,445;180,445])
add_line(sys,[135,145;180,145])
add_line(sys,[135,70;180,70])
add_line(sys,[135,295;180,295])
add_line(sys,[135,220;180,220])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
