function [ret,x0,str,ts,xts]=com_chan(t,x,u,flag);
%COM_CHAN	is the M-file description of the SIMULINK system named COM_CHAN.
%	The block-diagram can be displayed by typing: COM_CHAN.
%
%	SYS=COM_CHAN(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_CHAN to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_CHAN with a FLAG of zero:
%	[SIZES]=COM_CHAN([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[242,70,812,601])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['AWGN',13,'channel'].

new_system([sys,'/',['AWGN',13,'channel']])
set_param([sys,'/',['AWGN',13,'channel']],'Location',[86,493,348,639])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Sum']],...
		'position',[150,55,170,75])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/out_1']])
set_param([sys,'/',['AWGN',13,'channel/out_1']],...
		'position',[200,55,220,75])


%     Subsystem  ['AWGN',13,'channel/Gaussian',13,'noise'].

new_system([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],'Location',[409,168,757,373])

add_block('built-in/State-Space',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['AWGN',13,'channel/Gaussian',13,'noise'].

set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'channel/in_1']])
set_param([sys,'/',['AWGN',13,'channel/in_1']],...
		'position',[45,10,65,30])
add_line([sys,'/',['AWGN',13,'channel']],[90,70;145,70])
add_line([sys,'/',['AWGN',13,'channel']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['AWGN',13,'channel']],[175,65;195,65])
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);AWGN',...
		'Mask Type','AWGN channel, fixed parameter')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Dialogue','Additive white Gaussian noise channel\nwith fixed mean and variance.|Mean value:|Variance (std^2):|Initial Seed:')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);[x,y]=chanicon;')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Help','This block adds white Gaussian noise to the input signal. The mean and the variance can be a scalar or vector with the same length as the input signal.')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Entries','0\/.01\/12345\/')


%     Finished composite block ['AWGN',13,'channel'].

set_param([sys,'/',['AWGN',13,'channel']],...
		'position',[35,78,115,122])


%     Subsystem  ['Rayleigh fading',13,'channel CE'].

new_system([sys,'/',['Rayleigh fading',13,'channel CE']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE']],'Location',[265,109,636,349])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel CE/in_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/in_1']],...
		'position',[30,20,50,40])

add_block('built-in/Constant',[sys,'/',['Rayleigh fading',13,'channel CE/Constant']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Constant']],...
		'Value','[in_p, -quad]',...
		'position',[30,70,105,100])


%     Subsystem  ['Rayleigh fading',13,'channel CE/Inner',13,'Product'].

new_system([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product/Product']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product/Sum']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product/out_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product/in_2']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product/in_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product']],[40,100;60,70])
add_line([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product']],[150,65;180,65])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Rayleigh fading',13,'channel CE/Inner',13,'Product'].

set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product']],...
		'position',[150,69,170,91])

add_block('built-in/Constant',[sys,'/',['Rayleigh fading',13,'channel CE/Constant1']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Constant1']],...
		'Value','[quad, in_p]',...
		'position',[30,155,105,185])


%     Subsystem  ['Rayleigh fading',13,'channel CE/Inner',13,'Product1'].

new_system([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1/in_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1/in_2']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1/out_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1/Sum']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1/Product']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1']],[150,65;180,65])
add_line([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1']],[95,65;120,65])
add_line([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1']],[40,35;60,60])
add_line([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1']],[40,100;60,70])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Rayleigh fading',13,'channel CE/Inner',13,'Product1'].

set_param([sys,'/',['Rayleigh fading',13,'channel CE/Inner',13,'Product1']],...
		'position',[150,154,170,176])

add_block('built-in/Mux',[sys,'/',['Rayleigh fading',13,'channel CE/Mux']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/Mux']],...
		'inputs','2',...
		'position',[220,116,255,149])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading',13,'channel CE/out_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel CE/out_1']],...
		'position',[290,125,310,145])
add_line([sys,'/',['Rayleigh fading',13,'channel CE']],[55,30;120,30;120,75;145,75])
add_line([sys,'/',['Rayleigh fading',13,'channel CE']],[110,85;145,85])
add_line([sys,'/',['Rayleigh fading',13,'channel CE']],[110,170;145,170])
add_line([sys,'/',['Rayleigh fading',13,'channel CE']],[120,75;120,160;145,160])
add_line([sys,'/',['Rayleigh fading',13,'channel CE']],[175,80;190,80;190,125;215,125])
add_line([sys,'/',['Rayleigh fading',13,'channel CE']],[175,165;190,165;190,140;215,140])
add_line([sys,'/',['Rayleigh fading',13,'channel CE']],[260,135;285,135])
set_param([sys,'/',['Rayleigh fading',13,'channel CE']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rayl F',...
		'Mask Type','Rayleigh fading channel, fixed parameter')
set_param([sys,'/',['Rayleigh fading',13,'channel CE']],...
		'Mask Dialogue','Rayleigh fading channel with fixed\nfading envelope and phase shift.|Rayleigh fading envelope:|Phase shift of the channel (rad):')
set_param([sys,'/',['Rayleigh fading',13,'channel CE']],...
		'Mask Translate','a=@1;b=@2;in_p=a*cos(b);quad=a*sin(b);[x,y]=chanicon;[v,w]=cmplxicn(0,50,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rayleigh fading',13,'channel CE']],...
		'Mask Help','This block applies the fading and phase shifting to the transmitting signal. In general, the fading envelope should be no larger than one. The input and the output of this block are both complex signals.')
set_param([sys,'/',['Rayleigh fading',13,'channel CE']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['Rayleigh fading',13,'channel CE'].

set_param([sys,'/',['Rayleigh fading',13,'channel CE']],...
		'position',[325,78,405,122])

add_block('built-in/Note',[sys,'/','Baseband Channel'])
set_param([sys,'/','Baseband Channel'],...
		'Font Name','Arial',...
		'Font Size',11,...
		'position',[430,40,435,45])


%     Subsystem  ['Rayleigh fading channel',13,'w vary para CE'].

new_system([sys,'/',['Rayleigh fading channel',13,'w vary para CE']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],'Location',[266,502,924,748])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_3']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_3']],...
		'Port','3',...
		'position',[45,160,65,180])

add_block('built-in/Fcn',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Fcn']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[110,132,180,158])

add_block('built-in/Demux',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Demux']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Demux']],...
		'outputs','2',...
		'position',[140,15,180,50])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_1']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_1']],...
		'position',[75,25,95,45])

add_block('built-in/Product',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product']],...
		'position',[300,20,325,40])

add_block('built-in/Fcn',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Fcn1']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Fcn1']],...
		'position',[115,192,185,218])

add_block('built-in/Product',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product2']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product2']],...
		'position',[300,130,325,150])

add_block('built-in/Product',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product3']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product3']],...
		'position',[300,190,325,210])

add_block('built-in/Sum',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Sum']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Sum']],...
		'inputs','+-',...
		'position',[425,70,445,90])

add_block('built-in/Sum',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Sum1']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Sum1']],...
		'position',[425,125,445,145])

add_block('built-in/Product',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product1']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product1']],...
		'position',[295,90,320,110])

add_block('built-in/Mux',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Mux']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Mux']],...
		'inputs','2',...
		'position',[495,96,530,129])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/out_1']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/out_1']],...
		'position',[625,90,645,110])

add_block('built-in/Product',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product4']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product4']],...
		'position',[565,90,590,110])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_2']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_2']],...
		'Port','2',...
		'position',[495,40,515,60])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[70,170;80,170;80,145;105,145])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[80,170;80,205;110,205])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[100,35;135,35])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[185,25;295,25])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[240,25;240,95;290,95])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[185,40;215,40;215,135;295,135])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[215,135;215,195;295,195])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[185,145;230,145;230,35;295,35])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[230,145;295,145])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[190,205;240,205;240,105;290,105])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[240,205;295,205])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[330,30;370,30;370,75;420,75])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[330,200;370,200;370,85;420,85])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[325,100;385,100;385,130;420,130])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[330,140;420,140])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[450,80;465,80;465,105;490,105])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[450,135;465,135;465,120;490,120])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[535,115;540,115;540,105;560,105])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[595,100;620,100])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[520,50;540,50;540,95;560,95])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rayl F',...
		'Mask Type','Rayleigh fading channel, vary parameter')
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],...
		'Mask Dialogue','The fading envelope and the phase shift of the channel changes with the 2nd and 3rd input port values.')
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],...
		'Mask Translate','[x,y]=chanicon;x=x*.9+10;[v,w]=cmplxicn(0,85,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,55,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],...
		'Mask Help','This block applies Rayleigh fading to the transmitting signals. The fading envelope and the phase of the channel are provided in the 2nd and the 3rd input port. The 1st input port and the output of this block are complex signals.')


%     Finished composite block ['Rayleigh fading channel',13,'w vary para CE'].

set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],...
		'position',[325,153,405,197])


%     Subsystem  ['QASK Mo//Dem',13,'demo2'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo2']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],...
		'Mask Display','Rayleigh\nfading\ndemo',...
		'Mask Dialogue','eval(''ts=.01;td=.2;Fc=100/2/pi;M=16;num=1;den=1;tceps3cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo2'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[470,78,550,122])

add_block('built-in/Note',[sys,'/','Passband Channel'])
set_param([sys,'/','Passband Channel'],...
		'Font Name','Arial',...
		'Font Size',11,...
		'position',[145,45,150,50])


%     Subsystem  ['QASK Mo//Dem',13,'demo6'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo6']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo6']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo6']],...
		'Mask Display','AWGN\nnoise\ndemo',...
		'Mask Dialogue','eval(''ts=.01;td=.1;M=8;Fc=100/2/pi;tddmqask'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo6'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo6']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[180,78,260,122])


%     Subsystem  ['Max-err lmtd',13,'b-err channel'].

new_system([sys,'/',['Max-err lmtd',13,'b-err channel']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],'Location',[103,574,409,680])

add_block('built-in/Outport',[sys,'/',['Max-err lmtd',13,'b-err channel/out_1']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/out_1']],...
		'hide name',0,...
		'position',[275,20,295,40])

add_block('built-in/S-Function',[sys,'/',['Max-err lmtd',13,'b-err channel/Mdu']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/Mdu']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/Mdu']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/Mdu']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/Mdu']],...
		'Mask Entries','2\/',...
		'position',[195,11,255,49])

add_block('built-in/Sum',[sys,'/',['Max-err lmtd',13,'b-err channel/S']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/S']],...
		'hide name',0,...
		'position',[150,20,170,40])

add_block('built-in/Inport',[sys,'/',['Max-err lmtd',13,'b-err channel/in_1']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/in_1']],...
		'hide name',0,...
		'position',[40,5,60,25])

add_block('built-in/Outport',[sys,'/',['Max-err lmtd',13,'b-err channel/out_2']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/out_2']],...
		'hide name',0,...
		'Port','2',...
		'position',[275,50,295,70])


%     Subsystem  ['Max-err lmtd',13,'b-err channel/B-n'].

new_system([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],'Location',[36,445,326,560])

add_block('built-in/S-Function',[sys,'/',['Max-err lmtd',13,'b-err channel/B-n/S-function']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n/S-function']],...
		'function name','srandbit',...
		'parameters','n, prob, seed',...
		'position',[90,35,140,55])

add_block('built-in/Outport',[sys,'/',['Max-err lmtd',13,'b-err channel/B-n/out_1']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n/out_1']],...
		'position',[190,35,210,55])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],[145,45;185,45])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'Mask Display','B-vector\ngenerator',...
		'Mask Type','Binary noise generator')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'Mask Dialogue','Generate a binary vector with the probability of "1"s in the vector being specified.|Vector length(can''t be changed during simulation):|Probability of a "one", two "ones",three "ones"...:|Seed:')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'Mask Translate','n=@1;prob=@2;seed=@3;')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'Mask Help','This block outputs a zero vector with "1"s randomly distributed the vector. The maximum number of "1"s in the vector is the same as the length of the vector probability. The value of ith element of the probability is the probability of i number of "1"s in the vector.')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'Mask Entries','leng\/prob\/seed\/')


%     Finished composite block ['Max-err lmtd',13,'b-err channel/B-n'].

set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'hide name',0,...
		'position',[30,38,110,82])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel']],[175,30;190,30])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel']],[260,30;270,30])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel']],[115,60;130,60;130,35;145,35])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel']],[115,60;270,60])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel']],[65,15;90,15;90,25;145,25])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'Mask Display','plot(0,0,100,100,x,y);Lmtd b-err',...
		'Mask Type','Limited binary error channel')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'Mask Dialogue','Add binary errors with specified error\nnumber probability.|Vector length(can''t be changed during simulation):|Probability of one err, two errs, three errs...:|Seed:')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'Mask Translate','leng=@1;prob=@2;seed=@3;[x,y]=chanicon;')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'Mask Help','This block adds binary errors to the input signal. The maximum number of errors added to the signal is the same as the length of the vector probability. The value of ith element of the probability is the probability of i number of errors in the vector. The 1st outport is the signal with added noise. The 2nd outport is the added noise.')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'Mask Entries','7\/1/2\/12345\/')


%     Finished composite block ['Max-err lmtd',13,'b-err channel'].

set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'position',[35,303,115,347])


%     Subsystem  ['Binary error',13,'channel'].

new_system([sys,'/',['Binary error',13,'channel']])
set_param([sys,'/',['Binary error',13,'channel']],'Location',[154,494,633,699])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/out_2']])
set_param([sys,'/',['Binary error',13,'channel/out_2']],...
		'Port','2',...
		'position',[275,125,295,145])

add_block('built-in/Saturation',[sys,'/',['Binary error',13,'channel/Saturation']])
set_param([sys,'/',['Binary error',13,'channel/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','1',...
		'position',[165,70,190,90])

add_block('built-in/S-Function',[sys,'/',['Binary error',13,'channel/Modulo',13,'operation']])
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulo operation:|Modulo base:')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[300,56,360,94])

add_block('built-in/Sum',[sys,'/',['Binary error',13,'channel/Sum']])
set_param([sys,'/',['Binary error',13,'channel/Sum']],...
		'position',[235,65,255,85])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/out_1']])
set_param([sys,'/',['Binary error',13,'channel/out_1']],...
		'position',[390,65,410,85])


%     Subsystem  ['Binary error',13,'channel/Poisson',13,'noise'].

new_system([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],'Location',[391,74,676,237])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/Poisson',13,'noise/out_1']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise/out_1']],...
		'position',[165,65,185,85])

add_block('built-in/S-Function',[sys,'/',['Binary error',13,'channel/Poisson',13,'noise/Poisson distribution',13,'number']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise/Poisson distribution',13,'number']],...
		'function name','srandpoi',...
		'parameters','seed,lambda',...
		'position',[65,55,135,95])
add_line([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],[140,75;160,75])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Display','Poison\nrand int',...
		'Mask Type','Poisson distribution noise.',...
		'Mask Dialogue','Poisson distribution number generator.|Lambda:|Seed:')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Translate','seed=@2;lambda=@1;')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Help','The output of this block is poisson distributed integers. The output size is the same as the vector size for seed. Please use function disttool to see the distribution of the outputof this block.')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Entries','P\/(randint(1, M)+100)*1000*max(P)\/')


%     Finished composite block ['Binary error',13,'channel/Poisson',13,'noise'].

set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'position',[40,94,115,136])

add_block('built-in/Inport',[sys,'/',['Binary error',13,'channel/in_1']])
set_param([sys,'/',['Binary error',13,'channel/in_1']],...
		'position',[95,30,115,50])
add_line([sys,'/',['Binary error',13,'channel']],[195,80;230,80])
add_line([sys,'/',['Binary error',13,'channel']],[210,80;210,135;270,135])
add_line([sys,'/',['Binary error',13,'channel']],[260,75;295,75])
add_line([sys,'/',['Binary error',13,'channel']],[120,115;140,115;140,80;160,80])
add_line([sys,'/',['Binary error',13,'channel']],[120,40;210,40;210,70;230,70])
add_line([sys,'/',['Binary error',13,'channel']],[365,75;385,75])
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);B-error',...
		'Mask Type','Add binary errors')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Dialogue','The error probability can be a scalar or a vector with the same length as the\ninput vector length.|Error probability:|Input vector length:')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Translate','M=@2;P=@1;if length(P)~=M,P=ones(1,M)*P(1);end;[x,y]=chanicon;')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Help','This block adds binary errors to transmitted binary signals. The error probability is given in the parameter setting. The first output port outputs the transmitting signal (after adding noise). The second port outputs the errors signal added to the transmitting signal.')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Entries','0.05\/15\/')


%     Finished composite block ['Binary error',13,'channel'].

set_param([sys,'/',['Binary error',13,'channel']],...
		'position',[35,228,115,272])


%     Subsystem  ['QASK Mo//Dem',13,'demo'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo']],...
		'Mask Display','Rayleigh\nnoise\ndemo',...
		'Mask Dialogue','eval(''ts=.04;[num,den]=butter(2,100/pi/2*ts);td=.2;M=64;tcemqask'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[470,228,550,272])


%     Subsystem  ['QASK Mo//Dem',13,'demo1'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo1']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],...
		'Mask Display','Rician\nnoise\ndemo')
set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],...
		'Mask Dialogue','eval(''ts=.01;td=.2;Fc=100/2/pi;NIR=[6 12 18 24 30 38];AIR=[1 1.93 2.88 3.83 4.78 6.05];PIR=zeros(1,6);[num,den]=butter(4,100/pi*ts);M=sum(NIR);tceps2cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo1'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[470,378,550,422])


%     Subsystem  ['QASK Mo//Dem',13,'demo5'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo5']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo5']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo5']],...
		'Mask Display','Rician\nnoise\ndemo2')
set_param([sys,'/',['QASK Mo//Dem',13,'demo5']],...
		'Mask Dialogue','eval(''ts=.01;td=.2;Fc=100/2/pi;NIR=[6 12 18 24 30 38];AIR=[1 1.93 2.88 3.83 4.78 6.05];PIR=zeros(1,6);[num,den]=butter(4,100/pi*ts);M=sum(NIR);tceps2c2'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo5'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo5']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[470,453,550,497])


%     Subsystem  ['Rayleigh noise channel',13,'w vary var CE'].

new_system([sys,'/',['Rayleigh noise channel',13,'w vary var CE']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],'Location',[398,439,681,575])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise channel',13,'w vary var CE/Sum']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Sum']],...
		'position',[195,55,215,75])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise channel',13,'w vary var CE/out_1']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/out_1']],...
		'position',[245,55,265,75])

add_block('built-in/Inport',[sys,'/',['Rayleigh noise channel',13,'w vary var CE/in_1']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/in_1']],...
		'position',[100,15,120,35])


%     Subsystem  ['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise'].

new_system([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],'Location',[482,386,830,557])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/White Noise',[sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[40,82,85,118])

add_block('built-in/Inport',[sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/in_1']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/in_1']],...
		'position',[55,35,75,55])

add_block('built-in/Inport',[sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/in_2']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/in_2']],...
		'Port','2',...
		'position',[170,35,190,55])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/out_1']],...
		'position',[300,80,320,100])

add_block('built-in/Product',[sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/Product']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise/Product']],...
		'position',[240,80,265,100])
add_line([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],[80,45;110,45;110,90;135,90])
add_line([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],[90,100;135,100])
add_line([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],[270,90;295,90])
add_line([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],[165,95;235,95])
add_line([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],[195,45;210,45;210,85;235,85])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Initial Seed(s):')
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],...
		'Mask Translate','s=@1;')
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],...
		'Mask Help','The meanvalue is determined by value from the frist input. The standard deviation is determined by the second input. ')
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],...
		'Mask Entries','s\/')


%     Finished composite block ['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise'].

set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/Gaussian',13,'noise']],...
		'position',[75,50,150,90])

add_block('built-in/Inport',[sys,'/',['Rayleigh noise channel',13,'w vary var CE/in_2']])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE/in_2']],...
		'Port','2',...
		'position',[10,70,30,90])
add_line([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],[220,65;240,65])
add_line([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],[125,25;160,25;160,60;190,60])
add_line([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],[155,70;190,70])
add_line([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],[35,80;70,80])
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rayl N',...
		'Mask Type','Rayleigh noise channel, vary parameter')
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],...
		'Mask Dialogue','Add Rayleigh noise to the transmitting signal with noise variant (2nd port) as input. Seed should be a 1x2 vector.|Initial Seeds (1x2 vector):')
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],...
		'Mask Translate','s=@1;if length(s)<1,s=[s s+s+1];end;[x,y]=chanicon;x=x*.9+10;[v,w]=cmplxicn(0,75,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,55,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],...
		'Mask Help','This block adds Rayleigh noise to the transmitting signal. The input and output of this block are complex data. The Rayleigh noise is composed with two independant zero mean Gaussian noise. These two Gaussian components have the same standard deviation sigma. The sigma value is provided at the 2nd inport of this block.')
set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],...
		'Mask Entries','[12345, 54321]\/')


%     Finished composite block ['Rayleigh noise channel',13,'w vary var CE'].

set_param([sys,'/',['Rayleigh noise channel',13,'w vary var CE']],...
		'position',[325,303,405,347])


%     Subsystem  ['Rayleigh noise',13,'channel CE'].

new_system([sys,'/',['Rayleigh noise',13,'channel CE']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],'Location',[496,318,758,464])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise',13,'channel CE/Sum']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Sum']],...
		'position',[150,55,170,75])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise',13,'channel CE/out_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/out_1']],...
		'position',[200,55,220,75])


%     Subsystem  ['Rayleigh noise',13,'channel CE/Gaussian',13,'noise'].

new_system([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],'Location',[371,386,719,591])

add_block('built-in/State-Space',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['Rayleigh noise',13,'channel CE/Gaussian',13,'noise'].

set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Inport',[sys,'/',['Rayleigh noise',13,'channel CE/in_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/in_1']],...
		'position',[45,10,65,30])
add_line([sys,'/',['Rayleigh noise',13,'channel CE']],[90,70;145,70])
add_line([sys,'/',['Rayleigh noise',13,'channel CE']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['Rayleigh noise',13,'channel CE']],[175,65;195,65])
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rayl N',...
		'Mask Type','Rayleigh noise channel, fixed parameter')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Dialogue','Additive Rayleigh noise channel for\nbaseband signal simulation. Input\nand output signals are complex.|sigma:|Seeds (1x2 vector):')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Translate','m=0;d=@1;d=d^2;s=@2;if length(s)<2,s=[s s+s];end;[x,y]=chanicon;[v,w]=cmplxicn(0,50,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Help','This block adds Rayleigh noise to the transmitting signal. The input and output of this block are complex data. The Rayleigh noise is composed with two independant zero mean Gaussian noise. These two Gaussian components have the same standard deviation sigma.')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Entries','.01\/[12345 54321]\/')


%     Finished composite block ['Rayleigh noise',13,'channel CE'].

set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'position',[325,228,405,272])


%     Subsystem  ['QASK Mo//Dem',13,'demo7'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo7']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo7']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo7']],...
		'Mask Display','AWGN\nnoise\ndemo2')
set_param([sys,'/',['QASK Mo//Dem',13,'demo7']],...
		'Mask Dialogue','eval(''ts=.01;td=.2;Fc=100/2/pi;NIR=[6 12 18 24 30 38];AIR=[1 1.93 2.88 3.83 4.78 6.05];PIR=zeros(1,6);[num,den]=butter(4,100/pi*ts);M=sum(NIR);tddps2cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo7'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo7']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[180,153,260,197])


%     Subsystem  ['AWGN',13,'w vary para'].

new_system([sys,'/',['AWGN',13,'w vary para']])
set_param([sys,'/',['AWGN',13,'w vary para']],'Location',[122,181,405,317])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'w vary para/Sum']])
set_param([sys,'/',['AWGN',13,'w vary para/Sum']],...
		'position',[195,55,215,75])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'w vary para/out_1']])
set_param([sys,'/',['AWGN',13,'w vary para/out_1']],...
		'position',[245,55,265,75])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'w vary para/in_1']])
set_param([sys,'/',['AWGN',13,'w vary para/in_1']],...
		'position',[100,15,120,35])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'w vary para/in_2']])
set_param([sys,'/',['AWGN',13,'w vary para/in_2']],...
		'Port','2',...
		'position',[10,50,30,70])


%     Subsystem  ['AWGN',13,'w vary para/Gaussian',13,'noise'].

new_system([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],'Location',[482,386,830,557])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/White Noise',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[40,82,85,118])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/in_1']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/in_1']],...
		'position',[55,35,75,55])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/in_2']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/in_2']],...
		'Port','2',...
		'position',[170,35,190,55])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/out_1']],...
		'position',[300,80,320,100])

add_block('built-in/Product',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Product']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Product']],...
		'position',[240,80,265,100])
add_line([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],[80,45;110,45;110,90;135,90])
add_line([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],[90,100;135,100])
add_line([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],[270,90;295,90])
add_line([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],[165,95;235,95])
add_line([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],[195,45;210,45;210,85;235,85])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Initial Seed(s):',...
		'Mask Translate','s=@1;')
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],...
		'Mask Help','The meanvalue is determined by value from the frist input. The standard deviation is determined by the second input. ',...
		'Mask Entries','s\/')


%     Finished composite block ['AWGN',13,'w vary para/Gaussian',13,'noise'].

set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],...
		'position',[75,50,150,90])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'w vary para/in_3']])
set_param([sys,'/',['AWGN',13,'w vary para/in_3']],...
		'Port','3',...
		'position',[20,95,40,115])
add_line([sys,'/',['AWGN',13,'w vary para']],[220,65;240,65])
add_line([sys,'/',['AWGN',13,'w vary para']],[125,25;160,25;160,60;190,60])
add_line([sys,'/',['AWGN',13,'w vary para']],[155,70;190,70])
add_line([sys,'/',['AWGN',13,'w vary para']],[35,60;70,60])
add_line([sys,'/',['AWGN',13,'w vary para']],[45,105;55,105;55,80;70,80])
set_param([sys,'/',['AWGN',13,'w vary para']],...
		'Mask Display','plot(0,0,100,100,x,y);AWGN',...
		'Mask Type','AWGN channel, vary parameter')
set_param([sys,'/',['AWGN',13,'w vary para']],...
		'Mask Dialogue','AWGN channel with varying mean (2nd\nport) and standard deviation (3rd port) as input. Seed vector size is the block output size.|Initial seed:')
set_param([sys,'/',['AWGN',13,'w vary para']],...
		'Mask Translate','s=@1;[x,y]=chanicon;')
set_param([sys,'/',['AWGN',13,'w vary para']],...
		'Mask Help','This block adds white Gaussian noise to the input signal. When the mean value and/or the seed is a vector, a vector noise is added to the input vector signal. The mean value and the standard deviation are inputted from the second port and the third port respectively. The mean and std input can be scalars or vectors with the same length as the input signal.')
set_param([sys,'/',['AWGN',13,'w vary para']],...
		'Mask Entries','123456\/')


%     Finished composite block ['AWGN',13,'w vary para'].

set_param([sys,'/',['AWGN',13,'w vary para']],...
		'position',[35,153,110,197])


%     Subsystem  ['Vector BCH',13,'Co//Dec demo'].

new_system([sys,'/',['Vector BCH',13,'Co//Dec demo']])
set_param([sys,'/',['Vector BCH',13,'Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector BCH',13,'Co//Dec demo']],...
		'Mask Display','Limited\nbinary error\ndemo',...
		'Mask Dialogue','eval(''N_bch_demo=15;K_bch_demo=5;T_bch_demo=3;tstbchcd'')')


%     Finished composite block ['Vector BCH',13,'Co//Dec demo'].

set_param([sys,'/',['Vector BCH',13,'Co//Dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[180,303,260,347])


%     Subsystem  ['Sequence BCH',13,'Co//Dec demo'].

new_system([sys,'/',['Sequence BCH',13,'Co//Dec demo']])
set_param([sys,'/',['Sequence BCH',13,'Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Sequence BCH',13,'Co//Dec demo']],...
		'Mask Display','Binary\nerror\ndemo',...
		'Mask Dialogue','eval(''N_bch_demo=15;K_bch_demo=5;T_bch_demo=3;tstbchsq'')')


%     Finished composite block ['Sequence BCH',13,'Co//Dec demo'].

set_param([sys,'/',['Sequence BCH',13,'Co//Dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[180,228,260,272])

add_block('built-in/Note',[sys,'/','Channel Library'])
set_param([sys,'/','Channel Library'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[290,10,295,15])


%     Subsystem  ['QASK Mo//Dem',13,'demo8'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo8']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo8']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo8']],...
		'Mask Display','Rayleigh\nfading\ndemo2',...
		'Mask Dialogue','eval(''ts=.02;[num,den]=butter(3,100/pi/2*ts);td=.2;M=32;tceps3cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo8'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo8']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[470,153,550,197])


%     Subsystem  ['QASK Mo//Dem',13,'demo3'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo3']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo3']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo3']],...
		'Mask Display','Rayleigh\nnoise\ndemo2',...
		'Mask Dialogue','eval(''ts=.02;[num,den]=butter(3,100/pi/2*ts);td=.2;M=32;tcemqas2'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo3'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo3']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[470,303,550,347])


%     Subsystem  ['Rician noise',13,'channel'].

new_system([sys,'/',['Rician noise',13,'channel']])
set_param([sys,'/',['Rician noise',13,'channel']],'Location',[496,318,758,464])

add_block('built-in/Inport',[sys,'/',['Rician noise',13,'channel/in_1']])
set_param([sys,'/',['Rician noise',13,'channel/in_1']],...
		'position',[45,10,65,30])


%     Subsystem  ['Rician noise',13,'channel/Gaussian',13,'noise'].

new_system([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']])
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']],'Location',[358,505,706,710])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/',...
		'position',[210,81,235,109])
add_line([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']],[240,95;290,95])
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']],...
		'Mask Entries','[m1 m2]\/[d d]\/s\/')


%     Finished composite block ['Rician noise',13,'channel/Gaussian',13,'noise'].

set_param([sys,'/',['Rician noise',13,'channel/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'channel/out_1']])
set_param([sys,'/',['Rician noise',13,'channel/out_1']],...
		'position',[200,55,220,75])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'channel/Sum']])
set_param([sys,'/',['Rician noise',13,'channel/Sum']],...
		'position',[150,55,170,75])
add_line([sys,'/',['Rician noise',13,'channel']],[175,65;195,65])
add_line([sys,'/',['Rician noise',13,'channel']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['Rician noise',13,'channel']],[90,70;145,70])
set_param([sys,'/',['Rician noise',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rician N',...
		'Mask Type','Rician noise channel, fixed parameter')
set_param([sys,'/',['Rician noise',13,'channel']],...
		'Mask Dialogue','Additive Rician noise channel for\nbaseband signal simulation. Input\nand output signals are complex.|In-phase m:|Quadrature m:|sigma:|Seed (1x2 vector):')
set_param([sys,'/',['Rician noise',13,'channel']],...
		'Mask Translate','m1=@1;m2=@2;d=@3;s=@4;if length(s)<2,s=[s s+s];end;[x,y]=chanicon;[v,w]=cmplxicn(0,50,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rician noise',13,'channel']],...
		'Mask Help','This block adds Rician noise to the input signal. The input and output of this block are complex signals. A Rician noise is composed with two independant Gaussian noise elements. The two Gaussian components have the same standard deviation, sigma. Their mean values are in-phase m and quadrature m respectively.')
set_param([sys,'/',['Rician noise',13,'channel']],...
		'Mask Entries','.1\/.3\/.1\/[1234 4321]\/')


%     Finished composite block ['Rician noise',13,'channel'].

set_param([sys,'/',['Rician noise',13,'channel']],...
		'position',[325,378,405,422])


%     Subsystem  ['Rician noise channel',13,'w vary para CE'].

new_system([sys,'/',['Rician noise channel',13,'w vary para CE']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE']],'Location',[550,71,921,341])

add_block('built-in/Inport',[sys,'/',['Rician noise channel',13,'w vary para CE/in_3']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/in_3']],...
		'Port','3',...
		'position',[15,95,35,115])

add_block('built-in/Inport',[sys,'/',['Rician noise channel',13,'w vary para CE/in_1']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/in_1']],...
		'position',[180,10,200,30])

add_block('built-in/Inport',[sys,'/',['Rician noise channel',13,'w vary para CE/in_4']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/in_4']],...
		'Port','4',...
		'position',[25,135,45,155])

add_block('built-in/Mux',[sys,'/',['Rician noise channel',13,'w vary para CE/Mux']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Mux']],...
		'inputs','2',...
		'position',[80,46,115,79])

add_block('built-in/Inport',[sys,'/',['Rician noise channel',13,'w vary para CE/in_2']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/in_2']],...
		'Port','2',...
		'position',[15,45,35,65])


%     Subsystem  ['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise'].

new_system([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],'Location',[482,386,830,557])

add_block('built-in/Product',[sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/Product']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/Product']],...
		'position',[240,80,265,100])

add_block('built-in/Outport',[sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/out_1']],...
		'position',[300,80,320,100])

add_block('built-in/Inport',[sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/in_2']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/in_2']],...
		'Port','2',...
		'position',[170,35,190,55])

add_block('built-in/Inport',[sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/in_1']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/in_1']],...
		'position',[55,35,75,55])

add_block('built-in/White Noise',[sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[40,82,85,118])

add_block('built-in/Sum',[sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],[195,45;210,45;210,85;235,85])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],[165,95;235,95])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],[270,90;295,90])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],[90,100;135,100])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],[80,45;110,45;110,90;135,90])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Initial Seed(s):')
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],...
		'Mask Translate','s=@1;')
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],...
		'Mask Help','The meanvalue is determined by value from the frist input. The standard deviation is determined by the second input. ')
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],...
		'Mask Entries','s\/')


%     Finished composite block ['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise'].

set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Gaussian',13,'noise']],...
		'position',[155,55,230,95])

add_block('built-in/Sum',[sys,'/',['Rician noise channel',13,'w vary para CE/Sum']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/Sum']],...
		'position',[275,60,295,80])

add_block('built-in/Outport',[sys,'/',['Rician noise channel',13,'w vary para CE/out_1']])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE/out_1']],...
		'position',[325,60,345,80])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE']],[235,75;270,75])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE']],[205,20;240,20;240,65;270,65])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE']],[300,70;320,70])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE']],[40,55;75,55])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE']],[40,105;50,105;50,70;75,70])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE']],[120,65;150,65])
add_line([sys,'/',['Rician noise channel',13,'w vary para CE']],[50,145;120,145;120,85;150,85])
set_param([sys,'/',['Rician noise channel',13,'w vary para CE']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rician N',...
		'Mask Type','Rician noise channel, vary parameter')
set_param([sys,'/',['Rician noise channel',13,'w vary para CE']],...
		'Mask Dialogue','Add Rician noise to complex signal (1st port) with the varying in-phase m (2nd port), quadrature m (3rd port), and sigma (4th port).|Seeds (1x2 vector):')
set_param([sys,'/',['Rician noise channel',13,'w vary para CE']],...
		'Mask Translate','s=@1;if length(s)<1,s=[s s+s+1];end;[x,y]=chanicon;x=x*.9+10;[v,w]=cmplxicn(0,89,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rician noise channel',13,'w vary para CE']],...
		'Mask Help','This block adds Rician noise to the transmitting signal. The 1st port input and output of this block are complex data. The Rician noise is composed with two independant Gaussian noise elements. The mean value of the two Gaussian components are inputted from 2nd and 3rd inports respectively. Their standard deviations, sigma, are the same which is inputted from the 4th inport.')
set_param([sys,'/',['Rician noise channel',13,'w vary para CE']],...
		'Mask Entries','[13579,  24680]\/')


%     Finished composite block ['Rician noise channel',13,'w vary para CE'].

set_param([sys,'/',['Rician noise channel',13,'w vary para CE']],...
		'position',[325,453,405,497])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
