function [ret,x0,str,ts,xts]=com_cmpr(t,x,u,flag);
%COM_CMPR     is the M-file description of the SIMULINK system named COM_CMPR.
%       The block-diagram can be displayed by typing: COM_CMPR.
%
%       SYS=COM_CMPR(T,X,U,FLAG) returns depending on FLAG certain
%     system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes COM_CMPR to return state derivatives, FLAG=2
%     discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling COM_CMPR with a FLAG of zero:
%  [SIZES]=COM_CMPR([],[],[],0),  returns a vector, SIZES, which
%  contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs.
%     For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[65,59,492,516])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Karhunen-Loeve',13,'expanssion'].

new_system([sys,'/',['Karhunen-Loeve',13,'expanssion']])
set_param([sys,'/',['Karhunen-Loeve',13,'expanssion']],'Location',[681,543,995,748])

add_block('built-in/Outport',[sys,'/',['Karhunen-Loeve',13,'expanssion/out_1']])
set_param([sys,'/',['Karhunen-Loeve',13,'expanssion/out_1']],...
           'position',[190,135,210,155])

add_block('built-in/Inport',[sys,'/',['Karhunen-Loeve',13,'expanssion/in_1']])
set_param([sys,'/',['Karhunen-Loeve',13,'expanssion/in_1']],...
              'position',[35,135,55,155])
add_line([sys,'/',['Karhunen-Loeve',13,'expanssion']],[60,145;185,145])
set_param([sys,'/',['Karhunen-Loeve',13,'expanssion']],...
            'Mask Display','KL\nexpans',...
         'Mask Type','IKL expanssion',...
                'Mask Dialogue','Inverse principal component transform (Karhunen Loeve) expanssion:|Original signal length:')
set_param([sys,'/',['Karhunen-Loeve',13,'expanssion']],...
         'Mask Translate','sz=@1;',...
           'Mask Help','Ref: Lynch 5.2; Rosenfeld 5.2',...
         'Mask Entries','\/')


%     Finished composite block ['Karhunen-Loeve',13,'expanssion'].

set_param([sys,'/',['Karhunen-Loeve',13,'expanssion']],...
                'orientation',2,...
             'position',[280,65,360,105])


%     Subsystem  ['Karhunen-Loeve',13,'compressor'].

new_system([sys,'/',['Karhunen-Loeve',13,'compressor']])
set_param([sys,'/',['Karhunen-Loeve',13,'compressor']],'Location',[681,543,995,748])

add_block('built-in/Inport',[sys,'/',['Karhunen-Loeve',13,'compressor/in_1']])
set_param([sys,'/',['Karhunen-Loeve',13,'compressor/in_1']],...
               'position',[35,135,55,155])

add_block('built-in/Outport',[sys,'/',['Karhunen-Loeve',13,'compressor/out_1']])
set_param([sys,'/',['Karhunen-Loeve',13,'compressor/out_1']],...
             'position',[190,135,210,155])
add_line([sys,'/',['Karhunen-Loeve',13,'compressor']],[60,145;185,145])
set_param([sys,'/',['Karhunen-Loeve',13,'compressor']],...
          'Mask Display','KL\ncomprs',...
         'Mask Type','KL compressor',...
         'Mask Dialogue','Principal component transform (Karhunen Loeve) compression:|Compressed length:')
set_param([sys,'/',['Karhunen-Loeve',13,'compressor']],...
             'Mask Translate','K=@1;',...
            'Mask Help','Ref: Lynch 5.2Rosenfeld 5.2',...
           'Mask Entries','256\/')


%     Finished composite block ['Karhunen-Loeve',13,'compressor'].

set_param([sys,'/',['Karhunen-Loeve',13,'compressor']],...
             'position',[70,33,145,77])


%     Subsystem  ['Haar transfrom',13,'compressor'].

new_system([sys,'/',['Haar transfrom',13,'compressor']])
set_param([sys,'/',['Haar transfrom',13,'compressor']],'Location',[681,543,995,748])

add_block('built-in/Outport',[sys,'/',['Haar transfrom',13,'compressor/out_1']])
set_param([sys,'/',['Haar transfrom',13,'compressor/out_1']],...
              'position',[190,135,210,155])

add_block('built-in/Inport',[sys,'/',['Haar transfrom',13,'compressor/in_1']])
set_param([sys,'/',['Haar transfrom',13,'compressor/in_1']],...
              'position',[35,135,55,155])
add_line([sys,'/',['Haar transfrom',13,'compressor']],[60,145;185,145])
set_param([sys,'/',['Haar transfrom',13,'compressor']],...
            'Mask Display','Haar\ncomprs',...
               'Mask Type','Haar compressor',...
               'Mask Dialogue','Haar transfrom compressor:|Compressed length:',...
             'Mask Translate','K=@1;')
set_param([sys,'/',['Haar transfrom',13,'compressor']],...
             'Mask Help','Ref: Lynch 5.2; ',...
              'Mask Entries','\/')


%     Finished composite block ['Haar transfrom',13,'compressor'].

set_param([sys,'/',['Haar transfrom',13,'compressor']],...
                'position',[70,308,145,352])


%     Subsystem  ['Hadamard transfrom',13,'compressor'].

new_system([sys,'/',['Hadamard transfrom',13,'compressor']])
set_param([sys,'/',['Hadamard transfrom',13,'compressor']],'Location',[681,543,995,748])

add_block('built-in/Inport',[sys,'/',['Hadamard transfrom',13,'compressor/in_1']])
set_param([sys,'/',['Hadamard transfrom',13,'compressor/in_1']],...
           'position',[35,135,55,155])

add_block('built-in/Outport',[sys,'/',['Hadamard transfrom',13,'compressor/out_1']])
set_param([sys,'/',['Hadamard transfrom',13,'compressor/out_1']],...
             'position',[190,135,210,155])
add_line([sys,'/',['Hadamard transfrom',13,'compressor']],[60,145;185,145])
set_param([sys,'/',['Hadamard transfrom',13,'compressor']],...
          'Mask Display','Hadamard\ncomprs',...
           'Mask Type','Hadamard compressor',...
           'Mask Dialogue','Hadamard transfrom compressor:|Compressed length:',...
         'Mask Translate','K=@1;')
set_param([sys,'/',['Hadamard transfrom',13,'compressor']],...
         'Mask Help','Ref: Lynch 5.2; Rosenfeld 5.3',...
         'Mask Entries','\/')


%     Finished composite block ['Hadamard transfrom',13,'compressor'].

set_param([sys,'/',['Hadamard transfrom',13,'compressor']],...
                'position',[70,213,145,257])


%     Subsystem  ['Discrete Fourier',13,'Transform compressor'].

new_system([sys,'/',['Discrete Fourier',13,'Transform compressor']])
set_param([sys,'/',['Discrete Fourier',13,'Transform compressor']],'Location',[681,543,995,748])

add_block('built-in/Outport',[sys,'/',['Discrete Fourier',13,'Transform compressor/out_1']])
set_param([sys,'/',['Discrete Fourier',13,'Transform compressor/out_1']],...
                'position',[190,135,210,155])

add_block('built-in/Inport',[sys,'/',['Discrete Fourier',13,'Transform compressor/in_1']])
set_param([sys,'/',['Discrete Fourier',13,'Transform compressor/in_1']],...
              'position',[35,135,55,155])
add_line([sys,'/',['Discrete Fourier',13,'Transform compressor']],[60,145;185,145])
set_param([sys,'/',['Discrete Fourier',13,'Transform compressor']],...
            'Mask Display','DFT\ncomprs',...
                'Mask Type','DFT compressor',...
                'Mask Dialogue','Discrete Fourier transfrom compressor:|Compressed length:')
set_param([sys,'/',['Discrete Fourier',13,'Transform compressor']],...
              'Mask Translate','K=@1;',...
            'Mask Help','Ref: Lynch 5.2; Rosenfeld 5.3',...
         'Mask Entries','256\/')


%     Finished composite block ['Discrete Fourier',13,'Transform compressor'].

set_param([sys,'/',['Discrete Fourier',13,'Transform compressor']],...
             'position',[70,118,145,162])


%     Subsystem  'Block quantization'.

new_system([sys,'/','Block quantization'])
set_param([sys,'/','Block quantization'],'Location',[681,543,995,748])

add_block('built-in/Inport',[sys,'/','Block quantization/in_1'])
set_param([sys,'/','Block quantization/in_1'],...
             'position',[35,135,55,155])

add_block('built-in/Outport',[sys,'/','Block quantization/out_1'])
set_param([sys,'/','Block quantization/out_1'],...
         'position',[190,135,210,155])
add_line([sys,'/','Block quantization'],[60,145;185,145])
set_param([sys,'/','Block quantization'],...
              'Mask Display','Block\nquantization',...
                'Mask Type','Block quantization',...
            'Mask Dialogue','Block quantizatio:|Number of transfer sample:',...
             'Mask Translate','num=@1;')
set_param([sys,'/','Block quantization'],...
         'Mask Help','Ref: Lynch 5.3; ',...
              'Mask Entries','\/')


%     Finished composite block 'Block quantization'.

set_param([sys,'/','Block quantization'],...
            'position',[65,393,140,437])


%     Subsystem  ['Inverse Discrete',13,'Fourier transform',13,'expanssion'].

new_system([sys,'/',['Inverse Discrete',13,'Fourier transform',13,'expanssion']])
set_param([sys,'/',['Inverse Discrete',13,'Fourier transform',13,'expanssion']],'Location',[681,543,995,748])

add_block('built-in/Inport',[sys,'/',['Inverse Discrete',13,'Fourier transform',13,'expanssion/in_1']])
set_param([sys,'/',['Inverse Discrete',13,'Fourier transform',13,'expanssion/in_1']],...
          'position',[35,135,55,155])

add_block('built-in/Outport',[sys,'/',['Inverse Discrete',13,'Fourier transform',13,'expanssion/out_1']])
set_param([sys,'/',['Inverse Discrete',13,'Fourier transform',13,'expanssion/out_1']],...
           'position',[190,135,210,155])
add_line([sys,'/',['Inverse Discrete',13,'Fourier transform',13,'expanssion']],[60,145;185,145])
set_param([sys,'/',['Inverse Discrete',13,'Fourier transform',13,'expanssion']],...
                'Mask Display','IDFT\nexpans',...
               'Mask Type','IDFT expanssion',...
               'Mask Dialogue','Inverse Discrete Fourier transfrom expanssion|Original signal length')
set_param([sys,'/',['Inverse Discrete',13,'Fourier transform',13,'expanssion']],...
              'Mask Translate','len=@1;',...
          'Mask Help','Ref: Lynch 5.2; Rosenfeld 5.3',...
         'Mask Entries','\/')


%     Finished composite block ['Inverse Discrete',13,'Fourier transform',13,'expanssion'].

set_param([sys,'/',['Inverse Discrete',13,'Fourier transform',13,'expanssion']],...
              'orientation',2,...
             'position',[280,150,360,190])


%     Subsystem  ['Hadamard transfrom',13,'expanssion'].

new_system([sys,'/',['Hadamard transfrom',13,'expanssion']])
set_param([sys,'/',['Hadamard transfrom',13,'expanssion']],'Location',[681,543,995,748])

add_block('built-in/Outport',[sys,'/',['Hadamard transfrom',13,'expanssion/out_1']])
set_param([sys,'/',['Hadamard transfrom',13,'expanssion/out_1']],...
               'position',[190,135,210,155])

add_block('built-in/Inport',[sys,'/',['Hadamard transfrom',13,'expanssion/in_1']])
set_param([sys,'/',['Hadamard transfrom',13,'expanssion/in_1']],...
              'position',[35,135,55,155])
add_line([sys,'/',['Hadamard transfrom',13,'expanssion']],[60,145;185,145])
set_param([sys,'/',['Hadamard transfrom',13,'expanssion']],...
            'Mask Display','Hadamard\nexpans',...
           'Mask Type','Hadamard expanssion',...
           'Mask Dialogue','Inverse hadamard transfrom expanssion:|Original signal length:')
set_param([sys,'/',['Hadamard transfrom',13,'expanssion']],...
         'Mask Translate','len=@1;',...
          'Mask Help','Ref: Lynch 5.2; Rosenfeld 5.3',...
         'Mask Entries','\/')


%     Finished composite block ['Hadamard transfrom',13,'expanssion'].

set_param([sys,'/',['Hadamard transfrom',13,'expanssion']],...
                'orientation',2,...
             'position',[275,245,355,285])


%     Subsystem  ['Haar transfrom',13,'expanssion'].

new_system([sys,'/',['Haar transfrom',13,'expanssion']])
set_param([sys,'/',['Haar transfrom',13,'expanssion']],'Location',[681,543,995,748])

add_block('built-in/Inport',[sys,'/',['Haar transfrom',13,'expanssion/in_1']])
set_param([sys,'/',['Haar transfrom',13,'expanssion/in_1']],...
              'position',[35,135,55,155])

add_block('built-in/Outport',[sys,'/',['Haar transfrom',13,'expanssion/out_1']])
set_param([sys,'/',['Haar transfrom',13,'expanssion/out_1']],...
             'position',[190,135,210,155])
add_line([sys,'/',['Haar transfrom',13,'expanssion']],[60,145;185,145])
set_param([sys,'/',['Haar transfrom',13,'expanssion']],...
          'Mask Display','Haar\nexpans',...
               'Mask Type','Haar expanssion',...
               'Mask Dialogue','Inverse haar transfrom expanssion:|Original signal length:',...
                'Mask Translate','len=@1;')
set_param([sys,'/',['Haar transfrom',13,'expanssion']],...
           'Mask Help','Ref: Lynch 5.2;',...
               'Mask Entries','\/')


%     Finished composite block ['Haar transfrom',13,'expanssion'].

set_param([sys,'/',['Haar transfrom',13,'expanssion']],...
                'orientation',2,...
             'position',[275,340,355,380])
add_line(sys,[150,55;385,55;385,85;365,85])
add_line(sys,[150,140;390,140;390,170;365,170])
add_line(sys,[150,235;390,235;390,265;360,265])
add_line(sys,[150,330;390,330;390,360;360,360])

% Return any arguments.
if (nargin | nargout)
       % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
end
