function [ret,x0,str,ts,xts]=com_encr(t,x,u,flag);
%COM_ENCR     is the M-file description of the SIMULINK system named COM_ENCR.
%       The block-diagram can be displayed by typing: COM_ENCR.
%
%       SYS=COM_ENCR(T,X,U,FLAG) returns depending on FLAG certain
%     system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes COM_ENCR to return state derivatives, FLAG=2
%     discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling COM_ENCR with a FLAG of zero:
%  [SIZES]=COM_ENCR([],[],[],0),  returns a vector, SIZES, which
%  contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs.
%     For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[71,80,422,521])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Cipher-system',13,'encrypt'].

new_system([sys,'/',['Cipher-system',13,'encrypt']])
set_param([sys,'/',['Cipher-system',13,'encrypt']],'Location',[696,477,995,748])

add_block('built-in/Outport',[sys,'/',['Cipher-system',13,'encrypt/out_1']])
set_param([sys,'/',['Cipher-system',13,'encrypt/out_1']],...
               'position',[145,135,165,155])

add_block('built-in/Inport',[sys,'/',['Cipher-system',13,'encrypt/in_1']])
set_param([sys,'/',['Cipher-system',13,'encrypt/in_1']],...
              'position',[35,135,55,155])

add_block('built-in/Inport',[sys,'/',['Cipher-system',13,'encrypt/in_2']])
set_param([sys,'/',['Cipher-system',13,'encrypt/in_2']],...
                'Port','2',...
          'position',[40,190,60,210])
add_line([sys,'/',['Cipher-system',13,'encrypt']],[60,145;140,145])
set_param([sys,'/',['Cipher-system',13,'encrypt']],...
            'Mask Display','Cipher\nencrypt',...
            'Mask Type','Cipher system encrypt',...
         'Mask Dialogue','Cipher system encrypt:|Key:',...
               'Mask Translate','key=@1;')
set_param([sys,'/',['Cipher-system',13,'encrypt']],...
               'Mask Help','The Cipher encrypt block encode a digital signal by cipher system encypt method. The first input is the signal to be encoded. The second input is the pace control pulse.')
set_param([sys,'/',['Cipher-system',13,'encrypt']],...
          'Mask Entries','[''abcdefghijklmnopqrstuvwxyz'';''zyxwvutsrqponmlkjihgfedcba'']\/')


%     Finished composite block ['Cipher-system',13,'encrypt'].

set_param([sys,'/',['Cipher-system',13,'encrypt']],...
         'position',[50,28,120,77])


%     Subsystem  ['Cipher system',13,'decrypt'].

new_system([sys,'/',['Cipher system',13,'decrypt']])
set_param([sys,'/',['Cipher system',13,'decrypt']],'Location',[696,477,995,748])

add_block('built-in/Inport',[sys,'/',['Cipher system',13,'decrypt/in_1']])
set_param([sys,'/',['Cipher system',13,'decrypt/in_1']],...
             'position',[35,135,55,155])

add_block('built-in/Outport',[sys,'/',['Cipher system',13,'decrypt/out_1']])
set_param([sys,'/',['Cipher system',13,'decrypt/out_1']],...
             'position',[145,135,165,155])

add_block('built-in/Inport',[sys,'/',['Cipher system',13,'decrypt/in_2']])
set_param([sys,'/',['Cipher system',13,'decrypt/in_2']],...
              'Port','2',...
          'position',[40,205,60,225])
add_line([sys,'/',['Cipher system',13,'decrypt']],[60,145;140,145])
set_param([sys,'/',['Cipher system',13,'decrypt']],...
            'Mask Display','Cipher\ndecrypt',...
            'Mask Type','Cipher system decrypt',...
         'Mask Dialogue','Cipher system decrypt:|Key:',...
               'Mask Translate','key=@1;')
set_param([sys,'/',['Cipher system',13,'decrypt']],...
               'Mask Help','The Cipher system decrypt block decodes the digital signal encripted by Cipher system encypt block. The first port inputs the signal. The second port inputs the pace control pulse.')
set_param([sys,'/',['Cipher system',13,'decrypt']],...
               'Mask Entries','\/')


%     Finished composite block ['Cipher system',13,'decrypt'].

set_param([sys,'/',['Cipher system',13,'decrypt']],...
                'orientation',2,...
             'position',[230,62,300,113])


%     Subsystem  ['RSA scheme',13,'decrypt'].

new_system([sys,'/',['RSA scheme',13,'decrypt']])
set_param([sys,'/',['RSA scheme',13,'decrypt']],'Location',[643,513,995,748])

add_block('built-in/Outport',[sys,'/',['RSA scheme',13,'decrypt/out_1']])
set_param([sys,'/',['RSA scheme',13,'decrypt/out_1']],...
               'position',[505,145,525,165])

add_block('built-in/Inport',[sys,'/',['RSA scheme',13,'decrypt/in_1']])
set_param([sys,'/',['RSA scheme',13,'decrypt/in_1']],...
            'position',[35,135,55,155])

add_block('built-in/Inport',[sys,'/',['RSA scheme',13,'decrypt/in_2']])
set_param([sys,'/',['RSA scheme',13,'decrypt/in_2']],...
              'Port','2',...
          'position',[50,190,70,210])
set_param([sys,'/',['RSA scheme',13,'decrypt']],...
          'Mask Display','RSA\ndecrypt',...
               'Mask Type','RSA decrypt',...
           'Mask Dialogue','Decrypt a binary sequence using RSA scheme:|Key:',...
               'Mask Translate','key=@1;')
set_param([sys,'/',['RSA scheme',13,'decrypt']],...
          'Mask Help','ref Sklar 12.5',...
                'Mask Entries','\/')


%     Finished composite block ['RSA scheme',13,'decrypt'].

set_param([sys,'/',['RSA scheme',13,'decrypt']],...
              'orientation',2,...
             'position',[230,244,300,291])


%     Subsystem  ['RSA scheme',13,'encrypt'].

new_system([sys,'/',['RSA scheme',13,'encrypt']])
set_param([sys,'/',['RSA scheme',13,'encrypt']],'Location',[635,580,995,748])

add_block('built-in/Inport',[sys,'/',['RSA scheme',13,'encrypt/in_1']])
set_param([sys,'/',['RSA scheme',13,'encrypt/in_1']],...
         'position',[35,135,55,155])

add_block('built-in/Inport',[sys,'/',['RSA scheme',13,'encrypt/in_2']])
set_param([sys,'/',['RSA scheme',13,'encrypt/in_2']],...
              'Port','2',...
          'position',[40,180,60,200])

add_block('built-in/Outport',[sys,'/',['RSA scheme',13,'encrypt/out_1']])
set_param([sys,'/',['RSA scheme',13,'encrypt/out_1']],...
           'position',[160,170,180,190])
add_line([sys,'/',['RSA scheme',13,'encrypt']],[60,145;100,145;100,180;155,180])
set_param([sys,'/',['RSA scheme',13,'encrypt']],...
                'Mask Display','RSA\nencrypt',...
               'Mask Type','RSA encrypt',...
           'Mask Dialogue','Encrypt a binary sequence using RSA scheme:|Key:',...
               'Mask Translate','key = @1;')
set_param([sys,'/',['RSA scheme',13,'encrypt']],...
                'Mask Help','ref Sklar 12.5',...
                'Mask Entries','\/')


%     Finished composite block ['RSA scheme',13,'encrypt'].

set_param([sys,'/',['RSA scheme',13,'encrypt']],...
              'position',[50,213,120,257])


%     Subsystem  ['Permutation',13,'decrypt'].

new_system([sys,'/',['Permutation',13,'decrypt']])
set_param([sys,'/',['Permutation',13,'decrypt']],'Location',[541,444,995,748])

add_block('built-in/Inport',[sys,'/',['Permutation',13,'decrypt/in_1']])
set_param([sys,'/',['Permutation',13,'decrypt/in_1']],...
             'position',[35,135,55,155])

add_block('built-in/Outport',[sys,'/',['Permutation',13,'decrypt/out_1']])
set_param([sys,'/',['Permutation',13,'decrypt/out_1']],...
         'position',[505,145,525,165])

add_block('built-in/Inport',[sys,'/',['Permutation',13,'decrypt/in_2']])
set_param([sys,'/',['Permutation',13,'decrypt/in_2']],...
          'Port','2',...
          'position',[45,185,65,205])
add_line([sys,'/',['Permutation',13,'decrypt']],[60,145;275,145;275,155;500,155])
set_param([sys,'/',['Permutation',13,'decrypt']],...
                'Mask Display','Permutation\ndecrypt',...
               'Mask Type','Permutation decript',...
           'Mask Dialogue','Decrypt a binary sequence by permutation system:|Key:',...
             'Mask Translate','key=@1;')
set_param([sys,'/',['Permutation',13,'decrypt']],...
         'Mask Help','ref Sklar 12.3',...
                'Mask Entries','\/')


%     Finished composite block ['Permutation',13,'decrypt'].

set_param([sys,'/',['Permutation',13,'decrypt']],...
            'orientation',2,...
             'position',[230,152,300,203])


%     Subsystem  ['Permutation',13,'encrypt'].

new_system([sys,'/',['Permutation',13,'encrypt']])
set_param([sys,'/',['Permutation',13,'encrypt']],'Location',[552,495,995,748])

add_block('built-in/Inport',[sys,'/',['Permutation',13,'encrypt/in_1']])
set_param([sys,'/',['Permutation',13,'encrypt/in_1']],...
            'position',[35,135,55,155])

add_block('built-in/Inport',[sys,'/',['Permutation',13,'encrypt/in_2']])
set_param([sys,'/',['Permutation',13,'encrypt/in_2']],...
            'Port','2',...
          'position',[35,165,55,185])

add_block('built-in/Outport',[sys,'/',['Permutation',13,'encrypt/out_1']])
set_param([sys,'/',['Permutation',13,'encrypt/out_1']],...
         'position',[110,135,130,155])
add_line([sys,'/',['Permutation',13,'encrypt']],[60,145;105,145])
set_param([sys,'/',['Permutation',13,'encrypt']],...
              'Mask Display','Permutation\nencrypt',...
               'Mask Type','Permutation',...
           'Mask Dialogue','Encrypt a code by permutation system:|Key:',...
                'Mask Translate','key=@1;')
set_param([sys,'/',['Permutation',13,'encrypt']],...
         'Mask Help','ref: Sklar 12.3',...
               'Mask Entries','\/')


%     Finished composite block ['Permutation',13,'encrypt'].

set_param([sys,'/',['Permutation',13,'encrypt']],...
            'position',[50,118,120,167])


%     Subsystem  ['Merkle-Hellman',13,'encrypt'].

new_system([sys,'/',['Merkle-Hellman',13,'encrypt']])
set_param([sys,'/',['Merkle-Hellman',13,'encrypt']],'Location',[458,470,995,748])

add_block('built-in/Outport',[sys,'/',['Merkle-Hellman',13,'encrypt/out_1']])
set_param([sys,'/',['Merkle-Hellman',13,'encrypt/out_1']],...
           'position',[505,145,525,165])

add_block('built-in/Inport',[sys,'/',['Merkle-Hellman',13,'encrypt/in_1']])
set_param([sys,'/',['Merkle-Hellman',13,'encrypt/in_1']],...
            'position',[35,135,55,155])

add_block('built-in/Inport',[sys,'/',['Merkle-Hellman',13,'encrypt/in_2']])
set_param([sys,'/',['Merkle-Hellman',13,'encrypt/in_2']],...
              'Port','2',...
          'position',[40,190,60,210])
set_param([sys,'/',['Merkle-Hellman',13,'encrypt']],...
              'Mask Display','MH\nencrypt',...
                'Mask Type','Merkle-Hellman encrypt',...
                'Mask Dialogue','Encrypt a binary sequence by Merkle-Hellman scheme:|Key:',...
          'Mask Translate','key@1;')
set_param([sys,'/',['Merkle-Hellman',13,'encrypt']],...
               'Mask Help','ref Sklar 12.5',...
                'Mask Entries','\/')


%     Finished composite block ['Merkle-Hellman',13,'encrypt'].

set_param([sys,'/',['Merkle-Hellman',13,'encrypt']],...
              'position',[45,299,115,346])


%     Subsystem  ['Merkle-Hellman',13,'decrypt'].

new_system([sys,'/',['Merkle-Hellman',13,'decrypt']])
set_param([sys,'/',['Merkle-Hellman',13,'decrypt']],'Location',[501,481,995,748])

add_block('built-in/Inport',[sys,'/',['Merkle-Hellman',13,'decrypt/in_1']])
set_param([sys,'/',['Merkle-Hellman',13,'decrypt/in_1']],...
              'position',[35,135,55,155])

add_block('built-in/Outport',[sys,'/',['Merkle-Hellman',13,'decrypt/out_1']])
set_param([sys,'/',['Merkle-Hellman',13,'decrypt/out_1']],...
           'position',[505,145,525,165])

add_block('built-in/Inport',[sys,'/',['Merkle-Hellman',13,'decrypt/in_2']])
set_param([sys,'/',['Merkle-Hellman',13,'decrypt/in_2']],...
            'Port','2',...
          'position',[45,210,65,230])
set_param([sys,'/',['Merkle-Hellman',13,'decrypt']],...
              'Mask Display','MH\ndecrypt',...
                'Mask Type','Merkle-Hellman decrypt',...
                'Mask Dialogue','Decrypt a binary sequence by Merkle-Hellman scheme:|Key:',...
          'Mask Translate','key')
set_param([sys,'/',['Merkle-Hellman',13,'decrypt']],...
          'Mask Help','ref: Sklar 12.5',...
               'Mask Entries','\/')


%     Finished composite block ['Merkle-Hellman',13,'decrypt'].

set_param([sys,'/',['Merkle-Hellman',13,'decrypt']],...
              'orientation',2,...
             'position',[225,337,295,388])
add_line(sys,[125,55;325,55;325,75;305,75])
add_line(sys,[125,145;325,145;325,165;305,165])
add_line(sys,[125,235;325,235;325,255;305,255])
add_line(sys,[120,325;320,325;320,350;300,350])

% Return any arguments.
if (nargin | nargout)
       % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
end
