function [ret,x0,str,ts,xts]=com_filt(t,x,u,flag);
%COM_FILT	is the M-file description of the SIMULINK system named COM_FILT.
%	The block-diagram can be displayed by typing: COM_FILT.
%
%	SYS=COM_FILT(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_FILT to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_FILT with a FLAG of zero:
%	[SIZES]=COM_FILT([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[41,46,480,544])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Raised cosine',13,'filter demo1'].

new_system([sys,'/',['Raised cosine',13,'filter demo1']])
set_param([sys,'/',['Raised cosine',13,'filter demo1']],'Location',[175,552,335,697])
set_param([sys,'/',['Raised cosine',13,'filter demo1']],...
		'Mask Display','RC filter\ndemo 2',...
		'Mask Dialogue','eval(''tstrcos2'')')


%     Finished composite block ['Raised cosine',13,'filter demo1'].

set_param([sys,'/',['Raised cosine',13,'filter demo1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,43,395,87])


%     Subsystem  ['Raised cosine',13,'filter'].

new_system([sys,'/',['Raised cosine',13,'filter']])
set_param([sys,'/',['Raised cosine',13,'filter']],'Location',[131,545,589,761])


%     Subsystem  ['Raised cosine',13,'filter/Memory Impulse'].

new_system([sys,'/',['Raised cosine',13,'filter/Memory Impulse']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],'Location',[541,520,939,745])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/in_1']],...
		'position',[35,185,55,205])

add_block('built-in/Zero-Order Hold',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/Zero-Order',13,'Hold']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/Zero-Order',13,'Hold']],...
		'Sample time','ts',...
		'position',[205,84,240,116])

add_block('built-in/Product',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/Product']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/Product']],...
		'position',[155,90,180,110])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/out_1']],...
		'position',[355,130,375,150])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/Constant']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/Constant']],...
		'Value','x',...
		'position',[210,155,230,175])

add_block('built-in/Switch',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/Switch']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/Switch']],...
		'Threshold','.5',...
		'position',[295,124,320,156])


%     Subsystem  ['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

new_system([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],'Location',[419,521,808,713])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Unit Delay',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']],...
		'Sample time','ts',...
		'position',[120,87,170,103])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[175,95;195,95])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[45,25;45,95;115,95])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Dialogue','Rising edge detection:|Threshold:|Sampling time:',...
		'Mask Translate','thld=@1;ts=@2;')
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Entries','thr\/ts\/')


%     Finished composite block ['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'position',[65,26,120,54])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter/Memory Impulse/in_2']])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse/in_2']],...
		'Port','2',...
		'position',[25,30,45,50])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],[245,100;260,100;260,130;290,130])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],[185,100;200,100])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],[60,195;280,195;290,150])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],[95,195;95,105;150,105])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],[325,140;350,140])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],[235,165;250,165;250,140;290,140])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],[125,40;130,40;130,95;150,95])
add_line([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],[50,40;60,40])
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],...
		'Mask Display','1/sinc',...
		'Mask Type','Impulse',...
		'Mask Dialogue','1/sinc filter:|Holding time:|Threshold for clock pulse: ')
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],...
		'Mask Translate','ts=@1;thr=@2;x=thr>0;')
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],...
		'Mask Help','When the threshold is greater than zero, this block outputs an impulse signal, which begins at the raising edge of the second input and lasts the holding time. The impulse holds a constant amplitude, which equals the amplitude of the first input at the begining of the impulse. A clock raising edge will trigger next impulse. When the threshold is less or equal to zero, this block faithfully outputs the first input.')
set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],...
		'Mask Entries','ts\/x\/')


%     Finished composite block ['Raised cosine',13,'filter/Memory Impulse'].

set_param([sys,'/',['Raised cosine',13,'filter/Memory Impulse']],...
		'position',[155,30,225,70])

add_block('built-in/Filter',[sys,'/',['Raised cosine',13,'filter/Filter']])
set_param([sys,'/',['Raised cosine',13,'filter/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,31,310,69])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter/out_1']],...
		'position',[330,40,350,60])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter/in_1']],...
		'position',[35,30,55,50])


%     Subsystem  ['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','td\/1\/off\/')


%     Finished composite block ['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'position',[35,71,95,109])
add_line([sys,'/',['Raised cosine',13,'filter']],[100,90;115,90;115,60;150,60])
add_line([sys,'/',['Raised cosine',13,'filter']],[230,50;250,50])
add_line([sys,'/',['Raised cosine',13,'filter']],[60,40;150,40])
add_line([sys,'/',['Raised cosine',13,'filter']],[315,50;325,50])
set_param([sys,'/',['Raised cosine',13,'filter']],...
		'Mask Display','R-C\nfilter',...
		'Mask Type','R-C filter')
set_param([sys,'/',['Raised cosine',13,'filter']],...
		'Mask Dialogue','Design a raised cosine filter and use it to filter the input signal.|Symbol interval (sec):|Computation sampling time (sec):|Filter rolloff factor:|Delay step (integer to multiply symbol interval):|Filter type (FIR or IIR) / (Normal or Sqrt):|With or without sinc filter (1 or 0, suggest 1):')
set_param([sys,'/',['Raised cosine',13,'filter']],...
		'Mask Translate','td=@1;if length(td)>1,off=td(2);td=td(1);else,off=0;end;ts=@2;R=@3;delay=@4;fil=@5;[num,den]=rcosine(1/td(1),1/ts(1),fil,R,delay);x=@6/2;')
set_param([sys,'/',['Raised cosine',13,'filter']],...
		'Mask Help','This block designs a raised cosine filter using the specified parameter. The filter is used to filter the input signal. You can optionally use the sinc filter in the filtering computation.')
set_param([sys,'/',['Raised cosine',13,'filter']],...
		'Mask Entries','.1\/.01\/.5\/6\/''FIR''\/1\/')


%     Finished composite block ['Raised cosine',13,'filter'].

set_param([sys,'/',['Raised cosine',13,'filter']],...
		'position',[40,43,120,87])

add_block('built-in/Note',[sys,'/','Special Filter Library'])
set_param([sys,'/','Special Filter Library'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[220,6,225,11])


%     Subsystem  'Memory impulse'.

new_system([sys,'/','Memory impulse'])
set_param([sys,'/','Memory impulse'],'Location',[413,205,811,430])

add_block('built-in/Inport',[sys,'/','Memory impulse/in_1'])
set_param([sys,'/','Memory impulse/in_1'],...
		'position',[35,185,55,205])

add_block('built-in/Zero-Order Hold',[sys,'/',['Memory impulse/Zero-Order',13,'Hold']])
set_param([sys,'/',['Memory impulse/Zero-Order',13,'Hold']],...
		'Sample time','ts',...
		'position',[205,84,240,116])

add_block('built-in/Product',[sys,'/','Memory impulse/Product'])
set_param([sys,'/','Memory impulse/Product'],...
		'position',[155,90,180,110])

add_block('built-in/Outport',[sys,'/','Memory impulse/out_1'])
set_param([sys,'/','Memory impulse/out_1'],...
		'position',[355,130,375,150])

add_block('built-in/Constant',[sys,'/','Memory impulse/Constant'])
set_param([sys,'/','Memory impulse/Constant'],...
		'Value','x',...
		'position',[210,155,230,175])

add_block('built-in/Switch',[sys,'/','Memory impulse/Switch'])
set_param([sys,'/','Memory impulse/Switch'],...
		'Threshold','.5',...
		'position',[295,124,320,156])


%     Subsystem  ['Memory impulse/discrete',13,'Rising edge',13,'detector'].

new_system([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']])
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],'Location',[419,521,808,713])

add_block('built-in/Relational Operator',[sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Constant',[sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/one1']])
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Unit Delay',[sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']])
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']],...
		'Sample time','ts',...
		'position',[120,87,170,103])
add_line([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],[175,95;195,95])
add_line([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],[45,25;45,95;115,95])
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:|Sampling time:')
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;ts=@2;')
set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thr\/ts\/')


%     Finished composite block ['Memory impulse/discrete',13,'Rising edge',13,'detector'].

set_param([sys,'/',['Memory impulse/discrete',13,'Rising edge',13,'detector']],...
		'position',[65,26,120,54])

add_block('built-in/Inport',[sys,'/','Memory impulse/in_2'])
set_param([sys,'/','Memory impulse/in_2'],...
		'Port','2',...
		'position',[25,30,45,50])
add_line([sys,'/','Memory impulse'],[245,100;260,100;260,130;290,130])
add_line([sys,'/','Memory impulse'],[185,100;200,100])
add_line([sys,'/','Memory impulse'],[60,195;280,195;290,150])
add_line([sys,'/','Memory impulse'],[95,195;95,105;150,105])
add_line([sys,'/','Memory impulse'],[325,140;350,140])
add_line([sys,'/','Memory impulse'],[235,165;250,165;250,140;290,140])
add_line([sys,'/','Memory impulse'],[125,40;130,40;130,95;150,95])
add_line([sys,'/','Memory impulse'],[50,40;60,40])
set_param([sys,'/','Memory impulse'],...
		'Mask Display','plot(0,0,100,100,v,w);Sinc',...
		'Mask Type','Sinc filter')
set_param([sys,'/','Memory impulse'],...
		'Mask Dialogue','The rising edge of the second input\nsignal locks the signal value at the first inport for the period of holding time.|Holding time (sec):|Threshold for trigger pulse: ')
set_param([sys,'/','Memory impulse'],...
		'Mask Translate','ts=@1;thr=@2;x=thr>0;[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/','Memory impulse'],...
		'Mask Help','When the threshold is greater than zero, this block outputs an impulse signal, which begins at the rising edge of the trigger signal from the second input port. The width of the impulse equals the holding time. The impulse holds a constant amplitude, which equals the amplitude of the first input at the rising edge of the trigger signal. When the threshold is less than or equal to zero, this block outputs the first input.')
set_param([sys,'/','Memory impulse'],...
		'Mask Entries','.01\/.2\/')


%     Finished composite block 'Memory impulse'.

set_param([sys,'/','Memory impulse'],...
		'position',[40,118,120,162])


%     Subsystem  'Hilbert transform filter'.

new_system([sys,'/','Hilbert transform filter'])
set_param([sys,'/','Hilbert transform filter'],'Location',[117,572,380,656])

add_block('built-in/Note',[sys,'/','Hilbert transform filter/Ref: Hambley: An Intro to Comm. Systems. pp82'])
set_param([sys,'/','Hilbert transform filter/Ref: Hambley: An Intro to Comm. Systems. pp82'],...
		'position',[355,290,360,295])

add_block('built-in/Outport',[sys,'/','Hilbert transform filter/out_1'])
set_param([sys,'/','Hilbert transform filter/out_1'],...
		'position',[195,20,215,40])

add_block('built-in/Inport',[sys,'/','Hilbert transform filter/in_1'])
set_param([sys,'/','Hilbert transform filter/in_1'],...
		'position',[35,20,55,40])

add_block('built-in/Filter',[sys,'/','Hilbert transform filter/Filter'])
set_param([sys,'/','Hilbert transform filter/Filter'],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[95,11,150,49])
add_line([sys,'/','Hilbert transform filter'],[60,30;90,30])
add_line([sys,'/','Hilbert transform filter'],[155,30;190,30])
set_param([sys,'/','Hilbert transform filter'],...
		'Mask Display','Hilbert\nfilter',...
		'Mask Type','Hilbert transform filter')
set_param([sys,'/','Hilbert transform filter'],...
		'Mask Dialogue','Design a Hilbert transform filter and use it to filter the input signal.|Bandwidth of the input signal (Hz):|Time delay for Hilbert transform filter (sec):|Sample time (sec):')
set_param([sys,'/','Hilbert transform filter'],...
		'Mask Translate','ban=@1;dly=@2;ts=@3;if ban>1/ts, ban=1/ts-ts;end;[num,den]=hilbiir(ts,dly,ban);pi2=2*pi;pih=pi/2;')
set_param([sys,'/','Hilbert transform filter'],...
		'Mask Help','This block designs a Hilbert transform filter. The filter is used to filter the input signal. Hilbert transform filter is a non-causal filter and needs a positive time delay. The filter works with the signal in the given frequency range.')
set_param([sys,'/','Hilbert transform filter'],...
		'Mask Entries','1/ts/10\/ts*10\/ts\/')


%     Finished composite block 'Hilbert transform filter'.

set_param([sys,'/','Hilbert transform filter'],...
		'position',[40,193,120,237])


%     Subsystem  ['Raised cosine',13,'filter demo'].

new_system([sys,'/',['Raised cosine',13,'filter demo']])
set_param([sys,'/',['Raised cosine',13,'filter demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Raised cosine',13,'filter demo']],...
		'Mask Display','RC filter\ndemo',...
		'Mask Dialogue','eval(''ts=.01;Fc=100/pi/2;[num,den]=butter(2,Fc*2*ts);td=.1;M=16;tstrcos'')')


%     Finished composite block ['Raised cosine',13,'filter demo'].

set_param([sys,'/',['Raised cosine',13,'filter demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[185,43,265,87])


%     Subsystem  ['Raised cosine',13,'filter demo2'].

new_system([sys,'/',['Raised cosine',13,'filter demo2']])
set_param([sys,'/',['Raised cosine',13,'filter demo2']],'Location',[175,552,335,697])
set_param([sys,'/',['Raised cosine',13,'filter demo2']],...
		'Mask Display','Sinc filter\ndemo',...
		'Mask Dialogue','eval(''tstsinc'')')


%     Finished composite block ['Raised cosine',13,'filter demo2'].

set_param([sys,'/',['Raised cosine',13,'filter demo2']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[185,118,265,162])


%     Subsystem  ['Raised cosine',13,'filter demo3'].

new_system([sys,'/',['Raised cosine',13,'filter demo3']])
set_param([sys,'/',['Raised cosine',13,'filter demo3']],'Location',[175,552,335,697])
set_param([sys,'/',['Raised cosine',13,'filter demo3']],...
		'Mask Display','Hilbert filter\ndemo',...
		'Mask Dialogue','eval(''ts=0.01;tsthilbt'')')


%     Finished composite block ['Raised cosine',13,'filter demo3'].

set_param([sys,'/',['Raised cosine',13,'filter demo3']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[185,193,265,237])


%     Subsystem  'Filters'.

new_system([sys,'/','Filters'])
set_param([sys,'/','Filters'],'Location',[15,243,212,738])
set_param([sys,'/','Filters'],...
		'Mask Display','SIMULINK\nfilter\nblocks',...
		'Mask Dialogue','eval(''extrfilt;'')')


%     Finished composite block 'Filters'.

set_param([sys,'/','Filters'],...
		'position',[40,343,120,387])


%     Subsystem  'dsplib'.

new_system([sys,'/','dsplib'])
set_param([sys,'/','dsplib'],'Location',[15,243,212,738])
set_param([sys,'/','dsplib'],...
		'Mask Display','DSP\nDesign\nblocks',...
		'Mask Dialogue','eval(''if (exist(''''dsplib'''')<=0), disp(''''This block call DSPBLOCK toolbox. The toolbox is not in your path.'''');else,dsplib;end;'')')


%     Finished composite block 'dsplib'.

set_param([sys,'/','dsplib'],...
		'position',[40,418,120,462])

add_block('built-in/S-Function',[sys,'/','Complex filter'])
set_param([sys,'/','Complex filter'],...
		'function name','cmplxflt',...
		'parameters','num, den, ts',...
		'Mask Display','plot(0,0,100,100,x,y,u,v);Filter',...
		'Mask Type','Complex filter')
set_param([sys,'/','Complex filter'],...
		'Mask Dialogue','Vector expression for numerator and\ndenominator. Complex coefficients are in ascending power of 1/z.|Numerator:|Denominator:|Sample time:')
set_param([sys,'/','Complex filter'],...
		'Mask Translate','num=@1;den=@2;ts=@3;num=[real(num(:))'';imag(num(:))''];den=[real(den(:))'';imag(den(:))''];if max(abs(den(2,:))) <=0, den=den(1,:); end;if max(abs(num(2,:))) <=0, num=num(1,:); end;[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));[x,y]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/','Complex filter'],...
		'Mask Help','This block takes real or complex signal input and outputs complex signal. The numerator can be a real or a complex vector with the coeficient ordered in ascending power of 1/z. Same for the denominator.')
set_param([sys,'/','Complex filter'],...
		'Mask Entries','[1 2 3 4]+sqrt(-1)*[5 6 7 8]\/[8 7 6 5]+sqrt(-1)*[4 3 2 1]\/.1\/',...
		'position',[45,268,120,312])


%     Subsystem  ['Raised cosine',13,'filter demo4'].

new_system([sys,'/',['Raised cosine',13,'filter demo4']])
set_param([sys,'/',['Raised cosine',13,'filter demo4']],'Location',[175,552,335,697])
set_param([sys,'/',['Raised cosine',13,'filter demo4']],...
		'Mask Display','Complex filter\ndemo',...
		'Mask Dialogue','eval(''tcmplxfl'')')


%     Finished composite block ['Raised cosine',13,'filter demo4'].

set_param([sys,'/',['Raised cosine',13,'filter demo4']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[185,268,265,312])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
