function [ret,x0,str,ts,xts]=com_frmt(t,x,u,flag);
%COM_FRMT	is the M-file description of the SIMULINK system named COM_FRMT.
%	The block-diagram can be displayed by typing: COM_FRMT.
%
%	SYS=COM_FRMT(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_FRMT to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_FRMT with a FLAG of zero:
%	[SIZES]=COM_FRMT([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[58,65,461,519])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['A-law',13,'expander'].

new_system([sys,'/',['A-law',13,'expander']])
set_param([sys,'/',['A-law',13,'expander']],'Location',[22,127,673,410])

add_block('built-in/Constant',[sys,'/',['A-law',13,'expander/Constant']])
set_param([sys,'/',['A-law',13,'expander/Constant']],...
		'ForeGround',3,...
		'Value','VdA',...
		'position',[250,185,295,205])

add_block('built-in/S-Function',[sys,'/',['A-law',13,'expander/Array',13,'function']])
set_param([sys,'/',['A-law',13,'expander/Array',13,'function']],...
		'ForeGround',2,...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['A-law',13,'expander/Array',13,'function']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['A-law',13,'expander/Array',13,'function']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''exp''\/',...
		'position',[305,136,350,164])

add_block('built-in/Sum',[sys,'/',['A-law',13,'expander/Sum']])
set_param([sys,'/',['A-law',13,'expander/Sum']],...
		'BackGround',5,...
		'inputs','+-',...
		'position',[260,140,280,160])

add_block('built-in/Constant',[sys,'/',['A-law',13,'expander/Constant4']])
set_param([sys,'/',['A-law',13,'expander/Constant4']],...
		'ForeGround',3,...
		'position',[175,180,200,200])

add_block('built-in/Inport',[sys,'/',['A-law',13,'expander/Inport']])
set_param([sys,'/',['A-law',13,'expander/Inport']],...
		'position',[30,70,50,90])

add_block('built-in/Abs',[sys,'/',['A-law',13,'expander/Abs']])
set_param([sys,'/',['A-law',13,'expander/Abs']],...
		'position',[105,68,135,92])

add_block('built-in/Outport',[sys,'/',['A-law',13,'expander/out_1']])
set_param([sys,'/',['A-law',13,'expander/out_1']],...
		'position',[570,105,590,125])

add_block('built-in/Product',[sys,'/',['A-law',13,'expander/Product1']])
set_param([sys,'/',['A-law',13,'expander/Product1']],...
		'BackGround',7,...
		'position',[510,103,535,127])

add_block('built-in/Relational Operator',[sys,'/',['A-law',13,'expander/Relational',13,'Operator']])
set_param([sys,'/',['A-law',13,'expander/Relational',13,'Operator']],...
		'BackGround',5,...
		'Operator','<=',...
		'position',[330,73,360,102])

add_block('built-in/Constant',[sys,'/',['A-law',13,'expander/Constant1']])
set_param([sys,'/',['A-law',13,'expander/Constant1']],...
		'ForeGround',3,...
		'Value','VdlnA1',...
		'position',[200,84,250,106])

add_block('built-in/Switch',[sys,'/',['A-law',13,'expander/Switch']])
set_param([sys,'/',['A-law',13,'expander/Switch']],...
		'Threshold','.2',...
		'position',[445,74,470,106])

add_block('built-in/Constant',[sys,'/',['A-law',13,'expander/Constant3']])
set_param([sys,'/',['A-law',13,'expander/Constant3']],...
		'ForeGround',3,...
		'Value','lnA1dA',...
		'position',[80,27,125,53])

add_block('built-in/Product',[sys,'/',['A-law',13,'expander/Product2']])
set_param([sys,'/',['A-law',13,'expander/Product2']],...
		'BackGround',7,...
		'position',[265,33,295,57])

add_block('built-in/S-Function',[sys,'/',['A-law',13,'expander/Array',13,'function1']])
set_param([sys,'/',['A-law',13,'expander/Array',13,'function1']],...
		'ForeGround',2,...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['A-law',13,'expander/Array',13,'function1']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['A-law',13,'expander/Array',13,'function1']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sgn''\/',...
		'position',[115,206,160,234])

add_block('built-in/Product',[sys,'/',['A-law',13,'expander/Product']])
set_param([sys,'/',['A-law',13,'expander/Product']],...
		'BackGround',7,...
		'position',[380,143,410,167])

add_block('built-in/Constant',[sys,'/',['A-law',13,'expander/Constant2']])
set_param([sys,'/',['A-law',13,'expander/Constant2']],...
		'ForeGround',3,...
		'Value','lnA1dV',...
		'position',[95,140,145,160])

add_block('built-in/Product',[sys,'/',['A-law',13,'expander/Product3']])
set_param([sys,'/',['A-law',13,'expander/Product3']],...
		'BackGround',7,...
		'position',[185,133,215,157])
add_line([sys,'/',['A-law',13,'expander']],[355,150;375,150])
add_line([sys,'/',['A-law',13,'expander']],[285,150;300,150])
add_line([sys,'/',['A-law',13,'expander']],[220,145;255,145])
add_line([sys,'/',['A-law',13,'expander']],[55,80;100,80])
add_line([sys,'/',['A-law',13,'expander']],[540,115;565,115])
add_line([sys,'/',['A-law',13,'expander']],[70,80;70,220;110,220])
add_line([sys,'/',['A-law',13,'expander']],[165,220;480,220;480,120;505,120])
add_line([sys,'/',['A-law',13,'expander']],[475,90;485,90;485,110;505,110])
add_line([sys,'/',['A-law',13,'expander']],[140,80;325,80])
add_line([sys,'/',['A-law',13,'expander']],[255,95;325,95])
add_line([sys,'/',['A-law',13,'expander']],[365,90;440,90])
add_line([sys,'/',['A-law',13,'expander']],[160,80;160,50;260,50])
add_line([sys,'/',['A-law',13,'expander']],[300,45;400,45;400,80;440,80])
add_line([sys,'/',['A-law',13,'expander']],[130,40;260,40])
add_line([sys,'/',['A-law',13,'expander']],[150,150;180,150])
add_line([sys,'/',['A-law',13,'expander']],[160,80;160,140;180,140])
add_line([sys,'/',['A-law',13,'expander']],[205,190;235,190;235,155;255,155])
add_line([sys,'/',['A-law',13,'expander']],[300,195;365,195;375,160])
add_line([sys,'/',['A-law',13,'expander']],[415,155;420,155;420,100;440,100])
set_param([sys,'/',['A-law',13,'expander']],...
		'Mask Display','A-law\nexpander',...
		'Mask Type','A-law expander',...
		'Mask Dialogue','Inverse computation of A-law compressor.|A value:|Signal peak magnitude:')
set_param([sys,'/',['A-law',13,'expander']],...
		'Mask Translate','A=@1;V=@2;lnA1=log(A)+1;VdlnA1=V/lnA1;lnA1dA=lnA1/A;lnA1dV=lnA1/V;VdA=V/A;')
set_param([sys,'/',['A-law',13,'expander']],...
		'Mask Help','This block reverses the computation with A-law compressor. The prevailing value for A is A=87.6.',...
		'Mask Entries','87.6\/1\/')


%     Finished composite block ['A-law',13,'expander'].

set_param([sys,'/',['A-law',13,'expander']],...
		'position',[165,283,245,327])


%     Subsystem  ['mu-law',13,'expander'].

new_system([sys,'/',['mu-law',13,'expander']])
set_param([sys,'/',['mu-law',13,'expander']],'Location',[29,427,472,583])

add_block('built-in/Product',[sys,'/',['mu-law',13,'expander/Product']])
set_param([sys,'/',['mu-law',13,'expander/Product']],...
		'position',[130,53,160,77])

add_block('built-in/Constant',[sys,'/',['mu-law',13,'expander/Constant1']])
set_param([sys,'/',['mu-law',13,'expander/Constant1']],...
		'Value','ln1mdV',...
		'position',[30,5,80,25])

add_block('built-in/Inport',[sys,'/',['mu-law',13,'expander/Inport']])
set_param([sys,'/',['mu-law',13,'expander/Inport']],...
		'position',[10,60,30,80])

add_block('built-in/Abs',[sys,'/',['mu-law',13,'expander/Abs']])
set_param([sys,'/',['mu-law',13,'expander/Abs']],...
		'position',[65,58,95,82])

add_block('built-in/S-Function',[sys,'/',['mu-law',13,'expander/Array',13,'function1']])
set_param([sys,'/',['mu-law',13,'expander/Array',13,'function1']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['mu-law',13,'expander/Array',13,'function1']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['mu-law',13,'expander/Array',13,'function1']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''exp''\/',...
		'position',[190,51,235,79])

add_block('built-in/Sum',[sys,'/',['mu-law',13,'expander/Sum']])
set_param([sys,'/',['mu-law',13,'expander/Sum']],...
		'inputs','-+',...
		'position',[275,50,295,70])

add_block('built-in/Constant',[sys,'/',['mu-law',13,'expander/Constant3']])
set_param([sys,'/',['mu-law',13,'expander/Constant3']],...
		'position',[205,10,225,30])

add_block('built-in/S-Function',[sys,'/',['mu-law',13,'expander/Array',13,'function2']])
set_param([sys,'/',['mu-law',13,'expander/Array',13,'function2']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['mu-law',13,'expander/Array',13,'function2']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['mu-law',13,'expander/Array',13,'function2']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sgn''\/',...
		'position',[260,96,305,124])

add_block('built-in/Constant',[sys,'/',['mu-law',13,'expander/Constant2']])
set_param([sys,'/',['mu-law',13,'expander/Constant2']],...
		'Value','Vmu',...
		'position',[265,10,315,30])

add_block('built-in/Product',[sys,'/',['mu-law',13,'expander/Product1']])
set_param([sys,'/',['mu-law',13,'expander/Product1']],...
		'inputs','3',...
		'position',[360,45,385,75])

add_block('built-in/Outport',[sys,'/',['mu-law',13,'expander/out_1']])
set_param([sys,'/',['mu-law',13,'expander/out_1']],...
		'position',[410,50,430,70])
add_line([sys,'/',['mu-law',13,'expander']],[85,15;105,15;105,60;125,60])
add_line([sys,'/',['mu-law',13,'expander']],[100,70;125,70])
add_line([sys,'/',['mu-law',13,'expander']],[165,65;185,65])
add_line([sys,'/',['mu-law',13,'expander']],[320,20;330,20;330,50;355,50])
add_line([sys,'/',['mu-law',13,'expander']],[35,70;60,70])
add_line([sys,'/',['mu-law',13,'expander']],[45,70;45,110;255,110])
add_line([sys,'/',['mu-law',13,'expander']],[310,110;325,110;325,70;355,70])
add_line([sys,'/',['mu-law',13,'expander']],[390,60;405,60])
add_line([sys,'/',['mu-law',13,'expander']],[240,65;270,65])
add_line([sys,'/',['mu-law',13,'expander']],[300,60;355,60])
add_line([sys,'/',['mu-law',13,'expander']],[230,20;250,20;250,55;270,55])
set_param([sys,'/',['mu-law',13,'expander']],...
		'Mask Display','mu-law\nexpander',...
		'Mask Type','mu-law expander',...
		'Mask Dialogue','Inverse computation of mu-law compressor.|mu value:|Signal peak magnitude:')
set_param([sys,'/',['mu-law',13,'expander']],...
		'Mask Translate','mu=@1;V=@2;Vmu=V/mu;ln1mdV=log(1+mu)/V;',...
		'Mask Help','This block reverses the computation with mu-law compressor. The prevailing value for mu is mu=255.')
set_param([sys,'/',['mu-law',13,'expander']],...
		'Mask Entries','255\/1\/')


%     Finished composite block ['mu-law',13,'expander'].

set_param([sys,'/',['mu-law',13,'expander']],...
		'position',[165,208,245,252])


%     Subsystem  ['mu-law',13,'compressor'].

new_system([sys,'/',['mu-law',13,'compressor']])
set_param([sys,'/',['mu-law',13,'compressor']],'Location',[30,201,488,356])

add_block('built-in/Sum',[sys,'/',['mu-law',13,'compressor/Sum']])
set_param([sys,'/',['mu-law',13,'compressor/Sum']],...
		'position',[210,50,230,70])

add_block('built-in/Product',[sys,'/',['mu-law',13,'compressor/Product']])
set_param([sys,'/',['mu-law',13,'compressor/Product']],...
		'position',[145,53,175,77])

add_block('built-in/Abs',[sys,'/',['mu-law',13,'compressor/Abs']])
set_param([sys,'/',['mu-law',13,'compressor/Abs']],...
		'position',[75,58,105,82])

add_block('built-in/Constant',[sys,'/',['mu-law',13,'compressor/Constant']])
set_param([sys,'/',['mu-law',13,'compressor/Constant']],...
		'Value','mudV',...
		'position',[35,10,80,30])

add_block('built-in/Constant',[sys,'/',['mu-law',13,'compressor/Constant1']])
set_param([sys,'/',['mu-law',13,'compressor/Constant1']],...
		'position',[140,10,160,30])

add_block('built-in/S-Function',[sys,'/',['mu-law',13,'compressor/Array',13,'function']])
set_param([sys,'/',['mu-law',13,'compressor/Array',13,'function']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['mu-law',13,'compressor/Array',13,'function']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['mu-law',13,'compressor/Array',13,'function']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''ln''\/',...
		'position',[255,46,300,74])

add_block('built-in/Inport',[sys,'/',['mu-law',13,'compressor/Inport']])
set_param([sys,'/',['mu-law',13,'compressor/Inport']],...
		'position',[15,60,35,80])

add_block('built-in/Constant',[sys,'/',['mu-law',13,'compressor/Constant2']])
set_param([sys,'/',['mu-law',13,'compressor/Constant2']],...
		'Value','Vln1mu',...
		'position',[250,5,300,25])

add_block('built-in/S-Function',[sys,'/',['mu-law',13,'compressor/Array',13,'function1']])
set_param([sys,'/',['mu-law',13,'compressor/Array',13,'function1']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['mu-law',13,'compressor/Array',13,'function1']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['mu-law',13,'compressor/Array',13,'function1']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sgn''\/',...
		'position',[175,96,220,124])

add_block('built-in/Product',[sys,'/',['mu-law',13,'compressor/Product1']])
set_param([sys,'/',['mu-law',13,'compressor/Product1']],...
		'inputs','3',...
		'position',[360,45,385,75])

add_block('built-in/Outport',[sys,'/',['mu-law',13,'compressor/out_1']])
set_param([sys,'/',['mu-law',13,'compressor/out_1']],...
		'position',[420,50,440,70])
add_line([sys,'/',['mu-law',13,'compressor']],[110,70;140,70])
add_line([sys,'/',['mu-law',13,'compressor']],[85,20;115,20;115,60;140,60])
add_line([sys,'/',['mu-law',13,'compressor']],[180,65;205,65])
add_line([sys,'/',['mu-law',13,'compressor']],[165,20;185,20;185,55;205,55])
add_line([sys,'/',['mu-law',13,'compressor']],[235,60;250,60])
add_line([sys,'/',['mu-law',13,'compressor']],[40,70;70,70])
add_line([sys,'/',['mu-law',13,'compressor']],[50,70;50,110;170,110])
add_line([sys,'/',['mu-law',13,'compressor']],[305,60;355,60])
add_line([sys,'/',['mu-law',13,'compressor']],[225,110;325,110;325,70;355,70])
add_line([sys,'/',['mu-law',13,'compressor']],[305,15;325,15;325,50;355,50])
add_line([sys,'/',['mu-law',13,'compressor']],[390,60;415,60])
set_param([sys,'/',['mu-law',13,'compressor']],...
		'Mask Display','mu-law\ncompressor',...
		'Mask Type','mu-law compressor')
set_param([sys,'/',['mu-law',13,'compressor']],...
		'Mask Dialogue','Compress the input signal using mu-law\ncompressor. The mu-law compressor\nuses logarithm computation.|mu value:|Peak signal magnitude:')
set_param([sys,'/',['mu-law',13,'compressor']],...
		'Mask Translate','mu=@1;V=@2;mudV=mu/V;Vln1mu=V/log(1+mu);')
set_param([sys,'/',['mu-law',13,'compressor']],...
		'Mask Help','This block processes a vector signal. The output has the same length as the input signal. The prevailing value is mu=255.',...
		'Mask Entries','255\/1\/')


%     Finished composite block ['mu-law',13,'compressor'].

set_param([sys,'/',['mu-law',13,'compressor']],...
		'position',[35,208,115,252])


%     Subsystem  ['Sampled',13,'quantizer encode'].

new_system([sys,'/',['Sampled',13,'quantizer encode']])
set_param([sys,'/',['Sampled',13,'quantizer encode']],'Location',[37,120,369,253])

add_block('built-in/Outport',[sys,'/',['Sampled',13,'quantizer encode/out_3']])
set_param([sys,'/',['Sampled',13,'quantizer encode/out_3']],...
		'Port','3',...
		'position',[255,85,275,105])

add_block('built-in/Outport',[sys,'/',['Sampled',13,'quantizer encode/out_2']])
set_param([sys,'/',['Sampled',13,'quantizer encode/out_2']],...
		'Port','2',...
		'position',[290,55,310,75])

add_block('built-in/Outport',[sys,'/',['Sampled',13,'quantizer encode/out_1']])
set_param([sys,'/',['Sampled',13,'quantizer encode/out_1']],...
		'position',[260,20,280,40])

add_block('built-in/Inport',[sys,'/',['Sampled',13,'quantizer encode/in_1']])
set_param([sys,'/',['Sampled',13,'quantizer encode/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Demux',[sys,'/',['Sampled',13,'quantizer encode/Demux']])
set_param([sys,'/',['Sampled',13,'quantizer encode/Demux']],...
		'outputs','[n n n]',...
		'position',[175,47,215,83])

add_block('built-in/S-Function',[sys,'/',['Sampled',13,'quantizer encode/S-function']])
set_param([sys,'/',['Sampled',13,'quantizer encode/S-function']],...
		'function name','simquans',...
		'parameters','n, partition, codebook,sample_time',...
		'position',[80,55,135,75])
add_line([sys,'/',['Sampled',13,'quantizer encode']],[220,75;235,75;235,95;250,95])
add_line([sys,'/',['Sampled',13,'quantizer encode']],[220,65;285,65])
add_line([sys,'/',['Sampled',13,'quantizer encode']],[220,55;235,55;235,30;255,30])
add_line([sys,'/',['Sampled',13,'quantizer encode']],[140,65;170,65])
add_line([sys,'/',['Sampled',13,'quantizer encode']],[40,65;75,65])
set_param([sys,'/',['Sampled',13,'quantizer encode']],...
		'Mask Display','Scalar\nquantizer',...
		'Mask Type','Scalar quantization encode')
set_param([sys,'/',['Sampled',13,'quantizer encode']],...
		'Mask Dialogue','Quantize an analog signal to (1)digital\nsignal, (2)quantization value, and (3)distor-\ntion at every sample time point.|Quantization partition:|Quantization codebook:|Input signal vector length:|Sample time (sec):')
set_param([sys,'/',['Sampled',13,'quantizer encode']],...
		'Mask Translate','partition=@1;codebook=@2;n=@3;sample_time=@4;')
set_param([sys,'/',['Sampled',13,'quantizer encode']],...
		'Mask Help','This block converts the input analog signal to digital signal (1st outport) with the quantized value (2nd outport), and distortion (3rd outport) at every sample point. The input signa can be a vector. When the sample time is a two-elements vector, the second element is the offset value. The length of the partition is one less than the length of codebook. Use LLOYDS to optimize the partition and codebook.')
set_param([sys,'/',['Sampled',13,'quantizer encode']],...
		'Mask Entries','[-.75 -.25 .25 .75]\/[-.825 -.5 0 .5 .825]\/2\/.1\/')


%     Finished composite block ['Sampled',13,'quantizer encode'].

set_param([sys,'/',['Sampled',13,'quantizer encode']],...
		'position',[35,58,115,102])


%     Subsystem  ['A-law',13,'compressor'].

new_system([sys,'/',['A-law',13,'compressor']])
set_param([sys,'/',['A-law',13,'compressor']],'Location',[24,465,668,718])

add_block('built-in/Product',[sys,'/',['A-law',13,'compressor/Product3']])
set_param([sys,'/',['A-law',13,'compressor/Product3']],...
		'BackGround',7,...
		'position',[195,118,225,142])

add_block('built-in/S-Function',[sys,'/',['A-law',13,'compressor/Array',13,'function']])
set_param([sys,'/',['A-law',13,'compressor/Array',13,'function']],...
		'ForeGround',2,...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['A-law',13,'compressor/Array',13,'function']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['A-law',13,'compressor/Array',13,'function']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''ln''\/',...
		'position',[255,116,300,144])

add_block('built-in/Sum',[sys,'/',['A-law',13,'compressor/Sum']])
set_param([sys,'/',['A-law',13,'compressor/Sum']],...
		'BackGround',5,...
		'position',[330,125,350,145])

add_block('built-in/Constant',[sys,'/',['A-law',13,'compressor/Constant2']])
set_param([sys,'/',['A-law',13,'compressor/Constant2']],...
		'ForeGround',3,...
		'Value','AdV',...
		'position',[105,125,155,145])

add_block('built-in/Constant',[sys,'/',['A-law',13,'compressor/Constant4']])
set_param([sys,'/',['A-law',13,'compressor/Constant4']],...
		'ForeGround',3,...
		'position',[220,165,245,185])

add_block('built-in/Product',[sys,'/',['A-law',13,'compressor/Product']])
set_param([sys,'/',['A-law',13,'compressor/Product']],...
		'BackGround',7,...
		'position',[390,128,420,152])

add_block('built-in/Constant',[sys,'/',['A-law',13,'compressor/Constant']])
set_param([sys,'/',['A-law',13,'compressor/Constant']],...
		'ForeGround',3,...
		'Value','VdlnA1',...
		'position',[320,165,365,185])

add_block('built-in/S-Function',[sys,'/',['A-law',13,'compressor/Array',13,'function1']])
set_param([sys,'/',['A-law',13,'compressor/Array',13,'function1']],...
		'ForeGround',2,...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['A-law',13,'compressor/Array',13,'function1']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['A-law',13,'compressor/Array',13,'function1']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sgn''\/',...
		'position',[125,191,170,219])

add_block('built-in/Product',[sys,'/',['A-law',13,'compressor/Product2']])
set_param([sys,'/',['A-law',13,'compressor/Product2']],...
		'BackGround',7,...
		'position',[275,18,305,42])

add_block('built-in/Constant',[sys,'/',['A-law',13,'compressor/Constant3']])
set_param([sys,'/',['A-law',13,'compressor/Constant3']],...
		'ForeGround',3,...
		'Value','AdlnA1',...
		'position',[90,12,135,38])

add_block('built-in/Switch',[sys,'/',['A-law',13,'compressor/Switch']])
set_param([sys,'/',['A-law',13,'compressor/Switch']],...
		'Threshold','.2',...
		'position',[455,59,480,91])

add_block('built-in/Constant',[sys,'/',['A-law',13,'compressor/Constant1']])
set_param([sys,'/',['A-law',13,'compressor/Constant1']],...
		'ForeGround',3,...
		'Value','VdA',...
		'position',[230,70,260,90])

add_block('built-in/Relational Operator',[sys,'/',['A-law',13,'compressor/Relational',13,'Operator']])
set_param([sys,'/',['A-law',13,'compressor/Relational',13,'Operator']],...
		'BackGround',5,...
		'Operator','<=',...
		'position',[340,58,370,87])

add_block('built-in/Product',[sys,'/',['A-law',13,'compressor/Product1']])
set_param([sys,'/',['A-law',13,'compressor/Product1']],...
		'BackGround',7,...
		'position',[520,88,545,112])

add_block('built-in/Outport',[sys,'/',['A-law',13,'compressor/out_1']])
set_param([sys,'/',['A-law',13,'compressor/out_1']],...
		'position',[580,90,600,110])

add_block('built-in/Abs',[sys,'/',['A-law',13,'compressor/Abs']])
set_param([sys,'/',['A-law',13,'compressor/Abs']],...
		'position',[115,53,145,77])

add_block('built-in/Inport',[sys,'/',['A-law',13,'compressor/Inport']])
set_param([sys,'/',['A-law',13,'compressor/Inport']],...
		'position',[40,55,60,75])
add_line([sys,'/',['A-law',13,'compressor']],[425,140;430,140;430,85;450,85])
add_line([sys,'/',['A-law',13,'compressor']],[355,135;385,135])
add_line([sys,'/',['A-law',13,'compressor']],[370,175;375,175;385,145])
add_line([sys,'/',['A-law',13,'compressor']],[250,175;305,175;305,140;325,140])
add_line([sys,'/',['A-law',13,'compressor']],[305,130;325,130])
add_line([sys,'/',['A-law',13,'compressor']],[230,130;250,130])
add_line([sys,'/',['A-law',13,'compressor']],[150,65;335,65])
add_line([sys,'/',['A-law',13,'compressor']],[170,65;170,35;270,35])
add_line([sys,'/',['A-law',13,'compressor']],[170,65;170,125;190,125])
add_line([sys,'/',['A-law',13,'compressor']],[160,135;190,135])
add_line([sys,'/',['A-law',13,'compressor']],[140,25;270,25])
add_line([sys,'/',['A-law',13,'compressor']],[310,30;410,30;410,65;450,65])
add_line([sys,'/',['A-law',13,'compressor']],[375,75;450,75])
add_line([sys,'/',['A-law',13,'compressor']],[265,80;335,80])
add_line([sys,'/',['A-law',13,'compressor']],[485,75;495,75;495,95;515,95])
add_line([sys,'/',['A-law',13,'compressor']],[175,205;490,205;490,105;515,105])
add_line([sys,'/',['A-law',13,'compressor']],[65,65;110,65])
add_line([sys,'/',['A-law',13,'compressor']],[80,65;80,205;120,205])
add_line([sys,'/',['A-law',13,'compressor']],[550,100;575,100])
set_param([sys,'/',['A-law',13,'compressor']],...
		'Mask Display','A-law\ncompressor',...
		'Mask Type','A-law compressor')
set_param([sys,'/',['A-law',13,'compressor']],...
		'Mask Dialogue','Compress the input signal using A-law\ncompressor. The A-law compressor\nuses logarithm computation.|A value:|Peak signal magnitude:')
set_param([sys,'/',['A-law',13,'compressor']],...
		'Mask Translate','A=@1;V=@2;lnA1=log(A)+1;AdlnA1=A/lnA1;VdlnA1=V/lnA1;VdA=V/A;AdV=A/V;')
set_param([sys,'/',['A-law',13,'compressor']],...
		'Mask Help','This block processes a vector signal. The output has the same length as the input signal. The prevailing value for A is A=87.6.',...
		'Mask Entries','87.6\/1\/')


%     Finished composite block ['A-law',13,'compressor'].

set_param([sys,'/',['A-law',13,'compressor']],...
		'position',[35,283,115,327])


%     Subsystem  ['Enabled',13,'quantizer encode'].

new_system([sys,'/',['Enabled',13,'quantizer encode']])
set_param([sys,'/',['Enabled',13,'quantizer encode']],'Location',[37,101,520,257])

add_block('built-in/Inport',[sys,'/',['Enabled',13,'quantizer encode/in_1']])
set_param([sys,'/',['Enabled',13,'quantizer encode/in_1']],...
		'position',[40,45,60,65])

add_block('built-in/Mux',[sys,'/',['Enabled',13,'quantizer encode/Mux']])
set_param([sys,'/',['Enabled',13,'quantizer encode/Mux']],...
		'inputs','[n 1]',...
		'position',[115,46,150,79])

add_block('built-in/Inport',[sys,'/',['Enabled',13,'quantizer encode/in_2']])
set_param([sys,'/',['Enabled',13,'quantizer encode/in_2']],...
		'Port','2',...
		'position',[40,105,60,125])

add_block('built-in/S-Function',[sys,'/',['Enabled',13,'quantizer encode/S-function']])
set_param([sys,'/',['Enabled',13,'quantizer encode/S-function']],...
		'function name','simquan',...
		'parameters','n, partition, codebook',...
		'position',[190,55,240,75])

add_block('built-in/Demux',[sys,'/',['Enabled',13,'quantizer encode/Demux']])
set_param([sys,'/',['Enabled',13,'quantizer encode/Demux']],...
		'outputs','[n n n]',...
		'position',[280,47,320,83])

add_block('built-in/Outport',[sys,'/',['Enabled',13,'quantizer encode/out_1']])
set_param([sys,'/',['Enabled',13,'quantizer encode/out_1']],...
		'position',[385,20,405,40])

add_block('built-in/Outport',[sys,'/',['Enabled',13,'quantizer encode/out_2']])
set_param([sys,'/',['Enabled',13,'quantizer encode/out_2']],...
		'Port','2',...
		'position',[420,55,440,75])

add_block('built-in/Outport',[sys,'/',['Enabled',13,'quantizer encode/out_3']])
set_param([sys,'/',['Enabled',13,'quantizer encode/out_3']],...
		'Port','3',...
		'position',[385,85,405,105])
add_line([sys,'/',['Enabled',13,'quantizer encode']],[65,55;110,55])
add_line([sys,'/',['Enabled',13,'quantizer encode']],[65,115;80,115;80,70;110,70])
add_line([sys,'/',['Enabled',13,'quantizer encode']],[155,65;185,65])
add_line([sys,'/',['Enabled',13,'quantizer encode']],[245,65;275,65])
add_line([sys,'/',['Enabled',13,'quantizer encode']],[325,55;340,55;340,30;380,30])
add_line([sys,'/',['Enabled',13,'quantizer encode']],[325,65;415,65])
add_line([sys,'/',['Enabled',13,'quantizer encode']],[325,75;340,75;340,95;380,95])
set_param([sys,'/',['Enabled',13,'quantizer encode']],...
		'Mask Display','plot(0,0,100,100,v,w);Quantizer',...
		'Mask Type','Scalar quantization encode')
set_param([sys,'/',['Enabled',13,'quantizer encode']],...
		'Mask Dialogue','Triggered by 2nd input signal, this block\nquantize an analog signal to (1)digital\nsignal, (2)quantization value, (3)distortion.|Quantization partition:|Quantization codebook:|Input signal vector length:')
set_param([sys,'/',['Enabled',13,'quantizer encode']],...
		'Mask Translate','partition=@1;codebook=@2;n=@3;[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Enabled',13,'quantizer encode']],...
		'Mask Help','This block quantizes the first inport signal into quantization index (1st outport), quantized value (2nd outport), and distortion (3rd outport). This block uses scalar quantization method. The input signal to the 1st inport can be a vector. The operation of this block is enabled by the non-zero signal from the second inport. When the block is not enabled, the block keeps the last output value.')
set_param([sys,'/',['Enabled',13,'quantizer encode']],...
		'Mask Entries','[-.75 -.25 .25 .75]\/[-.825 -.5 0 .5 .825]\/2\/')


%     Finished composite block ['Enabled',13,'quantizer encode'].

set_param([sys,'/',['Enabled',13,'quantizer encode']],...
		'position',[35,358,115,402])


%     Subsystem  ['Quantizer',13,'decode2'].

new_system([sys,'/',['Quantizer',13,'decode2']])
set_param([sys,'/',['Quantizer',13,'decode2']],'Location',[596,274,888,411])

add_block('built-in/Inport',[sys,'/',['Quantizer',13,'decode2/in_1']])
set_param([sys,'/',['Quantizer',13,'decode2/in_1']],...
		'position',[20,30,40,50])

add_block('built-in/Outport',[sys,'/',['Quantizer',13,'decode2/out_1']])
set_param([sys,'/',['Quantizer',13,'decode2/out_1']],...
		'position',[225,30,245,50])

add_block('built-in/S-Function',[sys,'/',['Quantizer',13,'decode2/Index lookup',13,'table']])
set_param([sys,'/',['Quantizer',13,'decode2/Index lookup',13,'table']],...
		'function name','indxtabl',...
		'parameters','codebook',...
		'Mask Display','Index\nLookup tb',...
		'Mask Type','No-intepret Lookup table')
set_param([sys,'/',['Quantizer',13,'decode2/Index lookup',13,'table']],...
		'Mask Dialogue','Output one of the values in the look-up table.|Codebook:',...
		'Mask Translate','codebook=@1;')
set_param([sys,'/',['Quantizer',13,'decode2/Index lookup',13,'table']],...
		'Mask Help','When codebook is a matrix, the block input can only be a scalar. The block output the row with the column index provided in the input. When codebook is a vector, the block output the same length as the input vector. The output is one of the values in codebook with the index provided by the input.')
set_param([sys,'/',['Quantizer',13,'decode2/Index lookup',13,'table']],...
		'Mask Entries','codebook\/',...
		'position',[105,19,165,61])
add_line([sys,'/',['Quantizer',13,'decode2']],[170,40;220,40])
add_line([sys,'/',['Quantizer',13,'decode2']],[45,40;100,40])
set_param([sys,'/',['Quantizer',13,'decode2']],...
		'Mask Display','Quantizer\ndecode',...
		'Mask Type','Scalar quantization decode')
set_param([sys,'/',['Quantizer',13,'decode2']],...
		'Mask Dialogue','Output the value in the given codebook\nbased on the input index value.|Quantization codebook:',...
		'Mask Translate','codebook=@1;')
set_param([sys,'/',['Quantizer',13,'decode2']],...
		'Mask Help','This block takes the quantized index as input and outputs the quantization value. The output vector size the is same as the input vector size. Inputs 0, 1, ..., N-1 lead to CK(1), CK(2), .. CK(N) output.')
set_param([sys,'/',['Quantizer',13,'decode2']],...
		'Mask Entries','[-.825 -.5 0, .5 .825]\/')


%     Finished composite block ['Quantizer',13,'decode2'].

set_param([sys,'/',['Quantizer',13,'decode2']],...
		'position',[170,358,250,402])

add_block('built-in/Note',[sys,'/','Source Coding//Decoding Library'])
set_param([sys,'/','Source Coding//Decoding Library'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[195,11,200,16])


%     Subsystem  ['Sampled',13,'quantizer demo'].

new_system([sys,'/',['Sampled',13,'quantizer demo']])
set_param([sys,'/',['Sampled',13,'quantizer demo']],'Location',[811,642,1004,748])
set_param([sys,'/',['Sampled',13,'quantizer demo']],...
		'Mask Display','Sampled\nquantizer\ndemo',...
		'Mask Dialogue','eval(''tstquans;'')')


%     Finished composite block ['Sampled',13,'quantizer demo'].

set_param([sys,'/',['Sampled',13,'quantizer demo']],...
		'orientation',2,...
		'BackGround',7,...
		'position',[295,58,375,102])


%     Subsystem  ['DPCM',13,'demo'].

new_system([sys,'/',['DPCM',13,'demo']])
set_param([sys,'/',['DPCM',13,'demo']],'Location',[811,642,1004,748])
set_param([sys,'/',['DPCM',13,'demo']],...
		'Mask Display','DPCM\ndemo',...
		'Mask Dialogue','eval(''x=sin([0:.1:40]);[p_trans,codebook,partition]=dpcmopt(x,1,8);tstdpcms;'')')


%     Finished composite block ['DPCM',13,'demo'].

set_param([sys,'/',['DPCM',13,'demo']],...
		'orientation',2,...
		'BackGround',7,...
		'position',[295,133,375,177])


%     Subsystem  ['DPCM',13,'decode'].

new_system([sys,'/',['DPCM',13,'decode']])
set_param([sys,'/',['DPCM',13,'decode']],'Location',[32,515,384,677])

add_block('built-in/Inport',[sys,'/',['DPCM',13,'decode/in_1']])
set_param([sys,'/',['DPCM',13,'decode/in_1']],...
		'position',[30,40,50,60])


%     Subsystem  ['DPCM',13,'decode/Quantizer',13,'decode'].

new_system([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']])
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],'Location',[596,274,888,411])

add_block('built-in/Inport',[sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/in_1']])
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/in_1']],...
		'position',[20,30,40,50])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/out_1']])
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/out_1']],...
		'position',[225,30,245,50])

add_block('built-in/S-Function',[sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/Index lookup',13,'table']])
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/Index lookup',13,'table']],...
		'function name','indxtabl',...
		'parameters','codebook',...
		'Mask Display','Index\nLookup tb',...
		'Mask Type','No-intepret Lookup table')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/Index lookup',13,'table']],...
		'Mask Dialogue','Output one of the values in the look-up table.|Codebook:',...
		'Mask Translate','codebook=@1;')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/Index lookup',13,'table']],...
		'Mask Help','When codebook is a matrix, the block input can only be a scalar. The block output the row with the column index provided in the input. When codebook is a vector, the block output the same length as the input vector. The output is one of the values in codebook with the index provided by the input.')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/Index lookup',13,'table']],...
		'Mask Entries','codebook\/',...
		'position',[105,19,165,61])
add_line([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],[170,40;220,40])
add_line([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],[45,40;100,40])
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],...
		'Mask Display','Quantizer\ndecode',...
		'Mask Type','Scalar quantization decode')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],...
		'Mask Dialogue','Output is one of the elements in codebook. Output vector length is the same as the input length.|Quantization codebook:',...
		'Mask Translate','codebook=@1;')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],...
		'Mask Help','This block takes the quantized index as input and returns the quantization value. The output vector size the the same as the input vector size. Input 0, 1, ..., N-1 leads to CK(1), CK(2), .. CK(N) ouptut.')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],...
		'Mask Entries','codebook\/')


%     Finished composite block ['DPCM',13,'decode/Quantizer',13,'decode'].

set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],...
		'position',[85,30,145,70])

add_block('built-in/Sum',[sys,'/',['DPCM',13,'decode/Sum1']])
set_param([sys,'/',['DPCM',13,'decode/Sum1']],...
		'position',[185,45,205,65])

add_block('built-in/Filter',[sys,'/',['DPCM',13,'decode/Filter']])
set_param([sys,'/',['DPCM',13,'decode/Filter']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','sample_time',...
		'position',[200,90,260,130])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'decode/out_1']])
set_param([sys,'/',['DPCM',13,'decode/out_1']],...
		'position',[315,45,335,65])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'decode/out_2']])
set_param([sys,'/',['DPCM',13,'decode/out_2']],...
		'Port','2',...
		'position',[235,10,255,30])
add_line([sys,'/',['DPCM',13,'decode']],[55,50;80,50])
add_line([sys,'/',['DPCM',13,'decode']],[195,110;165,110;165,60;180,60])
add_line([sys,'/',['DPCM',13,'decode']],[210,55;310,55])
add_line([sys,'/',['DPCM',13,'decode']],[285,55;285,110;265,110])
add_line([sys,'/',['DPCM',13,'decode']],[150,50;180,50])
add_line([sys,'/',['DPCM',13,'decode']],[160,50;160,20;230,20])
set_param([sys,'/',['DPCM',13,'decode']],...
		'Mask Display','DPCM\ndecode',...
		'Mask Type','DPCM decode')
set_param([sys,'/',['DPCM',13,'decode']],...
		'Mask Dialogue','Input the DPCM coded index. Output\nDPCM decodes to the 1st outport and\nquantization decode to the 2nd outport.|Predictor transfer function numerator:|Predictor transfer function denominator:|Quantization codebook:|Sample time (sec):')
set_param([sys,'/',['DPCM',13,'decode']],...
		'Mask Translate','num=@1;den=@2;codebook=@3;sample_time=@4;')
set_param([sys,'/',['DPCM',13,'decode']],...
		'Mask Help','This block recovers the source code using the DPCM decode method. The parameters in this block should match the parameters in the DPCM encoder.')
set_param([sys,'/',['DPCM',13,'decode']],...
		'Mask Entries','[0 .9963]\/1\/[-.0848 -.029 .0298 .0853]\/.1\/')


%     Finished composite block ['DPCM',13,'decode'].

set_param([sys,'/',['DPCM',13,'decode']],...
		'position',[165,133,245,177])


%     Subsystem  ['DPCM',13,'encode'].

new_system([sys,'/',['DPCM',13,'encode']])
set_param([sys,'/',['DPCM',13,'encode']],'Location',[469,413,916,648])

add_block('built-in/Inport',[sys,'/',['DPCM',13,'encode/in_1']])
set_param([sys,'/',['DPCM',13,'encode/in_1']],...
		'position',[40,50,60,70])

add_block('built-in/Sum',[sys,'/',['DPCM',13,'encode/Sum']])
set_param([sys,'/',['DPCM',13,'encode/Sum']],...
		'inputs','+-',...
		'position',[105,55,125,75])

add_block('built-in/Sum',[sys,'/',['DPCM',13,'encode/Sum1']])
set_param([sys,'/',['DPCM',13,'encode/Sum1']],...
		'position',[265,100,285,120])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'encode/out_1']])
set_param([sys,'/',['DPCM',13,'encode/out_1']],...
		'position',[295,10,315,30])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'encode/out_2']])
set_param([sys,'/',['DPCM',13,'encode/out_2']],...
		'Port','2',...
		'position',[295,55,315,75])

add_block('built-in/Filter',[sys,'/',['DPCM',13,'encode/Filter']])
set_param([sys,'/',['DPCM',13,'encode/Filter']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','sample_time',...
		'position',[150,120,210,160])


%     Subsystem  ['DPCM',13,'encode/Sampled',13,'quantizer enco'].

new_system([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],'Location',[37,120,369,253])

add_block('built-in/S-Function',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/S-function']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/S-function']],...
		'function name','simquans',...
		'parameters','n, partition, codebook,sample_time',...
		'position',[80,55,135,75])

add_block('built-in/Demux',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/Demux']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/Demux']],...
		'outputs','[n n n]',...
		'position',[175,47,215,83])

add_block('built-in/Inport',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/in_1']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_1']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_1']],...
		'position',[260,20,280,40])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_2']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_2']],...
		'Port','2',...
		'position',[290,55,310,75])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_3']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_3']],...
		'Port','3',...
		'position',[255,85,275,105])
add_line([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],[40,65;75,65])
add_line([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],[140,65;170,65])
add_line([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],[220,55;235,55;235,30;255,30])
add_line([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],[220,65;285,65])
add_line([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],[220,75;235,75;235,95;250,95])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'Mask Display','Scalar\nquantizer',...
		'Mask Type','Scalar quantization encode')
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'Mask Dialogue','Quantize an analog signal to finite digital\nindex (1st outport), quantization value (2nd outport), and distortion (3rd outport) at every sample time point.|Quantization partition:|Quantization codebook:|Input signal vector length:|Sample time (sec):')
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'Mask Translate','partition=@1;codebook=@2;n=@3;sample_time=@4;')
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'Mask Help','This block quantizes the input signal to quantization index (1st outport), quantized value (2nd outport), and distortion (3rd outport) at every sample point. The inptu signa can be a vector. When the sample time is a two elements vector, the second element is the offset value. The length of partition is one less than the length of codebook. Use LLOYDS to optimize the partition and codebook.')
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'Mask Entries','partition\/codebook\/1\/sample_time\/')


%     Finished composite block ['DPCM',13,'encode/Sampled',13,'quantizer enco'].

set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'position',[155,43,220,87])
add_line([sys,'/',['DPCM',13,'encode']],[65,60;100,60])
add_line([sys,'/',['DPCM',13,'encode']],[130,65;150,65])
add_line([sys,'/',['DPCM',13,'encode']],[290,110;300,110;300,140;215,140])
add_line([sys,'/',['DPCM',13,'encode']],[145,140;80,140;80,70;100,70])
add_line([sys,'/',['DPCM',13,'encode']],[80,115;260,115])
add_line([sys,'/',['DPCM',13,'encode']],[225,50;250,50;250,20;290,20])
add_line([sys,'/',['DPCM',13,'encode']],[225,65;250,65;260,105])
add_line([sys,'/',['DPCM',13,'encode']],[250,65;290,65])
set_param([sys,'/',['DPCM',13,'encode']],...
		'Mask Display','DPCM\nencode',...
		'Mask Type','DPCM encode')
set_param([sys,'/',['DPCM',13,'encode']],...
		'Mask Dialogue','Output the DPCM encoded index to the\n1st outport and the quantization\nrecovered value to the 2nd outport.|Predictor numerator:|Predictor denominator:|Quantization partition:|Quantization codebook:|Sample time (sec):')
set_param([sys,'/',['DPCM',13,'encode']],...
		'Mask Translate','num=@1;den=@2;partition=@3;codebook=@4;sample_time=@5;')
set_param([sys,'/',['DPCM',13,'encode']],...
		'Mask Help','The 1st outport outputs the index of the predictive error. The 2nd outport outputs the predictive error. Use the DPCMOPT function for the FIR filter training. A delta modulation is a special case with the numerator as [0,x], the denominator as 1 for the\npredictor.')
set_param([sys,'/',['DPCM',13,'encode']],...
		'Mask Entries','[0 .9963]\/1\/[-.0569 .0004 .0576]\/[-.0848 -.029 .0298 .0853]\/.1\/')


%     Finished composite block ['DPCM',13,'encode'].

set_param([sys,'/',['DPCM',13,'encode']],...
		'position',[35,133,115,177])


%     Subsystem  ['Triggered',13,'quantizer demo'].

new_system([sys,'/',['Triggered',13,'quantizer demo']])
set_param([sys,'/',['Triggered',13,'quantizer demo']],'Location',[811,642,1004,748])
set_param([sys,'/',['Triggered',13,'quantizer demo']],...
		'Mask Display','Triggered\nquantizer\ndemo',...
		'Mask Dialogue','eval(''tstquant;'')')


%     Finished composite block ['Triggered',13,'quantizer demo'].

set_param([sys,'/',['Triggered',13,'quantizer demo']],...
		'orientation',2,...
		'BackGround',7,...
		'position',[295,358,375,402])


%     Subsystem  ['Quantizer',13,'decode'].

new_system([sys,'/',['Quantizer',13,'decode']])
set_param([sys,'/',['Quantizer',13,'decode']],'Location',[596,274,888,411])

add_block('built-in/S-Function',[sys,'/',['Quantizer',13,'decode/Index lookup',13,'table']])
set_param([sys,'/',['Quantizer',13,'decode/Index lookup',13,'table']],...
		'function name','indxtabl',...
		'parameters','codebook',...
		'Mask Display','Index\nLookup tb',...
		'Mask Type','No-intepret Lookup table')
set_param([sys,'/',['Quantizer',13,'decode/Index lookup',13,'table']],...
		'Mask Dialogue','Output one of the values in the look-up table.|Codebook:',...
		'Mask Translate','codebook=@1;')
set_param([sys,'/',['Quantizer',13,'decode/Index lookup',13,'table']],...
		'Mask Help','When codebook is a matrix, the block input can only be a scalar. The block output the row with the column index provided in the input. When codebook is a vector, the block output the same length as the input vector. The output is one of the values in codebook with the index provided by the input.')
set_param([sys,'/',['Quantizer',13,'decode/Index lookup',13,'table']],...
		'Mask Entries','codebook\/',...
		'position',[105,19,165,61])

add_block('built-in/Outport',[sys,'/',['Quantizer',13,'decode/out_1']])
set_param([sys,'/',['Quantizer',13,'decode/out_1']],...
		'position',[225,30,245,50])

add_block('built-in/Inport',[sys,'/',['Quantizer',13,'decode/in_1']])
set_param([sys,'/',['Quantizer',13,'decode/in_1']],...
		'position',[20,30,40,50])
add_line([sys,'/',['Quantizer',13,'decode']],[45,40;100,40])
add_line([sys,'/',['Quantizer',13,'decode']],[170,40;220,40])
set_param([sys,'/',['Quantizer',13,'decode']],...
		'Mask Display','Quantizer\ndecode',...
		'Mask Type','Scalar quantization decode')
set_param([sys,'/',['Quantizer',13,'decode']],...
		'Mask Dialogue','Output the value in the given codebook\nbased on the input index value.|Quantization codebook:',...
		'Mask Translate','codebook=@1;')
set_param([sys,'/',['Quantizer',13,'decode']],...
		'Mask Help','This block takes the quantized index as input and outputs the quantization value. The output vector size is the same as the input vector size. Inputs 0, 1, ..., N-1 lead to CK(1), CK(2), .. CK(N) output.')
set_param([sys,'/',['Quantizer',13,'decode']],...
		'Mask Entries','[-.825 -.5 0, .5 .825]\/')


%     Finished composite block ['Quantizer',13,'decode'].

set_param([sys,'/',['Quantizer',13,'decode']],...
		'position',[165,58,245,102])
add_line(sys,[120,65;140,65;140,80;160,80])
add_line(sys,[120,145;140,145;140,155;160,155])
add_line(sys,[120,230;160,230])
add_line(sys,[120,305;160,305])
add_line(sys,[120,365;125,365;125,380;165,380])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
