function [ret,x0,str,ts,xts]=com_mlac(t,x,u,flag);
%COM_MLAC	is the M-file description of the SIMULINK system named COM_MLAC.
%	The block-diagram can be displayed by typing: COM_MLAC.
%
%	SYS=COM_MLAC(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_MLAC to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_MLAC with a FLAG of zero:
%	[SIZES]=COM_MLAC([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[59,54,516,417])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Digital-TDMA',13,'demux'].

new_system([sys,'/',['Digital-TDMA',13,'demux']])
set_param([sys,'/',['Digital-TDMA',13,'demux']],'Location',[7,777,413,924])

add_block('built-in/Zero-Order Hold',[sys,'/',['Digital-TDMA',13,'demux/Zero-Order',13,'Hold']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[255,14,290,46])


%     Subsystem  ['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Entries','td\/N\/0\/')


%     Finished composite block ['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'position',[35,86,100,124])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'demux/out_1']])
set_param([sys,'/',['Digital-TDMA',13,'demux/out_1']],...
		'position',[335,20,355,40])


%     Subsystem  ['Digital-TDMA',13,'demux/Register-shift'].

new_system([sys,'/',['Digital-TDMA',13,'demux/Register-shift']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/in_2']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/in_1']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/out_2']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/out_1']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/Mux']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/S-function']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/Demux']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[55,80;75,80])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'Mask Entries','[N:-1:1]\/.1\/')


%     Finished composite block ['Digital-TDMA',13,'demux/Register-shift'].

set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'position',[150,18,225,62])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'demux/in_1']])
set_param([sys,'/',['Digital-TDMA',13,'demux/in_1']],...
		'position',[60,20,80,40])
add_line([sys,'/',['Digital-TDMA',13,'demux']],[295,30;330,30])
add_line([sys,'/',['Digital-TDMA',13,'demux']],[230,30;250,30])
add_line([sys,'/',['Digital-TDMA',13,'demux']],[105,105;120,105;120,50;145,50])
add_line([sys,'/',['Digital-TDMA',13,'demux']],[85,30;145,30])
set_param([sys,'/',['Digital-TDMA',13,'demux']],...
		'Mask Display','D-TDMA\ndemux',...
		'Mask Type','Reverse digital TDMA')
set_param([sys,'/',['Digital-TDMA',13,'demux']],...
		'Mask Dialogue','Input a scalar digital signal. Output a vector of a down-sampled digital signal.|Output symbol sample time (sec):|Output vector length:',...
		'Mask Translate','td=@1;N=@2;')
set_param([sys,'/',['Digital-TDMA',13,'demux']],...
		'Mask Help','This block inputs a scalar signal and outputs a down-sampled vector signal. The output sample time is T_out and vector length is N_out. The sample time for the input signal is T_out/N_out. For the input signal, a T_out time period is partitioned into N_out sections evenly in the time domain. Each element in the output vector outputs one of the partitioned sections.')
set_param([sys,'/',['Digital-TDMA',13,'demux']],...
		'Mask Entries','.1\/3\/')


%     Finished composite block ['Digital-TDMA',13,'demux'].

set_param([sys,'/',['Digital-TDMA',13,'demux']],...
		'position',[190,43,270,87])


%     Subsystem  ['Digital-TDMA',13,'mux'].

new_system([sys,'/',['Digital-TDMA',13,'mux']])
set_param([sys,'/',['Digital-TDMA',13,'mux']],'Location',[7,588,411,722])


%     Subsystem  ['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Entries','td\/[1 N]\/[0 0]\/')


%     Finished composite block ['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'position',[35,66,100,104])

add_block('built-in/Demux',[sys,'/',['Digital-TDMA',13,'mux/Demux']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Demux']],...
		'outputs','2',...
		'position',[130,65,180,100])


%     Subsystem  ['Digital-TDMA',13,'mux/Triggered',13,'buffer down'].

new_system([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Entries','N\/0\/1\/.1\/0\/')


%     Finished composite block ['Digital-TDMA',13,'mux/Triggered',13,'buffer down'].

set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'position',[215,53,275,97])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'mux/out_1']])
set_param([sys,'/',['Digital-TDMA',13,'mux/out_1']],...
		'position',[310,55,330,75])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'mux/in_1']])
set_param([sys,'/',['Digital-TDMA',13,'mux/in_1']],...
		'position',[115,20,135,40])
add_line([sys,'/',['Digital-TDMA',13,'mux']],[140,30;190,30;190,60;210,60])
add_line([sys,'/',['Digital-TDMA',13,'mux']],[280,65;305,65])
add_line([sys,'/',['Digital-TDMA',13,'mux']],[105,85;125,85])
add_line([sys,'/',['Digital-TDMA',13,'mux']],[185,75;210,75])
add_line([sys,'/',['Digital-TDMA',13,'mux']],[185,90;210,90])
set_param([sys,'/',['Digital-TDMA',13,'mux']],...
		'Mask Display','D-TDMA\nmux',...
		'Mask Type','Digital TDMA')
set_param([sys,'/',['Digital-TDMA',13,'mux']],...
		'Mask Dialogue','Input a vector digital signal. Output a scalar up-sampled digital signal.|Input symbol sample time (sec):|Input vector length:',...
		'Mask Translate','td=@1;N=@2;')
set_param([sys,'/',['Digital-TDMA',13,'mux']],...
		'Mask Help','This block inputs a length N_in vector input signal with sample time T_in. The output of this block is a vector with sample time T_in/N_in. For the output signal, a T_in time period is partitioned into N_in even time length sections. Each section contains the value of one element of the input vector. This block takes all elements from the input vector at the start point of the sample time.')
set_param([sys,'/',['Digital-TDMA',13,'mux']],...
		'Mask Entries','.1\/3\/')


%     Finished composite block ['Digital-TDMA',13,'mux'].

set_param([sys,'/',['Digital-TDMA',13,'mux']],...
		'position',[35,43,115,87])

add_block('built-in/Note',[sys,'/','Multiple Access Library'])
set_param([sys,'/','Multiple Access Library'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[215,6,220,11])


%     Subsystem  'CDMA demo'.

new_system([sys,'/','CDMA demo'])
set_param([sys,'/','CDMA demo'],'Location',[175,552,335,697])
set_param([sys,'/','CDMA demo'],...
		'Mask Display','CDMA\ndemo',...
		'Mask Dialogue','eval(''F0=50;F2=80;F4=110;ts=.002;[num0,den0]=butter(2,F0/2*ts);[num4,den4]=butter(2,F4/2*ts);[num2,den2]=butter(2,F2/2*ts);tstcdma'')')


%     Finished composite block 'CDMA demo'.

set_param([sys,'/','CDMA demo'],...
		'BackGround',7,...
		'position',[325,293,405,337])


%     Subsystem  'FDMA demo'.

new_system([sys,'/','FDMA demo'])
set_param([sys,'/','FDMA demo'],'Location',[175,552,335,697])
set_param([sys,'/','FDMA demo'],...
		'Mask Display','FDMA\ndemo',...
		'Mask Dialogue','eval(''F0=50;F2=80;F4=110;ts=.002;[num0,den0]=butter(2,F0/2*ts);[num4,den4]=butter(2,F4/2*ts);[num2,den2]=butter(2,F2/2*ts);tstfdma'')')


%     Finished composite block 'FDMA demo'.

set_param([sys,'/','FDMA demo'],...
		'BackGround',7,...
		'position',[325,208,405,252])


%     Subsystem  ['Time-sharing',13,'demo'].

new_system([sys,'/',['Time-sharing',13,'demo']])
set_param([sys,'/',['Time-sharing',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Time-sharing',13,'demo']],...
		'Mask Display','Time-share\ndemo',...
		'Mask Dialogue','eval(''tsttdmaa'')')


%     Finished composite block ['Time-sharing',13,'demo'].

set_param([sys,'/',['Time-sharing',13,'demo']],...
		'BackGround',7,...
		'position',[325,118,405,162])


%     Subsystem  ['Time-sharing',13,'mux'].

new_system([sys,'/',['Time-sharing',13,'mux']])
set_param([sys,'/',['Time-sharing',13,'mux']],'Location',[387,83,767,247])

add_block('built-in/Inport',[sys,'/',['Time-sharing',13,'mux/in_1']])
set_param([sys,'/',['Time-sharing',13,'mux/in_1']],...
		'position',[65,20,85,40])


%     Subsystem  ['Time-sharing',13,'mux/Triggered time',13,'domain switch'].

new_system([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']])
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],'Location',[672,516,1052,680])

add_block('built-in/Inport',[sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch/in_1']])
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch/in_1']],...
		'position',[65,20,85,40])

add_block('built-in/Mux',[sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch/Mux']])
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Outport',[sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch/out_1']])
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Inport',[sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch/in_2']])
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/S-Function',[sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch/S-function']])
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch/S-function']],...
		'function name','stdmamux',...
		'parameters','sw,ke,in,tt',...
		'position',[205,60,275,90])
add_line([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],[90,30;120,30;120,65;140,65])
add_line([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],[85,85;140,85])
add_line([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],[180,75;200,75])
add_line([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],[280,75;315,75])
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],...
		'Mask Display','Vector\nredistributor',...
		'Mask Type','Triggered time domain switch')
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],...
		'Mask Dialogue','The rasing edge impulse from the 2nd inport triggers the output of this block by the distribution of the next row in the switch box variable.|Switch box:|Keeping value:|Initial value:|Trigger threshold:')
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],...
		'Mask Translate','sw=@1;ke=@2;in=@3;tt=@4;')
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],...
		'Mask Help','The column number of the switch box is the size of the output vector size, which is the size for vector keep_value and initial_value. The raising edge of the 2nd inport trigger the distribution pattern goes to the next row of the switch box.  When switch_box has value 0, the output keeps the last output value if keeping_value is greater than 0; the output is initial_value when the keep_value is less than 0.')
set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],...
		'Mask Entries','[1:N]''\/-1\/0\/.1\/')


%     Finished composite block ['Time-sharing',13,'mux/Triggered time',13,'domain switch'].

set_param([sys,'/',['Time-sharing',13,'mux/Triggered time',13,'domain switch']],...
		'position',[170,15,250,70])

add_block('built-in/Outport',[sys,'/',['Time-sharing',13,'mux/out_1']])
set_param([sys,'/',['Time-sharing',13,'mux/out_1']],...
		'position',[295,35,315,55])


%     Subsystem  ['Time-sharing',13,'mux/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Entries','td\/N\/0\/')


%     Finished composite block ['Time-sharing',13,'mux/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Time-sharing',13,'mux/Pulses deivide',13,'same sample time']],...
		'position',[55,76,120,114])
add_line([sys,'/',['Time-sharing',13,'mux']],[255,45;290,45])
add_line([sys,'/',['Time-sharing',13,'mux']],[125,95;140,95;140,55;165,55])
add_line([sys,'/',['Time-sharing',13,'mux']],[90,30;165,30])
set_param([sys,'/',['Time-sharing',13,'mux']],...
		'Mask Display','Time-share\nmux',...
		'Mask Type','Time-sharing multiplex')
set_param([sys,'/',['Time-sharing',13,'mux']],...
		'Mask Dialogue','This block partitions each transfer\nperiod into even length time slots. Each element of the input vector takes one\nslot in turn.|Transfer period (sec):|Input vector length:')
set_param([sys,'/',['Time-sharing',13,'mux']],...
		'Mask Translate','td=@1;N=@2;')
set_param([sys,'/',['Time-sharing',13,'mux']],...
		'Mask Help','This block outputs one element of the input vector in turn. The input for this block is a length N_in vector. The output for this block is a scalar. The transfer period T_out is partitioned into N_in slot. Each input element takes one partition in sequential order arranged by the position of the vector input. This block takes all elements in the input vector at the sampling time point.')
set_param([sys,'/',['Time-sharing',13,'mux']],...
		'Mask Entries','1\/3\/')


%     Finished composite block ['Time-sharing',13,'mux'].

set_param([sys,'/',['Time-sharing',13,'mux']],...
		'position',[35,118,115,162])


%     Subsystem  ['Time-sharing',13,'demux'].

new_system([sys,'/',['Time-sharing',13,'demux']])
set_param([sys,'/',['Time-sharing',13,'demux']],'Location',[11,84,349,247])

add_block('built-in/Inport',[sys,'/',['Time-sharing',13,'demux/in_1']])
set_param([sys,'/',['Time-sharing',13,'demux/in_1']],...
		'position',[60,20,80,40])


%     Subsystem  ['Time-sharing',13,'demux/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Entries','td\/N\/0\/')


%     Finished composite block ['Time-sharing',13,'demux/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Time-sharing',13,'demux/Pulses deivide',13,'same sample time']],...
		'position',[35,86,100,124])

add_block('built-in/Outport',[sys,'/',['Time-sharing',13,'demux/out_1']])
set_param([sys,'/',['Time-sharing',13,'demux/out_1']],...
		'position',[275,35,295,55])


%     Subsystem  ['Time-sharing',13,'demux/Triggered time',13,'domain switch'].

new_system([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']])
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],'Location',[672,516,1052,680])

add_block('built-in/S-Function',[sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch/S-function']])
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch/S-function']],...
		'function name','stdmamux',...
		'parameters','sw,ke,in,tt',...
		'position',[205,60,275,90])

add_block('built-in/Inport',[sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch/in_2']])
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/Outport',[sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch/out_1']])
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Mux',[sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch/Mux']])
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Inport',[sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch/in_1']])
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch/in_1']],...
		'position',[65,20,85,40])
add_line([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],[280,75;315,75])
add_line([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],[180,75;200,75])
add_line([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],[85,85;140,85])
add_line([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],[90,30;120,30;120,65;140,65])
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],...
		'Mask Display','Vector\nredistributor',...
		'Mask Type','Triggered time domain switch')
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],...
		'Mask Dialogue','The rasing edge impulse from the 2nd inport triggers the output of this block by the distribution of the next row in the switch box variable.|Switch box:|Keeping value:|Initial value:|Trigger threshold:')
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],...
		'Mask Translate','sw=@1;ke=@2;in=@3;tt=@4;')
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],...
		'Mask Help','The column number of the switch box is the size of the output vector size, which is the size for vector keep_value and initial_value. The raising edge of the 2nd inport trigger the distribution pattern goes to the next row of the switch box.  When switch_box has value 0, the output keeps the last output value if keeping_value is greater than 0; the output is initial_value when the keep_value is less than 0.')
set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],...
		'Mask Entries','eye(N)\/-ones(1,N)\/zeros(1,N)\/.1\/')


%     Finished composite block ['Time-sharing',13,'demux/Triggered time',13,'domain switch'].

set_param([sys,'/',['Time-sharing',13,'demux/Triggered time',13,'domain switch']],...
		'position',[150,15,230,70])
add_line([sys,'/',['Time-sharing',13,'demux']],[85,30;145,30])
add_line([sys,'/',['Time-sharing',13,'demux']],[105,105;120,105;120,55;145,55])
add_line([sys,'/',['Time-sharing',13,'demux']],[235,45;270,45])
set_param([sys,'/',['Time-sharing',13,'demux']],...
		'Mask Display','Time-share\ndemux',...
		'Mask Type','Time-sharing demultiplex')
set_param([sys,'/',['Time-sharing',13,'demux']],...
		'Mask Dialogue','This block partitions each transfer\nperiod into even length time slots. Each element of the output vector takes one\ntime slot to output the input in turn.|Transfer period (sec):|Input vector length:')
set_param([sys,'/',['Time-sharing',13,'demux']],...
		'Mask Translate','td=@1;N=@2;')
set_param([sys,'/',['Time-sharing',13,'demux']],...
		'Mask Help','This block inputs a scalar signal and outputs a length N_out vector. The transfer period T_in is partitioned into N_out slots. Each time slot input is placed into different elements of the output in the order arranged by the position of the vector input.')
set_param([sys,'/',['Time-sharing',13,'demux']],...
		'Mask Entries','1\/3\/')


%     Finished composite block ['Time-sharing',13,'demux'].

set_param([sys,'/',['Time-sharing',13,'demux']],...
		'position',[190,118,270,162])


%     Subsystem  ['Digital-TDMA',13,'demo'].

new_system([sys,'/',['Digital-TDMA',13,'demo']])
set_param([sys,'/',['Digital-TDMA',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Digital-TDMA',13,'demo']],...
		'Mask Display','D-TDMA\ndemo',...
		'Mask Dialogue','eval(''tsttdma'')')


%     Finished composite block ['Digital-TDMA',13,'demo'].

set_param([sys,'/',['Digital-TDMA',13,'demo']],...
		'BackGround',7,...
		'position',[325,43,405,87])


%     Subsystem  ['Triggered',13,'signal switch'].

new_system([sys,'/',['Triggered',13,'signal switch']])
set_param([sys,'/',['Triggered',13,'signal switch']],'Location',[672,516,1052,680])

add_block('built-in/S-Function',[sys,'/',['Triggered',13,'signal switch/S-function']])
set_param([sys,'/',['Triggered',13,'signal switch/S-function']],...
		'function name','stdmamux',...
		'parameters','sw,ke,in,tt',...
		'position',[205,60,275,90])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'signal switch/in_2']])
set_param([sys,'/',['Triggered',13,'signal switch/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/Outport',[sys,'/',['Triggered',13,'signal switch/out_1']])
set_param([sys,'/',['Triggered',13,'signal switch/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Mux',[sys,'/',['Triggered',13,'signal switch/Mux']])
set_param([sys,'/',['Triggered',13,'signal switch/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'signal switch/in_1']])
set_param([sys,'/',['Triggered',13,'signal switch/in_1']],...
		'position',[65,20,85,40])
add_line([sys,'/',['Triggered',13,'signal switch']],[280,75;315,75])
add_line([sys,'/',['Triggered',13,'signal switch']],[180,75;200,75])
add_line([sys,'/',['Triggered',13,'signal switch']],[85,85;140,85])
add_line([sys,'/',['Triggered',13,'signal switch']],[90,30;120,30;120,65;140,65])
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Display','plot(0,0,100,100,v,w);Vct re-arr',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Dialogue','The rising edge from the 2nd inport\ntriggers the block to output the input\nelement with the index given in the next row of the switch box.|Switch box (column number equals block output length):|Keeping value (flag 0 element in switch box):|Initial value (before the 1st trigger is detected):|Trigger threshold:')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Translate','sw=@1;ke=@2;in=@3;tt=@4;[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Help','When current switch box row is [i,j], the 1st and 2nd elements output the ith and jth input respectively. The switch_box column number must be same lengths as the output, keep_value, and init_value. The rising edge of the 2nd inport triggers the distribution pattern following the next row of the switch_box. With 0 element in switch_box, the output keeps the last output value with a >=0 keep_value; it equals init_val otherwise.')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Entries','[1 2 3;2 3 1;3 1 2]\/[-1 -1 -1]\/[0 0 0]\/.1\/')


%     Finished composite block ['Triggered',13,'signal switch'].

set_param([sys,'/',['Triggered',13,'signal switch']],...
		'position',[35,198,115,242])
add_line(sys,[120,65;185,65])
add_line(sys,[120,140;185,140])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
