function [ret,x0,str,ts,xts]=com_mocd(t,x,u,flag);
%COM_MOCD	is the M-file description of the SIMULINK system named COM_MOCD.
%	The block-diagram can be displayed by typing: COM_MOCD.
%
%	SYS=COM_MOCD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_MOCD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_MOCD with a FLAG of zero:
%	[SIZES]=COM_MOCD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[104,42,769,713])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','Passband Digital Modulation//Demodulation Map//Demap Library'])
set_param([sys,'/','Passband Digital Modulation//Demodulation Map//Demap Library'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[325,0,330,5])


%     Subsystem  ['QASK',13,'arbitrary-map'].

new_system([sys,'/',['QASK',13,'arbitrary-map']])
set_param([sys,'/',['QASK',13,'arbitrary-map']],'Location',[58,103,403,268])

add_block('built-in/Outport',[sys,'/',['QASK',13,'arbitrary-map/Imag']])
set_param([sys,'/',['QASK',13,'arbitrary-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])

add_block('built-in/Outport',[sys,'/',['QASK',13,'arbitrary-map/Real']])
set_param([sys,'/',['QASK',13,'arbitrary-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'arbitrary-map/imag part1']])
set_param([sys,'/',['QASK',13,'arbitrary-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'arbitrary-map/real part']])
set_param([sys,'/',['QASK',13,'arbitrary-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Inport',[sys,'/',['QASK',13,'arbitrary-map/in_1']])
set_param([sys,'/',['QASK',13,'arbitrary-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'arbitrary-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'arbitrary-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])
add_line([sys,'/',['QASK',13,'arbitrary-map']],[215,110;270,110])
add_line([sys,'/',['QASK',13,'arbitrary-map']],[220,30;270,30])
add_line([sys,'/',['QASK',13,'arbitrary-map']],[120,30;175,30])
add_line([sys,'/',['QASK',13,'arbitrary-map']],[145,30;145,110;170,110])
add_line([sys,'/',['QASK',13,'arbitrary-map']],[50,30;75,30])
set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'Mask Display','QASK\nA-map',...
		'Mask Type','QASK A-map')
set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'Mask Dialogue','QASK mapping for arbitrary defined\nmap. Assume input digit is K. 1st\noutport outputs in-phase(K+1). 2nd\noutport outputs quadrature(K+1).|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;ly=length(y1);x=[-10 1:ly-1;1:ly-1 10*ly]-.5;x=x(:);y1=y1(:)'';y1=[y1;y1];y1=y1(:);y2=y2(:)'';y2=[y2;y2];y2=y2(:);')
set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The input signal is in the range of [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'Mask Entries','real(exp(j*[0:M-1]/M*pi*2))\/imag(exp(j*[0:M-1]/M*pi*2))\/td\/')


%     Finished composite block ['QASK',13,'arbitrary-map'].

set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'position',[40,273,120,317])


%     Subsystem  ['QASK',13,'arbitrary-demap'].

new_system([sys,'/',['QASK',13,'arbitrary-demap']])
set_param([sys,'/',['QASK',13,'arbitrary-demap']],'Location',[45,449,594,684])

add_block('built-in/Constant',[sys,'/',['QASK',13,'arbitrary-demap/imag_pt']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])

add_block('built-in/Constant',[sys,'/',['QASK',13,'arbitrary-demap/real_pt']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Outport',[sys,'/',['QASK',13,'arbitrary-demap/out_1']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'arbitrary-demap/Minimum1']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Sum',[sys,'/',['QASK',13,'arbitrary-demap/Sum2']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/Product',[sys,'/',['QASK',13,'arbitrary-demap/Product1']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Product',[sys,'/',['QASK',13,'arbitrary-demap/Product']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Sum',[sys,'/',['QASK',13,'arbitrary-demap/Sum6']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Sum',[sys,'/',['QASK',13,'arbitrary-demap/Sum1']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Inport',[sys,'/',['QASK',13,'arbitrary-demap/imag']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Inport',[sys,'/',['QASK',13,'arbitrary-demap/real']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[480,95;490,95])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[395,95;410,95])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[160,130;225,130])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[160,45;225,45])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[70,130;115,130])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[70,45;115,45])
set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'Mask Entries','real(exp(j*[0:M-1]/M*pi*2))\/imag(exp(j*[0:M-1]/M*pi*2))\/td\/')


%     Finished composite block ['QASK',13,'arbitrary-demap'].

set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'position',[445,273,525,317])


%     Subsystem  ['QASK Mo//Dem',13,'demo1'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo1']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],...
		'Mask Display','QASK\nC-map\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(4,100/pi/2*ts);td=.2;M=128;tstps2cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo1'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[565,198,645,242])


%     Subsystem  ['QASK Mo//Dem',13,'demo2'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo2']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],...
		'Mask Display','QASK\nA-map\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(4,100/pi/2*ts);td=.2;M=32;tstps3cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo2'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[565,273,645,317])


%     Subsystem  ['FSK Mo//Dem',13,'demo'].

new_system([sys,'/',['FSK Mo//Dem',13,'demo']])
set_param([sys,'/',['FSK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['FSK Mo//Dem',13,'demo']],...
		'Mask Display','MFSK\nmap\ndemo',...
		'Mask Dialogue','eval(''ts=.01;td=.2;M=8;Fc=100/pi/2;tstfs2cd'')')


%     Finished composite block ['FSK Mo//Dem',13,'demo'].

set_param([sys,'/',['FSK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[565,348,645,392])


%     Subsystem  'MFSK map'.

new_system([sys,'/','MFSK map'])
set_param([sys,'/','MFSK map'],'Location',[90,420,407,543])

add_block('built-in/Inport',[sys,'/','MFSK map/in_1'])
set_param([sys,'/','MFSK map/in_1'],...
		'position',[45,45,65,65])

add_block('built-in/Gain',[sys,'/','MFSK map/Gain'])
set_param([sys,'/','MFSK map/Gain'],...
		'Gain','Ton',...
		'position',[175,38,225,72])

add_block('built-in/Outport',[sys,'/','MFSK map/out_1'])
set_param([sys,'/','MFSK map/out_1'],...
		'position',[260,45,280,65])

add_block('built-in/Zero-Order Hold',[sys,'/',['MFSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MFSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[105,39,140,71])
add_line([sys,'/','MFSK map'],[230,55;255,55])
add_line([sys,'/','MFSK map'],[70,55;100,55])
add_line([sys,'/','MFSK map'],[145,55;170,55])
set_param([sys,'/','MFSK map'],...
		'Mask Display','MFSK\nmap',...
		'Mask Type','MFSK map')
set_param([sys,'/','MFSK map'],...
		'Mask Dialogue','Map input digital signal to analog tone space for FM modulation. The tone space\nis the frequency distance between two \nconsective digit numbers.|Tone space (Hz):|Input symbol interval and offset (sec):')
set_param([sys,'/','MFSK map'],...
		'Mask Translate','Ton=@1;td=@2;')
set_param([sys,'/','MFSK map'],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the FM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. Tone space is the frequency separation between two consective digits for the input signal. After FM, the modulated signal has a frequency in the range of [Fc, Fc+B]. B is the bandwidth of the FSK, B=(M-1) * Tone_space.')
set_param([sys,'/','MFSK map'],...
		'Mask Entries','M/td/5\/td\/')


%     Finished composite block 'MFSK map'.

set_param([sys,'/','MFSK map'],...
		'position',[40,348,120,392])


%     Subsystem  ['Coh corr MFSK',13,'demod passband'].

new_system([sys,'/',['Coh corr MFSK',13,'demod passband']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband']],'Location',[210,425,800,670])

add_block('built-in/Outport',[sys,'/',['Coh corr MFSK',13,'demod passband/out_1']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/out_1']],...
		'position',[560,55,580,75])

add_block('built-in/Inport',[sys,'/',['Coh corr MFSK',13,'demod passband/in_1']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/in_1']],...
		'position',[365,45,385,65])

add_block('built-in/S-Function',[sys,'/',['Coh corr MFSK',13,'demod passband/Array sin']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Array sin']],...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[325,85,375,105])

add_block('built-in/Sum',[sys,'/',['Coh corr MFSK',13,'demod passband/Sum1']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Sum1']],...
		'inputs','+++',...
		'position',[265,75,290,115])

add_block('built-in/Product',[sys,'/',['Coh corr MFSK',13,'demod passband/Product']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Product']],...
		'position',[415,46,440,79])

add_block('built-in/S-Function',[sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int1']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int1']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int1']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int1']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int1']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int1']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[470,44,530,86])

add_block('built-in/S-Function',[sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[140,39,200,81])

add_block('built-in/Constant',[sys,'/',['Coh corr MFSK',13,'demod passband/Shift key']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Shift key']],...
		'Value','sft',...
		'position',[60,48,80,72])

add_block('built-in/Constant',[sys,'/',['Coh corr MFSK',13,'demod passband/Initial phase']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Initial phase']],...
		'Value','Ph',...
		'position',[80,113,100,137])

add_block('built-in/Zero-Order Hold',[sys,'/',['Coh corr MFSK',13,'demod passband/Zero-Order',13,'Hold']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[135,184,170,216])

add_block('built-in/Clock',[sys,'/',['Coh corr MFSK',13,'demod passband/Clock']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Clock']],...
		'position',[35,160,55,180])

add_block('built-in/Sum',[sys,'/',['Coh corr MFSK',13,'demod passband/Sum2']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Sum2']],...
		'inputs','+-',...
		'position',[205,160,230,195])

add_block('built-in/Gain',[sys,'/',['Coh corr MFSK',13,'demod passband/Gain']])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband/Gain']],...
		'Gain','Fc',...
		'position',[70,155,110,185])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[535,65;555,65])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[390,55;410,55])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[445,65;465,65])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[295,95;320,95])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[380,95;400,95;410,70])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[85,60;135,60])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[205,60;225,60;225,80;260,80])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[105,125;230,125;230,95;260,95])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[60,170;65,170])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[235,180;250,180;260,110])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[115,170;200,170])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[115,170;130,200])
add_line([sys,'/',['Coh corr MFSK',13,'demod passband']],[175,200;180,200;180,185;200,185])
set_param([sys,'/',['Coh corr MFSK',13,'demod passband']],...
		'Mask Display','Coh corr\nMFSK dm',...
		'Mask Type','Passband coherent MFSK correlation')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband']],...
		'Mask Dialogue','Compute MFSK correlation. Take MFSK\nmodulated signal. Output a vector of\ncorrelation result.|M-ary number (input in range [0, M-1]):|Tone space (Hz):|Symbol interval and offset (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband']],...
		'Mask Translate','pi2=2*pi;N=@1;Fc=@4*pi2;Ph=@5;Ton=@2;sft=[0:N-1]*Ton*pi2;td=@3;ts=@6;')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband']],...
		'Mask Help','This block calculates the coherent correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their frequency the same as that of FM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MFSK demodulation result is the index of the largest output, using the Min/max demap block. The computation is phase sensitive.')
set_param([sys,'/',['Coh corr MFSK',13,'demod passband']],...
		'Mask Entries','M\/M/td/5\/td\/Fc\/0\/ts\/')


%     Finished composite block ['Coh corr MFSK',13,'demod passband'].

set_param([sys,'/',['Coh corr MFSK',13,'demod passband']],...
		'position',[320,348,400,392])


%     Subsystem  ['Noncoh corr MFSK',13,'demod  passband'].

new_system([sys,'/',['Noncoh corr MFSK',13,'demod  passband']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],'Location',[10,2228368,850,2228643])

add_block('built-in/Outport',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/out_1']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/out_1']],...
		'position',[825,85,845,105])

add_block('built-in/Inport',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/in_1']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/in_1']],...
		'position',[490,75,510,95])

add_block('built-in/Sum',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Sum3']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Sum3']],...
		'position',[385,113,405,142])

add_block('built-in/Mux',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Mux']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Mux']],...
		'inputs','[N N]',...
		'position',[425,78,455,122])

add_block('built-in/S-Function',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Array sin']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Array sin']],...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[470,90,520,110])

add_block('built-in/Product',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Product']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Product']],...
		'position',[540,76,565,109])

add_block('built-in/Constant',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Initial phase1']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Initial phase1']],...
		'Value','Ph',...
		'position',[335,153,355,177])

add_block('built-in/Product',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Product1']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Product1']],...
		'position',[675,76,700,109])

add_block('built-in/Demux',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Demux']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Demux']],...
		'outputs','[N N]',...
		'position',[720,75,760,110])

add_block('built-in/Sum',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Sum4']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Sum4']],...
		'position',[785,78,805,107])

add_block('built-in/S-Function',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int1']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int1']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int1']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int1']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int1']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int1']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[580,74,640,116])

add_block('built-in/Sum',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Sum2']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Sum2']],...
		'inputs','+-',...
		'position',[265,155,290,190])

add_block('built-in/Clock',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Clock']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Clock']],...
		'position',[95,155,115,175])

add_block('built-in/Gain',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Gain']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Gain']],...
		'Gain','Fc',...
		'position',[145,155,165,175])

add_block('built-in/Zero-Order Hold',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Zero-Order',13,'Hold']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[195,179,230,211])

add_block('built-in/Constant',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Initial phase']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Initial phase']],...
		'Value','Ph',...
		'position',[140,108,160,132])

add_block('built-in/Constant',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Shift key']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Shift key']],...
		'Value','sft',...
		'position',[120,43,140,67])

add_block('built-in/S-Function',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[200,34,260,76])

add_block('built-in/Sum',[sys,'/',['Noncoh corr MFSK',13,'demod  passband/Sum1']])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband/Sum1']],...
		'inputs','+++',...
		'position',[325,70,350,110])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[810,95;820,95])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[515,85;535,85])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[765,100;780,100])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[765,85;780,85])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[705,95;715,95])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[645,95;655,95;655,100;670,100])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[645,95;655,95;655,85;670,85])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[570,95;575,95])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[525,100;535,100])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[460,100;465,100])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[410,130;420,110])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[355,90;420,90])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[360,165;370,165;380,135])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[355,90;370,90;380,120])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[235,195;240,195;240,180;260,180])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[170,165;260,165])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[180,165;190,195])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[295,175;310,175;320,105])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[120,165;140,165])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[165,120;290,120;290,90;320,90])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[265,55;285,55;285,75;320,75])
add_line([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],[145,55;195,55])
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],...
		'Mask Display','Noncoh corr\nMFSK dm',...
		'Mask Type','Passband non-coherent MFSK correlation')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],...
		'Mask Dialogue','Compute MFSK correlation. Take MFSK\nmodulated signal. Output a vector of\ncorrelation result.|M-ary number (input in range [0, M-1]):|Tone space (Hz):|Symbol interval and offset (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],...
		'Mask Translate','pi2=2*pi;N=@1;Fc=@4*pi2;Ph=@5;Ton=@2;sft=[0:N-1]*Ton*pi2;td=@3;ts=@6;')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],...
		'Mask Help','This block calculates the noncoherent correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their frequency the same as that of FM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MFSK demodulation result is the index of the largest output, using the Min/max demap block.')
set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],...
		'Mask Entries','M\/M/td/5\/td\/Fc\/0\/ts\/')


%     Finished composite block ['Noncoh corr MFSK',13,'demod  passband'].

set_param([sys,'/',['Noncoh corr MFSK',13,'demod  passband']],...
		'position',[320,423,400,467])

add_block('built-in/Note',[sys,'/','(map+modu ===> demod+demap)'])
set_param([sys,'/','(map+modu ===> demod+demap)'],...
		'ForeGround',2,...
		'position',[320,20,325,25])


%     Subsystem  ['QASK',13,'circle-map'].

new_system([sys,'/',['QASK',13,'circle-map']])
set_param([sys,'/',['QASK',13,'circle-map']],'Location',[58,103,403,268])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'circle-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-map/in_1']])
set_param([sys,'/',['QASK',13,'circle-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'circle-map/real part']])
set_param([sys,'/',['QASK',13,'circle-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'circle-map/imag part1']])
set_param([sys,'/',['QASK',13,'circle-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-map/Real']])
set_param([sys,'/',['QASK',13,'circle-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-map/Imag']])
set_param([sys,'/',['QASK',13,'circle-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])
add_line([sys,'/',['QASK',13,'circle-map']],[50,30;75,30])
add_line([sys,'/',['QASK',13,'circle-map']],[120,30;175,30])
add_line([sys,'/',['QASK',13,'circle-map']],[145,30;145,110;170,110])
add_line([sys,'/',['QASK',13,'circle-map']],[220,30;270,30])
add_line([sys,'/',['QASK',13,'circle-map']],[215,110;270,110])
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Display','QASK\nC-map',...
		'Mask Type','QASK C-map')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Dialogue','QASK mapping with circle constellation. The constellation is defined in NIC, RIC and PIC.|Number of symbols in each circle NIC:|Radii in each circle RIC:|Phase shift in each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y1=[y1;y1];y1=y1(:);y2=imag(y1);y1=real(y1);x=[-sum(N) 1:sum(N)-1;1:sum(N)-1 10*sum(N)]-.5;x=x(:);')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The circle constellation is defined in NIC, RIC, and PIC. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Entries','[6 12 18 24 30 38]\/[1 1.93 2.88 3.83 4.78 6.05]\/[0 0 0 0 0 0]\/td\/')


%     Finished composite block ['QASK',13,'circle-map'].

set_param([sys,'/',['QASK',13,'circle-map']],...
		'position',[40,198,120,242])


%     Subsystem  ['QASK',13,'circle-demap'].

new_system([sys,'/',['QASK',13,'circle-demap']])
set_param([sys,'/',['QASK',13,'circle-demap']],'Location',[96,182,645,417])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-demap/real']])
set_param([sys,'/',['QASK',13,'circle-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-demap/imag']])
set_param([sys,'/',['QASK',13,'circle-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum1']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum6']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['QASK',13,'circle-demap/Product']])
set_param([sys,'/',['QASK',13,'circle-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['QASK',13,'circle-demap/Product1']])
set_param([sys,'/',['QASK',13,'circle-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum2']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'circle-demap/Minimum1']])
set_param([sys,'/',['QASK',13,'circle-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-demap/out_1']])
set_param([sys,'/',['QASK',13,'circle-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['QASK',13,'circle-demap/real_pt']])
set_param([sys,'/',['QASK',13,'circle-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['QASK',13,'circle-demap/imag_pt']])
set_param([sys,'/',['QASK',13,'circle-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['QASK',13,'circle-demap']],[70,45;115,45])
add_line([sys,'/',['QASK',13,'circle-demap']],[70,130;115,130])
add_line([sys,'/',['QASK',13,'circle-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['QASK',13,'circle-demap']],[160,45;225,45])
add_line([sys,'/',['QASK',13,'circle-demap']],[160,130;225,130])
add_line([sys,'/',['QASK',13,'circle-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['QASK',13,'circle-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['QASK',13,'circle-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['QASK',13,'circle-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['QASK',13,'circle-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['QASK',13,'circle-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['QASK',13,'circle-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['QASK',13,'circle-demap']],[395,95;410,95])
add_line([sys,'/',['QASK',13,'circle-demap']],[480,95;490,95])
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Display','QASK\nC-demap',...
		'Mask Type','QASK C-demap')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Number of symbols on each circle NIC::|Radii for each circle RIC:|Phase shift on each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y2=imag(y1);y1=real(y1);')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using circle constellation. You can place this block after a QAM demodulation block. The circle constellation is defined in NIC, RIC, and PIC. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero. Use function MODMAP to view the constellation.')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Entries','[6 12 18 24 30 38]\/[1 1.93 2.88 3.83 4.78 6.05]\/[0 0 0 0 0 0]\/td\/')


%     Finished composite block ['QASK',13,'circle-demap'].

set_param([sys,'/',['QASK',13,'circle-demap']],...
		'position',[445,198,525,242])


%     Subsystem  ['QASK',13,'square-demap'].

new_system([sys,'/',['QASK',13,'square-demap']])
set_param([sys,'/',['QASK',13,'square-demap']],'Location',[57,374,831,674])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'square-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'square-demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[135,24,170,56])

add_block('built-in/Inport',[sys,'/',['QASK',13,'square-demap/in_1']])
set_param([sys,'/',['QASK',13,'square-demap/in_1']],...
		'position',[60,30,80,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'square-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'square-demap/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[135,149,170,181])

add_block('built-in/Inport',[sys,'/',['QASK',13,'square-demap/in_2']])
set_param([sys,'/',['QASK',13,'square-demap/in_2']],...
		'Port','2',...
		'position',[60,155,80,175])

add_block('built-in/Sum',[sys,'/',['QASK',13,'square-demap/Sum5']])
set_param([sys,'/',['QASK',13,'square-demap/Sum5']],...
		'ForeGround',2,...
		'position',[470,153,490,182])


%     Subsystem  ['QASK',13,'square-demap/2-D Table'].

new_system([sys,'/',['QASK',13,'square-demap/2-D Table']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],'Location',[436,148,718,302])

add_block('built-in/Inport',[sys,'/',['QASK',13,'square-demap/2-D Table/y0']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table/y0']],...
		'Port','2',...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['QASK',13,'square-demap/2-D Table/table out']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table/table out']],...
		'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/',['QASK',13,'square-demap/2-D Table/x0']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table/x0']],...
		'position',[20,25,40,45])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'square-demap/2-D Table/S-function']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table/S-function']],...
		'function name','sftable2',...
		'parameters','xindex, yindex, table',...
		'position',[140,52,190,78])

add_block('built-in/Mux',[sys,'/',['QASK',13,'square-demap/2-D Table/Mux']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table/Mux']],...
		'inputs','2',...
		'position',[90,46,120,79])
add_line([sys,'/',['QASK',13,'square-demap/2-D Table']],[45,90;65,90;65,70;85,70])
add_line([sys,'/',['QASK',13,'square-demap/2-D Table']],[195,65;210,65])
add_line([sys,'/',['QASK',13,'square-demap/2-D Table']],[45,35;65,35;65,55;85,55])
add_line([sys,'/',['QASK',13,'square-demap/2-D Table']],[125,65;135,65])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'Mask Display','plot(-10,-10,110,110,[90,50,10],[90,40,30],[90,50,10],[50,26,20],[90,50,10],[22,13,10])',...
		'Mask Type','2-D Table Lookup')
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'Mask Dialogue','Two Dimensional Table Lookup\nThe first input corresponds to X Index and the second input corresponds to the Y Index|X Index|Y Index|Table')
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'Mask Translate','xindex=@1; yindex=@2; table=@3; sftab2chk(xindex,yindex,table);')
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'Mask Help','This block returns a linearly interpolated intersection from the table using the X index (which corresponds to the rows of the table) and the Y index (which corresponds to the columns of the table).  Extrapolation is used.')
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'Mask Entries','x\/y\/tab\/')


%     Finished composite block ['QASK',13,'square-demap/2-D Table'].

set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'position',[515,68,545,92])

add_block('built-in/Sum',[sys,'/',['QASK',13,'square-demap/Sum3']])
set_param([sys,'/',['QASK',13,'square-demap/Sum3']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[580,73,600,102])

add_block('built-in/Saturation',[sys,'/',['QASK',13,'square-demap/Saturation']])
set_param([sys,'/',['QASK',13,'square-demap/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','N-1',...
		'position',[630,78,660,102])

add_block('built-in/Outport',[sys,'/',['QASK',13,'square-demap/out_1']])
set_param([sys,'/',['QASK',13,'square-demap/out_1']],...
		'position',[685,80,705,100])

add_block('built-in/Sum',[sys,'/',['QASK',13,'square-demap/Sum4']])
set_param([sys,'/',['QASK',13,'square-demap/Sum4']],...
		'ForeGround',2,...
		'position',[470,58,490,87])

add_block('built-in/Sum',[sys,'/',['QASK',13,'square-demap/Sum1']])
set_param([sys,'/',['QASK',13,'square-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[280,33,300,62])

add_block('built-in/Sum',[sys,'/',['QASK',13,'square-demap/Sum2']])
set_param([sys,'/',['QASK',13,'square-demap/Sum2']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[290,158,310,187])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'square-demap/Minimum']])
set_param([sys,'/',['QASK',13,'square-demap/Minimum']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,165,450,185])

add_block('built-in/Constant',[sys,'/',['QASK',13,'square-demap/Shift key']])
set_param([sys,'/',['QASK',13,'square-demap/Shift key']],...
		'Value','sfty',...
		'position',[225,214,250,236])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'square-demap/Minimum1']])
set_param([sys,'/',['QASK',13,'square-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,40,445,60])

add_block('built-in/Constant',[sys,'/',['QASK',13,'square-demap/Shift key1']])
set_param([sys,'/',['QASK',13,'square-demap/Shift key1']],...
		'Value','sftx',...
		'position',[220,89,245,111])

add_block('built-in/Constant',[sys,'/',['QASK',13,'square-demap/Shift key2']])
set_param([sys,'/',['QASK',13,'square-demap/Shift key2']],...
		'BackGround',5,...
		'position',[325,114,350,136])

add_block('built-in/Abs',[sys,'/',['QASK',13,'square-demap/Abs1']])
set_param([sys,'/',['QASK',13,'square-demap/Abs1']],...
		'position',[325,38,355,62])

add_block('built-in/Abs',[sys,'/',['QASK',13,'square-demap/Abs']])
set_param([sys,'/',['QASK',13,'square-demap/Abs']],...
		'position',[325,163,355,187])
add_line([sys,'/',['QASK',13,'square-demap']],[85,40;130,40])
add_line([sys,'/',['QASK',13,'square-demap']],[360,175;380,175])
add_line([sys,'/',['QASK',13,'square-demap']],[315,175;320,175])
add_line([sys,'/',['QASK',13,'square-demap']],[255,225;260,225;260,180;285,180])
add_line([sys,'/',['QASK',13,'square-demap']],[250,100;255,100;255,55;275,55])
add_line([sys,'/',['QASK',13,'square-demap']],[305,50;320,50])
add_line([sys,'/',['QASK',13,'square-demap']],[360,50;380,50])
add_line([sys,'/',['QASK',13,'square-demap']],[665,90;680,90])
add_line([sys,'/',['QASK',13,'square-demap']],[550,80;575,80])
add_line([sys,'/',['QASK',13,'square-demap']],[605,90;625,90])
add_line([sys,'/',['QASK',13,'square-demap']],[450,50;450,65;465,65])
add_line([sys,'/',['QASK',13,'square-demap']],[455,175;465,175])
add_line([sys,'/',['QASK',13,'square-demap']],[495,170;500,170;510,85])
add_line([sys,'/',['QASK',13,'square-demap']],[355,125;560,125;560,95;575,95])
add_line([sys,'/',['QASK',13,'square-demap']],[450,125;450,160;465,160])
add_line([sys,'/',['QASK',13,'square-demap']],[450,125;450,80;465,80])
add_line([sys,'/',['QASK',13,'square-demap']],[495,75;510,75])
add_line([sys,'/',['QASK',13,'square-demap']],[85,165;130,165])
add_line([sys,'/',['QASK',13,'square-demap']],[175,165;285,165])
add_line([sys,'/',['QASK',13,'square-demap']],[175,40;275,40])
set_param([sys,'/',['QASK',13,'square-demap']],...
		'Mask Display','QASK\nS-demap',...
		'Mask Type','QASK S-demap')
set_param([sys,'/',['QASK',13,'square-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|QASK M-ary number (outputs are in range [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'square-demap']],...
		'Mask Translate','N=@1;td=@2;Ac=1;sftx=[1 -1 3 -3 5 -5 7 -7 9 -9 11 -11 13 -13 15 -15];sftx=sftx(1:2*ceil(sqrt(N)/2));sfty=sftx;if N==8,sfty=sfty(1:2);end;sftx=sftx/max(sftx)*Ac;sfty=sfty/max(sfty)*Ac;tab=qaskdeco(length(sftx),length(sfty),''fetch'')+1;x=[1:length(sftx)];y=[1:length(sfty)];')
set_param([sys,'/',['QASK',13,'square-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using square constellation. You can place this block after a QAM demodulation block. This block assumes the maximum amplitude of the input signals is 1. The output symbols are integers in the range [0, M-1]. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0.')
set_param([sys,'/',['QASK',13,'square-demap']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['QASK',13,'square-demap'].

set_param([sys,'/',['QASK',13,'square-demap']],...
		'position',[445,123,525,167])


%     Subsystem  ['QASK',13,'square-map'].

new_system([sys,'/',['QASK',13,'square-map']])
set_param([sys,'/',['QASK',13,'square-map']],'Location',[214,372,642,541])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'square-map/c-y axis']])
set_param([sys,'/',['QASK',13,'square-map/c-y axis']],...
		'Input_Values','z',...
		'Output_Values','y',...
		'position',[245,90,280,120])

add_block('built-in/Outport',[sys,'/',['QASK',13,'square-map/out_2']])
set_param([sys,'/',['QASK',13,'square-map/out_2']],...
		'Port','2',...
		'position',[325,95,345,115])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'square-map/s-x axis']])
set_param([sys,'/',['QASK',13,'square-map/s-x axis']],...
		'Input_Values','z',...
		'Output_Values','x',...
		'position',[245,25,280,55])

add_block('built-in/Outport',[sys,'/',['QASK',13,'square-map/out_1']])
set_param([sys,'/',['QASK',13,'square-map/out_1']],...
		'position',[325,30,345,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'square-map/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'square-map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[110,24,145,56])

add_block('built-in/Inport',[sys,'/',['QASK',13,'square-map/in_1']])
set_param([sys,'/',['QASK',13,'square-map/in_1']],...
		'position',[45,30,65,50])
add_line([sys,'/',['QASK',13,'square-map']],[70,40;105,40])
add_line([sys,'/',['QASK',13,'square-map']],[150,40;240,40])
add_line([sys,'/',['QASK',13,'square-map']],[185,40;185,105;240,105])
add_line([sys,'/',['QASK',13,'square-map']],[285,105;320,105])
add_line([sys,'/',['QASK',13,'square-map']],[285,40;320,40])
set_param([sys,'/',['QASK',13,'square-map']],...
		'Mask Display','QASK\nS-map',...
		'Mask Type','QASK S-map')
set_param([sys,'/',['QASK',13,'square-map']],...
		'Mask Dialogue','Use square constellation to map the\ninput digital signal into in-phase and\nquadrature components. M must be\nM=2^K with integer K.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'square-map']],...
		'Mask Translate','N=@1;Ac=1;td=@2;z=[[1:N];[1:N]];z=z(:);[x,y]=qaskenco(z-1,N);z=z-1.5;z=[z(2:2*N);N-.5];x=x/max(x);y=y/max(y);')
set_param([sys,'/',['QASK',13,'square-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The M-ary number must be M=2^K with integer K. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. The maximum amplitudes for the outputs are 1.')
set_param([sys,'/',['QASK',13,'square-map']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['QASK',13,'square-map'].

set_param([sys,'/',['QASK',13,'square-map']],...
		'position',[40,123,120,167])


%     Subsystem  ['QASK Mo//Dem',13,'demo'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo']],...
		'Mask Display','QASK\nS-map\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(4,100/pi/2*ts);td=.2;M=64;tstqa2cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[565,123,645,167])


%     Subsystem  'MASK demap'.

new_system([sys,'/','MASK demap'])
set_param([sys,'/','MASK demap'],'Location',[187,342,628,482])

add_block('built-in/Inport',[sys,'/','MASK demap/in_1'])
set_param([sys,'/','MASK demap/in_1'],...
		'position',[30,35,50,55])

add_block('built-in/S-Function',[sys,'/','MASK demap/Minimum'])
set_param([sys,'/','MASK demap/Minimum'],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[315,45,370,65])

add_block('built-in/Outport',[sys,'/','MASK demap/out_1'])
set_param([sys,'/','MASK demap/out_1'],...
		'position',[400,45,420,65])

add_block('built-in/Abs',[sys,'/','MASK demap/Abs'])
set_param([sys,'/','MASK demap/Abs'],...
		'position',[235,42,270,68])

add_block('built-in/Sum',[sys,'/','MASK demap/Sum2'])
set_param([sys,'/','MASK demap/Sum2'],...
		'inputs','+-',...
		'position',[180,38,200,67])

add_block('built-in/Constant',[sys,'/','MASK demap/Shift key'])
set_param([sys,'/','MASK demap/Shift key'],...
		'Value','sft',...
		'position',[115,93,135,117])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[85,29,120,61])
add_line([sys,'/','MASK demap'],[205,55;230,55])
add_line([sys,'/','MASK demap'],[140,105;155,105;155,60;175,60])
add_line([sys,'/','MASK demap'],[375,55;395,55])
add_line([sys,'/','MASK demap'],[125,45;175,45])
add_line([sys,'/','MASK demap'],[275,55;310,55])
add_line([sys,'/','MASK demap'],[55,45;80,45])
set_param([sys,'/','MASK demap'],...
		'Mask Display','MASK\ndemap',...
		'Mask Type','MASK demap')
set_param([sys,'/','MASK demap'],...
		'Mask Dialogue','Reverse the MASK mapping process\nConvert [-1 1] analog signal to [0, M-1] symbols.|M-ary number (digit integers in ranger [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/','MASK demap'],...
		'Mask Translate','N=@1;Ac=1;sft=[0:N-1]*Ac*2/(N-1)-Ac;td=@2;')
set_param([sys,'/','MASK demap'],...
		'Mask Help','This block demaps a MASK mapped signal back to digit symbols. You can place this block after a amplitude demodulation block. The input of this block is an analog signal in the range [-1, 1]. The demodulation decides the closest integer fitting in [0,M-1] range. When the input symbol interval is a two-elements vector, the second element is offset. The default offset value is 0.')
set_param([sys,'/','MASK demap'],...
		'Mask Entries','M\/[td, td-ts]\/')


%     Finished composite block 'MASK demap'.

set_param([sys,'/','MASK demap'],...
		'position',[445,48,525,92])


%     Subsystem  ['ASK Mo//Dem',13,'demo'].

new_system([sys,'/',['ASK Mo//Dem',13,'demo']])
set_param([sys,'/',['ASK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['ASK Mo//Dem',13,'demo']],...
		'Mask Display','MASK\nmap\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(2,100/pi/2*ts);td=.1;M=8;tstam2cd'')')


%     Finished composite block ['ASK Mo//Dem',13,'demo'].

set_param([sys,'/',['ASK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[565,48,645,92])


%     Subsystem  ['PSK Mo//Dem',13,'demo'].

new_system([sys,'/',['PSK Mo//Dem',13,'demo']])
set_param([sys,'/',['PSK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['PSK Mo//Dem',13,'demo']],...
		'Mask Display','MPSK\nmap\ndemo',...
		'Mask Dialogue','eval(''ts=.01;td=.2;M=8;Fc=100/2/pi;tstpk2cd'')')


%     Finished composite block ['PSK Mo//Dem',13,'demo'].

set_param([sys,'/',['PSK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[565,503,645,547])


%     Subsystem  'MPSK map'.

new_system([sys,'/','MPSK map'])
set_param([sys,'/','MPSK map'],'Location',[71,474,419,648])

add_block('built-in/Constant',[sys,'/','MPSK map/Multiple factor'])
set_param([sys,'/','MPSK map/Multiple factor'],...
		'Value','Sft',...
		'position',[130,108,150,132])

add_block('built-in/Outport',[sys,'/','MPSK map/out_1'])
set_param([sys,'/','MPSK map/out_1'],...
		'position',[310,85,330,105])

add_block('built-in/Product',[sys,'/','MPSK map/Product'])
set_param([sys,'/','MPSK map/Product'],...
		'position',[235,76,260,109])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MPSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[130,29,165,61])

add_block('built-in/Inport',[sys,'/','MPSK map/in_1'])
set_param([sys,'/','MPSK map/in_1'],...
		'position',[60,35,80,55])
add_line([sys,'/','MPSK map'],[155,120;200,120;200,100;230,100])
add_line([sys,'/','MPSK map'],[265,95;305,95])
add_line([sys,'/','MPSK map'],[85,45;125,45])
add_line([sys,'/','MPSK map'],[170,45;200,45;200,85;230,85])
set_param([sys,'/','MPSK map'],...
		'Mask Display','MPSK\nmap',...
		'Mask Type','MPSK map')
set_param([sys,'/','MPSK map'],...
		'Mask Dialogue','Map input digital signal to analog phase shift.|M-ary number (input integer in range [0, M-1]):|Input symbol interval and offset (sec):',...
		'Mask Translate','pi2=2*pi;Sft=pi2/@1;td=@2;')
set_param([sys,'/','MPSK map'],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the PM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. You can view the MPSK constellation using the MODMAP function.')
set_param([sys,'/','MPSK map'],...
		'Mask Entries','M\/td\/')


%     Finished composite block 'MPSK map'.

set_param([sys,'/','MPSK map'],...
		'position',[40,498,120,542])


%     Subsystem  'help'.

new_system([sys,'/','help'])
set_param([sys,'/','help'],'Location',[95,429,862,670])

add_block('built-in/Note',[sys,'/','help/(1) digital map: mapping digit signal to analog signal. '])
set_param([sys,'/','help/(1) digital map: mapping digit signal to analog signal. '],...
		'position',[255,100,260,105])

add_block('built-in/Note',[sys,'/','help/The blocks in this libraris contains (in five block columns):'])
set_param([sys,'/','help/The blocks in this libraris contains (in five block columns):'],...
		'position',[240,75,245,80])

add_block('built-in/Note',[sys,'/','help/(3) analog demodulation: demodulatig analog signal.'])
set_param([sys,'/','help/(3) analog demodulation: demodulatig analog signal.'],...
		'position',[250,150,255,155])

add_block('built-in/Note',[sys,'/',['help/This library is the ungroupped version of Digital Modulation//Demodulation Library (discrete-time filter).',13,'']])
set_param([sys,'/',['help/This library is the ungroupped version of Digital Modulation//Demodulation Library (discrete-time filter).',13,'']],...
		'position',[365,50,370,55])

add_block('built-in/Note',[sys,'/','help/(2) analog modulation: modulating analog signal to carrier frequency.'])
set_param([sys,'/','help/(2) analog modulation: modulating analog signal to carrier frequency.'],...
		'ForeGround',4,...
		'position',[295,125,300,130])

add_block('built-in/Note',[sys,'/','help/(4) digit demap: demaping the demodulated signal to digit signal.'])
set_param([sys,'/','help/(4) digit demap: demaping the demodulated signal to digit signal.'],...
		'position',[285,175,290,180])

add_block('built-in/Note',[sys,'/','help/(5) demo for how to use the blocks.'])
set_param([sys,'/','help/(5) demo for how to use the blocks.'],...
		'ForeGround',7,...
		'position',[200,200,205,205])
set_param([sys,'/','help'],...
		'Mask Display','?')


%     Finished composite block 'help'.

set_param([sys,'/','help'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[565,580,590,606])


%     Subsystem  'Blocks that can be found in some other sublibraries in this toolbox'.

new_system([sys,'/','Blocks that can be found in some other sublibraries in this toolbox'])
set_param([sys,'/','Blocks that can be found in some other sublibraries in this toolbox'],'Location',[175,552,335,697])
set_param([sys,'/','Blocks that can be found in some other sublibraries in this toolbox'],...
		'Mask Display','.')


%     Finished composite block 'Blocks that can be found in some other sublibraries in this toolbox'.

set_param([sys,'/','Blocks that can be found in some other sublibraries in this toolbox'],...
		'orientation',1,...
		'ForeGround',4,...
		'position',[40,640,95,663])


%     Subsystem  'Mapping//demapping blocks'.

new_system([sys,'/','Mapping//demapping blocks'])
set_param([sys,'/','Mapping//demapping blocks'],'Location',[175,552,335,697])
set_param([sys,'/','Mapping//demapping blocks'],...
		'Mask Display','.')


%     Finished composite block 'Mapping//demapping blocks'.

set_param([sys,'/','Mapping//demapping blocks'],...
		'orientation',1,...
		'position',[40,610,95,633])


%     Subsystem  'Demonstration blocks'.

new_system([sys,'/','Demonstration blocks'])
set_param([sys,'/','Demonstration blocks'],'Location',[175,552,335,697])
set_param([sys,'/','Demonstration blocks'],...
		'Mask Display','.')


%     Finished composite block 'Demonstration blocks'.

set_param([sys,'/','Demonstration blocks'],...
		'orientation',1,...
		'BackGround',7,...
		'position',[40,580,95,603])


%     Subsystem  ['Corr MPSK',13,'demod passband'].

new_system([sys,'/',['Corr MPSK',13,'demod passband']])
set_param([sys,'/',['Corr MPSK',13,'demod passband']],'Location',[269,223,837,414])

add_block('built-in/Gain',[sys,'/',['Corr MPSK',13,'demod passband/Gain']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/Gain']],...
		'Gain','Fc',...
		'position',[65,85,105,115])

add_block('built-in/Zero-Order Hold',[sys,'/',['Corr MPSK',13,'demod passband/Zero-Order',13,'Hold']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[125,119,160,151])

add_block('built-in/Clock',[sys,'/',['Corr MPSK',13,'demod passband/Clock']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/Clock']],...
		'position',[15,90,35,110])

add_block('built-in/Sum',[sys,'/',['Corr MPSK',13,'demod passband/Sum2']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/Sum2']],...
		'inputs','+-',...
		'position',[185,90,210,125])

add_block('built-in/Sum',[sys,'/',['Corr MPSK',13,'demod passband/Sum1']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/Sum1']],...
		'inputs','+++',...
		'position',[240,40,265,80])

add_block('built-in/Constant',[sys,'/',['Corr MPSK',13,'demod passband/Initial phase']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/Initial phase']],...
		'Value','Ph',...
		'position',[165,48,185,72])

add_block('built-in/S-Function',[sys,'/',['Corr MPSK',13,'demod passband/Array sin']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/Array sin']],...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[295,50,345,70])

add_block('built-in/Inport',[sys,'/',['Corr MPSK',13,'demod passband/in_1']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/in_1']],...
		'position',[305,100,325,120])

add_block('built-in/Product',[sys,'/',['Corr MPSK',13,'demod passband/Product']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/Product']],...
		'position',[385,51,410,84])

add_block('built-in/S-Function',[sys,'/',['Corr MPSK',13,'demod passband/Scheduled',13,'reset-int1']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/Scheduled',13,'reset-int1']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Corr MPSK',13,'demod passband/Scheduled',13,'reset-int1']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Corr MPSK',13,'demod passband/Scheduled',13,'reset-int1']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Corr MPSK',13,'demod passband/Scheduled',13,'reset-int1']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Corr MPSK',13,'demod passband/Scheduled',13,'reset-int1']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[440,49,500,91])

add_block('built-in/Outport',[sys,'/',['Corr MPSK',13,'demod passband/out_1']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/out_1']],...
		'position',[525,60,545,80])

add_block('built-in/Constant',[sys,'/',['Corr MPSK',13,'demod passband/Shift key']])
set_param([sys,'/',['Corr MPSK',13,'demod passband/Shift key']],...
		'Value','sft',...
		'position',[115,13,135,37])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[330,110;360,110;360,75;380,75])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[350,60;380,60])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[165,135;165,115;180,115])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[110,100;120,135])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[110,100;180,100])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[215,110;225,110;235,75])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[40,100;60,100])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[190,60;235,60])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[140,25;225,25;235,45])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[270,60;290,60])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[415,70;435,70])
add_line([sys,'/',['Corr MPSK',13,'demod passband']],[505,70;520,70])
set_param([sys,'/',['Corr MPSK',13,'demod passband']],...
		'Mask Display','Corr MPSK\ndemod',...
		'Mask Type','Passband coherent MPSK correlation')
set_param([sys,'/',['Corr MPSK',13,'demod passband']],...
		'Mask Dialogue','Compute MPSK correlation. Take MPSK\nmodulated signal. Output a vector of\ncorrelation result.|M-ary number (integer in range [0, M-1]):|Symbol interval and offset (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Corr MPSK',13,'demod passband']],...
		'Mask Translate','pi2=2*pi;N=@1;sft=[0:N-1]*pi2/N;td=@2;Fc=@3*pi2;Ph=@4;ts=@5;')
set_param([sys,'/',['Corr MPSK',13,'demod passband']],...
		'Mask Help','This block calculates the correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their phase shift the same as that of PM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MPSK demodulation result is the index of the largest output, using the Min/max demap block. The computation is phase sensitive.')
set_param([sys,'/',['Corr MPSK',13,'demod passband']],...
		'Mask Entries','M\/td\/Fc\/0\/ts\/')


%     Finished composite block ['Corr MPSK',13,'demod passband'].

set_param([sys,'/',['Corr MPSK',13,'demod passband']],...
		'position',[320,498,400,542])


%     Subsystem  ['QADM',13,'passband'].

new_system([sys,'/',['QADM',13,'passband']])
set_param([sys,'/',['QADM',13,'passband']],'Location',[194,478,738,741])

add_block('built-in/Clock',[sys,'/',['QADM',13,'passband/Clock']])
set_param([sys,'/',['QADM',13,'passband/Clock']],...
		'position',[60,110,80,130])

add_block('built-in/Gain',[sys,'/',['QADM',13,'passband/Gain']])
set_param([sys,'/',['QADM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[110,101,160,139])

add_block('built-in/Filter',[sys,'/',['QADM',13,'passband/Filter1']])
set_param([sys,'/',['QADM',13,'passband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,166,445,204])

add_block('built-in/Filter',[sys,'/',['QADM',13,'passband/Filter']])
set_param([sys,'/',['QADM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Gain',[sys,'/',['QADM',13,'passband/Gain1']])
set_param([sys,'/',['QADM',13,'passband/Gain1']],...
		'Gain','2',...
		'position',[270,118,295,142])

add_block('built-in/Inport',[sys,'/',['QADM',13,'passband/in_1']])
set_param([sys,'/',['QADM',13,'passband/in_1']],...
		'position',[230,120,250,140])

add_block('built-in/Note',[sys,'/',['QADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Fcn',[sys,'/',['QADM',13,'passband/Fcn']])
set_param([sys,'/',['QADM',13,'passband/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[205,55,300,85])

add_block('built-in/Fcn',[sys,'/',['QADM',13,'passband/Fcn1']])
set_param([sys,'/',['QADM',13,'passband/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[200,175,300,205])

add_block('built-in/Product',[sys,'/',['QADM',13,'passband/Product']])
set_param([sys,'/',['QADM',13,'passband/Product']],...
		'position',[330,62,355,93])

add_block('built-in/Product',[sys,'/',['QADM',13,'passband/Product1']])
set_param([sys,'/',['QADM',13,'passband/Product1']],...
		'position',[330,167,355,198])

add_block('built-in/Outport',[sys,'/',['QADM',13,'passband/out_2']])
set_param([sys,'/',['QADM',13,'passband/out_2']],...
		'Port','2',...
		'position',[480,175,500,195])

add_block('built-in/Outport',[sys,'/',['QADM',13,'passband/out_1']])
set_param([sys,'/',['QADM',13,'passband/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['QADM',13,'passband']],[300,130;305,130;305,175;325,175])
add_line([sys,'/',['QADM',13,'passband']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['QADM',13,'passband']],[255,130;265,130])
add_line([sys,'/',['QADM',13,'passband']],[165,120;185,120;185,70;200,70])
add_line([sys,'/',['QADM',13,'passband']],[185,120;195,190])
add_line([sys,'/',['QADM',13,'passband']],[305,70;325,70])
add_line([sys,'/',['QADM',13,'passband']],[305,190;325,190])
add_line([sys,'/',['QADM',13,'passband']],[360,80;385,80])
add_line([sys,'/',['QADM',13,'passband']],[450,80;475,80])
add_line([sys,'/',['QADM',13,'passband']],[360,185;385,185])
add_line([sys,'/',['QADM',13,'passband']],[450,185;475,185])
add_line([sys,'/',['QADM',13,'passband']],[85,120;105,120])
set_param([sys,'/',['QADM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);QADM',...
		'Mask Type','Passband DSB-SC QADM')
set_param([sys,'/',['QADM',13,'passband']],...
		'Mask Dialogue','Demodulate a DSB-SC QAM modulated\nsignal into in-phase and quadrature\ncomponents.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QADM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;num=@2;den=@3;Ph=@4;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['QADM',13,'passband']],...
		'Mask Help','This block demodulates the QM-DSB-SC-AM modulated signal. The first output port outputs the in-phase component and the second port outputs the quadrature component. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['QADM',13,'passband']],...
		'Mask Entries','100/2/pi\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/0\/.01\/')


%     Finished composite block ['QADM',13,'passband'].

set_param([sys,'/',['QADM',13,'passband']],...
		'ForeGround',4,...
		'position',[320,123,400,167])


%     Subsystem  ['QAM',13,'passband'].

new_system([sys,'/',['QAM',13,'passband']])
set_param([sys,'/',['QAM',13,'passband']],'Location',[302,478,834,743])

add_block('built-in/Fcn',[sys,'/',['QAM',13,'passband/Fcn']])
set_param([sys,'/',['QAM',13,'passband/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])

add_block('built-in/Fcn',[sys,'/',['QAM',13,'passband/Fcn1']])
set_param([sys,'/',['QAM',13,'passband/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Note',[sys,'/',['QAM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QAM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[250,305,255,310])

add_block('built-in/Product',[sys,'/',['QAM',13,'passband/Product']])
set_param([sys,'/',['QAM',13,'passband/Product']],...
		'position',[355,47,380,78])

add_block('built-in/Product',[sys,'/',['QAM',13,'passband/Product1']])
set_param([sys,'/',['QAM',13,'passband/Product1']],...
		'position',[355,112,380,143])

add_block('built-in/Sum',[sys,'/',['QAM',13,'passband/Sum2']])
set_param([sys,'/',['QAM',13,'passband/Sum2']],...
		'position',[430,90,450,110])

add_block('built-in/Outport',[sys,'/',['QAM',13,'passband/out_1']])
set_param([sys,'/',['QAM',13,'passband/out_1']],...
		'position',[490,90,510,110])

add_block('built-in/Inport',[sys,'/',['QAM',13,'passband/in_1']])
set_param([sys,'/',['QAM',13,'passband/in_1']],...
		'position',[160,30,180,50])

add_block('built-in/Inport',[sys,'/',['QAM',13,'passband/in_2']])
set_param([sys,'/',['QAM',13,'passband/in_2']],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Gain',[sys,'/',['QAM',13,'passband/Gain']])
set_param([sys,'/',['QAM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Clock',[sys,'/',['QAM',13,'passband/Clock']])
set_param([sys,'/',['QAM',13,'passband/Clock']],...
		'position',[80,85,100,105])
add_line([sys,'/',['QAM',13,'passband']],[455,100;485,100])
add_line([sys,'/',['QAM',13,'passband']],[330,70;350,70])
add_line([sys,'/',['QAM',13,'passband']],[185,40;335,40;335,55;350,55])
add_line([sys,'/',['QAM',13,'passband']],[330,120;350,120])
add_line([sys,'/',['QAM',13,'passband']],[185,155;330,155;330,135;350,135])
add_line([sys,'/',['QAM',13,'passband']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['QAM',13,'passband']],[385,130;400,130;400,105;425,105])
add_line([sys,'/',['QAM',13,'passband']],[105,95;125,95])
add_line([sys,'/',['QAM',13,'passband']],[185,95;200,95;200,70;225,70])
add_line([sys,'/',['QAM',13,'passband']],[200,95;200,120;225,120])
set_param([sys,'/',['QAM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);QAM',...
		'Mask Type','Passband DSB-SC QAM')
set_param([sys,'/',['QAM',13,'passband']],...
		'Mask Dialogue','Modulate the in-phase signal from first input port and quadrature signal from\nthe second port using QAM.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QAM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['QAM',13,'passband']],...
		'Mask Help','This block modulates the in-phase component inputted from the first port and the quadrature component inputted from the second port by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['QAM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/.01\/')


%     Finished composite block ['QAM',13,'passband'].

set_param([sys,'/',['QAM',13,'passband']],...
		'ForeGround',4,...
		'position',[155,123,235,167])


%     Subsystem  ['QAM',13,'passband2'].

new_system([sys,'/',['QAM',13,'passband2']])
set_param([sys,'/',['QAM',13,'passband2']],'Location',[302,478,834,743])

add_block('built-in/Clock',[sys,'/',['QAM',13,'passband2/Clock']])
set_param([sys,'/',['QAM',13,'passband2/Clock']],...
		'position',[80,85,100,105])

add_block('built-in/Gain',[sys,'/',['QAM',13,'passband2/Gain']])
set_param([sys,'/',['QAM',13,'passband2/Gain']],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Inport',[sys,'/',['QAM',13,'passband2/in_2']])
set_param([sys,'/',['QAM',13,'passband2/in_2']],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Inport',[sys,'/',['QAM',13,'passband2/in_1']])
set_param([sys,'/',['QAM',13,'passband2/in_1']],...
		'position',[160,30,180,50])

add_block('built-in/Outport',[sys,'/',['QAM',13,'passband2/out_1']])
set_param([sys,'/',['QAM',13,'passband2/out_1']],...
		'position',[490,90,510,110])

add_block('built-in/Sum',[sys,'/',['QAM',13,'passband2/Sum2']])
set_param([sys,'/',['QAM',13,'passband2/Sum2']],...
		'position',[430,90,450,110])

add_block('built-in/Product',[sys,'/',['QAM',13,'passband2/Product1']])
set_param([sys,'/',['QAM',13,'passband2/Product1']],...
		'position',[355,112,380,143])

add_block('built-in/Product',[sys,'/',['QAM',13,'passband2/Product']])
set_param([sys,'/',['QAM',13,'passband2/Product']],...
		'position',[355,47,380,78])

add_block('built-in/Note',[sys,'/',['QAM',13,'passband2/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QAM',13,'passband2/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[250,305,255,310])

add_block('built-in/Fcn',[sys,'/',['QAM',13,'passband2/Fcn1']])
set_param([sys,'/',['QAM',13,'passband2/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Fcn',[sys,'/',['QAM',13,'passband2/Fcn']])
set_param([sys,'/',['QAM',13,'passband2/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])
add_line([sys,'/',['QAM',13,'passband2']],[185,95;200,95;200,70;225,70])
add_line([sys,'/',['QAM',13,'passband2']],[200,95;200,120;225,120])
add_line([sys,'/',['QAM',13,'passband2']],[105,95;125,95])
add_line([sys,'/',['QAM',13,'passband2']],[385,130;400,130;400,105;425,105])
add_line([sys,'/',['QAM',13,'passband2']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['QAM',13,'passband2']],[185,155;330,155;330,135;350,135])
add_line([sys,'/',['QAM',13,'passband2']],[330,120;350,120])
add_line([sys,'/',['QAM',13,'passband2']],[185,40;335,40;335,55;350,55])
add_line([sys,'/',['QAM',13,'passband2']],[330,70;350,70])
add_line([sys,'/',['QAM',13,'passband2']],[455,100;485,100])
set_param([sys,'/',['QAM',13,'passband2']],...
		'Mask Display','plot(0,0,100,100,x,y);QAM',...
		'Mask Type','Passband DSB-SC QAM')
set_param([sys,'/',['QAM',13,'passband2']],...
		'Mask Dialogue','Modulate the in-phase signal from first input port and quadrature signal from\nthe second port using QAM.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QAM',13,'passband2']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['QAM',13,'passband2']],...
		'Mask Help','This block modulates the in-phase component inputted from the first port and the quadrature component inputted from the second port by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['QAM',13,'passband2']],...
		'Mask Entries','100/2/pi\/0\/.01\/')


%     Finished composite block ['QAM',13,'passband2'].

set_param([sys,'/',['QAM',13,'passband2']],...
		'ForeGround',4,...
		'position',[155,198,235,242])


%     Subsystem  ['QADM',13,'passband2'].

new_system([sys,'/',['QADM',13,'passband2']])
set_param([sys,'/',['QADM',13,'passband2']],'Location',[194,478,738,741])

add_block('built-in/Outport',[sys,'/',['QADM',13,'passband2/out_1']])
set_param([sys,'/',['QADM',13,'passband2/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Outport',[sys,'/',['QADM',13,'passband2/out_2']])
set_param([sys,'/',['QADM',13,'passband2/out_2']],...
		'Port','2',...
		'position',[480,175,500,195])

add_block('built-in/Product',[sys,'/',['QADM',13,'passband2/Product1']])
set_param([sys,'/',['QADM',13,'passband2/Product1']],...
		'position',[330,167,355,198])

add_block('built-in/Product',[sys,'/',['QADM',13,'passband2/Product']])
set_param([sys,'/',['QADM',13,'passband2/Product']],...
		'position',[330,62,355,93])

add_block('built-in/Fcn',[sys,'/',['QADM',13,'passband2/Fcn1']])
set_param([sys,'/',['QADM',13,'passband2/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[200,175,300,205])

add_block('built-in/Fcn',[sys,'/',['QADM',13,'passband2/Fcn']])
set_param([sys,'/',['QADM',13,'passband2/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[205,55,300,85])

add_block('built-in/Note',[sys,'/',['QADM',13,'passband2/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QADM',13,'passband2/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Inport',[sys,'/',['QADM',13,'passband2/in_1']])
set_param([sys,'/',['QADM',13,'passband2/in_1']],...
		'position',[230,120,250,140])

add_block('built-in/Gain',[sys,'/',['QADM',13,'passband2/Gain1']])
set_param([sys,'/',['QADM',13,'passband2/Gain1']],...
		'Gain','2',...
		'position',[270,118,295,142])

add_block('built-in/Filter',[sys,'/',['QADM',13,'passband2/Filter']])
set_param([sys,'/',['QADM',13,'passband2/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Filter',[sys,'/',['QADM',13,'passband2/Filter1']])
set_param([sys,'/',['QADM',13,'passband2/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,166,445,204])

add_block('built-in/Gain',[sys,'/',['QADM',13,'passband2/Gain']])
set_param([sys,'/',['QADM',13,'passband2/Gain']],...
		'Gain','Fc',...
		'position',[110,101,160,139])

add_block('built-in/Clock',[sys,'/',['QADM',13,'passband2/Clock']])
set_param([sys,'/',['QADM',13,'passband2/Clock']],...
		'position',[60,110,80,130])
add_line([sys,'/',['QADM',13,'passband2']],[85,120;105,120])
add_line([sys,'/',['QADM',13,'passband2']],[450,185;475,185])
add_line([sys,'/',['QADM',13,'passband2']],[360,185;385,185])
add_line([sys,'/',['QADM',13,'passband2']],[450,80;475,80])
add_line([sys,'/',['QADM',13,'passband2']],[360,80;385,80])
add_line([sys,'/',['QADM',13,'passband2']],[305,190;325,190])
add_line([sys,'/',['QADM',13,'passband2']],[305,70;325,70])
add_line([sys,'/',['QADM',13,'passband2']],[165,120;185,120;185,70;200,70])
add_line([sys,'/',['QADM',13,'passband2']],[185,120;195,190])
add_line([sys,'/',['QADM',13,'passband2']],[255,130;265,130])
add_line([sys,'/',['QADM',13,'passband2']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['QADM',13,'passband2']],[300,130;305,130;305,175;325,175])
set_param([sys,'/',['QADM',13,'passband2']],...
		'Mask Display','plot(0,0,100,100,x,y);QADM',...
		'Mask Type','Passband DSB-SC QADM')
set_param([sys,'/',['QADM',13,'passband2']],...
		'Mask Dialogue','Demodulate a DSB-SC QAM modulated\nsignal into in-phase and quadrature\ncomponents.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QADM',13,'passband2']],...
		'Mask Translate','Fc=@1*2*pi;num=@2;den=@3;Ph=@4;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['QADM',13,'passband2']],...
		'Mask Help','This block demodulates the QM-DSB-SC-AM modulated signal. The first output port outputs the in-phase component and the second port outputs the quadrature component. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['QADM',13,'passband2']],...
		'Mask Entries','100/2/pi\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/0\/.01\/')


%     Finished composite block ['QADM',13,'passband2'].

set_param([sys,'/',['QADM',13,'passband2']],...
		'ForeGround',4,...
		'position',[320,198,400,242])


%     Subsystem  ['QADM',13,'passband3'].

new_system([sys,'/',['QADM',13,'passband3']])
set_param([sys,'/',['QADM',13,'passband3']],'Location',[194,478,738,741])

add_block('built-in/Clock',[sys,'/',['QADM',13,'passband3/Clock']])
set_param([sys,'/',['QADM',13,'passband3/Clock']],...
		'position',[60,110,80,130])

add_block('built-in/Gain',[sys,'/',['QADM',13,'passband3/Gain']])
set_param([sys,'/',['QADM',13,'passband3/Gain']],...
		'Gain','Fc',...
		'position',[110,101,160,139])

add_block('built-in/Filter',[sys,'/',['QADM',13,'passband3/Filter1']])
set_param([sys,'/',['QADM',13,'passband3/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,166,445,204])

add_block('built-in/Filter',[sys,'/',['QADM',13,'passband3/Filter']])
set_param([sys,'/',['QADM',13,'passband3/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Gain',[sys,'/',['QADM',13,'passband3/Gain1']])
set_param([sys,'/',['QADM',13,'passband3/Gain1']],...
		'Gain','2',...
		'position',[270,118,295,142])

add_block('built-in/Inport',[sys,'/',['QADM',13,'passband3/in_1']])
set_param([sys,'/',['QADM',13,'passband3/in_1']],...
		'position',[230,120,250,140])

add_block('built-in/Note',[sys,'/',['QADM',13,'passband3/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QADM',13,'passband3/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Fcn',[sys,'/',['QADM',13,'passband3/Fcn']])
set_param([sys,'/',['QADM',13,'passband3/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[205,55,300,85])

add_block('built-in/Fcn',[sys,'/',['QADM',13,'passband3/Fcn1']])
set_param([sys,'/',['QADM',13,'passband3/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[200,175,300,205])

add_block('built-in/Product',[sys,'/',['QADM',13,'passband3/Product']])
set_param([sys,'/',['QADM',13,'passband3/Product']],...
		'position',[330,62,355,93])

add_block('built-in/Product',[sys,'/',['QADM',13,'passband3/Product1']])
set_param([sys,'/',['QADM',13,'passband3/Product1']],...
		'position',[330,167,355,198])

add_block('built-in/Outport',[sys,'/',['QADM',13,'passband3/out_2']])
set_param([sys,'/',['QADM',13,'passband3/out_2']],...
		'Port','2',...
		'position',[480,175,500,195])

add_block('built-in/Outport',[sys,'/',['QADM',13,'passband3/out_1']])
set_param([sys,'/',['QADM',13,'passband3/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['QADM',13,'passband3']],[300,130;305,130;305,175;325,175])
add_line([sys,'/',['QADM',13,'passband3']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['QADM',13,'passband3']],[255,130;265,130])
add_line([sys,'/',['QADM',13,'passband3']],[165,120;185,120;185,70;200,70])
add_line([sys,'/',['QADM',13,'passband3']],[185,120;195,190])
add_line([sys,'/',['QADM',13,'passband3']],[305,70;325,70])
add_line([sys,'/',['QADM',13,'passband3']],[305,190;325,190])
add_line([sys,'/',['QADM',13,'passband3']],[360,80;385,80])
add_line([sys,'/',['QADM',13,'passband3']],[450,80;475,80])
add_line([sys,'/',['QADM',13,'passband3']],[360,185;385,185])
add_line([sys,'/',['QADM',13,'passband3']],[450,185;475,185])
add_line([sys,'/',['QADM',13,'passband3']],[85,120;105,120])
set_param([sys,'/',['QADM',13,'passband3']],...
		'Mask Display','plot(0,0,100,100,x,y);QADM',...
		'Mask Type','Passband DSB-SC QADM')
set_param([sys,'/',['QADM',13,'passband3']],...
		'Mask Dialogue','Demodulate a DSB-SC QAM modulated\nsignal into in-phase and quadrature\ncomponents.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QADM',13,'passband3']],...
		'Mask Translate','Fc=@1*2*pi;num=@2;den=@3;Ph=@4;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['QADM',13,'passband3']],...
		'Mask Help','This block demodulates the QM-DSB-SC-AM modulated signal. The first output port outputs the in-phase component and the second port outputs the quadrature component. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['QADM',13,'passband3']],...
		'Mask Entries','100/2/pi\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/0\/.01\/')


%     Finished composite block ['QADM',13,'passband3'].

set_param([sys,'/',['QADM',13,'passband3']],...
		'ForeGround',4,...
		'position',[320,273,400,317])


%     Subsystem  ['QAM',13,'passband3'].

new_system([sys,'/',['QAM',13,'passband3']])
set_param([sys,'/',['QAM',13,'passband3']],'Location',[302,478,834,743])

add_block('built-in/Fcn',[sys,'/',['QAM',13,'passband3/Fcn']])
set_param([sys,'/',['QAM',13,'passband3/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])

add_block('built-in/Fcn',[sys,'/',['QAM',13,'passband3/Fcn1']])
set_param([sys,'/',['QAM',13,'passband3/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Note',[sys,'/',['QAM',13,'passband3/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QAM',13,'passband3/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[250,305,255,310])

add_block('built-in/Product',[sys,'/',['QAM',13,'passband3/Product']])
set_param([sys,'/',['QAM',13,'passband3/Product']],...
		'position',[355,47,380,78])

add_block('built-in/Product',[sys,'/',['QAM',13,'passband3/Product1']])
set_param([sys,'/',['QAM',13,'passband3/Product1']],...
		'position',[355,112,380,143])

add_block('built-in/Sum',[sys,'/',['QAM',13,'passband3/Sum2']])
set_param([sys,'/',['QAM',13,'passband3/Sum2']],...
		'position',[430,90,450,110])

add_block('built-in/Outport',[sys,'/',['QAM',13,'passband3/out_1']])
set_param([sys,'/',['QAM',13,'passband3/out_1']],...
		'position',[490,90,510,110])

add_block('built-in/Inport',[sys,'/',['QAM',13,'passband3/in_1']])
set_param([sys,'/',['QAM',13,'passband3/in_1']],...
		'position',[160,30,180,50])

add_block('built-in/Inport',[sys,'/',['QAM',13,'passband3/in_2']])
set_param([sys,'/',['QAM',13,'passband3/in_2']],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Gain',[sys,'/',['QAM',13,'passband3/Gain']])
set_param([sys,'/',['QAM',13,'passband3/Gain']],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Clock',[sys,'/',['QAM',13,'passband3/Clock']])
set_param([sys,'/',['QAM',13,'passband3/Clock']],...
		'position',[80,85,100,105])
add_line([sys,'/',['QAM',13,'passband3']],[455,100;485,100])
add_line([sys,'/',['QAM',13,'passband3']],[330,70;350,70])
add_line([sys,'/',['QAM',13,'passband3']],[185,40;335,40;335,55;350,55])
add_line([sys,'/',['QAM',13,'passband3']],[330,120;350,120])
add_line([sys,'/',['QAM',13,'passband3']],[185,155;330,155;330,135;350,135])
add_line([sys,'/',['QAM',13,'passband3']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['QAM',13,'passband3']],[385,130;400,130;400,105;425,105])
add_line([sys,'/',['QAM',13,'passband3']],[105,95;125,95])
add_line([sys,'/',['QAM',13,'passband3']],[185,95;200,95;200,70;225,70])
add_line([sys,'/',['QAM',13,'passband3']],[200,95;200,120;225,120])
set_param([sys,'/',['QAM',13,'passband3']],...
		'Mask Display','plot(0,0,100,100,x,y);QAM',...
		'Mask Type','Passband DSB-SC QAM')
set_param([sys,'/',['QAM',13,'passband3']],...
		'Mask Dialogue','Modulate the in-phase signal from first input port and quadrature signal from\nthe second port using QAM.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QAM',13,'passband3']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['QAM',13,'passband3']],...
		'Mask Help','This block modulates the in-phase component inputted from the first port and the quadrature component inputted from the second port by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['QAM',13,'passband3']],...
		'Mask Entries','100/2/pi\/0\/.01\/')


%     Finished composite block ['QAM',13,'passband3'].

set_param([sys,'/',['QAM',13,'passband3']],...
		'ForeGround',4,...
		'position',[155,273,235,317])


%     Subsystem  ['DSB-SC-ADM',13,'passband'].

new_system([sys,'/',['DSB-SC-ADM',13,'passband']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],'Location',[588,690,716,690])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'passband/In-phase',13,'output']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/In-phase',13,'output']],...
		'position',[695,50,715,70])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband/Filter1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband/Filter']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/sin']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Note',[sys,'/',['DSB-SC-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'passband/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband/Product']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/sin1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband/Product2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband/Sum1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Gain',[sys,'/',['DSB-SC-ADM',13,'passband/Gain1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband/Filter2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband/Product1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])


%     Subsystem  ['DSB-SC-ADM',13,'passband/Dis module',13,'integrator'].

new_system([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/module']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Unit Delay',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[410,40;440,40])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['DSB-SC-ADM',13,'passband/Dis module',13,'integrator'].

set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[400,60;690,60])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[655,60;645,115])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[315,185;300,185;290,135])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[305,125;290,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[360,125;345,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[485,225;655,225;645,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[155,225;420,225])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[70,55;120,55])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[90,55;90,230;120,230])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[605,120;600,120])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[435,125;430,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[155,60;335,60])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[530,120;465,120])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[260,130;215,130])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[240,130;240,180;225,180])
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB ADM',...
		'Mask Type','Passband DSB-SC ADM')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Dialogue','Demodulate a DSB-SC AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Help','This block demodulates a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Entries','100/2/pi\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/pi/2\/.01\/')


%     Finished composite block ['DSB-SC-ADM',13,'passband'].

set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'ForeGround',4,...
		'position',[320,48,400,92])


%     Subsystem  ['DSB-SC AM',13,'passband'].

new_system([sys,'/',['DSB-SC AM',13,'passband']])
set_param([sys,'/',['DSB-SC AM',13,'passband']],'Location',[103,459,555,641])

add_block('built-in/Sum',[sys,'/',['DSB-SC AM',13,'passband/Sum2']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Sum2']],...
		'position',[170,90,190,110])

add_block('built-in/Fcn',[sys,'/',['DSB-SC AM',13,'passband/Fcn']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Constant',[sys,'/',['DSB-SC AM',13,'passband/Constant1']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Inport',[sys,'/',['DSB-SC AM',13,'passband/in_1']])
set_param([sys,'/',['DSB-SC AM',13,'passband/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Outport',[sys,'/',['DSB-SC AM',13,'passband/out_1']])
set_param([sys,'/',['DSB-SC AM',13,'passband/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Product',[sys,'/',['DSB-SC AM',13,'passband/Product']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Clock',[sys,'/',['DSB-SC AM',13,'passband/Clock']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Gain',[sys,'/',['DSB-SC AM',13,'passband/Gain']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Zero-Order Hold',[sys,'/',['DSB-SC AM',13,'passband/Zero-Order',13,'Hold',13,'timing control']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Zero-Order',13,'Hold',13,'timing control']],...
		'Sample time','ts',...
		'position',[50,219,85,251])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[195,100;200,100])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[45,75;65,75])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[370,60;375,60])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[270,100;270,65;335,65])
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB AM',...
		'Mask Type','Passband DSB-SC AM')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using\nDSB-SC AM method.|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Translate','Fc=@1;Fc=Fc*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Help','This block modulates the input signal using the double-sideband suppressed-carrier amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Entries','100/2/pi\/pi/2\/.01\/')


%     Finished composite block ['DSB-SC AM',13,'passband'].

set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'ForeGround',4,...
		'position',[155,48,235,92])


%     Subsystem  'Min//max index'.

new_system([sys,'/','Min//max index'])
set_param([sys,'/','Min//max index'],'Location',[192,461,623,564])

add_block('built-in/S-Function',[sys,'/','Min//max index/Maximum'])
set_param([sys,'/','Min//max index/Maximum'],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])

add_block('built-in/Outport',[sys,'/','Min//max index/out_1'])
set_param([sys,'/','Min//max index/out_1'],...
		'position',[335,20,355,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Min//max index/Zero-Order',13,'Hold']])
set_param([sys,'/',['Min//max index/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Inport',[sys,'/','Min//max index/in_1'])
set_param([sys,'/','Min//max index/in_1'],...
		'position',[65,20,85,40])
add_line([sys,'/','Min//max index'],[205,30;235,30])
add_line([sys,'/','Min//max index'],[325,30;330,30])
add_line([sys,'/','Min//max index'],[90,30;160,30])
set_param([sys,'/','Min//max index'],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/','Min//max index'],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/','Min//max index'],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/','Min//max index'],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/','Min//max index'],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block 'Min//max index'.

set_param([sys,'/','Min//max index'],...
		'position',[445,348,525,392])


%     Subsystem  'MASK map'.

new_system([sys,'/','MASK map'])
set_param([sys,'/','MASK map'],'Location',[520,162,902,335])

add_block('built-in/Constant',[sys,'/','MASK map/Gain diff'])
set_param([sys,'/','MASK map/Gain diff'],...
		'Value','Ac',...
		'position',[180,96,215,124])

add_block('built-in/Sum',[sys,'/','MASK map/Sum1'])
set_param([sys,'/','MASK map/Sum1'],...
		'inputs','+-',...
		'position',[250,63,270,87])

add_block('built-in/Gain',[sys,'/','MASK map/Gain'])
set_param([sys,'/','MASK map/Gain'],...
		'Gain','Kc',...
		'position',[180,25,220,55])

add_block('built-in/Inport',[sys,'/','MASK map/in_1'])
set_param([sys,'/','MASK map/in_1'],...
		'position',[40,30,60,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK map/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[100,24,135,56])

add_block('built-in/Outport',[sys,'/','MASK map/out_1'])
set_param([sys,'/','MASK map/out_1'],...
		'position',[315,65,335,85])
add_line([sys,'/','MASK map'],[140,40;175,40])
add_line([sys,'/','MASK map'],[65,40;95,40])
add_line([sys,'/','MASK map'],[275,75;310,75])
add_line([sys,'/','MASK map'],[220,110;230,110;230,80;245,80])
add_line([sys,'/','MASK map'],[225,40;230,40;230,70;245,70])
set_param([sys,'/','MASK map'],...
		'Mask Display','MASK\nmap',...
		'Mask Type','MASK map')
set_param([sys,'/','MASK map'],...
		'Mask Dialogue','Map a digital symbol onto an analog\nsignal in the range [-1, 1] using M-ary\namplitude shift keying modulation mapping.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/','MASK map'],...
		'Mask Translate','N=@1;Ac=1;Kc=Ac*2/(N-1);td=@2;')
set_param([sys,'/','MASK map'],...
		'Mask Help','This block maps an input digit signal onto a signal in the range [-1, 1]. The coded signal can be modulated using analog\nmodulation blocks. Input digits are in the range [0, M-1], where M is the M-ary number. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/','MASK map'],...
		'Mask Entries','M\/td\/')


%     Finished composite block 'MASK map'.

set_param([sys,'/','MASK map'],...
		'position',[40,48,120,92])


%     Subsystem  'Min//max index2'.

new_system([sys,'/','Min//max index2'])
set_param([sys,'/','Min//max index2'],'Location',[192,461,623,564])

add_block('built-in/Inport',[sys,'/','Min//max index2/in_1'])
set_param([sys,'/','Min//max index2/in_1'],...
		'position',[65,20,85,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Min//max index2/Zero-Order',13,'Hold']])
set_param([sys,'/',['Min//max index2/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Outport',[sys,'/','Min//max index2/out_1'])
set_param([sys,'/','Min//max index2/out_1'],...
		'position',[335,20,355,40])

add_block('built-in/S-Function',[sys,'/','Min//max index2/Maximum'])
set_param([sys,'/','Min//max index2/Maximum'],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])
add_line([sys,'/','Min//max index2'],[90,30;160,30])
add_line([sys,'/','Min//max index2'],[325,30;330,30])
add_line([sys,'/','Min//max index2'],[205,30;235,30])
set_param([sys,'/','Min//max index2'],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/','Min//max index2'],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/','Min//max index2'],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/','Min//max index2'],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/','Min//max index2'],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block 'Min//max index2'.

set_param([sys,'/','Min//max index2'],...
		'position',[445,423,525,467])


%     Subsystem  'Min//max index3'.

new_system([sys,'/','Min//max index3'])
set_param([sys,'/','Min//max index3'],'Location',[192,461,623,564])

add_block('built-in/S-Function',[sys,'/','Min//max index3/Maximum'])
set_param([sys,'/','Min//max index3/Maximum'],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])

add_block('built-in/Outport',[sys,'/','Min//max index3/out_1'])
set_param([sys,'/','Min//max index3/out_1'],...
		'position',[335,20,355,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Min//max index3/Zero-Order',13,'Hold']])
set_param([sys,'/',['Min//max index3/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Inport',[sys,'/','Min//max index3/in_1'])
set_param([sys,'/','Min//max index3/in_1'],...
		'position',[65,20,85,40])
add_line([sys,'/','Min//max index3'],[205,30;235,30])
add_line([sys,'/','Min//max index3'],[325,30;330,30])
add_line([sys,'/','Min//max index3'],[90,30;160,30])
set_param([sys,'/','Min//max index3'],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/','Min//max index3'],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/','Min//max index3'],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/','Min//max index3'],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/','Min//max index3'],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block 'Min//max index3'.

set_param([sys,'/','Min//max index3'],...
		'position',[445,498,525,542])


%     Subsystem  ['PM',13,'passband'].

new_system([sys,'/',['PM',13,'passband']])
set_param([sys,'/',['PM',13,'passband']],'Location',[358,506,869,673])

add_block('built-in/Clock',[sys,'/',['PM',13,'passband/Clock']])
set_param([sys,'/',['PM',13,'passband/Clock']],...
		'position',[40,65,60,85])

add_block('built-in/Sum',[sys,'/',['PM',13,'passband/Sum2']])
set_param([sys,'/',['PM',13,'passband/Sum2']],...
		'inputs','+-',...
		'position',[220,55,245,90])

add_block('built-in/Outport',[sys,'/',['PM',13,'passband/out_1']])
set_param([sys,'/',['PM',13,'passband/out_1']],...
		'position',[445,65,465,85])

add_block('built-in/Inport',[sys,'/',['PM',13,'passband/in_1']])
set_param([sys,'/',['PM',13,'passband/in_1']],...
		'position',[150,10,170,30])

add_block('built-in/Fcn',[sys,'/',['PM',13,'passband/Fcn']])
set_param([sys,'/',['PM',13,'passband/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[325,60,400,90])

add_block('built-in/Sum',[sys,'/',['PM',13,'passband/Sum1']])
set_param([sys,'/',['PM',13,'passband/Sum1']],...
		'inputs','+++',...
		'position',[280,57,300,93])

add_block('built-in/Gain',[sys,'/',['PM',13,'passband/Gain']])
set_param([sys,'/',['PM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[80,60,120,90])

add_block('built-in/Zero-Order Hold',[sys,'/',['PM',13,'passband/Zero-Order',13,'Hold']])
set_param([sys,'/',['PM',13,'passband/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[150,94,185,126])

add_block('built-in/Constant',[sys,'/',['PM',13,'passband/Initial value']])
set_param([sys,'/',['PM',13,'passband/Initial value']],...
		'Value','Ph',...
		'position',[220,120,240,140])
add_line([sys,'/',['PM',13,'passband']],[405,75;440,75])
add_line([sys,'/',['PM',13,'passband']],[245,130;255,130;255,85;275,85])
add_line([sys,'/',['PM',13,'passband']],[305,75;320,75])
add_line([sys,'/',['PM',13,'passband']],[175,20;255,20;255,65;275,65])
add_line([sys,'/',['PM',13,'passband']],[65,75;75,75])
add_line([sys,'/',['PM',13,'passband']],[250,75;275,75])
add_line([sys,'/',['PM',13,'passband']],[125,75;165,75;165,65;215,65])
add_line([sys,'/',['PM',13,'passband']],[190,110;195,110;195,80;215,80])
add_line([sys,'/',['PM',13,'passband']],[125,75;130,75;130,110;145,110])
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);PM',...
		'Mask Type','Passband PM')
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using PM method.|Carrier frequency (Hz):|Initial phase (rad):|Symbol interval (sec, Use inf for analog case):')
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;td=@3;if isinf(td),td=inf;end;[x,y]=moduicon(3);',...
		'Mask Help','The PM block causes the change of the carrier signal depending on the input signal voltage.')
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/.1\/')


%     Finished composite block ['PM',13,'passband'].

set_param([sys,'/',['PM',13,'passband']],...
		'ForeGround',4,...
		'position',[155,498,235,542])


%     Subsystem  ['FM',13,'passband'].

new_system([sys,'/',['FM',13,'passband']])
set_param([sys,'/',['FM',13,'passband']],'Location',[451,587,939,737])

add_block('built-in/Sum',[sys,'/',['FM',13,'passband/Sum']])
set_param([sys,'/',['FM',13,'passband/Sum']],...
		'position',[130,42,150,78])

add_block('built-in/S-Function',[sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']])
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf/2\/',...
		'position',[200,39,260,81])

add_block('built-in/Constant',[sys,'/',['FM',13,'passband/Constant']])
set_param([sys,'/',['FM',13,'passband/Constant']],...
		'Value','Fc',...
		'position',[40,85,60,105])

add_block('built-in/Fcn',[sys,'/',['FM',13,'passband/sin']])
set_param([sys,'/',['FM',13,'passband/sin']],...
		'Expr','cos(u[1]*pi2+Ph)',...
		'position',[290,45,430,75])

add_block('built-in/Outport',[sys,'/',['FM',13,'passband/out_1']])
set_param([sys,'/',['FM',13,'passband/out_1']],...
		'position',[465,50,485,70])

add_block('built-in/Inport',[sys,'/',['FM',13,'passband/in_1']])
set_param([sys,'/',['FM',13,'passband/in_1']],...
		'position',[60,40,80,60])
add_line([sys,'/',['FM',13,'passband']],[85,50;125,50])
add_line([sys,'/',['FM',13,'passband']],[65,95;90,95;90,70;125,70])
add_line([sys,'/',['FM',13,'passband']],[155,60;195,60])
add_line([sys,'/',['FM',13,'passband']],[265,60;285,60])
add_line([sys,'/',['FM',13,'passband']],[435,60;460,60])
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);FM',...
		'Mask Type','Passband FM')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using FM method.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):|Symbol interval (sec; Use Inf for analog mod);')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2;pi2=2*pi;ts=@3;td=@4;if isinf(td),td=inf;end;[x,y]=moduicon(3);')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Help','This block modulates the input signal using frequency modulation method. The frequency of the output of the carrier signal depends on the amplitude of the input signal.')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/.01\/Inf\/')


%     Finished composite block ['FM',13,'passband'].

set_param([sys,'/',['FM',13,'passband']],...
		'ForeGround',4,...
		'position',[155,348,235,392])
add_line(sys,[125,370;150,370])
add_line(sys,[240,370;315,370])
add_line(sys,[405,135;440,135])
add_line(sys,[405,155;440,155])
add_line(sys,[125,135;150,135])
add_line(sys,[125,155;150,155])
add_line(sys,[405,70;440,70])
add_line(sys,[125,70;150,70])
add_line(sys,[285,370;285,445;315,445])
add_line(sys,[405,370;440,370])
add_line(sys,[405,445;440,445])
add_line(sys,[405,520;440,520])
add_line(sys,[240,520;315,520])
add_line(sys,[125,520;150,520])
add_line(sys,[405,305;440,305])
add_line(sys,[405,285;440,285])
add_line(sys,[125,305;150,305])
add_line(sys,[125,285;150,285])
add_line(sys,[125,210;150,210])
add_line(sys,[125,230;150,230])
add_line(sys,[405,210;440,210])
add_line(sys,[405,230;440,230])
add_line(sys,[240,145;315,145])
add_line(sys,[240,220;315,220])
add_line(sys,[240,295;315,295])
add_line(sys,[240,70;315,70])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
