function [ret,x0,str,ts,xts]=com_momp(t,x,u,flag);
%COM_MOMP	is the M-file description of the SIMULINK system named COM_MOMP.
%	The block-diagram can be displayed by typing: COM_MOMP.
%
%	SYS=COM_MOMP(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_MOMP to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_MOMP with a FLAG of zero:
%	[SIZES]=COM_MOMP([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[71,44,710,709])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Blocks that can be found in some other sublibraries in this toolbox'.

new_system([sys,'/','Blocks that can be found in some other sublibraries in this toolbox'])
set_param([sys,'/','Blocks that can be found in some other sublibraries in this toolbox'],'Location',[175,552,335,697])
set_param([sys,'/','Blocks that can be found in some other sublibraries in this toolbox'],...
		'Mask Display','.')


%     Finished composite block 'Blocks that can be found in some other sublibraries in this toolbox'.

set_param([sys,'/','Blocks that can be found in some other sublibraries in this toolbox'],...
		'orientation',1,...
		'ForeGround',4,...
		'position',[35,635,90,658])


%     Subsystem  'Mapping//demapping blocks '.

new_system([sys,'/','Mapping//demapping blocks '])
set_param([sys,'/','Mapping//demapping blocks '],'Location',[175,552,335,697])
set_param([sys,'/','Mapping//demapping blocks '],...
		'Mask Display','.')


%     Finished composite block 'Mapping//demapping blocks '.

set_param([sys,'/','Mapping//demapping blocks '],...
		'orientation',1,...
		'position',[35,605,90,628])


%     Subsystem  'Demonstration blocks'.

new_system([sys,'/','Demonstration blocks'])
set_param([sys,'/','Demonstration blocks'],'Location',[175,552,335,697])
set_param([sys,'/','Demonstration blocks'],...
		'Mask Display','.')


%     Finished composite block 'Demonstration blocks'.

set_param([sys,'/','Demonstration blocks'],...
		'orientation',1,...
		'BackGround',7,...
		'position',[35,575,90,598])


%     Subsystem  ['QAM',13,'baseband'].

new_system([sys,'/',['QAM',13,'baseband']])
set_param([sys,'/',['QAM',13,'baseband']],'Location',[321,500,954,793])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/I_out']])
set_param([sys,'/',['QAM',13,'baseband/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Sum',[sys,'/',['QAM',13,'baseband/Sum1']])
set_param([sys,'/',['QAM',13,'baseband/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product2']])
set_param([sys,'/',['QAM',13,'baseband/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product3']])
set_param([sys,'/',['QAM',13,'baseband/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/I2']])
set_param([sys,'/',['QAM',13,'baseband/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/R2']])
set_param([sys,'/',['QAM',13,'baseband/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Inport',[sys,'/',['QAM',13,'baseband/in_2']])
set_param([sys,'/',['QAM',13,'baseband/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/I1']])
set_param([sys,'/',['QAM',13,'baseband/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Constant',[sys,'/',['QAM',13,'baseband/Constant1']])
set_param([sys,'/',['QAM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Constant',[sys,'/',['QAM',13,'baseband/Constant']])
set_param([sys,'/',['QAM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Outport',[sys,'/',['QAM',13,'baseband/out_1']])
set_param([sys,'/',['QAM',13,'baseband/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Inport',[sys,'/',['QAM',13,'baseband/in_1']])
set_param([sys,'/',['QAM',13,'baseband/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Mux',[sys,'/',['QAM',13,'baseband/RI2C']])
set_param([sys,'/',['QAM',13,'baseband/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex',...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['QAM',13,'baseband/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['QAM',13,'baseband/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/R_out']])
set_param([sys,'/',['QAM',13,'baseband/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Sum',[sys,'/',['QAM',13,'baseband/Sum']])
set_param([sys,'/',['QAM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product1']])
set_param([sys,'/',['QAM',13,'baseband/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product']])
set_param([sys,'/',['QAM',13,'baseband/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/R1']])
set_param([sys,'/',['QAM',13,'baseband/R1']],...
		'position',[190,15,195,20])
add_line([sys,'/',['QAM',13,'baseband']],[410,220;425,220;425,150;465,150])
add_line([sys,'/',['QAM',13,'baseband']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['QAM',13,'baseband']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['QAM',13,'baseband']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['QAM',13,'baseband']],[120,40;295,40])
add_line([sys,'/',['QAM',13,'baseband']],[238,40;238,190;305,190])
add_line([sys,'/',['QAM',13,'baseband']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['QAM',13,'baseband']],[270,155;270,235;305,235])
add_line([sys,'/',['QAM',13,'baseband']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['QAM',13,'baseband']],[280,175;280,200;305,200])
add_line([sys,'/',['QAM',13,'baseband']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['QAM',13,'baseband']],[250,100;250,245;305,245])
add_line([sys,'/',['QAM',13,'baseband']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['QAM',13,'baseband']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['QAM',13,'baseband']],[550,140;580,140])
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Entries','0\/')


%     Finished composite block ['QAM',13,'baseband'].

set_param([sys,'/',['QAM',13,'baseband']],...
		'ForeGround',4,...
		'position',[150,118,230,162])


%     Subsystem  ['QAM',13,'baseband1'].

new_system([sys,'/',['QAM',13,'baseband1']])
set_param([sys,'/',['QAM',13,'baseband1']],'Location',[321,500,954,793])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband1/R1']])
set_param([sys,'/',['QAM',13,'baseband1/R1']],...
		'position',[190,15,195,20])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband1/Product']])
set_param([sys,'/',['QAM',13,'baseband1/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband1/Product1']])
set_param([sys,'/',['QAM',13,'baseband1/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Sum',[sys,'/',['QAM',13,'baseband1/Sum']])
set_param([sys,'/',['QAM',13,'baseband1/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband1/R_out']])
set_param([sys,'/',['QAM',13,'baseband1/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Mux',[sys,'/',['QAM',13,'baseband1/RI2C']])
set_param([sys,'/',['QAM',13,'baseband1/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex',...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['QAM',13,'baseband1/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['QAM',13,'baseband1/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Inport',[sys,'/',['QAM',13,'baseband1/in_1']])
set_param([sys,'/',['QAM',13,'baseband1/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Outport',[sys,'/',['QAM',13,'baseband1/out_1']])
set_param([sys,'/',['QAM',13,'baseband1/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Constant',[sys,'/',['QAM',13,'baseband1/Constant']])
set_param([sys,'/',['QAM',13,'baseband1/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Constant',[sys,'/',['QAM',13,'baseband1/Constant1']])
set_param([sys,'/',['QAM',13,'baseband1/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband1/I1']])
set_param([sys,'/',['QAM',13,'baseband1/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Inport',[sys,'/',['QAM',13,'baseband1/in_2']])
set_param([sys,'/',['QAM',13,'baseband1/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband1/R2']])
set_param([sys,'/',['QAM',13,'baseband1/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband1/I2']])
set_param([sys,'/',['QAM',13,'baseband1/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband1/Product3']])
set_param([sys,'/',['QAM',13,'baseband1/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband1/Product2']])
set_param([sys,'/',['QAM',13,'baseband1/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Sum',[sys,'/',['QAM',13,'baseband1/Sum1']])
set_param([sys,'/',['QAM',13,'baseband1/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband1/I_out']])
set_param([sys,'/',['QAM',13,'baseband1/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband1/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QAM',13,'baseband1/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])
add_line([sys,'/',['QAM',13,'baseband1']],[550,140;580,140])
add_line([sys,'/',['QAM',13,'baseband1']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['QAM',13,'baseband1']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['QAM',13,'baseband1']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['QAM',13,'baseband1']],[250,100;250,245;305,245])
add_line([sys,'/',['QAM',13,'baseband1']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['QAM',13,'baseband1']],[280,175;280,200;305,200])
add_line([sys,'/',['QAM',13,'baseband1']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['QAM',13,'baseband1']],[270,155;270,235;305,235])
add_line([sys,'/',['QAM',13,'baseband1']],[120,40;295,40])
add_line([sys,'/',['QAM',13,'baseband1']],[238,40;238,190;305,190])
add_line([sys,'/',['QAM',13,'baseband1']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['QAM',13,'baseband1']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['QAM',13,'baseband1']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['QAM',13,'baseband1']],[410,220;425,220;425,150;465,150])
set_param([sys,'/',['QAM',13,'baseband1']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['QAM',13,'baseband1']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['QAM',13,'baseband1']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['QAM',13,'baseband1']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['QAM',13,'baseband1']],...
		'Mask Entries','0\/')


%     Finished composite block ['QAM',13,'baseband1'].

set_param([sys,'/',['QAM',13,'baseband1']],...
		'ForeGround',4,...
		'position',[150,193,230,237])


%     Subsystem  ['QAM',13,'baseband2'].

new_system([sys,'/',['QAM',13,'baseband2']])
set_param([sys,'/',['QAM',13,'baseband2']],'Location',[321,500,954,793])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband2/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QAM',13,'baseband2/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband2/I_out']])
set_param([sys,'/',['QAM',13,'baseband2/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Sum',[sys,'/',['QAM',13,'baseband2/Sum1']])
set_param([sys,'/',['QAM',13,'baseband2/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband2/Product2']])
set_param([sys,'/',['QAM',13,'baseband2/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband2/Product3']])
set_param([sys,'/',['QAM',13,'baseband2/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband2/I2']])
set_param([sys,'/',['QAM',13,'baseband2/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband2/R2']])
set_param([sys,'/',['QAM',13,'baseband2/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Inport',[sys,'/',['QAM',13,'baseband2/in_2']])
set_param([sys,'/',['QAM',13,'baseband2/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband2/I1']])
set_param([sys,'/',['QAM',13,'baseband2/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Constant',[sys,'/',['QAM',13,'baseband2/Constant1']])
set_param([sys,'/',['QAM',13,'baseband2/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Constant',[sys,'/',['QAM',13,'baseband2/Constant']])
set_param([sys,'/',['QAM',13,'baseband2/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Outport',[sys,'/',['QAM',13,'baseband2/out_1']])
set_param([sys,'/',['QAM',13,'baseband2/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Inport',[sys,'/',['QAM',13,'baseband2/in_1']])
set_param([sys,'/',['QAM',13,'baseband2/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Mux',[sys,'/',['QAM',13,'baseband2/RI2C']])
set_param([sys,'/',['QAM',13,'baseband2/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex',...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['QAM',13,'baseband2/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['QAM',13,'baseband2/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband2/R_out']])
set_param([sys,'/',['QAM',13,'baseband2/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Sum',[sys,'/',['QAM',13,'baseband2/Sum']])
set_param([sys,'/',['QAM',13,'baseband2/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband2/Product1']])
set_param([sys,'/',['QAM',13,'baseband2/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband2/Product']])
set_param([sys,'/',['QAM',13,'baseband2/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband2/R1']])
set_param([sys,'/',['QAM',13,'baseband2/R1']],...
		'position',[190,15,195,20])
add_line([sys,'/',['QAM',13,'baseband2']],[410,220;425,220;425,150;465,150])
add_line([sys,'/',['QAM',13,'baseband2']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['QAM',13,'baseband2']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['QAM',13,'baseband2']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['QAM',13,'baseband2']],[120,40;295,40])
add_line([sys,'/',['QAM',13,'baseband2']],[238,40;238,190;305,190])
add_line([sys,'/',['QAM',13,'baseband2']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['QAM',13,'baseband2']],[270,155;270,235;305,235])
add_line([sys,'/',['QAM',13,'baseband2']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['QAM',13,'baseband2']],[280,175;280,200;305,200])
add_line([sys,'/',['QAM',13,'baseband2']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['QAM',13,'baseband2']],[250,100;250,245;305,245])
add_line([sys,'/',['QAM',13,'baseband2']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['QAM',13,'baseband2']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['QAM',13,'baseband2']],[550,140;580,140])
set_param([sys,'/',['QAM',13,'baseband2']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['QAM',13,'baseband2']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['QAM',13,'baseband2']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['QAM',13,'baseband2']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['QAM',13,'baseband2']],...
		'Mask Entries','0\/')


%     Finished composite block ['QAM',13,'baseband2'].

set_param([sys,'/',['QAM',13,'baseband2']],...
		'ForeGround',4,...
		'position',[150,268,230,312])


%     Subsystem  ['PM',13,'baseband'].

new_system([sys,'/',['PM',13,'baseband']])
set_param([sys,'/',['PM',13,'baseband']],'Location',[320,489,688,666])

add_block('built-in/Mux',[sys,'/',['PM',13,'baseband/Mux']])
set_param([sys,'/',['PM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[250,51,285,84])

add_block('built-in/Outport',[sys,'/',['PM',13,'baseband/out_1']])
set_param([sys,'/',['PM',13,'baseband/out_1']],...
		'position',[315,60,335,80])

add_block('built-in/Fcn',[sys,'/',['PM',13,'baseband/sin']])
set_param([sys,'/',['PM',13,'baseband/sin']],...
		'Expr','sin(u)',...
		'position',[155,106,210,134])

add_block('built-in/Fcn',[sys,'/',['PM',13,'baseband/cos']])
set_param([sys,'/',['PM',13,'baseband/cos']],...
		'Expr','cos(u)',...
		'position',[155,46,210,74])

add_block('built-in/Inport',[sys,'/',['PM',13,'baseband/in_1']])
set_param([sys,'/',['PM',13,'baseband/in_1']],...
		'position',[35,50,55,70])
add_line([sys,'/',['PM',13,'baseband']],[215,60;245,60])
add_line([sys,'/',['PM',13,'baseband']],[290,70;310,70])
add_line([sys,'/',['PM',13,'baseband']],[215,120;230,120;230,75;245,75])
add_line([sys,'/',['PM',13,'baseband']],[60,60;150,60])
add_line([sys,'/',['PM',13,'baseband']],[130,60;130,120;150,120])
set_param([sys,'/',['PM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);PM',...
		'Mask Type','PM CE',...
		'Mask Dialogue','Output the complex envelope of a PM\nmodulated signal.|Initial phase (rad):')
set_param([sys,'/',['PM',13,'baseband']],...
		'Mask Translate','Ph=@1;pi2=2*pi;[x,y]=moduicon(3);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['PM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the phase modulated signal. The output of this block is a complex signal.',...
		'Mask Entries','0\/')


%     Finished composite block ['PM',13,'baseband'].

set_param([sys,'/',['PM',13,'baseband']],...
		'ForeGround',4,...
		'position',[150,493,230,537])


%     Subsystem  ['DSB AM',13,'baseband'].

new_system([sys,'/',['DSB AM',13,'baseband']])
set_param([sys,'/',['DSB AM',13,'baseband']],'Location',[212,430,575,573])

add_block('built-in/Outport',[sys,'/',['DSB AM',13,'baseband/out_1']])
set_param([sys,'/',['DSB AM',13,'baseband/out_1']],...
		'position',[320,50,340,70])

add_block('built-in/Product',[sys,'/',['DSB AM',13,'baseband/Product']])
set_param([sys,'/',['DSB AM',13,'baseband/Product']],...
		'position',[255,42,280,73])

add_block('built-in/Inport',[sys,'/',['DSB AM',13,'baseband/in_1']])
set_param([sys,'/',['DSB AM',13,'baseband/in_1']],...
		'position',[115,15,135,35])

add_block('built-in/Mux',[sys,'/',['DSB AM',13,'baseband/Mux']])
set_param([sys,'/',['DSB AM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[170,66,205,99])

add_block('built-in/Constant',[sys,'/',['DSB AM',13,'baseband/Constant1']])
set_param([sys,'/',['DSB AM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[90,90,110,110])

add_block('built-in/Constant',[sys,'/',['DSB AM',13,'baseband/Constant']])
set_param([sys,'/',['DSB AM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[40,65,60,85])
add_line([sys,'/',['DSB AM',13,'baseband']],[65,75;165,75])
add_line([sys,'/',['DSB AM',13,'baseband']],[115,100;130,100;130,90;165,90])
add_line([sys,'/',['DSB AM',13,'baseband']],[140,25;185,25;185,50;250,50])
add_line([sys,'/',['DSB AM',13,'baseband']],[285,60;315,60])
add_line([sys,'/',['DSB AM',13,'baseband']],[210,85;230,85;230,65;250,65])
set_param([sys,'/',['DSB AM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);DSB AM',...
		'Mask Type','DSB-SC AM CE',...
		'Mask Dialogue','Output the complex envelope of a\nDSB-SC AM modulated signal.|Initial Phase (rad):')
set_param([sys,'/',['DSB AM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);pi2=2*pi;[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['DSB AM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the double-sideband suppressed-carrier amplitude modulated signal. The output is a complex signal.',...
		'Mask Entries','pi/2\/')


%     Finished composite block ['DSB AM',13,'baseband'].

set_param([sys,'/',['DSB AM',13,'baseband']],...
		'ForeGround',4,...
		'position',[150,43,230,87])


%     Subsystem  'MASK map'.

new_system([sys,'/','MASK map'])
set_param([sys,'/','MASK map'],'Location',[520,162,902,335])

add_block('built-in/Outport',[sys,'/','MASK map/out_1'])
set_param([sys,'/','MASK map/out_1'],...
		'position',[315,65,335,85])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK map/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[100,24,135,56])

add_block('built-in/Inport',[sys,'/','MASK map/in_1'])
set_param([sys,'/','MASK map/in_1'],...
		'position',[40,30,60,50])

add_block('built-in/Gain',[sys,'/','MASK map/Gain'])
set_param([sys,'/','MASK map/Gain'],...
		'Gain','Kc',...
		'position',[180,25,220,55])

add_block('built-in/Sum',[sys,'/','MASK map/Sum1'])
set_param([sys,'/','MASK map/Sum1'],...
		'inputs','+-',...
		'position',[250,63,270,87])

add_block('built-in/Constant',[sys,'/','MASK map/Gain diff'])
set_param([sys,'/','MASK map/Gain diff'],...
		'Value','Ac',...
		'position',[180,96,215,124])
add_line([sys,'/','MASK map'],[225,40;230,40;230,70;245,70])
add_line([sys,'/','MASK map'],[220,110;230,110;230,80;245,80])
add_line([sys,'/','MASK map'],[275,75;310,75])
add_line([sys,'/','MASK map'],[65,40;95,40])
add_line([sys,'/','MASK map'],[140,40;175,40])
set_param([sys,'/','MASK map'],...
		'Mask Display','MASK\nmap',...
		'Mask Type','MASK map')
set_param([sys,'/','MASK map'],...
		'Mask Dialogue','Map a digital symbol onto an analog\nsignal in the range [-1, 1] using M-ary\namplitude shift keying modulation mapping.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/','MASK map'],...
		'Mask Translate','N=@1;Ac=1;Kc=Ac*2/(N-1);td=@2;')
set_param([sys,'/','MASK map'],...
		'Mask Help','This block maps an input digit signal onto a signal in the range [-1, 1]. The coded signal can be modulated using analog\nmodulation blocks. Input digits are in the range [0, M-1], where M is the M-ary number. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/','MASK map'],...
		'Mask Entries','M\/td\/')


%     Finished composite block 'MASK map'.

set_param([sys,'/','MASK map'],...
		'position',[30,43,110,87])


%     Subsystem  'MPSK map'.

new_system([sys,'/','MPSK map'])
set_param([sys,'/','MPSK map'],'Location',[71,474,419,648])

add_block('built-in/Inport',[sys,'/','MPSK map/in_1'])
set_param([sys,'/','MPSK map/in_1'],...
		'position',[60,35,80,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MPSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[130,29,165,61])

add_block('built-in/Product',[sys,'/','MPSK map/Product'])
set_param([sys,'/','MPSK map/Product'],...
		'position',[235,76,260,109])

add_block('built-in/Outport',[sys,'/','MPSK map/out_1'])
set_param([sys,'/','MPSK map/out_1'],...
		'position',[310,85,330,105])

add_block('built-in/Constant',[sys,'/','MPSK map/Multiple factor'])
set_param([sys,'/','MPSK map/Multiple factor'],...
		'Value','Sft',...
		'position',[130,108,150,132])
add_line([sys,'/','MPSK map'],[170,45;200,45;200,85;230,85])
add_line([sys,'/','MPSK map'],[85,45;125,45])
add_line([sys,'/','MPSK map'],[265,95;305,95])
add_line([sys,'/','MPSK map'],[155,120;200,120;200,100;230,100])
set_param([sys,'/','MPSK map'],...
		'Mask Display','MPSK\nmap',...
		'Mask Type','MPSK map')
set_param([sys,'/','MPSK map'],...
		'Mask Dialogue','Map input digital signal to analog phase shift.|M-ary number (input integer in range [0, M-1]):|Input symbol interval and offset (sec):',...
		'Mask Translate','pi2=2*pi;Sft=pi2/@1;td=@2;')
set_param([sys,'/','MPSK map'],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the PM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. You can view the MPSK constellation using the MODMAP function.')
set_param([sys,'/','MPSK map'],...
		'Mask Entries','M\/td\/')


%     Finished composite block 'MPSK map'.

set_param([sys,'/','MPSK map'],...
		'position',[30,493,110,537])


%     Subsystem  ['QASK',13,'square-map'].

new_system([sys,'/',['QASK',13,'square-map']])
set_param([sys,'/',['QASK',13,'square-map']],'Location',[214,372,642,541])

add_block('built-in/Inport',[sys,'/',['QASK',13,'square-map/in_1']])
set_param([sys,'/',['QASK',13,'square-map/in_1']],...
		'position',[45,30,65,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'square-map/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'square-map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[110,24,145,56])

add_block('built-in/Outport',[sys,'/',['QASK',13,'square-map/out_1']])
set_param([sys,'/',['QASK',13,'square-map/out_1']],...
		'position',[325,30,345,50])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'square-map/s-x axis']])
set_param([sys,'/',['QASK',13,'square-map/s-x axis']],...
		'Input_Values','z',...
		'Output_Values','x',...
		'position',[245,25,280,55])

add_block('built-in/Outport',[sys,'/',['QASK',13,'square-map/out_2']])
set_param([sys,'/',['QASK',13,'square-map/out_2']],...
		'Port','2',...
		'position',[325,95,345,115])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'square-map/c-y axis']])
set_param([sys,'/',['QASK',13,'square-map/c-y axis']],...
		'Input_Values','z',...
		'Output_Values','y',...
		'position',[245,90,280,120])
add_line([sys,'/',['QASK',13,'square-map']],[285,40;320,40])
add_line([sys,'/',['QASK',13,'square-map']],[285,105;320,105])
add_line([sys,'/',['QASK',13,'square-map']],[150,40;240,40])
add_line([sys,'/',['QASK',13,'square-map']],[185,40;185,105;240,105])
add_line([sys,'/',['QASK',13,'square-map']],[70,40;105,40])
set_param([sys,'/',['QASK',13,'square-map']],...
		'Mask Display','QASK\nS-map',...
		'Mask Type','QASK S-map')
set_param([sys,'/',['QASK',13,'square-map']],...
		'Mask Dialogue','Use square constellation to map the\ninput digital signal into in-phase and\nquadrature components. M must be\nM=2^K with integer K.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'square-map']],...
		'Mask Translate','N=@1;Ac=1;td=@2;z=[[1:N];[1:N]];z=z(:);[x,y]=qaskenco(z-1,N);z=z-1.5;z=[z(2:2*N);N-.5];x=x/max(x);y=y/max(y);')
set_param([sys,'/',['QASK',13,'square-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The M-ary number must be M=2^K with integer K. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. The maximum amplitudes for the outputs are 1.')
set_param([sys,'/',['QASK',13,'square-map']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['QASK',13,'square-map'].

set_param([sys,'/',['QASK',13,'square-map']],...
		'position',[30,118,110,162])


%     Subsystem  ['QASK',13,'circle-map'].

new_system([sys,'/',['QASK',13,'circle-map']])
set_param([sys,'/',['QASK',13,'circle-map']],'Location',[58,103,403,268])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-map/Imag']])
set_param([sys,'/',['QASK',13,'circle-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-map/Real']])
set_param([sys,'/',['QASK',13,'circle-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'circle-map/imag part1']])
set_param([sys,'/',['QASK',13,'circle-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'circle-map/real part']])
set_param([sys,'/',['QASK',13,'circle-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-map/in_1']])
set_param([sys,'/',['QASK',13,'circle-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'circle-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])
add_line([sys,'/',['QASK',13,'circle-map']],[215,110;270,110])
add_line([sys,'/',['QASK',13,'circle-map']],[220,30;270,30])
add_line([sys,'/',['QASK',13,'circle-map']],[120,30;175,30])
add_line([sys,'/',['QASK',13,'circle-map']],[145,30;145,110;170,110])
add_line([sys,'/',['QASK',13,'circle-map']],[50,30;75,30])
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Display','QASK\nC-map',...
		'Mask Type','QASK C-map')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Dialogue','QASK mapping with circle constellation. The constellation is defined in NIC, RIC and PIC.|Number of symbols in each circle NIC:|Radii in each circle RIC:|Phase shift in each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y1=[y1;y1];y1=y1(:);y2=imag(y1);y1=real(y1);x=[-sum(N) 1:sum(N)-1;1:sum(N)-1 10*sum(N)]-.5;x=x(:);')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The circle constellation is defined in NIC, RIC, and PIC. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Entries','[6 12 18 24 30 38]\/[1 1.93 2.88 3.83 4.78 6.05]\/[0 0 0 0 0 0]\/td\/')


%     Finished composite block ['QASK',13,'circle-map'].

set_param([sys,'/',['QASK',13,'circle-map']],...
		'position',[30,193,110,237])


%     Subsystem  ['QASK',13,'arbitrary-map'].

new_system([sys,'/',['QASK',13,'arbitrary-map']])
set_param([sys,'/',['QASK',13,'arbitrary-map']],'Location',[58,103,403,268])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'arbitrary-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'arbitrary-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])

add_block('built-in/Inport',[sys,'/',['QASK',13,'arbitrary-map/in_1']])
set_param([sys,'/',['QASK',13,'arbitrary-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'arbitrary-map/real part']])
set_param([sys,'/',['QASK',13,'arbitrary-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'arbitrary-map/imag part1']])
set_param([sys,'/',['QASK',13,'arbitrary-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Outport',[sys,'/',['QASK',13,'arbitrary-map/Real']])
set_param([sys,'/',['QASK',13,'arbitrary-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Outport',[sys,'/',['QASK',13,'arbitrary-map/Imag']])
set_param([sys,'/',['QASK',13,'arbitrary-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])
add_line([sys,'/',['QASK',13,'arbitrary-map']],[50,30;75,30])
add_line([sys,'/',['QASK',13,'arbitrary-map']],[120,30;175,30])
add_line([sys,'/',['QASK',13,'arbitrary-map']],[145,30;145,110;170,110])
add_line([sys,'/',['QASK',13,'arbitrary-map']],[220,30;270,30])
add_line([sys,'/',['QASK',13,'arbitrary-map']],[215,110;270,110])
set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'Mask Display','QASK\nA-map',...
		'Mask Type','QASK A-map')
set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'Mask Dialogue','QASK mapping for arbitrary defined\nmap. Assume input digit is K. 1st\noutport outputs in-phase(K+1). 2nd\noutport outputs quadrature(K+1).|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;ly=length(y1);x=[-10 1:ly-1;1:ly-1 10*ly]-.5;x=x(:);y1=y1(:)'';y1=[y1;y1];y1=y1(:);y2=y2(:)'';y2=[y2;y2];y2=y2(:);')
set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The input signal is in the range of [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'Mask Entries','real(exp(j*[0:M-1]/M*pi*2))\/imag(exp(j*[0:M-1]/M*pi*2))\/td\/')


%     Finished composite block ['QASK',13,'arbitrary-map'].

set_param([sys,'/',['QASK',13,'arbitrary-map']],...
		'position',[30,268,110,312])


%     Subsystem  ['FM',13,'baseband'].

new_system([sys,'/',['FM',13,'baseband']])
set_param([sys,'/',['FM',13,'baseband']],'Location',[55,571,668,718])

add_block('built-in/Constant',[sys,'/',['FM',13,'baseband/Constant']])
set_param([sys,'/',['FM',13,'baseband/Constant']],...
		'Value','Ph',...
		'position',[180,90,205,110])

add_block('built-in/Sum',[sys,'/',['FM',13,'baseband/Sum']])
set_param([sys,'/',['FM',13,'baseband/Sum']],...
		'position',[265,30,285,50])

add_block('built-in/Inport',[sys,'/',['FM',13,'baseband/in_1']])
set_param([sys,'/',['FM',13,'baseband/in_1']],...
		'position',[35,25,55,45])

add_block('built-in/Fcn',[sys,'/',['FM',13,'baseband/cos']])
set_param([sys,'/',['FM',13,'baseband/cos']],...
		'Expr','cos(u)',...
		'position',[330,26,385,54])

add_block('built-in/Fcn',[sys,'/',['FM',13,'baseband/sin']])
set_param([sys,'/',['FM',13,'baseband/sin']],...
		'Expr','sin(u)',...
		'position',[330,86,385,114])

add_block('built-in/Mux',[sys,'/',['FM',13,'baseband/Mux']])
set_param([sys,'/',['FM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[415,31,450,64])

add_block('built-in/Outport',[sys,'/',['FM',13,'baseband/out_1']])
set_param([sys,'/',['FM',13,'baseband/out_1']],...
		'position',[550,40,570,60])

add_block('built-in/Gain',[sys,'/',['FM',13,'baseband/Sensitivity']])
set_param([sys,'/',['FM',13,'baseband/Sensitivity']],...
		'Gain','pi2',...
		'position',[80,25,120,55])

add_block('built-in/S-Function',[sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']])
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/pi2\/',...
		'position',[155,14,215,56])
add_line([sys,'/',['FM',13,'baseband']],[290,40;325,40])
add_line([sys,'/',['FM',13,'baseband']],[300,40;300,100;325,100])
add_line([sys,'/',['FM',13,'baseband']],[210,100;250,100;260,45])
add_line([sys,'/',['FM',13,'baseband']],[220,35;260,35])
add_line([sys,'/',['FM',13,'baseband']],[390,40;410,40])
add_line([sys,'/',['FM',13,'baseband']],[455,50;545,50])
add_line([sys,'/',['FM',13,'baseband']],[390,100;395,100;395,55;410,55])
add_line([sys,'/',['FM',13,'baseband']],[60,35;60,40;75,40])
add_line([sys,'/',['FM',13,'baseband']],[125,40;150,35])
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);FM',...
		'Mask Type','FM CE')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of the FM signal.|Initial phase (rad):|Sample time (second):|Symbol interval (for digital mod, use Inf for analog mod):')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Translate','Kc=2*pi;Ph=@1;pi2=2*pi;ts=@2;td=@3;if isinf(td),td=inf;end;[x,y]=moduicon(3);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the frequency modulated signal. The output is a complex signal. This block resets the phase at the very beginning of the symbol interval. For continuous-time simulation, the symbol interval can be set as infinity.')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Entries','0\/.01\/Inf\/')


%     Finished composite block ['FM',13,'baseband'].

set_param([sys,'/',['FM',13,'baseband']],...
		'ForeGround',4,...
		'position',[155,343,230,387])


%     Subsystem  'MFSK map'.

new_system([sys,'/','MFSK map'])
set_param([sys,'/','MFSK map'],'Location',[90,420,407,543])

add_block('built-in/Zero-Order Hold',[sys,'/',['MFSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MFSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[105,39,140,71])

add_block('built-in/Outport',[sys,'/','MFSK map/out_1'])
set_param([sys,'/','MFSK map/out_1'],...
		'position',[260,45,280,65])

add_block('built-in/Gain',[sys,'/','MFSK map/Gain'])
set_param([sys,'/','MFSK map/Gain'],...
		'Gain','Ton',...
		'position',[175,38,225,72])

add_block('built-in/Inport',[sys,'/','MFSK map/in_1'])
set_param([sys,'/','MFSK map/in_1'],...
		'position',[45,45,65,65])
add_line([sys,'/','MFSK map'],[145,55;170,55])
add_line([sys,'/','MFSK map'],[70,55;100,55])
add_line([sys,'/','MFSK map'],[230,55;255,55])
set_param([sys,'/','MFSK map'],...
		'Mask Display','MFSK\nmap',...
		'Mask Type','MFSK map')
set_param([sys,'/','MFSK map'],...
		'Mask Dialogue','Map input digital signal to analog tone space for FM modulation. The tone space\nis the frequency distance between two \nconsective digit numbers.|Tone space (Hz):|Input symbol interval and offset (sec):')
set_param([sys,'/','MFSK map'],...
		'Mask Translate','Ton=@1;td=@2;')
set_param([sys,'/','MFSK map'],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the FM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. Tone space is the frequency separation between two consective digits for the input signal. After FM, the modulated signal has a frequency in the range of [Fc, Fc+B]. B is the bandwidth of the FSK, B=(M-1) * Tone_space.')
set_param([sys,'/','MFSK map'],...
		'Mask Entries','M/td/5\/td\/')


%     Finished composite block 'MFSK map'.

set_param([sys,'/','MFSK map'],...
		'position',[30,343,110,387])


%     Subsystem  ['ASK Mo//Dem',13,'demo'].

new_system([sys,'/',['ASK Mo//Dem',13,'demo']])
set_param([sys,'/',['ASK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['ASK Mo//Dem',13,'demo']],...
		'Mask Display','MASK\nmap\ndemo',...
		'Mask Dialogue','eval(''ts=.02;[num,den]=butter(2,100/pi/2*ts);td=.1;M=8;tmpam2cd'')')


%     Finished composite block ['ASK Mo//Dem',13,'demo'].

set_param([sys,'/',['ASK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[536,43,616,87])


%     Subsystem  ['PSK Mo//Dem',13,'demo'].

new_system([sys,'/',['PSK Mo//Dem',13,'demo']])
set_param([sys,'/',['PSK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['PSK Mo//Dem',13,'demo']],...
		'Mask Display','MPSK\nmap\ndemo',...
		'Mask Dialogue','eval(''ts=.01;td=.2;M=8;tmppk2cd'')')


%     Finished composite block ['PSK Mo//Dem',13,'demo'].

set_param([sys,'/',['PSK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[536,493,616,537])


%     Subsystem  ['FSK Mo//Dem',13,'demo'].

new_system([sys,'/',['FSK Mo//Dem',13,'demo']])
set_param([sys,'/',['FSK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['FSK Mo//Dem',13,'demo']],...
		'Mask Display','MFSK\nmap\ndemo',...
		'Mask Dialogue','eval(''ts=.02;td=.2;M=8;tmpfs2cd'')')


%     Finished composite block ['FSK Mo//Dem',13,'demo'].

set_param([sys,'/',['FSK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[536,343,616,387])


%     Subsystem  ['QASK Mo//Dem',13,'demo2'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo2']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],...
		'Mask Display','QASK\nA-map\ndemo',...
		'Mask Dialogue','eval(''ts=.02;[num,den]=butter(3,100/pi/2*ts);td=.2;M=32;tmpps3cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo2'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[536,268,616,312])


%     Subsystem  ['QASK Mo//Dem',13,'demo1'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo1']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],...
		'Mask Display','QASK\nC-map\ndemo',...
		'Mask Dialogue','eval(''ts=.02;[num,den]=butter(3,100/pi/2*ts);td=.2;M=128;tmpps2cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo1'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[536,193,616,237])


%     Subsystem  ['QASK Mo//Dem',13,'demo'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo']],...
		'Mask Display','QASK\nS-map\ndemo',...
		'Mask Dialogue','eval(''ts=.04;[num,den]=butter(2,100/pi/2*ts);td=.2;M=64;tmpqa2cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[536,118,616,162])


%     Subsystem  ['Coh MFSK demod',13,'corr baseband'].

new_system([sys,'/',['Coh MFSK demod',13,'corr baseband']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],'Location',[124,519,842,743])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Entries','N\/td\/ts\/''backward''\/',...
		'position',[510,128,585,172])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Entries','N\/td\/ts\/''backward''\/',...
		'position',[505,18,580,62])

add_block('built-in/Sum',[sys,'/',['Coh MFSK demod',13,'corr baseband/Sum3']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Sum3']],...
		'position',[640,105,660,125])

add_block('built-in/Outport',[sys,'/',['Coh MFSK demod',13,'corr baseband/out_1']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/out_1']],...
		'position',[685,105,705,125])

add_block('built-in/Product',[sys,'/',['Coh MFSK demod',13,'corr baseband/Product3']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Product3']],...
		'position',[455,131,480,164])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK demod',13,'corr baseband/Array sin1']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Array sin1']],...
		'ForeGround',4,...
		'function name','arysin',...
		'parameters','''sin''',...
		'position',[330,145,380,165])

add_block('built-in/Product',[sys,'/',['Coh MFSK demod',13,'corr baseband/Product']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Product']],...
		'position',[450,21,475,54])

add_block('built-in/Demux',[sys,'/',['Coh MFSK demod',13,'corr baseband/Demux']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Demux']],...
		'ForeGround',2,...
		'outputs','2',...
		'position',[330,20,370,55])

add_block('built-in/Inport',[sys,'/',['Coh MFSK demod',13,'corr baseband/in_1']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/in_1']],...
		'position',[260,30,280,50])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[125,39,185,81])

add_block('built-in/Constant',[sys,'/',['Coh MFSK demod',13,'corr baseband/Initial phase']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Initial phase']],...
		'Value','Ph',...
		'position',[105,113,125,137])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK demod',13,'corr baseband/Array sin']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Array sin']],...
		'ForeGround',3,...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[325,85,375,105])

add_block('built-in/Sum',[sys,'/',['Coh MFSK demod',13,'corr baseband/Sum1']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Sum1']],...
		'position',[265,77,290,108])

add_block('built-in/Constant',[sys,'/',['Coh MFSK demod',13,'corr baseband/Shift key']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Shift key']],...
		'Value','sft',...
		'position',[60,48,80,72])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[375,45;405,45;405,140;450,140])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[385,155;450,155])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[485,150;505,150])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[480,40;500,40])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[585,40;605,40;605,110;635,110])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[590,150;605,150;605,120;635,120])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[665,115;680,115])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[380,95;415,95;415,45;445,45])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[375,30;445,30])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[285,40;325,40])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[295,95;320,95])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[305,95;305,155;325,155])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[85,60;120,60])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[190,60;225,60;225,85;260,85])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[130,125;230,125;230,100;260,100])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'Mask Display','plot(0,0,100,100,u,v);   Co MFSK',...
		'Mask Type','Baseband coherent MFSK correlation')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'Mask Dialogue','Compute baseband MFSK correlation. Take\nMFSK CE modulated signal. Output a vector\nof correlation result.|M-ary number (input in range [0, M-1]):|Tone space (Hz):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'Mask Translate','pi2=2*pi;N=@1;Ph=@4;Ton=@2;sft=[0:N-1]*Ton*pi2;td=@3;ts=@5;[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'Mask Help','This block calculates the coherent correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their frequency the same as that of FM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MFSK demodulation result is the index of the largest output. The computation is phase sensitive. The input of this block is complex signal.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'Mask Entries','8\/8/.2/5\/.2\/0\/.01\/')


%     Finished composite block ['Coh MFSK demod',13,'corr baseband'].

set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'position',[285,343,365,387])


%     Subsystem  ['Non-coh MFSK dm',13,'corr baseband'].

new_system([sys,'/',['Non-coh MFSK dm',13,'corr baseband']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],'Location',[69,218,990,452])

add_block('built-in/S-Function',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Entries','N*2\/td\/ts\/''backward''\/',...
		'position',[525,133,600,177])

add_block('built-in/S-Function',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Entries','N*2\/td\/ts\/''backward''\/',...
		'position',[530,28,605,72])

add_block('built-in/Demux',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux']],...
		'outputs','2',...
		'position',[685,35,725,70])

add_block('built-in/Demux',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux2']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux2']],...
		'outputs','2',...
		'position',[695,140,735,175])

add_block('built-in/Outport',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/out_1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/out_1']],...
		'position',[830,100,850,120])

add_block('built-in/Product',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product']],...
		'position',[490,31,515,64])

add_block('built-in/Product',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product1']],...
		'position',[645,36,670,69])

add_block('built-in/Demux',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux1']],...
		'ForeGround',2,...
		'outputs','2',...
		'position',[395,30,435,65])

add_block('built-in/Inport',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/in_1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/in_1']],...
		'position',[345,40,365,60])

add_block('built-in/Product',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product3']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product3']],...
		'position',[480,136,505,169])

add_block('built-in/Product',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product2']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product2']],...
		'position',[645,141,670,174])

add_block('built-in/Sum',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum4']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum4']],...
		'inputs','++++',...
		'position',[785,87,805,133])

add_block('built-in/S-Function',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Array sin1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Array sin1']],...
		'ForeGround',4,...
		'function name','arysin',...
		'parameters','''sin''',...
		'position',[395,150,445,170])

add_block('built-in/S-Function',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Array sin']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Array sin']],...
		'ForeGround',3,...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[390,90,440,110])

add_block('built-in/Mux',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Mux']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Mux']],...
		'inputs','2',...
		'position',[325,78,355,122])

add_block('built-in/Constant',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Initial phase']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Initial phase']],...
		'Value','Ph',...
		'position',[85,118,105,142])

add_block('built-in/Sum',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum3']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum3']],...
		'position',[285,108,305,137])

add_block('built-in/Sum',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum1']],...
		'position',[210,72,235,103])

add_block('built-in/S-Function',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[105,34,165,76])

add_block('built-in/Constant',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Shift key']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Shift key']],...
		'Value','sft',...
		'position',[40,43,60,67])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[445,100;460,100;460,55;485,55])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[440,40;485,40])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[440,55;450,55;450,145;475,145])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[450,160;475,160])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[740,165;760,165;760,125;780,125])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[740,150;755,150;755,115;780,115])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[510,155;520,155])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[605,155;615,155;615,150;640,150])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[605,155;615,155;615,165;640,165])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[675,160;690,160])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[370,50;390,50])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[360,100;385,100])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[370,100;370,160;390,160])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[110,130;185,130;185,95;205,95])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[185,130;280,130])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[240,90;320,90])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[260,90;260,115;280,115])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[170,55;185,55;185,80;205,80])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[65,55;100,55])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[810,110;825,110])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[730,60;755,60;755,105;780,105])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[730,45;760,45;760,95;780,95])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[675,55;680,55])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[610,50;615,60;640,60])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[610,50;615,45;640,45])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[520,50;525,50])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[310,125;320,110])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Display','plot(0,0,100,100,u,v);  NC MFSK',...
		'Mask Type','Baseband non-coherent MFSK correlation')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Dialogue','Compute baseband MFSK correlation. Take\nMFSK CE modulated signal. Output a vector\nof correlation result.|M-ary number (input in range [0, M-1]):|Tone space (Hz):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Translate','pi2=2*pi;N=@1;Ph=@4;Ton=@2;sft=[0:N-1]*Ton*pi2;td=@3;ts=@5;[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Help','This block calculates the noncoherent correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their frequency the same as that of FM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MFSK demodulation result is the index of the largest output, using the Min/max demap block. The input of this block is complex signal.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Entries','8\/8/.2/5\/.2\/0\/.01\/')


%     Finished composite block ['Non-coh MFSK dm',13,'corr baseband'].

set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'position',[285,418,365,462])


%     Subsystem  ['MPSK demod',13,'corr baseband'].

new_system([sys,'/',['MPSK demod',13,'corr baseband']])
set_param([sys,'/',['MPSK demod',13,'corr baseband']],'Location',[102,505,735,711])

add_block('built-in/Constant',[sys,'/',['MPSK demod',13,'corr baseband/Shift key']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Shift key']],...
		'Value','sft',...
		'position',[40,63,60,87])

add_block('built-in/Sum',[sys,'/',['MPSK demod',13,'corr baseband/Sum1']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Sum1']],...
		'position',[165,75,190,115])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[420,19,480,61])

add_block('built-in/Product',[sys,'/',['MPSK demod',13,'corr baseband/Product']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Product']],...
		'position',[355,21,380,54])

add_block('built-in/Demux',[sys,'/',['MPSK demod',13,'corr baseband/Demux']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Demux']],...
		'ForeGround',2,...
		'outputs','2',...
		'position',[235,20,275,55])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'corr baseband/Array cos']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Array cos']],...
		'ForeGround',3,...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[230,85,280,105])

add_block('built-in/Outport',[sys,'/',['MPSK demod',13,'corr baseband/out_1']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/out_1']],...
		'position',[585,105,605,125])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'corr baseband/Array sin']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Array sin']],...
		'ForeGround',4,...
		'function name','arysin',...
		'parameters','''sin''',...
		'position',[230,130,280,150])

add_block('built-in/Product',[sys,'/',['MPSK demod',13,'corr baseband/Product3']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Product3']],...
		'position',[355,116,380,149])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[420,114,480,156])

add_block('built-in/Inport',[sys,'/',['MPSK demod',13,'corr baseband/in_1']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/in_1']],...
		'position',[175,30,195,50])

add_block('built-in/Sum',[sys,'/',['MPSK demod',13,'corr baseband/Sum3']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Sum3']],...
		'position',[535,105,555,125])

add_block('built-in/Constant',[sys,'/',['MPSK demod',13,'corr baseband/Initial phase']])
set_param([sys,'/',['MPSK demod',13,'corr baseband/Initial phase']],...
		'Value','Ph',...
		'position',[100,93,120,117])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[200,40;230,40])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[280,45;310,45;310,125;350,125])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[285,140;350,140])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[385,135;415,135])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[385,40;415,40])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[485,40;510,40;510,110;530,110])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[485,135;510,135;510,120;530,120])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[560,115;580,115])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[285,95;320,95;320,45;350,45])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[280,30;350,30])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[195,95;225,95])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[205,95;205,140;225,140])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[125,105;160,105])
add_line([sys,'/',['MPSK demod',13,'corr baseband']],[65,75;95,75;95,85;160,85])
set_param([sys,'/',['MPSK demod',13,'corr baseband']],...
		'Mask Display','plot(0,0,100,100,u,v);  MPSK corr',...
		'Mask Type','Baseband MPSK correlationA')
set_param([sys,'/',['MPSK demod',13,'corr baseband']],...
		'Mask Dialogue','Compute Baseband MPSK correlation. Take\nMPSK CE modulated signal. Output a vector of correlation result.|M-ary number (integer in range [0, M-1]):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['MPSK demod',13,'corr baseband']],...
		'Mask Translate','pi2=2*pi;N=@1;sft=[0:N-1]*pi2/N;td=@2;Ph=@3;ts=@4;[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MPSK demod',13,'corr baseband']],...
		'Mask Help','This block calculates the correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their phase shift the same as that of PM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MPSK demodulation result is the index of the largest output, using the Min/max demap block. The input of this block is complex signal.')
set_param([sys,'/',['MPSK demod',13,'corr baseband']],...
		'Mask Entries','8\/.2\/0\/.01\/')


%     Finished composite block ['MPSK demod',13,'corr baseband'].

set_param([sys,'/',['MPSK demod',13,'corr baseband']],...
		'position',[285,493,365,537])


%     Subsystem  ['QADM',13,'baseband'].

new_system([sys,'/',['QADM',13,'baseband']])
set_param([sys,'/',['QADM',13,'baseband']],'Location',[283,122,827,462])

add_block('built-in/Outport',[sys,'/',['QADM',13,'baseband/out_1']])
set_param([sys,'/',['QADM',13,'baseband/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Note',[sys,'/',['QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Filter',[sys,'/',['QADM',13,'baseband/Filter']])
set_param([sys,'/',['QADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product']])
set_param([sys,'/',['QADM',13,'baseband/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Sum',[sys,'/',['QADM',13,'baseband/Sum']])
set_param([sys,'/',['QADM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product3']])
set_param([sys,'/',['QADM',13,'baseband/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product2']])
set_param([sys,'/',['QADM',13,'baseband/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Constant',[sys,'/',['QADM',13,'baseband/Constant']])
set_param([sys,'/',['QADM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Demux',[sys,'/',['QADM',13,'baseband/Demux']])
set_param([sys,'/',['QADM',13,'baseband/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product1']])
set_param([sys,'/',['QADM',13,'baseband/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Filter',[sys,'/',['QADM',13,'baseband/Filter1']])
set_param([sys,'/',['QADM',13,'baseband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Outport',[sys,'/',['QADM',13,'baseband/out_2']])
set_param([sys,'/',['QADM',13,'baseband/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Sum',[sys,'/',['QADM',13,'baseband/Sum1']])
set_param([sys,'/',['QADM',13,'baseband/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Constant',[sys,'/',['QADM',13,'baseband/Constant1']])
set_param([sys,'/',['QADM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Inport',[sys,'/',['QADM',13,'baseband/in_1']])
set_param([sys,'/',['QADM',13,'baseband/in_1']],...
		'position',[55,115,75,135])
add_line([sys,'/',['QADM',13,'baseband']],[455,230;480,230])
add_line([sys,'/',['QADM',13,'baseband']],[365,230;390,230])
add_line([sys,'/',['QADM',13,'baseband']],[450,80;475,80])
add_line([sys,'/',['QADM',13,'baseband']],[360,80;385,80])
add_line([sys,'/',['QADM',13,'baseband']],[80,125;115,125])
add_line([sys,'/',['QADM',13,'baseband']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['QADM',13,'baseband']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['QADM',13,'baseband']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['QADM',13,'baseband']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['QADM',13,'baseband']],[180,50;255,50])
add_line([sys,'/',['QADM',13,'baseband']],[215,50;215,200;265,200])
add_line([sys,'/',['QADM',13,'baseband']],[165,130;255,130])
add_line([sys,'/',['QADM',13,'baseband']],[180,130;180,210;265,210])
add_line([sys,'/',['QADM',13,'baseband']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['QADM',13,'baseband']],[200,255;265,255])
add_line([sys,'/',['QADM',13,'baseband']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['QADM',13,'baseband']],[230,115;230,245;265,245])
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Entries','[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/0\/.01\/')


%     Finished composite block ['QADM',13,'baseband'].

set_param([sys,'/',['QADM',13,'baseband']],...
		'ForeGround',4,...
		'position',[285,118,365,162])


%     Subsystem  ['QADM',13,'baseband1'].

new_system([sys,'/',['QADM',13,'baseband1']])
set_param([sys,'/',['QADM',13,'baseband1']],'Location',[283,122,827,462])

add_block('built-in/Inport',[sys,'/',['QADM',13,'baseband1/in_1']])
set_param([sys,'/',['QADM',13,'baseband1/in_1']],...
		'position',[55,115,75,135])

add_block('built-in/Constant',[sys,'/',['QADM',13,'baseband1/Constant1']])
set_param([sys,'/',['QADM',13,'baseband1/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Sum',[sys,'/',['QADM',13,'baseband1/Sum1']])
set_param([sys,'/',['QADM',13,'baseband1/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Outport',[sys,'/',['QADM',13,'baseband1/out_2']])
set_param([sys,'/',['QADM',13,'baseband1/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Filter',[sys,'/',['QADM',13,'baseband1/Filter1']])
set_param([sys,'/',['QADM',13,'baseband1/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband1/Product1']])
set_param([sys,'/',['QADM',13,'baseband1/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Demux',[sys,'/',['QADM',13,'baseband1/Demux']])
set_param([sys,'/',['QADM',13,'baseband1/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Constant',[sys,'/',['QADM',13,'baseband1/Constant']])
set_param([sys,'/',['QADM',13,'baseband1/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband1/Product2']])
set_param([sys,'/',['QADM',13,'baseband1/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband1/Product3']])
set_param([sys,'/',['QADM',13,'baseband1/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Sum',[sys,'/',['QADM',13,'baseband1/Sum']])
set_param([sys,'/',['QADM',13,'baseband1/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband1/Product']])
set_param([sys,'/',['QADM',13,'baseband1/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Filter',[sys,'/',['QADM',13,'baseband1/Filter']])
set_param([sys,'/',['QADM',13,'baseband1/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Note',[sys,'/',['QADM',13,'baseband1/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QADM',13,'baseband1/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Outport',[sys,'/',['QADM',13,'baseband1/out_1']])
set_param([sys,'/',['QADM',13,'baseband1/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['QADM',13,'baseband1']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['QADM',13,'baseband1']],[230,115;230,245;265,245])
add_line([sys,'/',['QADM',13,'baseband1']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['QADM',13,'baseband1']],[200,255;265,255])
add_line([sys,'/',['QADM',13,'baseband1']],[165,130;255,130])
add_line([sys,'/',['QADM',13,'baseband1']],[180,130;180,210;265,210])
add_line([sys,'/',['QADM',13,'baseband1']],[180,50;255,50])
add_line([sys,'/',['QADM',13,'baseband1']],[215,50;215,200;265,200])
add_line([sys,'/',['QADM',13,'baseband1']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['QADM',13,'baseband1']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['QADM',13,'baseband1']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['QADM',13,'baseband1']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['QADM',13,'baseband1']],[80,125;115,125])
add_line([sys,'/',['QADM',13,'baseband1']],[360,80;385,80])
add_line([sys,'/',['QADM',13,'baseband1']],[450,80;475,80])
add_line([sys,'/',['QADM',13,'baseband1']],[365,230;390,230])
add_line([sys,'/',['QADM',13,'baseband1']],[455,230;480,230])
set_param([sys,'/',['QADM',13,'baseband1']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['QADM',13,'baseband1']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QADM',13,'baseband1']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['QADM',13,'baseband1']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['QADM',13,'baseband1']],...
		'Mask Entries','[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/0\/.01\/')


%     Finished composite block ['QADM',13,'baseband1'].

set_param([sys,'/',['QADM',13,'baseband1']],...
		'ForeGround',4,...
		'position',[285,193,365,237])


%     Subsystem  ['QADM',13,'baseband2'].

new_system([sys,'/',['QADM',13,'baseband2']])
set_param([sys,'/',['QADM',13,'baseband2']],'Location',[283,122,827,462])

add_block('built-in/Outport',[sys,'/',['QADM',13,'baseband2/out_1']])
set_param([sys,'/',['QADM',13,'baseband2/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Note',[sys,'/',['QADM',13,'baseband2/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QADM',13,'baseband2/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Filter',[sys,'/',['QADM',13,'baseband2/Filter']])
set_param([sys,'/',['QADM',13,'baseband2/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband2/Product']])
set_param([sys,'/',['QADM',13,'baseband2/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Sum',[sys,'/',['QADM',13,'baseband2/Sum']])
set_param([sys,'/',['QADM',13,'baseband2/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband2/Product3']])
set_param([sys,'/',['QADM',13,'baseband2/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband2/Product2']])
set_param([sys,'/',['QADM',13,'baseband2/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Constant',[sys,'/',['QADM',13,'baseband2/Constant']])
set_param([sys,'/',['QADM',13,'baseband2/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Demux',[sys,'/',['QADM',13,'baseband2/Demux']])
set_param([sys,'/',['QADM',13,'baseband2/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband2/Product1']])
set_param([sys,'/',['QADM',13,'baseband2/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Filter',[sys,'/',['QADM',13,'baseband2/Filter1']])
set_param([sys,'/',['QADM',13,'baseband2/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Outport',[sys,'/',['QADM',13,'baseband2/out_2']])
set_param([sys,'/',['QADM',13,'baseband2/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Sum',[sys,'/',['QADM',13,'baseband2/Sum1']])
set_param([sys,'/',['QADM',13,'baseband2/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Constant',[sys,'/',['QADM',13,'baseband2/Constant1']])
set_param([sys,'/',['QADM',13,'baseband2/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Inport',[sys,'/',['QADM',13,'baseband2/in_1']])
set_param([sys,'/',['QADM',13,'baseband2/in_1']],...
		'position',[55,115,75,135])
add_line([sys,'/',['QADM',13,'baseband2']],[455,230;480,230])
add_line([sys,'/',['QADM',13,'baseband2']],[365,230;390,230])
add_line([sys,'/',['QADM',13,'baseband2']],[450,80;475,80])
add_line([sys,'/',['QADM',13,'baseband2']],[360,80;385,80])
add_line([sys,'/',['QADM',13,'baseband2']],[80,125;115,125])
add_line([sys,'/',['QADM',13,'baseband2']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['QADM',13,'baseband2']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['QADM',13,'baseband2']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['QADM',13,'baseband2']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['QADM',13,'baseband2']],[180,50;255,50])
add_line([sys,'/',['QADM',13,'baseband2']],[215,50;215,200;265,200])
add_line([sys,'/',['QADM',13,'baseband2']],[165,130;255,130])
add_line([sys,'/',['QADM',13,'baseband2']],[180,130;180,210;265,210])
add_line([sys,'/',['QADM',13,'baseband2']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['QADM',13,'baseband2']],[200,255;265,255])
add_line([sys,'/',['QADM',13,'baseband2']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['QADM',13,'baseband2']],[230,115;230,245;265,245])
set_param([sys,'/',['QADM',13,'baseband2']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['QADM',13,'baseband2']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QADM',13,'baseband2']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['QADM',13,'baseband2']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['QADM',13,'baseband2']],...
		'Mask Entries','[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/0\/.01\/')


%     Finished composite block ['QADM',13,'baseband2'].

set_param([sys,'/',['QADM',13,'baseband2']],...
		'ForeGround',4,...
		'position',[285,268,365,312])


%     Subsystem  ['DSB-ADM',13,'baseband'].

new_system([sys,'/',['DSB-ADM',13,'baseband']])
set_param([sys,'/',['DSB-ADM',13,'baseband']],'Location',[172,360,722,581])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/out_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/out_1']],...
		'position',[485,35,505,55])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Product1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Product1']],...
		'orientation',2,...
		'position',[390,110,425,130])

add_block('built-in/Filter',[sys,'/',['DSB-ADM',13,'baseband/Filter']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[260,26,315,64])


%     Subsystem  ['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

new_system([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],'Location',[297,318,980,694])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']],...
		'Port','2',...
		'position',[25,205,45,225])

add_block('built-in/Demux',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'position',[80,194,155,236])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']],...
		'position',[35,90,55,110])

add_block('built-in/Demux',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'position',[85,79,160,121])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']],...
		'position',[55,0,60,5])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']],...
		'position',[450,286,455,291])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']],...
		'position',[450,95,455,100])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']],...
		'position',[380,280,400,300])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']],...
		'position',[305,298,335,322])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']],...
		'position',[305,253,335,277])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']],...
		'inputs','+-',...
		'position',[380,110,400,130])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']],...
		'position',[305,143,335,167])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']],...
		'position',[305,83,335,107])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']],...
		'position',[190,185,195,190])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']],...
		'position',[195,65,200,70])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']],...
		'position',[198,108,203,113])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']],...
		'Port','2',...
		'position',[485,280,505,300])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']],...
		'position',[495,110,515,130])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']],...
		'position',[170,225,175,230])

add_block('built-in/Gain',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']],...
		'Gain','-1',...
		'position',[190,210,230,240])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,310;350,310;350,295;375,295])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,265;350,265;350,285;375,285])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,110;250,110;250,150;300,150])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[255,150;255,315;300,315])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,205;275,205;275,100;300,100])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[275,205;275,305;300,305])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,90;300,90])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[243,90;243,260;300,260])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,155;350,155;350,125;375,125])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,95;350,95;350,115;375,115])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[50,215;75,215])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[60,100;80,100])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,290;480,290])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,120;490,120])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,225;185,225])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[235,225;260,225;260,160;300,160])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[260,225;260,270;300,270])


%     Finished composite block ['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],...
		'orientation',2,...
		'position',[40,90,115,130])

add_block('built-in/Filter',[sys,'/',['DSB-ADM',13,'baseband/Filter1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[250,176,305,214])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/in_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/in_1']],...
		'orientation',2,...
		'position',[185,90,205,110])


%     Subsystem  ['DSB-ADM',13,'baseband/FM CE//VCO'].

new_system([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],'Location',[493,551,1106,698])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/in_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/in_1']],...
		'position',[35,25,55,45])

add_block('built-in/Gain',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[80,21,120,49])

add_block('built-in/Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/cos']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/cos']],...
		'Expr','cos(u)',...
		'position',[270,21,325,49])

add_block('built-in/Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/sin']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/sin']],...
		'Expr','sin(u)',...
		'position',[270,81,325,109])

add_block('built-in/Mux',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Mux']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Mux']],...
		'inputs','2',...
		'position',[355,26,390,59])

add_block('built-in/Gain',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity1']],...
		'Gain','Ac',...
		'position',[420,31,460,59])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/out_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/out_1']],...
		'position',[490,35,510,55])


%     Subsystem  ['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator'].

new_system([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])

add_block('built-in/Unit Delay',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/module']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[410,40;440,40])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[140,35;190,35])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Entries','pi2\/0\/ts\/')


%     Finished composite block ['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator'].

set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'position',[135,16,195,54])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sum']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sum']],...
		'position',[220,30,240,50])

add_block('built-in/Constant',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Constant']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Constant']],...
		'Value','Ph',...
		'position',[160,100,180,120])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[60,35;75,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[125,35;130,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[465,45;485,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[330,35;350,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[395,45;415,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[330,95;335,95;335,50;350,50])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[200,35;215,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[245,40;245,35;265,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[185,110;200,110;200,45;215,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[245,40;250,40;250,95;265,95])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Display','FM\ncmplx env',...
		'Mask Type','FM with cmplx env out')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Dialogue','Frequency modulation with complex envelop output:|Amplitude constant:|Modulation sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Translate','Ac=@1;Kc=@2*2*pi;Ph=@3;pi2=2*pi;ts=@4;')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Help','The FM block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Entries','1\/1\/Ph\/ts\/')


%     Finished composite block ['DSB-ADM',13,'baseband/FM CE//VCO'].

set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'orientation',2,...
		'position',[215,100,295,140])

add_block('built-in/Filter',[sys,'/',['DSB-ADM',13,'baseband/Filter2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[310,100,370,140])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[320,45;480,45])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[445,45;445,115;430,115])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[180,100;120,100])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[35,100;20,100;20,45;255,45])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[35,120;15,120;15,195;245,195])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[310,195;445,195;445,125;430,125])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[385,120;375,120])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[305,120;300,120])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[210,120;120,120])
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);DSB ADM',...
		'Mask Type','DSB-SC ADM CE')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nDSB-SC AM modulated signal.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;pi2=pi*2;ts=@4;[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block requires you to specify a lowpass filter that eliminates the carrier frequency and keeps the message signal. This block takes a complex signal.')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Entries','[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/pi/2\/.01\/')


%     Finished composite block ['DSB-ADM',13,'baseband'].

set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'ForeGround',4,...
		'position',[285,43,365,87])


%     Subsystem  'Min//max index2'.

new_system([sys,'/','Min//max index2'])
set_param([sys,'/','Min//max index2'],'Location',[192,461,623,564])

add_block('built-in/Inport',[sys,'/','Min//max index2/in_1'])
set_param([sys,'/','Min//max index2/in_1'],...
		'position',[65,20,85,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Min//max index2/Zero-Order',13,'Hold']])
set_param([sys,'/',['Min//max index2/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Outport',[sys,'/','Min//max index2/out_1'])
set_param([sys,'/','Min//max index2/out_1'],...
		'position',[335,20,355,40])

add_block('built-in/S-Function',[sys,'/','Min//max index2/Maximum'])
set_param([sys,'/','Min//max index2/Maximum'],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])
add_line([sys,'/','Min//max index2'],[90,30;160,30])
add_line([sys,'/','Min//max index2'],[325,30;330,30])
add_line([sys,'/','Min//max index2'],[205,30;235,30])
set_param([sys,'/','Min//max index2'],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/','Min//max index2'],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/','Min//max index2'],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/','Min//max index2'],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/','Min//max index2'],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block 'Min//max index2'.

set_param([sys,'/','Min//max index2'],...
		'ForeGround',4,...
		'position',[410,493,490,537])


%     Subsystem  'Min//max index1'.

new_system([sys,'/','Min//max index1'])
set_param([sys,'/','Min//max index1'],'Location',[192,461,623,564])

add_block('built-in/S-Function',[sys,'/','Min//max index1/Maximum'])
set_param([sys,'/','Min//max index1/Maximum'],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])

add_block('built-in/Outport',[sys,'/','Min//max index1/out_1'])
set_param([sys,'/','Min//max index1/out_1'],...
		'position',[335,20,355,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Min//max index1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Min//max index1/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Inport',[sys,'/','Min//max index1/in_1'])
set_param([sys,'/','Min//max index1/in_1'],...
		'position',[65,20,85,40])
add_line([sys,'/','Min//max index1'],[205,30;235,30])
add_line([sys,'/','Min//max index1'],[325,30;330,30])
add_line([sys,'/','Min//max index1'],[90,30;160,30])
set_param([sys,'/','Min//max index1'],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/','Min//max index1'],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/','Min//max index1'],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/','Min//max index1'],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/','Min//max index1'],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block 'Min//max index1'.

set_param([sys,'/','Min//max index1'],...
		'ForeGround',4,...
		'position',[410,418,490,462])


%     Subsystem  'Min//max index'.

new_system([sys,'/','Min//max index'])
set_param([sys,'/','Min//max index'],'Location',[192,461,623,564])

add_block('built-in/Inport',[sys,'/','Min//max index/in_1'])
set_param([sys,'/','Min//max index/in_1'],...
		'position',[65,20,85,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Min//max index/Zero-Order',13,'Hold']])
set_param([sys,'/',['Min//max index/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Outport',[sys,'/','Min//max index/out_1'])
set_param([sys,'/','Min//max index/out_1'],...
		'position',[335,20,355,40])

add_block('built-in/S-Function',[sys,'/','Min//max index/Maximum'])
set_param([sys,'/','Min//max index/Maximum'],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])
add_line([sys,'/','Min//max index'],[90,30;160,30])
add_line([sys,'/','Min//max index'],[325,30;330,30])
add_line([sys,'/','Min//max index'],[205,30;235,30])
set_param([sys,'/','Min//max index'],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/','Min//max index'],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/','Min//max index'],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/','Min//max index'],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/','Min//max index'],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block 'Min//max index'.

set_param([sys,'/','Min//max index'],...
		'ForeGround',4,...
		'position',[410,343,490,387])


%     Subsystem  'MASK demap'.

new_system([sys,'/','MASK demap'])
set_param([sys,'/','MASK demap'],'Location',[187,342,628,482])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[85,29,120,61])

add_block('built-in/Constant',[sys,'/','MASK demap/Shift key'])
set_param([sys,'/','MASK demap/Shift key'],...
		'Value','sft',...
		'position',[115,93,135,117])

add_block('built-in/Sum',[sys,'/','MASK demap/Sum2'])
set_param([sys,'/','MASK demap/Sum2'],...
		'inputs','+-',...
		'position',[180,38,200,67])

add_block('built-in/Abs',[sys,'/','MASK demap/Abs'])
set_param([sys,'/','MASK demap/Abs'],...
		'position',[235,42,270,68])

add_block('built-in/Outport',[sys,'/','MASK demap/out_1'])
set_param([sys,'/','MASK demap/out_1'],...
		'position',[400,45,420,65])

add_block('built-in/S-Function',[sys,'/','MASK demap/Minimum'])
set_param([sys,'/','MASK demap/Minimum'],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[315,45,370,65])

add_block('built-in/Inport',[sys,'/','MASK demap/in_1'])
set_param([sys,'/','MASK demap/in_1'],...
		'position',[30,35,50,55])
add_line([sys,'/','MASK demap'],[55,45;80,45])
add_line([sys,'/','MASK demap'],[275,55;310,55])
add_line([sys,'/','MASK demap'],[125,45;175,45])
add_line([sys,'/','MASK demap'],[375,55;395,55])
add_line([sys,'/','MASK demap'],[140,105;155,105;155,60;175,60])
add_line([sys,'/','MASK demap'],[205,55;230,55])
set_param([sys,'/','MASK demap'],...
		'Mask Display','MASK\ndemap',...
		'Mask Type','MASK demap')
set_param([sys,'/','MASK demap'],...
		'Mask Dialogue','Reverse the MASK mapping process\nConvert [-1 1] analog signal to [0, M-1] symbols.|M-ary number (digit integers in ranger [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/','MASK demap'],...
		'Mask Translate','N=@1;Ac=1;sft=[0:N-1]*Ac*2/(N-1)-Ac;td=@2;')
set_param([sys,'/','MASK demap'],...
		'Mask Help','This block demaps a MASK mapped signal back to digit symbols. You can place this block after a amplitude demodulation block. The input of this block is an analog signal in the range [-1, 1]. The demodulation decides the closest integer fitting in [0,M-1] range. When the input symbol interval is a two-elements vector, the second element is offset. The default offset value is 0.')
set_param([sys,'/','MASK demap'],...
		'Mask Entries','M\/[td, td-ts]\/')


%     Finished composite block 'MASK demap'.

set_param([sys,'/','MASK demap'],...
		'position',[410,43,490,87])


%     Subsystem  ['QASK',13,'square-demap'].

new_system([sys,'/',['QASK',13,'square-demap']])
set_param([sys,'/',['QASK',13,'square-demap']],'Location',[57,374,831,674])

add_block('built-in/Abs',[sys,'/',['QASK',13,'square-demap/Abs']])
set_param([sys,'/',['QASK',13,'square-demap/Abs']],...
		'position',[325,163,355,187])

add_block('built-in/Abs',[sys,'/',['QASK',13,'square-demap/Abs1']])
set_param([sys,'/',['QASK',13,'square-demap/Abs1']],...
		'position',[325,38,355,62])

add_block('built-in/Constant',[sys,'/',['QASK',13,'square-demap/Shift key2']])
set_param([sys,'/',['QASK',13,'square-demap/Shift key2']],...
		'BackGround',5,...
		'position',[325,114,350,136])

add_block('built-in/Constant',[sys,'/',['QASK',13,'square-demap/Shift key1']])
set_param([sys,'/',['QASK',13,'square-demap/Shift key1']],...
		'Value','sftx',...
		'position',[220,89,245,111])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'square-demap/Minimum1']])
set_param([sys,'/',['QASK',13,'square-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,40,445,60])

add_block('built-in/Constant',[sys,'/',['QASK',13,'square-demap/Shift key']])
set_param([sys,'/',['QASK',13,'square-demap/Shift key']],...
		'Value','sfty',...
		'position',[225,214,250,236])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'square-demap/Minimum']])
set_param([sys,'/',['QASK',13,'square-demap/Minimum']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,165,450,185])

add_block('built-in/Sum',[sys,'/',['QASK',13,'square-demap/Sum2']])
set_param([sys,'/',['QASK',13,'square-demap/Sum2']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[290,158,310,187])

add_block('built-in/Sum',[sys,'/',['QASK',13,'square-demap/Sum1']])
set_param([sys,'/',['QASK',13,'square-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[280,33,300,62])

add_block('built-in/Sum',[sys,'/',['QASK',13,'square-demap/Sum4']])
set_param([sys,'/',['QASK',13,'square-demap/Sum4']],...
		'ForeGround',2,...
		'position',[470,58,490,87])

add_block('built-in/Outport',[sys,'/',['QASK',13,'square-demap/out_1']])
set_param([sys,'/',['QASK',13,'square-demap/out_1']],...
		'position',[685,80,705,100])

add_block('built-in/Saturation',[sys,'/',['QASK',13,'square-demap/Saturation']])
set_param([sys,'/',['QASK',13,'square-demap/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','N-1',...
		'position',[630,78,660,102])

add_block('built-in/Sum',[sys,'/',['QASK',13,'square-demap/Sum3']])
set_param([sys,'/',['QASK',13,'square-demap/Sum3']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[580,73,600,102])


%     Subsystem  ['QASK',13,'square-demap/2-D Table'].

new_system([sys,'/',['QASK',13,'square-demap/2-D Table']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],'Location',[436,148,718,302])

add_block('built-in/Mux',[sys,'/',['QASK',13,'square-demap/2-D Table/Mux']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table/Mux']],...
		'inputs','2',...
		'position',[90,46,120,79])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'square-demap/2-D Table/S-function']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table/S-function']],...
		'function name','sftable2',...
		'parameters','xindex, yindex, table',...
		'position',[140,52,190,78])

add_block('built-in/Inport',[sys,'/',['QASK',13,'square-demap/2-D Table/x0']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table/x0']],...
		'position',[20,25,40,45])

add_block('built-in/Outport',[sys,'/',['QASK',13,'square-demap/2-D Table/table out']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table/table out']],...
		'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/',['QASK',13,'square-demap/2-D Table/y0']])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table/y0']],...
		'Port','2',...
		'position',[20,80,40,100])
add_line([sys,'/',['QASK',13,'square-demap/2-D Table']],[125,65;135,65])
add_line([sys,'/',['QASK',13,'square-demap/2-D Table']],[45,35;65,35;65,55;85,55])
add_line([sys,'/',['QASK',13,'square-demap/2-D Table']],[195,65;210,65])
add_line([sys,'/',['QASK',13,'square-demap/2-D Table']],[45,90;65,90;65,70;85,70])
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'Mask Display','plot(-10,-10,110,110,[90,50,10],[90,40,30],[90,50,10],[50,26,20],[90,50,10],[22,13,10])',...
		'Mask Type','2-D Table Lookup')
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'Mask Dialogue','Two Dimensional Table Lookup\nThe first input corresponds to X Index and the second input corresponds to the Y Index|X Index|Y Index|Table')
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'Mask Translate','xindex=@1; yindex=@2; table=@3; sftab2chk(xindex,yindex,table);')
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'Mask Help','This block returns a linearly interpolated intersection from the table using the X index (which corresponds to the rows of the table) and the Y index (which corresponds to the columns of the table).  Extrapolation is used.')
set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'Mask Entries','x\/y\/tab\/')


%     Finished composite block ['QASK',13,'square-demap/2-D Table'].

set_param([sys,'/',['QASK',13,'square-demap/2-D Table']],...
		'position',[515,68,545,92])

add_block('built-in/Sum',[sys,'/',['QASK',13,'square-demap/Sum5']])
set_param([sys,'/',['QASK',13,'square-demap/Sum5']],...
		'ForeGround',2,...
		'position',[470,153,490,182])

add_block('built-in/Inport',[sys,'/',['QASK',13,'square-demap/in_2']])
set_param([sys,'/',['QASK',13,'square-demap/in_2']],...
		'Port','2',...
		'position',[60,155,80,175])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'square-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'square-demap/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[135,149,170,181])

add_block('built-in/Inport',[sys,'/',['QASK',13,'square-demap/in_1']])
set_param([sys,'/',['QASK',13,'square-demap/in_1']],...
		'position',[60,30,80,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'square-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'square-demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[135,24,170,56])
add_line([sys,'/',['QASK',13,'square-demap']],[175,40;275,40])
add_line([sys,'/',['QASK',13,'square-demap']],[175,165;285,165])
add_line([sys,'/',['QASK',13,'square-demap']],[85,165;130,165])
add_line([sys,'/',['QASK',13,'square-demap']],[495,75;510,75])
add_line([sys,'/',['QASK',13,'square-demap']],[355,125;560,125;560,95;575,95])
add_line([sys,'/',['QASK',13,'square-demap']],[450,125;450,160;465,160])
add_line([sys,'/',['QASK',13,'square-demap']],[450,125;450,80;465,80])
add_line([sys,'/',['QASK',13,'square-demap']],[495,170;500,170;510,85])
add_line([sys,'/',['QASK',13,'square-demap']],[455,175;465,175])
add_line([sys,'/',['QASK',13,'square-demap']],[450,50;450,65;465,65])
add_line([sys,'/',['QASK',13,'square-demap']],[605,90;625,90])
add_line([sys,'/',['QASK',13,'square-demap']],[550,80;575,80])
add_line([sys,'/',['QASK',13,'square-demap']],[665,90;680,90])
add_line([sys,'/',['QASK',13,'square-demap']],[360,50;380,50])
add_line([sys,'/',['QASK',13,'square-demap']],[305,50;320,50])
add_line([sys,'/',['QASK',13,'square-demap']],[250,100;255,100;255,55;275,55])
add_line([sys,'/',['QASK',13,'square-demap']],[255,225;260,225;260,180;285,180])
add_line([sys,'/',['QASK',13,'square-demap']],[315,175;320,175])
add_line([sys,'/',['QASK',13,'square-demap']],[360,175;380,175])
add_line([sys,'/',['QASK',13,'square-demap']],[85,40;130,40])
set_param([sys,'/',['QASK',13,'square-demap']],...
		'Mask Display','QASK\nS-demap',...
		'Mask Type','QASK S-demap')
set_param([sys,'/',['QASK',13,'square-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|QASK M-ary number (outputs are in range [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'square-demap']],...
		'Mask Translate','N=@1;td=@2;Ac=1;sftx=[1 -1 3 -3 5 -5 7 -7 9 -9 11 -11 13 -13 15 -15];sftx=sftx(1:2*ceil(sqrt(N)/2));sfty=sftx;if N==8,sfty=sfty(1:2);end;sftx=sftx/max(sftx)*Ac;sfty=sfty/max(sfty)*Ac;tab=qaskdeco(length(sftx),length(sfty),''fetch'')+1;x=[1:length(sftx)];y=[1:length(sfty)];')
set_param([sys,'/',['QASK',13,'square-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using square constellation. You can place this block after a QAM demodulation block. This block assumes the maximum amplitude of the input signals is 1. The output symbols are integers in the range [0, M-1]. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0.')
set_param([sys,'/',['QASK',13,'square-demap']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['QASK',13,'square-demap'].

set_param([sys,'/',['QASK',13,'square-demap']],...
		'position',[410,118,490,162])


%     Subsystem  ['QASK',13,'circle-demap'].

new_system([sys,'/',['QASK',13,'circle-demap']])
set_param([sys,'/',['QASK',13,'circle-demap']],'Location',[96,182,645,417])

add_block('built-in/Constant',[sys,'/',['QASK',13,'circle-demap/imag_pt']])
set_param([sys,'/',['QASK',13,'circle-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])

add_block('built-in/Constant',[sys,'/',['QASK',13,'circle-demap/real_pt']])
set_param([sys,'/',['QASK',13,'circle-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-demap/out_1']])
set_param([sys,'/',['QASK',13,'circle-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'circle-demap/Minimum1']])
set_param([sys,'/',['QASK',13,'circle-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum2']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/Product',[sys,'/',['QASK',13,'circle-demap/Product1']])
set_param([sys,'/',['QASK',13,'circle-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Product',[sys,'/',['QASK',13,'circle-demap/Product']])
set_param([sys,'/',['QASK',13,'circle-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum6']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum1']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-demap/imag']])
set_param([sys,'/',['QASK',13,'circle-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-demap/real']])
set_param([sys,'/',['QASK',13,'circle-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])
add_line([sys,'/',['QASK',13,'circle-demap']],[480,95;490,95])
add_line([sys,'/',['QASK',13,'circle-demap']],[395,95;410,95])
add_line([sys,'/',['QASK',13,'circle-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['QASK',13,'circle-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['QASK',13,'circle-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['QASK',13,'circle-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['QASK',13,'circle-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['QASK',13,'circle-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['QASK',13,'circle-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['QASK',13,'circle-demap']],[160,130;225,130])
add_line([sys,'/',['QASK',13,'circle-demap']],[160,45;225,45])
add_line([sys,'/',['QASK',13,'circle-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['QASK',13,'circle-demap']],[70,130;115,130])
add_line([sys,'/',['QASK',13,'circle-demap']],[70,45;115,45])
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Display','QASK\nC-demap',...
		'Mask Type','QASK C-demap')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Number of symbols on each circle NIC::|Radii for each circle RIC:|Phase shift on each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y2=imag(y1);y1=real(y1);')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using circle constellation. You can place this block after a QAM demodulation block. The circle constellation is defined in NIC, RIC, and PIC. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero. Use function MODMAP to view the constellation.')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Entries','[6 12 18 24 30 38]\/[1 1.93 2.88 3.83 4.78 6.05]\/[0 0 0 0 0 0]\/td\/')


%     Finished composite block ['QASK',13,'circle-demap'].

set_param([sys,'/',['QASK',13,'circle-demap']],...
		'position',[410,193,490,237])


%     Subsystem  ['QASK',13,'arbitrary-demap'].

new_system([sys,'/',['QASK',13,'arbitrary-demap']])
set_param([sys,'/',['QASK',13,'arbitrary-demap']],'Location',[45,449,594,684])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['QASK',13,'arbitrary-demap/real']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['QASK',13,'arbitrary-demap/imag']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['QASK',13,'arbitrary-demap/Sum1']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['QASK',13,'arbitrary-demap/Sum6']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['QASK',13,'arbitrary-demap/Product']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['QASK',13,'arbitrary-demap/Product1']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['QASK',13,'arbitrary-demap/Sum2']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'arbitrary-demap/Minimum1']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['QASK',13,'arbitrary-demap/out_1']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['QASK',13,'arbitrary-demap/real_pt']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['QASK',13,'arbitrary-demap/imag_pt']])
set_param([sys,'/',['QASK',13,'arbitrary-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[70,45;115,45])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[70,130;115,130])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[160,45;225,45])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[160,130;225,130])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[395,95;410,95])
add_line([sys,'/',['QASK',13,'arbitrary-demap']],[480,95;490,95])
set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'Mask Entries','real(exp(j*[0:M-1]/M*pi*2))\/imag(exp(j*[0:M-1]/M*pi*2))\/td\/')


%     Finished composite block ['QASK',13,'arbitrary-demap'].

set_param([sys,'/',['QASK',13,'arbitrary-demap']],...
		'position',[410,268,490,312])

add_block('built-in/Note',[sys,'/','Baseband Digital Modulation//Demodulation Map//Demap Library'])
set_param([sys,'/','Baseband Digital Modulation//Demodulation Map//Demap Library'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[300,0,305,5])

add_block('built-in/Note',[sys,'/','(map+modu ==> demod+demap)'])
set_param([sys,'/','(map+modu ==> demod+demap)'],...
		'ForeGround',2,...
		'position',[285,15,290,20])
add_line(sys,[115,65;145,65])
add_line(sys,[235,65;280,65])
add_line(sys,[115,225;145,225])
add_line(sys,[115,205;145,205])
add_line(sys,[115,280;145,280])
add_line(sys,[115,300;145,300])
add_line(sys,[370,515;405,515])
add_line(sys,[115,150;145,150])
add_line(sys,[115,130;145,130])
add_line(sys,[235,365;280,365])
add_line(sys,[370,440;405,440])
add_line(sys,[370,365;405,365])
add_line(sys,[115,365;150,365])
add_line(sys,[235,515;280,515])
add_line(sys,[115,515;145,515])
add_line(sys,[260,365;260,440;280,440])
add_line(sys,[370,65;405,65])
add_line(sys,[370,130;405,130])
add_line(sys,[370,150;405,150])
add_line(sys,[370,205;405,205])
add_line(sys,[370,225;405,225])
add_line(sys,[370,280;405,280])
add_line(sys,[370,300;405,300])
add_line(sys,[235,140;280,140])
add_line(sys,[235,215;280,215])
add_line(sys,[235,290;280,290])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
