function [ret,x0,str,ts,xts]=com_pres(t,x,u,flag);
%COM_PRES	is the M-file description of the SIMULINK system named COM_PRES.
%	The block-diagram can be displayed by typing: COM_PRES.
%
%	SYS=COM_PRES(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_PRES to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_PRES with a FLAG of zero:
%	[SIZES]=COM_PRES([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[199,78,1102,873])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','COMMUNICATIONS TOOLBOX'])
set_param([sys,'/','COMMUNICATIONS TOOLBOX'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[435,20,440,25])

add_block('built-in/Note',[sys,'/','these two parts.'])
set_param([sys,'/','these two parts.'],...
		'position',[285,175,290,180])


%     Subsystem  'Channel1'.

new_system([sys,'/','Channel1'])
set_param([sys,'/','Channel1'],'Location',[446,298,1025,565])

add_block('built-in/Outport',[sys,'/','Channel1/out_1'])
set_param([sys,'/','Channel1/out_1'],...
		'position',[455,85,475,105])

add_block('built-in/Sum',[sys,'/','Channel1/Sum'])
set_param([sys,'/','Channel1/Sum'],...
		'inputs','+++',...
		'position',[340,77,360,113])


%     Subsystem  'Channel1/Sub-system1'.

new_system([sys,'/','Channel1/Sub-system1'])
set_param([sys,'/','Channel1/Sub-system1'],'Location',[575,99,983,538])

add_block('built-in/Sum',[sys,'/','Channel1/Sub-system1/Sum'])
set_param([sys,'/','Channel1/Sub-system1/Sum'],...
		'inputs','+++',...
		'position',[325,207,345,243])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system1/out_1'])
set_param([sys,'/','Channel1/Sub-system1/out_1'],...
		'position',[365,215,385,235])

add_block('built-in/Mux',[sys,'/','Channel1/Sub-system1/Mux2'])
set_param([sys,'/','Channel1/Sub-system1/Mux2'],...
		'inputs','2',...
		'position',[235,321,270,354])

add_block('built-in/Mux',[sys,'/','Channel1/Sub-system1/Mux1'])
set_param([sys,'/','Channel1/Sub-system1/Mux1'],...
		'inputs','2',...
		'position',[230,81,265,114])

add_block('built-in/Mux',[sys,'/','Channel1/Sub-system1/Mux'])
set_param([sys,'/','Channel1/Sub-system1/Mux'],...
		'inputs','2',...
		'position',[220,206,255,239])


%     Subsystem  'Channel1/Sub-system1/Sub-system6'.

new_system([sys,'/','Channel1/Sub-system1/Sub-system6'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system6'],'Location',[568,271,976,714])

add_block('built-in/Constant',[sys,'/','Channel1/Sub-system1/Sub-system6/Switch Key'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system6/Switch Key'],...
		'position',[65,85,85,105])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system1/Sub-system6/out_1'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system6/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel1/Sub-system1/Sub-system6'],[90,95;290,95])
set_param([sys,'/','Channel1/Sub-system1/Sub-system6'],...
		'Mask Display','Receiver Noise')


%     Finished composite block 'Channel1/Sub-system1/Sub-system6'.

set_param([sys,'/','Channel1/Sub-system1/Sub-system6'],...
		'hide name',0,...
		'position',[30,361,135,409])


%     Subsystem  'Channel1/Sub-system1/Sub-system5'.

new_system([sys,'/','Channel1/Sub-system1/Sub-system5'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system5'],'Location',[568,271,976,714])

add_block('built-in/Constant',[sys,'/','Channel1/Sub-system1/Sub-system5/Switch Key'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system5/Switch Key'],...
		'position',[100,85,120,105])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system1/Sub-system5/out_1'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system5/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel1/Sub-system1/Sub-system5'],[125,95;290,95])
set_param([sys,'/','Channel1/Sub-system1/Sub-system5'],...
		'Mask Display','Terrestrial Noise')


%     Finished composite block 'Channel1/Sub-system1/Sub-system5'.

set_param([sys,'/','Channel1/Sub-system1/Sub-system5'],...
		'hide name',0,...
		'position',[30,291,135,339])


%     Subsystem  'Channel1/Sub-system1/Sub-system4'.

new_system([sys,'/','Channel1/Sub-system1/Sub-system4'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system4'],'Location',[568,271,976,714])

add_block('built-in/Constant',[sys,'/','Channel1/Sub-system1/Sub-system4/Switch Key'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system4/Switch Key'],...
		'Value','2',...
		'position',[95,80,115,100])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system1/Sub-system4/out_1'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system4/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel1/Sub-system1/Sub-system4'],[120,90;200,90;200,95;290,95])
set_param([sys,'/','Channel1/Sub-system1/Sub-system4'],...
		'Mask Display','IM Noise')


%     Finished composite block 'Channel1/Sub-system1/Sub-system4'.

set_param([sys,'/','Channel1/Sub-system1/Sub-system4'],...
		'hide name',0,...
		'position',[30,231,135,279])


%     Subsystem  'Channel1/Sub-system1/Sub-system3'.

new_system([sys,'/','Channel1/Sub-system1/Sub-system3'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system3'],'Location',[568,271,976,714])

add_block('built-in/Constant',[sys,'/','Channel1/Sub-system1/Sub-system3/Switch Key'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system3/Switch Key'],...
		'position',[110,85,130,105])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system1/Sub-system3/out_1'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system3/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel1/Sub-system1/Sub-system3'],[135,95;290,95])
set_param([sys,'/','Channel1/Sub-system1/Sub-system3'],...
		'Mask Display','Atmosphere Noise')


%     Finished composite block 'Channel1/Sub-system1/Sub-system3'.

set_param([sys,'/','Channel1/Sub-system1/Sub-system3'],...
		'hide name',0,...
		'position',[30,171,135,219])


%     Subsystem  'Channel1/Sub-system1/Sub-system2'.

new_system([sys,'/','Channel1/Sub-system1/Sub-system2'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system2'],'Location',[568,271,976,714])

add_block('built-in/Constant',[sys,'/','Channel1/Sub-system1/Sub-system2/Switch Key'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system2/Switch Key'],...
		'position',[130,85,150,105])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system1/Sub-system2/out_1'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system2/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel1/Sub-system1/Sub-system2'],[155,95;290,95])
set_param([sys,'/','Channel1/Sub-system1/Sub-system2'],...
		'Mask Display','Random Noise')


%     Finished composite block 'Channel1/Sub-system1/Sub-system2'.

set_param([sys,'/','Channel1/Sub-system1/Sub-system2'],...
		'hide name',0,...
		'position',[30,101,120,149])


%     Subsystem  'Channel1/Sub-system1/Sub-system1'.

new_system([sys,'/','Channel1/Sub-system1/Sub-system1'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system1'],'Location',[185,298,593,741])

add_block('built-in/Constant',[sys,'/','Channel1/Sub-system1/Sub-system1/Switch Key'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system1/Switch Key'],...
		'position',[115,100,135,120])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system1/Sub-system1/out_1'])
set_param([sys,'/','Channel1/Sub-system1/Sub-system1/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel1/Sub-system1/Sub-system1'],[140,110;210,110;210,95;290,95])
set_param([sys,'/','Channel1/Sub-system1/Sub-system1'],...
		'Mask Display','LO phase noise')


%     Finished composite block 'Channel1/Sub-system1/Sub-system1'.

set_param([sys,'/','Channel1/Sub-system1/Sub-system1'],...
		'hide name',0,...
		'position',[30,26,120,74])
add_line([sys,'/','Channel1/Sub-system1'],[350,225;360,225])
add_line([sys,'/','Channel1/Sub-system1'],[275,340;280,340;280,235;320,235])
add_line([sys,'/','Channel1/Sub-system1'],[260,225;320,225])
add_line([sys,'/','Channel1/Sub-system1'],[270,100;280,100;280,215;320,215])
add_line([sys,'/','Channel1/Sub-system1'],[140,385;180,385;180,345;230,345])
add_line([sys,'/','Channel1/Sub-system1'],[140,315;180,315;180,330;230,330])
add_line([sys,'/','Channel1/Sub-system1'],[140,255;170,255;170,230;215,230])
add_line([sys,'/','Channel1/Sub-system1'],[140,195;170,195;170,215;215,215])
add_line([sys,'/','Channel1/Sub-system1'],[125,125;170,125;170,105;225,105])
add_line([sys,'/','Channel1/Sub-system1'],[125,50;170,50;170,90;225,90])
set_param([sys,'/','Channel1/Sub-system1'],...
		'Mask Display','Noise')


%     Finished composite block 'Channel1/Sub-system1'.

set_param([sys,'/','Channel1/Sub-system1'],...
		'hide name',0,...
		'position',[165,10,235,60])

add_block('built-in/Note',[sys,'/','Channel1/Fiber Optic Communications'])
set_param([sys,'/','Channel1/Fiber Optic Communications'],...
		'position',[80,240,85,245])

add_block('built-in/Note',[sys,'/','Channel1/Satellite Communications'])
set_param([sys,'/','Channel1/Satellite Communications'],...
		'position',[70,215,75,220])


%     Subsystem  'Channel1/Sub-system5'.

new_system([sys,'/','Channel1/Sub-system5'])
set_param([sys,'/','Channel1/Sub-system5'],'Location',[213,332,807,610])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system5/out_1'])
set_param([sys,'/','Channel1/Sub-system5/out_1'],...
		'position',[395,55,415,75])

add_block('built-in/Mux',[sys,'/','Channel1/Sub-system5/Mux'])
set_param([sys,'/','Channel1/Sub-system5/Mux'],...
		'inputs','2',...
		'position',[270,46,305,79])


%     Subsystem  'Channel1/Sub-system5/Sub-system7'.

new_system([sys,'/','Channel1/Sub-system5/Sub-system7'])
set_param([sys,'/','Channel1/Sub-system5/Sub-system7'],'Location',[196,225,790,503])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system5/Sub-system7/out_1'])
set_param([sys,'/','Channel1/Sub-system5/Sub-system7/out_1'],...
		'position',[395,35,415,55])
set_param([sys,'/','Channel1/Sub-system5/Sub-system7'],...
		'Mask Display','Co-channel interference')


%     Finished composite block 'Channel1/Sub-system5/Sub-system7'.

set_param([sys,'/','Channel1/Sub-system5/Sub-system7'],...
		'hide name',0,...
		'position',[30,142,200,178])


%     Subsystem  'Channel1/Sub-system5/Sub-system6'.

new_system([sys,'/','Channel1/Sub-system5/Sub-system6'])
set_param([sys,'/','Channel1/Sub-system5/Sub-system6'],'Location',[196,225,790,503])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system5/Sub-system6/out_1'])
set_param([sys,'/','Channel1/Sub-system5/Sub-system6/out_1'],...
		'position',[395,35,415,55])
set_param([sys,'/','Channel1/Sub-system5/Sub-system6'],...
		'Mask Display','Adjacent channel interference')


%     Finished composite block 'Channel1/Sub-system5/Sub-system6'.

set_param([sys,'/','Channel1/Sub-system5/Sub-system6'],...
		'hide name',0,...
		'position',[30,82,200,118])


%     Subsystem  'Channel1/Sub-system5/Sub-system5'.

new_system([sys,'/','Channel1/Sub-system5/Sub-system5'])
set_param([sys,'/','Channel1/Sub-system5/Sub-system5'],'Location',[196,225,790,503])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system5/Sub-system5/out_1'])
set_param([sys,'/','Channel1/Sub-system5/Sub-system5/out_1'],...
		'position',[395,35,415,55])
set_param([sys,'/','Channel1/Sub-system5/Sub-system5'],...
		'Mask Display','Intersymbol Interference')


%     Finished composite block 'Channel1/Sub-system5/Sub-system5'.

set_param([sys,'/','Channel1/Sub-system5/Sub-system5'],...
		'hide name',0,...
		'position',[30,25,200,65])
add_line([sys,'/','Channel1/Sub-system5'],[310,65;390,65])
add_line([sys,'/','Channel1/Sub-system5'],[205,100;230,100;230,70;265,70])
add_line([sys,'/','Channel1/Sub-system5'],[205,45;230,45;230,55;265,55])
set_param([sys,'/','Channel1/Sub-system5'],...
		'Mask Display','Interference')


%     Finished composite block 'Channel1/Sub-system5'.

set_param([sys,'/','Channel1/Sub-system5'],...
		'hide name',0,...
		'position',[165,141,235,189])

add_block('built-in/Inport',[sys,'/','Channel1/in_1'])
set_param([sys,'/','Channel1/in_1'],...
		'position',[35,85,55,105])


%     Subsystem  'Channel1/Sub-system4'.

new_system([sys,'/','Channel1/Sub-system4'])
set_param([sys,'/','Channel1/Sub-system4'],'Location',[586,358,1012,641])

add_block('built-in/Outport',[sys,'/','Channel1/Sub-system4/out_1'])
set_param([sys,'/','Channel1/Sub-system4/out_1'],...
		'position',[145,135,165,155])

add_block('built-in/Inport',[sys,'/','Channel1/Sub-system4/in_1'])
set_param([sys,'/','Channel1/Sub-system4/in_1'],...
		'position',[35,135,55,155])
add_line([sys,'/','Channel1/Sub-system4'],[60,145;140,145])
set_param([sys,'/','Channel1/Sub-system4'],...
		'Mask Display','Loss')


%     Finished composite block 'Channel1/Sub-system4'.

set_param([sys,'/','Channel1/Sub-system4'],...
		'hide name',0,...
		'position',[165,73,235,117])
add_line([sys,'/','Channel1'],[365,95;450,95])
add_line([sys,'/','Channel1'],[240,95;335,95])
add_line([sys,'/','Channel1'],[240,165;295,165;295,105;335,105])
add_line([sys,'/','Channel1'],[240,35;295,35;295,85;335,85])
add_line([sys,'/','Channel1'],[60,95;160,95])
set_param([sys,'/','Channel1'],...
		'Mask Display','Channel',...
		'Mask Dialogue','eval(''com_chan;'')')


%     Finished composite block 'Channel1'.

set_param([sys,'/','Channel1'],...
		'ForeGround',2,...
		'hide name',0,...
		'move name',0,...
		'position',[595,459,685,511])


%     Subsystem  'Multi_Access'.

new_system([sys,'/','Multi_Access'])
set_param([sys,'/','Multi_Access'],'Location',[165,401,464,518])

add_block('built-in/Outport',[sys,'/','Multi_Access/out_1'])
set_param([sys,'/','Multi_Access/out_1'],...
		'position',[245,30,265,50])

add_block('built-in/Inport',[sys,'/','Multi_Access/in_2'])
set_param([sys,'/','Multi_Access/in_2'],...
		'Port','2',...
		'position',[80,60,100,80])

add_block('built-in/Mux',[sys,'/','Multi_Access/Mux'])
set_param([sys,'/','Multi_Access/Mux'],...
		'inputs','2',...
		'position',[145,21,180,54])

add_block('built-in/Inport',[sys,'/','Multi_Access/in_1'])
set_param([sys,'/','Multi_Access/in_1'],...
		'position',[60,20,80,40])
add_line([sys,'/','Multi_Access'],[185,40;240,40])
add_line([sys,'/','Multi_Access'],[105,70;115,70;115,45;140,45])
add_line([sys,'/','Multi_Access'],[85,30;140,30])
set_param([sys,'/','Multi_Access'],...
		'Mask Display','Multiple\naccess',...
		'Mask Dialogue','eval(''com_mlac;'')')


%     Finished composite block 'Multi_Access'.

set_param([sys,'/','Multi_Access'],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[595,411,685,464])

add_block('built-in/Note',[sys,'/','To be Done'])
set_param([sys,'/','To be Done'],...
		'ForeGround',2,...
		'position',[630,380,635,385])

add_block('built-in/Note',[sys,'/','Progress Status:'])
set_param([sys,'/','Progress Status:'],...
		'Font Weight','bold',...
		'position',[75,370,80,375])

add_block('built-in/Note',[sys,'/','MATLAB commands:'])
set_param([sys,'/','MATLAB commands:'],...
		'Font Weight','bold',...
		'position',[85,685,90,690])

add_block('built-in/Note',[sys,'/','See MATLAB workspace.'])
set_param([sys,'/','See MATLAB workspace.'],...
		'position',[465,700,470,705])

add_block('built-in/Note',[sys,'/','Characteristics'])
set_param([sys,'/','Characteristics'],...
		'Font Weight','bold',...
		'position',[100,3255,105,3260])

add_block('built-in/Note',[sys,'/','Parameters'])
set_param([sys,'/','Parameters'],...
		'Font Weight','bold',...
		'position',[85,3225,90,3230])

add_block('built-in/Note',[sys,'/','Description'])
set_param([sys,'/','Description'],...
		'Font Weight','bold',...
		'position',[85,3190,90,3195])

add_block('built-in/Note',[sys,'/','Block Title'])
set_param([sys,'/','Block Title'],...
		'position',[80,3155,85,3160])

add_block('built-in/Note',[sys,'/','_________________________________________________________________________'])
set_param([sys,'/','_________________________________________________________________________'],...
		'position',[370,3130,375,3135])

add_block('built-in/Note',[sys,'/','Sub-Library: Digital Modulation'])
set_param([sys,'/','Sub-Library: Digital Modulation'],...
		'position',[625,3155,630,3160])

add_block('built-in/Note',[sys,'/','M-ary Amplitude Shift-Keying Modulation'])
set_param([sys,'/','M-ary Amplitude Shift-Keying Modulation'],...
		'Font Weight','bold',...
		'position',[195,3120,200,3125])


%     Subsystem  ['MASK',13,'modulation'].

new_system([sys,'/',['MASK',13,'modulation']])
set_param([sys,'/',['MASK',13,'modulation']],'Location',[145,136,638,408])

add_block('built-in/Memory',[sys,'/',['MASK',13,'modulation/Memory1']])
set_param([sys,'/',['MASK',13,'modulation/Memory1']],...
		'orientation',2,...
		'position',[185,80,225,110])

add_block('built-in/Gain',[sys,'/',['MASK',13,'modulation/Gain']])
set_param([sys,'/',['MASK',13,'modulation/Gain']],...
		'Gain','Kc',...
		'position',[265,30,305,60])


%     Subsystem  ['MASK',13,'modulation/Rising edge',13,'detector'].

new_system([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['MASK',13,'modulation/Rising edge',13,'detector'].

set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],...
		'position',[75,78,135,122])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/in_2']])
set_param([sys,'/',['MASK',13,'modulation/in_2']],...
		'Port','2',...
		'position',[30,90,50,110])

add_block('built-in/Switch',[sys,'/',['MASK',13,'modulation/Switch']])
set_param([sys,'/',['MASK',13,'modulation/Switch']],...
		'Threshold','eps',...
		'position',[190,29,220,61])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/in_1']])
set_param([sys,'/',['MASK',13,'modulation/in_1']],...
		'position',[85,25,105,45])

add_block('built-in/Product',[sys,'/',['MASK',13,'modulation/Product']])
set_param([sys,'/',['MASK',13,'modulation/Product']],...
		'position',[395,100,420,120])

add_block('built-in/Outport',[sys,'/',['MASK',13,'modulation/out_1']])
set_param([sys,'/',['MASK',13,'modulation/out_1']],...
		'position',[450,100,470,120])

add_block('built-in/Sum',[sys,'/',['MASK',13,'modulation/Sum1']])
set_param([sys,'/',['MASK',13,'modulation/Sum1']],...
		'inputs','+-',...
		'position',[335,68,355,92])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Gain diff']])
set_param([sys,'/',['MASK',13,'modulation/Gain diff']],...
		'Value','Ac',...
		'position',[265,103,285,127])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/one']])
set_param([sys,'/',['MASK',13,'modulation/one']],...
		'Value','Fc',...
		'position',[30,171,55,199])


%     Subsystem  ['MASK',13,'modulation/Module',13,'Integrator'].

new_system([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/in_1']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/in_1']],...
		'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Memory']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/module']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/one']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Sum']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/out_1']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/out_1']],...
		'position',[370,30,390,50])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator',...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['MASK',13,'modulation/Module',13,'Integrator'].

set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],...
		'position',[80,166,140,204])

add_block('built-in/Gain',[sys,'/',['MASK',13,'modulation/Gain1']])
set_param([sys,'/',['MASK',13,'modulation/Gain1']],...
		'Gain','pi2',...
		'position',[165,171,200,199])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'modulation/Oscilation']])
set_param([sys,'/',['MASK',13,'modulation/Oscilation']],...
		'Expr','sin(u)',...
		'position',[270,178,310,202])

add_block('built-in/Sum',[sys,'/',['MASK',13,'modulation/Sum']])
set_param([sys,'/',['MASK',13,'modulation/Sum']],...
		'position',[230,178,250,202])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Initial phase']])
set_param([sys,'/',['MASK',13,'modulation/Initial phase']],...
		'Value','Ph',...
		'position',[190,218,210,242])
add_line([sys,'/',['MASK',13,'modulation']],[425,110;445,110])
add_line([sys,'/',['MASK',13,'modulation']],[315,190;340,190;340,115;390,115])
add_line([sys,'/',['MASK',13,'modulation']],[215,230;225,195])
add_line([sys,'/',['MASK',13,'modulation']],[145,185;160,185])
add_line([sys,'/',['MASK',13,'modulation']],[60,185;75,185])
add_line([sys,'/',['MASK',13,'modulation']],[255,190;265,190])
add_line([sys,'/',['MASK',13,'modulation']],[55,100;70,100])
add_line([sys,'/',['MASK',13,'modulation']],[110,35;185,35])
add_line([sys,'/',['MASK',13,'modulation']],[180,95;165,95;165,55;185,55])
add_line([sys,'/',['MASK',13,'modulation']],[140,100;150,100;150,45;185,45])
add_line([sys,'/',['MASK',13,'modulation']],[205,185;225,185])
add_line([sys,'/',['MASK',13,'modulation']],[225,45;250,45;250,95;230,95])
add_line([sys,'/',['MASK',13,'modulation']],[250,45;260,45])
add_line([sys,'/',['MASK',13,'modulation']],[310,45;315,45;315,75;330,75])
add_line([sys,'/',['MASK',13,'modulation']],[360,80;370,80;370,105;390,105])
add_line([sys,'/',['MASK',13,'modulation']],[290,115;315,115;315,85;330,85])
set_param([sys,'/',['MASK',13,'modulation']],...
		'Mask Display','MASK',...
		'Mask Type','MASK')
set_param([sys,'/',['MASK',13,'modulation']],...
		'Mask Dialogue','M-ary Amplitude Shift Keying Modulation:|M-ary number:|Carrier frequency (Hz):|Maximum amplitude:|Trigger signal threshold:|Initial phase (rad):')
set_param([sys,'/',['MASK',13,'modulation']],...
		'Mask Translate','pi2=2*pi;N=@1;Fc=@2;Ac=@3;Kc=Ac*2/(N-1);thld=@4;Ph=@5;')
set_param([sys,'/',['MASK',13,'modulation']],...
		'Mask Help','This block modulates an M-ary digital signal onto a given carrier frequency using amplitude shift keying method. The first input port is for the original digital signal, which is coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input.')
set_param([sys,'/',['MASK',13,'modulation']],...
		'Mask Entries','16\/100\/1\/.2\/0\/')


%     Finished composite block ['MASK',13,'modulation'].

set_param([sys,'/',['MASK',13,'modulation']],...
		'position',[495,3078,555,3122])


%     Subsystem  ['MASK',13,'demodulation'].

new_system([sys,'/',['MASK',13,'demodulation']])
set_param([sys,'/',['MASK',13,'demodulation']],'Location',[202,402,920,610])


%     Subsystem  ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas'].

new_system([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],'Location',[150,97,844,378])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/out_1']],...
		'position',[660,50,680,70])

add_block('built-in/Gain',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Gain']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Gain']],...
		'Gain','G',...
		'position',[605,45,630,75])

add_block('built-in/Product',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product1']],...
		'orientation',2,...
		'position',[525,110,555,130])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[460,175,480,195])

add_block('built-in/Transfer Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter1']],...
		'orientation',2,...
		'Numerator','Fn',...
		'Denominator','Fd',...
		'position',[450,100,500,140])

add_block('built-in/Sum',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Sum']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Sum']],...
		'orientation',2,...
		'position',[380,115,400,135])


%     Subsystem  ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator'].

new_system([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],'Location',[529,321,954,458])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/in_1']],...
		'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Memory']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/module']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/one']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Sum']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/out_1']],...
		'position',[370,30,390,50])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator'].

set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
		'orientation',2,...
		'position',[290,110,350,140])

add_block('built-in/Transfer Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter2']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter2']],...
		'Numerator','Fn',...
		'Denominator','Fd',...
		'position',[325,204,375,246])

add_block('built-in/Product',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product2']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin1']],...
		'orientation',2,...
		'Expr','sin(u[1]*pi2+pih)',...
		'position',[120,160,220,190])

add_block('built-in/Transfer Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter']],...
		'Numerator','Fn',...
		'Denominator','Fd',...
		'position',[240,39,290,81])

add_block('built-in/Product',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin']],...
		'orientation',2,...
		'Expr','sin(u[1]*pi2)',...
		'position',[120,113,205,137])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Note',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[295,60;600,60])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[580,60;580,115;560,115])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[285,125;210,125])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[250,125;250,175;225,175])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[635,60;655,60])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[155,60;235,60])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[115,125;105,125;105,65;120,65])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[455,185;430,185;430,130;405,130])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[375,125;355,125])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[520,120;505,120])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[445,120;405,120])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[115,175;105,175;105,220;120,220])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[70,55;120,55])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[90,55;90,230;120,230])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[155,225;320,225])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[380,225;580,225;580,125;560,125])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Display','Costas PL\nDSB ADM',...
		'Mask Type','DSB-SC ADM')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Dialogue','Double-sideband suppressed-carrier amplitude demodulation:|Carrier frequency:|Filter numerator:|Filter denominator:|Output gain:')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Translate','Fc=@1;Fn=@2;Fd=@3;G=@4;pi2=pi*2;pih=pi/2;')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Help','The Double-Sideband Supressed-Carrier Amplitude Modulation demodulates a DSB-SC-AM signal using Costas Phase-Locked Loop method.')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Entries','Fc\/num\/den\/2\/')


%     Finished composite block ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas'].

set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'position',[150,25,220,65])

add_block('built-in/Memory',[sys,'/',['MASK',13,'demodulation/Memory2']])
set_param([sys,'/',['MASK',13,'demodulation/Memory2']],...
		'orientation',2,...
		'ForeGround',2,...
		'x0','-Ac',...
		'position',[345,95,385,125])

add_block('built-in/Switch',[sys,'/',['MASK',13,'demodulation/Switch2']])
set_param([sys,'/',['MASK',13,'demodulation/Switch2']],...
		'ForeGround',2,...
		'Threshold','eps',...
		'position',[350,39,380,71])

add_block('built-in/Sum',[sys,'/',['MASK',13,'demodulation/Sum2']])
set_param([sys,'/',['MASK',13,'demodulation/Sum2']],...
		'inputs','+-',...
		'position',[495,48,515,77])

add_block('built-in/Abs',[sys,'/',['MASK',13,'demodulation/Abs']])
set_param([sys,'/',['MASK',13,'demodulation/Abs']],...
		'position',[545,53,575,77])

add_block('built-in/S-Function',[sys,'/',['MASK',13,'demodulation/Minimum']])
set_param([sys,'/',['MASK',13,'demodulation/Minimum']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[600,55,655,75])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/out_1']],...
		'position',[685,55,705,75])

add_block('built-in/Note',[sys,'/',['MASK',13,'demodulation/zero hold']])
set_param([sys,'/',['MASK',13,'demodulation/zero hold']],...
		'ForeGround',2,...
		'position',[370,15,375,20])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/Shift key']])
set_param([sys,'/',['MASK',13,'demodulation/Shift key']],...
		'Value','sft',...
		'position',[435,103,455,127])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/in_1']],...
		'position',[15,35,35,55])


%     Subsystem  ['MASK',13,'demodulation/Rising edge',13,'detector'].

new_system([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],'Location',[431,241,820,415])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Memory1']],...
		'x0','ini',...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:|Initial condition:')
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;ini=@2;',...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
		'Mask Entries','thld\/1\/')


%     Finished composite block ['MASK',13,'demodulation/Rising edge',13,'detector'].

set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
		'ForeGround',4,...
		'position',[170,123,230,167])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/in_2']])
set_param([sys,'/',['MASK',13,'demodulation/in_2']],...
		'Port','2',...
		'position',[70,135,90,155])
add_line([sys,'/',['MASK',13,'demodulation']],[225,45;345,45])
add_line([sys,'/',['MASK',13,'demodulation']],[660,65;680,65])
add_line([sys,'/',['MASK',13,'demodulation']],[95,145;165,145])
add_line([sys,'/',['MASK',13,'demodulation']],[340,110;335,110;345,65])
add_line([sys,'/',['MASK',13,'demodulation']],[235,145;305,145;305,55;345,55])
add_line([sys,'/',['MASK',13,'demodulation']],[385,55;400,55;390,110])
add_line([sys,'/',['MASK',13,'demodulation']],[400,55;490,55])
add_line([sys,'/',['MASK',13,'demodulation']],[460,115;465,115;465,70;490,70])
add_line([sys,'/',['MASK',13,'demodulation']],[520,65;540,65])
add_line([sys,'/',['MASK',13,'demodulation']],[580,65;595,65])
add_line([sys,'/',['MASK',13,'demodulation']],[40,45;145,45])
set_param([sys,'/',['MASK',13,'demodulation']],...
		'Mask Display','MASK\ndemodu',...
		'Mask Type','MASK Demodulation')
set_param([sys,'/',['MASK',13,'demodulation']],...
		'Mask Dialogue','M-ary Amplitude Shift Keying Demodulation:|M-ary number:|Carrier Frequency:|Carrier signal maximum amplitude:|Trigger signal threshold:')
set_param([sys,'/',['MASK',13,'demodulation']],...
		'Mask Translate','N=@1;Fc=@2;Ac=@3;thld=@4;sft=[0:N-1]*Ac*2/(N-1)-Ac;[num,den]=cheby1(2,.1,Fc*pi/5,''s'');')
set_param([sys,'/',['MASK',13,'demodulation']],...
		'Mask Help','This block demodulates a MASK modulated signal using noncoherent method. The first input port is for the received signal, which is MASK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The output signal has one clock period delay over the original signal.')
set_param([sys,'/',['MASK',13,'demodulation']],...
		'Mask Entries','16\/100\/1\/.2\/')


%     Finished composite block ['MASK',13,'demodulation'].

set_param([sys,'/',['MASK',13,'demodulation']],...
		'position',[620,3080,695,3120])

add_block('built-in/Note',[sys,'/','Format for SIMULINK Block Library References'])
set_param([sys,'/','Format for SIMULINK Block Library References'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',11,...
		'position',[385,3045,390,3050])

add_block('built-in/Note',[sys,'/','Bibliography'])
set_param([sys,'/','Bibliography'],...
		'Font Weight','bold',...
		'position',[225,3005,230,3010])

add_block('built-in/Note',[sys,'/','Chapter 5: MATLAB function References'])
set_param([sys,'/','Chapter 5: MATLAB function References'],...
		'Font Weight','bold',...
		'position',[245,2975,260,2980])

add_block('built-in/Note',[sys,'/','Same Section Titled as Chapter 2 or Alpha-beta order.'])
set_param([sys,'/','Same Section Titled as Chapter 2 or Alpha-beta order.'],...
		'position',[365,2945,370,2950])

add_block('built-in/Note',[sys,'/','Chapter 4: SIMULINK Block Library References'])
set_param([sys,'/','Chapter 4: SIMULINK Block Library References'],...
		'Font Weight','bold',...
		'position',[275,2920,280,2925])

add_block('built-in/Note',[sys,'/','Chapter 3: Examples'])
set_param([sys,'/','Chapter 3: Examples'],...
		'Font Weight','bold',...
		'position',[175,2890,180,2895])

add_block('built-in/Note',[sys,'/','Galois Field Calculations'])
set_param([sys,'/','Galois Field Calculations'],...
		'position',[260,2860,265,2865])

add_block('built-in/Note',[sys,'/','Utilities'])
set_param([sys,'/','Utilities'],...
		'position',[200,2835,205,2840])

add_block('built-in/Note',[sys,'/','Synchronization_'])
set_param([sys,'/','Synchronization_'],...
		'position',[235,2805,240,2810])

add_block('built-in/Note',[sys,'/','Channel_'])
set_param([sys,'/','Channel_'],...
		'position',[210,2770,215,2775])

add_block('built-in/Note',[sys,'/','Multiple Access'])
set_param([sys,'/','Multiple Access'],...
		'position',[230,2740,235,2745])

add_block('built-in/Note',[sys,'/','Low-Pass Equivalent Modultion//Demodualtion'])
set_param([sys,'/','Low-Pass Equivalent Modultion//Demodualtion'],...
		'position',[335,2710,340,2715])

add_block('built-in/Note',[sys,'/','Digital Modulation//Demodualtion'])
set_param([sys,'/','Digital Modulation//Demodualtion'],...
		'position',[290,2675,295,2680])

add_block('built-in/Note',[sys,'/','Analog Modulation//Demodulation'])
set_param([sys,'/','Analog Modulation//Demodulation'],...
		'position',[290,2640,295,2645])

add_block('built-in/Note',[sys,'/','Error-Control Coding'])
set_param([sys,'/','Error-Control Coding'],...
		'position',[250,2605,255,2610])

add_block('built-in/Note',[sys,'/','Source Coding'])
set_param([sys,'/','Source Coding'],...
		'position',[230,2565,235,2570])

add_block('built-in/Note',[sys,'/','Data Input//Output and Display'])
set_param([sys,'/','Data Input//Output and Display'],...
		'position',[280,2525,285,2530])

add_block('built-in/Note',[sys,'/','Chapter 2: Technical Background'])
set_param([sys,'/','Chapter 2: Technical Background'],...
		'Font Weight','bold',...
		'position',[220,2495,225,2500])

add_block('built-in/Note',[sys,'/','The Structure of the Manual'])
set_param([sys,'/','The Structure of the Manual'],...
		'position',[270,2465,275,2470])

add_block('built-in/Note',[sys,'/','Quick Start'])
set_param([sys,'/','Quick Start'],...
		'position',[215,2435,220,2440])

add_block('built-in/Note',[sys,'/','What is Communications Toolbox'])
set_param([sys,'/','What is Communications Toolbox'],...
		'position',[290,2410,295,2415])

add_block('built-in/Note',[sys,'/','Chapter 1: Introduction'])
set_param([sys,'/','Chapter 1: Introduction'],...
		'Font Weight','bold',...
		'position',[185,2375,190,2380])

add_block('built-in/Note',[sys,'/','DOCUMENTATION (Manual)'])
set_param([sys,'/','DOCUMENTATION (Manual)'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[320,2325,325,2330])

add_block('built-in/Note',[sys,'/','Application Examples:'])
set_param([sys,'/','Application Examples:'],...
		'Font Weight','bold',...
		'position',[85,2265,90,2270])

add_block('built-in/Note',[sys,'/','To be done.'])
set_param([sys,'/','To be done.'],...
		'position',[275,2265,280,2270])

add_block('built-in/Note',[sys,'/','Channel:'])
set_param([sys,'/','Channel:'],...
		'Font Weight','bold',...
		'position',[35,2230,40,2235])

add_block('built-in/Note',[sys,'/','Noise, Loss, and Interference.'])
set_param([sys,'/','Noise, Loss, and Interference.'],...
		'position',[335,2230,340,2235])

add_block('built-in/Note',[sys,'/','Low-Pass Equivalent Modulation.'])
set_param([sys,'/','Low-Pass Equivalent Modulation.'],...
		'position',[405,2190,410,2195])

add_block('built-in/Note',[sys,'/','ASK, PSK, FSK, ASK//PSK, QASK'])
set_param([sys,'/','ASK, PSK, FSK, ASK//PSK, QASK'],...
		'position',[410,2160,415,2165])

add_block('built-in/Note',[sys,'/','DSB-AM, SSB-AM, AM-with Carrier, FM, PM'])
set_param([sys,'/','DSB-AM, SSB-AM, AM-with Carrier, FM, PM'],...
		'position',[445,2130,450,2135])

add_block('built-in/Note',[sys,'/','The following modullation methods are implemeted:'])
set_param([sys,'/','The following modullation methods are implemeted:'],...
		'position',[410,2100,415,2105])

add_block('built-in/Note',[sys,'/','of channel noise.'])
set_param([sys,'/','of channel noise.'],...
		'position',[290,2070,295,2075])

add_block('built-in/Note',[sys,'/','Modulation can be effectly used to match a channel character and minimize the effect '])
set_param([sys,'/','Modulation can be effectly used to match a channel character and minimize the effect '],...
		'position',[525,2045,530,2050])

add_block('built-in/Note',[sys,'/','It is one of the most important signal procesisng procedures in communication systems'])
set_param([sys,'/','It is one of the most important signal procesisng procedures in communication systems'],...
		'position',[535,2020,540,2025])

add_block('built-in/Note',[sys,'/','Modulation//Demodulation:'])
set_param([sys,'/','Modulation//Demodulation:'],...
		'Font Weight','bold',...
		'position',[105,2020,110,2025])


%     Subsystem  ['Vector Convolution',13,'Co//Dec demo'].

new_system([sys,'/',['Vector Convolution',13,'Co//Dec demo']])
set_param([sys,'/',['Vector Convolution',13,'Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector Convolution',13,'Co//Dec demo']],...
		'Mask Display','Convol\nCo/Dec',...
		'Mask Dialogue','eval(''tstconcd'')')


%     Finished composite block ['Vector Convolution',13,'Co//Dec demo'].

set_param([sys,'/',['Vector Convolution',13,'Co//Dec demo']],...
		'BackGround',7,...
		'position',[420,1905,505,1941])

add_block('built-in/Note',[sys,'/','A SIMULINK demo for convolution coding with trellis display.'])
set_param([sys,'/','A SIMULINK demo for convolution coding with trellis display.'],...
		'position',[435,1870,440,1875])


%     Subsystem  'transfer function'.

new_system([sys,'/','transfer function'])
set_param([sys,'/','transfer function'],'Location',[436,197,856,343])
set_param([sys,'/','transfer function'],...
		'Mask Display','Generating\ntran_func',...
		'Mask Dialogue','eval(''fig_10_9; tf = sim2gen(''''fig_10_9''''),[tmp,tmp2]=simviter(tf);N_con_demo=tmp(1);K_con_demo=tmp(2);'')')


%     Finished composite block 'transfer function'.

set_param([sys,'/','transfer function'],...
		'BackGround',7,...
		'position',[415,1805,500,1847])

add_block('built-in/Note',[sys,'/','Add redundancy bits//words in the transfer side.'])
set_param([sys,'/','Add redundancy bits//words in the transfer side.'],...
		'position',[400,1485,405,1490])

add_block('built-in/Note',[sys,'/','Use the redundancy bits//words to detect//correct errors caused by transformation'])
set_param([sys,'/','Use the redundancy bits//words to detect//correct errors caused by transformation'],...
		'position',[515,1505,520,1510])

add_block('built-in/Note',[sys,'/','Example of using Reed-Solomon code to transfer a text through a noisy channel.'])
set_param([sys,'/','Example of using Reed-Solomon code to transfer a text through a noisy channel.'],...
		'position',[515,1535,520,1540])

add_block('built-in/Note',[sys,'/','This example is designed to be able to correct 6 errors per every 127 characters.'])
set_param([sys,'/','This example is designed to be able to correct 6 errors per every 127 characters.'],...
		'position',[515,1560,520,1565])

add_block('built-in/Note',[sys,'/','Error control Code//Decode:'])
set_param([sys,'/','Error control Code//Decode:'],...
		'Font Weight','bold',...
		'position',[115,1485,120,1490])

add_block('built-in/Note',[sys,'/','Convolution code: constructed with shift registers and Modulo-2 sum (XOR) blocks. '])
set_param([sys,'/','Convolution code: constructed with shift registers and Modulo-2 sum (XOR) blocks. '],...
		'position',[520,1770,525,1775])


%     Subsystem  ['DPCM data',13,'training3'].

new_system([sys,'/',['DPCM data',13,'training3']])
set_param([sys,'/',['DPCM data',13,'training3']],'Location',[111,168,452,354])
set_param([sys,'/',['DPCM data',13,'training3']],...
		'Mask Display','BCH code\nexample',...
		'Mask Dialogue','eval(''tstbchdm'')')


%     Finished composite block ['DPCM data',13,'training3'].

set_param([sys,'/',['DPCM data',13,'training3']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[415,1718,505,1761])


%     Subsystem  ['Click to see',13,'results'].

new_system([sys,'/',['Click to see',13,'results']])
set_param([sys,'/',['Click to see',13,'results']],'Location',[111,168,452,354])
set_param([sys,'/',['Click to see',13,'results']],...
		'Mask Display','DPCM\nexample')
set_param([sys,'/',['Click to see',13,'results']],...
		'Mask Dialogue','eval(''x=sin([0:.1:40]);[pt,co,pa]=dpcmopt(x,1,8);sig=sin(x*pi/3);id=dpcmenco(sig,co,pa,pt);qu=dpcmdeco(id,co,pt);subplot(211);plot(id);subplot(212);plot([sig;qu]'''');'')')


%     Finished composite block ['Click to see',13,'results'].

set_param([sys,'/',['Click to see',13,'results']],...
		'BackGround',7,...
		'position',[735,1403,805,1456])


%     Subsystem  'Synchronization'.

new_system([sys,'/','Synchronization'])
set_param([sys,'/','Synchronization'],'Location',[618,158,867,453])
set_param([sys,'/','Synchronization'],...
		'Mask Display','Synchronization',...
		'Mask Dialogue','eval(''com_clos;com_sync;'')')


%     Finished composite block 'Synchronization'.

set_param([sys,'/','Synchronization'],...
		'ForeGround',6,...
		'hide name',0,...
		'Font Angle','italic',...
		'position',[415,409,505,461])


%     Subsystem  'Utility1'.

new_system([sys,'/','Utility1'])
set_param([sys,'/','Utility1'],'Location',[136,230,381,439])
set_param([sys,'/','Utility1'],...
		'Mask Display','Utilities',...
		'Mask Dialogue','eval(''com_clos;com_util;'')')


%     Finished composite block 'Utility1'.

set_param([sys,'/','Utility1'],...
		'ForeGround',6,...
		'hide name',0,...
		'Font Angle','italic',...
		'position',[415,459,505,511])


%     Subsystem  'Utility2'.

new_system([sys,'/','Utility2'])
set_param([sys,'/','Utility2'],'Location',[136,230,381,439])
set_param([sys,'/','Utility2'],...
		'Mask Display','Demos',...
		'Mask Dialogue','eval(''com_clos;comtest;'')')


%     Finished composite block 'Utility2'.

set_param([sys,'/','Utility2'],...
		'ForeGround',6,...
		'hide name',0,...
		'Font Angle','italic',...
		'position',[415,509,505,561])

add_block('built-in/Note',[sys,'/','Partially done'])
set_param([sys,'/','Partially done'],...
		'position',[460,380,465,385])

add_block('built-in/Note',[sys,'/','Marketing Analysis'])
set_param([sys,'/','Marketing Analysis'],...
		'Font Weight','bold',...
		'position',[75,760,80,765])

add_block('built-in/Note',[sys,'/','Competation'])
set_param([sys,'/','Competation'],...
		'Font Weight','bold',...
		'position',[50,895,55,900])

add_block('built-in/Note',[sys,'/','FUNCTIONALITIES'])
set_param([sys,'/','FUNCTIONALITIES'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',11,...
		'position',[315,1185,320,1190])

add_block('built-in/Note',[sys,'/','Lack of flexibility. Fixed methods avaialable. Have to extend by independantly'])
set_param([sys,'/','Lack of flexibility. Fixed methods avaialable. Have to extend by independantly'],...
		'position',[540,920,545,925])

add_block('built-in/Note',[sys,'/','write your own C-file. The source code for some of the blocks are available with'])
set_param([sys,'/','write your own C-file. The source code for some of the blocks are available with'],...
		'position',[545,940,550,945])

add_block('built-in/Note',[sys,'/','__________________________________________________________________________________________________'])
set_param([sys,'/','__________________________________________________________________________________________________'],...
		'position',[450,3025,455,3030])

add_block('built-in/Note',[sys,'/','_________________________________________________________________________________________________'])
set_param([sys,'/','_________________________________________________________________________________________________'],...
		'position',[450,3345,455,3350])

add_block('built-in/Note',[sys,'/','Access the Toolbox:'])
set_param([sys,'/','Access the Toolbox:'],...
		'position',[380,3380,385,3385])

add_block('built-in/Note',[sys,'/','cd //home//wang//comm'])
set_param([sys,'/','cd //home//wang//comm'],...
		'position',[125,3425,130,3430])

add_block('built-in/Note',[sys,'/','COSSAP'])
set_param([sys,'/','COSSAP'],...
		'position',[265,990,270,995])

add_block('built-in/Note',[sys,'/','ACOLADE'])
set_param([sys,'/','ACOLADE'],...
		'position',[270,1040,275,1045])

add_block('built-in/Note',[sys,'/','trscode test.txt testenco.txt '])
set_param([sys,'/','trscode test.txt testenco.txt '],...
		'Font Name','Times New Roman',...
		'position',[410,1590,415,1595])

add_block('built-in/Note',[sys,'/','You may add "noise" to a few characters in file testenco.txt'])
set_param([sys,'/','You may add "noise" to a few characters in file testenco.txt'],...
		'position',[435,1610,440,1615])


%     Subsystem  ['DPCM data',13,'training1'].

new_system([sys,'/',['DPCM data',13,'training1']])
set_param([sys,'/',['DPCM data',13,'training1']],'Location',[111,168,452,354])
set_param([sys,'/',['DPCM data',13,'training1']],...
		'Mask Display','R-S encode\nexample',...
		'Mask Dialogue','eval(''trscode test.txt testenco.txt'')')


%     Finished composite block ['DPCM data',13,'training1'].

set_param([sys,'/',['DPCM data',13,'training1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[720,1588,810,1636])

add_block('built-in/Note',[sys,'/','Algebraic code: based on abstract algebraic theory'])
set_param([sys,'/','Algebraic code: based on abstract algebraic theory'],...
		'position',[410,1690,415,1695])

add_block('built-in/Note',[sys,'/','There are two different kind of error-control coding methods:'])
set_param([sys,'/','There are two different kind of error-control coding methods:'],...
		'position',[440,1665,445,1670])

add_block('built-in/Note',[sys,'/','trscode2 testenco.txt testdeco.txt'])
set_param([sys,'/','trscode2 testenco.txt testdeco.txt'],...
		'Font Name','Times New Roman',...
		'position',[425,1635,430,1640])


%     Subsystem  ['Click to execute',13,'Warning: It is slow'].

new_system([sys,'/',['Click to execute',13,'Warning: It is slow']])
set_param([sys,'/',['Click to execute',13,'Warning: It is slow']],'Location',[111,168,452,354])
set_param([sys,'/',['Click to execute',13,'Warning: It is slow']],...
		'Mask Display','R-S decode\nexample',...
		'Mask Dialogue','eval(''trscode2 testenco.txt testdeco.txt'')')


%     Finished composite block ['Click to execute',13,'Warning: It is slow'].

set_param([sys,'/',['Click to execute',13,'Warning: It is slow']],...
		'BackGround',7,...
		'position',[720,1633,810,1676])

add_block('built-in/Note',[sys,'/','[p_tran, codebook, partition] = dpcmopt(x, 1, 8);'])
set_param([sys,'/','[p_tran, codebook, partition] = dpcmopt(x, 1, 8);'],...
		'Font Name','Times New Roman',...
		'position',[485,1345,490,1350])

add_block('built-in/Note',[sys,'/','indx = dpcmenco(sig, codebook, partition, p_tran); '])
set_param([sys,'/','indx = dpcmenco(sig, codebook, partition, p_tran); '],...
		'Font Name','Times New Roman',...
		'position',[490,1395,495,1400])

add_block('built-in/Note',[sys,'/','quant = dpcmdeco(indx, codebook, p_tran);'])
set_param([sys,'/','quant = dpcmdeco(indx, codebook, p_tran);'],...
		'Font Name','Times New Roman',...
		'position',[465,1415,470,1420])

add_block('built-in/Note',[sys,'/','Read the README file in the directory. '])
set_param([sys,'/','Read the README file in the directory. '],...
		'position',[180,3450,185,3455])


%     Subsystem  'Receiver'.

new_system([sys,'/','Receiver'])
set_param([sys,'/','Receiver'],'Location',[384,427,663,590])

add_block('built-in/Inport',[sys,'/','Receiver/in_1'])
set_param([sys,'/','Receiver/in_1'],...
		'orientation',2,...
		'position',[215,50,235,70])

add_block('built-in/Outport',[sys,'/','Receiver/out_1'])
set_param([sys,'/','Receiver/out_1'],...
		'orientation',2,...
		'position',[80,50,100,70])
add_line([sys,'/','Receiver'],[210,60;105,60])
set_param([sys,'/','Receiver'],...
		'Mask Display','Receiving\nprocess',...
		'Mask Dialogue','eval(''com_trans;'')')


%     Finished composite block 'Receiver'.

set_param([sys,'/','Receiver'],...
		'hide name',0,...
		'position',[570,310,650,360])


%     Subsystem  ['Store N',13,'Display'].

new_system([sys,'/',['Store N',13,'Display']])
set_param([sys,'/',['Store N',13,'Display']],'Location',[427,463,684,617])

add_block('built-in/Inport',[sys,'/',['Store N',13,'Display/in_1']])
set_param([sys,'/',['Store N',13,'Display/in_1']],...
		'position',[55,45,75,65])
set_param([sys,'/',['Store N',13,'Display']],...
		'Mask Display','Store N\nDisplay',...
		'Mask Dialogue','eval(''com_sour;'');')


%     Finished composite block ['Store N',13,'Display'].

set_param([sys,'/',['Store N',13,'Display']],...
		'hide name',0,...
		'position',[680,310,760,360])


%     Subsystem  'Click here'.

new_system([sys,'/','Click here'])
set_param([sys,'/','Click here'],'Location',[136,230,381,439])
set_param([sys,'/','Click here'],...
		'Mask Display','A complete\nstructure',...
		'Mask Dialogue','eval(''commu'')')


%     Finished composite block 'Click here'.

set_param([sys,'/','Click here'],...
		'BackGround',7,...
		'Font Angle','italic',...
		'position',[790,305,875,351])

add_block('built-in/Note',[sys,'/','General structure of'])
set_param([sys,'/','General structure of'],...
		'ForeGround',4,...
		'Font Weight','bold',...
		'position',[80,325,85,330])

add_block('built-in/Note',[sys,'/','Systems to transmitting information from transmitting site to receiver site.'])
set_param([sys,'/','Systems to transmitting information from transmitting site to receiver site.'],...
		'position',[480,75,485,80])

add_block('built-in/Note',[sys,'/','The transmitted information could be analog signal or digital signal.'])
set_param([sys,'/','The transmitted information could be analog signal or digital signal.'],...
		'position',[460,100,465,105])

add_block('built-in/Note',[sys,'/','A collection of MATLAB functions and SIMULINK blocks for Communication '])
set_param([sys,'/','A collection of MATLAB functions and SIMULINK blocks for Communication '],...
		'position',[495,135,500,140])

add_block('built-in/Note',[sys,'/','System design, simulation and analysis. There are some overlap and  between'])
set_param([sys,'/','System design, simulation and analysis. There are some overlap and  between'],...
		'position',[500,155,505,160])

add_block('built-in/Note',[sys,'/','Use the scror bar to go to the next frame of this tutorial demo ------>'])
set_param([sys,'/','Use the scror bar to go to the next frame of this tutorial demo ------>'],...
		'position',[465,210,470,215])


%     Subsystem  'Click here1'.

new_system([sys,'/','Click here1'])
set_param([sys,'/','Click here1'],'Location',[380,422,702,464])

add_block('built-in/Note',[sys,'/','Click here1/Welcome to Communication toolbox.'])
set_param([sys,'/','Click here1/Welcome to Communication toolbox.'],...
		'position',[150,10,155,15])
set_param([sys,'/','Click here1'],...
		'Mask Display','.')


%     Finished composite block 'Click here1'.

set_param([sys,'/','Click here1'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Angle','italic',...
		'position',[560,245,630,273])

add_block('built-in/Note',[sys,'/','All cyan color block are blocks with examples '])
set_param([sys,'/','All cyan color block are blocks with examples '],...
		'position',[390,245,395,250])

add_block('built-in/Note',[sys,'/','Communications Toolbox:'])
set_param([sys,'/','Communications Toolbox:'],...
		'ForeGround',4,...
		'Font Weight','bold',...
		'position',[110,135,115,140])

add_block('built-in/Note',[sys,'/','Communication Systems:'])
set_param([sys,'/','Communication Systems:'],...
		'ForeGround',4,...
		'Font Weight','bold',...
		'position',[105,75,110,80])

add_block('built-in/Note',[sys,'/','About this On-Line Tutorial:'])
set_param([sys,'/','About this On-Line Tutorial:'],...
		'ForeGround',4,...
		'Font Name','helvetica',...
		'Font Weight','bold',...
		'position',[110,210,115,215])

add_block('built-in/Note',[sys,'/','a communication system:'])
set_param([sys,'/','a communication system:'],...
		'ForeGround',4,...
		'Font Weight','bold',...
		'position',[105,345,110,350])

add_block('built-in/Note',[sys,'/','A highly demanding area because of "information super high way", "wireless phone", etc'])
set_param([sys,'/','A highly demanding area because of "information super high way", "wireless phone", etc'],...
		'position',[535,765,540,770])

add_block('built-in/Note',[sys,'/','No flexibel tool available for researches and design purpose.'])
set_param([sys,'/','No flexibel tool available for researches and design purpose.'],...
		'position',[445,790,450,795])

add_block('built-in/Note',[sys,'/','Current available products can do very limited simulation. Few rooms for testing'])
set_param([sys,'/','Current available products can do very limited simulation. Few rooms for testing'],...
		'position',[510,835,515,840])

add_block('built-in/Note',[sys,'/','modified systems and new methods. No interactive display.'])
set_param([sys,'/','modified systems and new methods. No interactive display.'],...
		'position',[445,855,450,860])

add_block('built-in/Note',[sys,'/','SPW: (BOSS, comdisco) Major competitor. '])
set_param([sys,'/','SPW: (BOSS, comdisco) Major competitor. '],...
		'position',[390,900,395,905])

add_block('built-in/Note',[sys,'/','a very expensive price.'])
set_param([sys,'/','a very expensive price.'],...
		'position',[355,960,360,965])

add_block('built-in/Note',[sys,'/','DSPStation'])
set_param([sys,'/','DSPStation'],...
		'position',[275,1015,280,1020])

add_block('built-in/Note',[sys,'/','Hypersignal'])
set_param([sys,'/','Hypersignal'],...
		'position',[280,1065,285,1070])

add_block('built-in/Note',[sys,'/','SystemView (ELANIX Inc.): Very Preliminary, on PC-Window.'])
set_param([sys,'/','SystemView (ELANIX Inc.): Very Preliminary, on PC-Window.'],...
		'position',[440,1090,445,1095])

add_block('built-in/Note',[sys,'/','EESof (HP): Communication Design Suit: Channel Analysis'])
set_param([sys,'/','EESof (HP): Communication Design Suit: Channel Analysis'],...
		'position',[440,1115,445,1120])

add_block('built-in/Note',[sys,'/','Source//Sink:'])
set_param([sys,'/','Source//Sink:'],...
		'Font Weight','bold',...
		'position',[55,1220,60,1225])

add_block('built-in/Note',[sys,'/','Source coding:'])
set_param([sys,'/','Source coding:'],...
		'Font Weight','bold',...
		'position',[65,1260,70,1265])

add_block('built-in/Note',[sys,'/','Data input; Store data; Data conversion; Data representation // display'])
set_param([sys,'/','Data input; Store data; Data conversion; Data representation // display'],...
		'position',[475,1220,480,1225])

add_block('built-in/Note',[sys,'/','Sampling; Analog-to-Digital conversion; Data compression.'])
set_param([sys,'/','Sampling; Analog-to-Digital conversion; Data compression.'],...
		'position',[445,1260,450,1265])

add_block('built-in/Note',[sys,'/','For example: to compress a sin signal  using delta-modulation method.'])
set_param([sys,'/','For example: to compress a sin signal  using delta-modulation method.'],...
		'position',[480,1290,485,1295])

add_block('built-in/Note',[sys,'/','x = sin([0 : .1 : 40]);'])
set_param([sys,'/','x = sin([0 : .1 : 40]);'],...
		'Font Name','Times New Roman',...
		'position',[400,1325,405,1330])

add_block('built-in/Note',[sys,'/','sig=sin(x*pi//3);'])
set_param([sys,'/','sig=sin(x*pi//3);'],...
		'Font Name','Times New Roman',...
		'position',[380,1370,385,1375])

add_block('built-in/Note',[sys,'/','subplot(211); plot(indx);'])
set_param([sys,'/','subplot(211); plot(indx);'],...
		'Font Name','Times New Roman',...
		'position',[410,1435,415,1440])

add_block('built-in/Note',[sys,'/',['subplot(212); plot([sig; quant]'')']])
set_param([sys,'/',['subplot(212); plot([sig; quant]'')']],...
		'Font Name','Times New Roman',...
		'position',[425,1460,430,1465])


%     Subsystem  'Source 1'.

new_system([sys,'/','Source 1'])
set_param([sys,'/','Source 1'],'Location',[185,105,363,240])

add_block('built-in/Outport',[sys,'/','Source 1/out_1'])
set_param([sys,'/','Source 1/out_1'],...
		'position',[110,60,130,80])
set_param([sys,'/','Source 1'],...
		'Mask Display','Source',...
		'Mask Type','Source',...
		'Mask Dialogue','eval(''com_sour;'')')


%     Finished composite block 'Source 1'.

set_param([sys,'/','Source 1'],...
		'hide name',0,...
		'position',[245,560,335,610])


%     Subsystem  ['Analog',13,'Modulation'].

new_system([sys,'/',['Analog',13,'Modulation']])
set_param([sys,'/',['Analog',13,'Modulation']],'Location',[56,131,246,209])

add_block('built-in/Outport',[sys,'/',['Analog',13,'Modulation/out_1']])
set_param([sys,'/',['Analog',13,'Modulation/out_1']],...
		'position',[325,40,345,60])

add_block('built-in/Inport',[sys,'/',['Analog',13,'Modulation/in_1']])
set_param([sys,'/',['Analog',13,'Modulation/in_1']],...
		'position',[235,40,255,60])
add_line([sys,'/',['Analog',13,'Modulation']],[260,50;320,50])
set_param([sys,'/',['Analog',13,'Modulation']],...
		'Mask Display','Modulation',...
		'Mask Dialogue','eval(''com_modu;'')')


%     Finished composite block ['Analog',13,'Modulation'].

set_param([sys,'/',['Analog',13,'Modulation']],...
		'hide name',0,...
		'Font Weight','bold',...
		'Font Angle','italic',...
		'position',[245,510,335,560])


%     Subsystem  ['Error-control',13,'coding'].

new_system([sys,'/',['Error-control',13,'coding']])
set_param([sys,'/',['Error-control',13,'coding']],'Location',[474,259,732,444])

add_block('built-in/Outport',[sys,'/',['Error-control',13,'coding/out_1']])
set_param([sys,'/',['Error-control',13,'coding/out_1']],...
		'position',[145,74,165,96])

add_block('built-in/Inport',[sys,'/',['Error-control',13,'coding/in_1']])
set_param([sys,'/',['Error-control',13,'coding/in_1']],...
		'position',[35,75,55,95])
add_line([sys,'/',['Error-control',13,'coding']],[60,85;140,85])
set_param([sys,'/',['Error-control',13,'coding']],...
		'Mask Display','Error\ncontrol\ncoding',...
		'Mask Dialogue','eval(''com_code;'');')


%     Finished composite block ['Error-control',13,'coding'].

set_param([sys,'/',['Error-control',13,'coding']],...
		'hide name',0,...
		'position',[245,460,335,510])


%     Subsystem  'Transmitter1'.

new_system([sys,'/','Transmitter1'])
set_param([sys,'/','Transmitter1'],'Location',[126,473,408,606])

add_block('built-in/Outport',[sys,'/','Transmitter1/out_1'])
set_param([sys,'/','Transmitter1/out_1'],...
		'position',[190,45,210,65])

add_block('built-in/Inport',[sys,'/','Transmitter1/in_1'])
set_param([sys,'/','Transmitter1/in_1'],...
		'position',[35,45,55,65])
add_line([sys,'/','Transmitter1'],[60,55;185,55])
set_param([sys,'/','Transmitter1'],...
		'Mask Display','Transmitter\n/filters',...
		'Mask Dialogue','eval(''com_filt;'')')


%     Finished composite block 'Transmitter1'.

set_param([sys,'/','Transmitter1'],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[415,560,505,610])


%     Subsystem  'Frequency_Spread1'.

new_system([sys,'/','Frequency_Spread1'])
set_param([sys,'/','Frequency_Spread1'],'Location',[84,452,356,591])

add_block('built-in/Outport',[sys,'/','Frequency_Spread1/out_1'])
set_param([sys,'/','Frequency_Spread1/out_1'],...
		'position',[460,50,480,70])

add_block('built-in/Inport',[sys,'/','Frequency_Spread1/in_1'])
set_param([sys,'/','Frequency_Spread1/in_1'],...
		'position',[295,50,315,70])
add_line([sys,'/','Frequency_Spread1'],[320,60;455,60])
set_param([sys,'/','Frequency_Spread1'],...
		'Mask Display','Data\nCompression',...
		'Mask Dialogue','eval(''com_sprd;'')')


%     Finished composite block 'Frequency_Spread1'.

set_param([sys,'/','Frequency_Spread1'],...
		'hide name',0,...
		'position',[740,509,830,561])


%     Subsystem  'Frequency_Spread'.

new_system([sys,'/','Frequency_Spread'])
set_param([sys,'/','Frequency_Spread'],'Location',[84,452,356,591])

add_block('built-in/Inport',[sys,'/','Frequency_Spread/in_1'])
set_param([sys,'/','Frequency_Spread/in_1'],...
		'position',[295,50,315,70])

add_block('built-in/Outport',[sys,'/','Frequency_Spread/out_1'])
set_param([sys,'/','Frequency_Spread/out_1'],...
		'position',[460,50,480,70])
add_line([sys,'/','Frequency_Spread'],[320,60;455,60])
set_param([sys,'/','Frequency_Spread'],...
		'Mask Display','Spread\nspectrum',...
		'Mask Dialogue','eval(''com_sprd;'')')


%     Finished composite block 'Frequency_Spread'.

set_param([sys,'/','Frequency_Spread'],...
		'hide name',0,...
		'position',[740,459,830,511])


%     Subsystem  'Encrypt1'.

new_system([sys,'/','Encrypt1'])
set_param([sys,'/','Encrypt1'],'Location',[679,439,963,603])

add_block('built-in/Outport',[sys,'/','Encrypt1/out_1'])
set_param([sys,'/','Encrypt1/out_1'],...
		'position',[140,75,160,95])

add_block('built-in/Inport',[sys,'/','Encrypt1/in_1'])
set_param([sys,'/','Encrypt1/in_1'],...
		'position',[40,75,60,95])
add_line([sys,'/','Encrypt1'],[65,85;135,85])
set_param([sys,'/','Encrypt1'],...
		'Mask Display','Encrypt',...
		'Mask Dialogue','eval(''com_encr;'')')


%     Finished composite block 'Encrypt1'.

set_param([sys,'/','Encrypt1'],...
		'hide name',0,...
		'position',[740,409,830,461])

add_block('built-in/Note',[sys,'/',['Drop to',13,'next version']])
set_param([sys,'/',['Drop to',13,'next version']],...
		'position',[780,375,785,380])


%     Subsystem  'Source '.

new_system([sys,'/','Source '])
set_param([sys,'/','Source '],'Location',[185,105,363,240])

add_block('built-in/Outport',[sys,'/','Source /out_1'])
set_param([sys,'/','Source /out_1'],...
		'position',[110,60,130,80])
set_param([sys,'/','Source '],...
		'Mask Display','Source',...
		'Mask Type','Source',...
		'Mask Dialogue','eval(''com_sour;'')')


%     Finished composite block 'Source '.

set_param([sys,'/','Source '],...
		'hide name',0,...
		'position',[240,310,320,360])


%     Subsystem  'Transmitter'.

new_system([sys,'/','Transmitter'])
set_param([sys,'/','Transmitter'],'Location',[126,473,408,606])

add_block('built-in/Outport',[sys,'/','Transmitter/out_1'])
set_param([sys,'/','Transmitter/out_1'],...
		'position',[190,45,210,65])

add_block('built-in/Inport',[sys,'/','Transmitter/in_1'])
set_param([sys,'/','Transmitter/in_1'],...
		'position',[35,45,55,65])
add_line([sys,'/','Transmitter'],[60,55;185,55])
set_param([sys,'/','Transmitter'],...
		'Mask Display','Transmiting\nprocess',...
		'Mask Dialogue','eval(''com_trans;'')')


%     Finished composite block 'Transmitter'.

set_param([sys,'/','Transmitter'],...
		'hide name',0,...
		'position',[350,310,430,360])


%     Subsystem  'Channel'.

new_system([sys,'/','Channel'])
set_param([sys,'/','Channel'],'Location',[446,298,1025,565])

add_block('built-in/Outport',[sys,'/','Channel/out_1'])
set_param([sys,'/','Channel/out_1'],...
		'position',[455,85,475,105])

add_block('built-in/Sum',[sys,'/','Channel/Sum'])
set_param([sys,'/','Channel/Sum'],...
		'inputs','+++',...
		'position',[340,77,360,113])


%     Subsystem  'Channel/Sub-system1'.

new_system([sys,'/','Channel/Sub-system1'])
set_param([sys,'/','Channel/Sub-system1'],'Location',[575,99,983,538])

add_block('built-in/Sum',[sys,'/','Channel/Sub-system1/Sum'])
set_param([sys,'/','Channel/Sub-system1/Sum'],...
		'inputs','+++',...
		'position',[325,207,345,243])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system1/out_1'])
set_param([sys,'/','Channel/Sub-system1/out_1'],...
		'position',[365,215,385,235])

add_block('built-in/Mux',[sys,'/','Channel/Sub-system1/Mux2'])
set_param([sys,'/','Channel/Sub-system1/Mux2'],...
		'inputs','2',...
		'position',[235,321,270,354])

add_block('built-in/Mux',[sys,'/','Channel/Sub-system1/Mux1'])
set_param([sys,'/','Channel/Sub-system1/Mux1'],...
		'inputs','2',...
		'position',[230,81,265,114])

add_block('built-in/Mux',[sys,'/','Channel/Sub-system1/Mux'])
set_param([sys,'/','Channel/Sub-system1/Mux'],...
		'inputs','2',...
		'position',[220,206,255,239])


%     Subsystem  'Channel/Sub-system1/Sub-system6'.

new_system([sys,'/','Channel/Sub-system1/Sub-system6'])
set_param([sys,'/','Channel/Sub-system1/Sub-system6'],'Location',[568,271,976,714])

add_block('built-in/Constant',[sys,'/','Channel/Sub-system1/Sub-system6/Switch Key'])
set_param([sys,'/','Channel/Sub-system1/Sub-system6/Switch Key'],...
		'position',[65,85,85,105])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system1/Sub-system6/out_1'])
set_param([sys,'/','Channel/Sub-system1/Sub-system6/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel/Sub-system1/Sub-system6'],[90,95;290,95])
set_param([sys,'/','Channel/Sub-system1/Sub-system6'],...
		'Mask Display','Receiver Noise')


%     Finished composite block 'Channel/Sub-system1/Sub-system6'.

set_param([sys,'/','Channel/Sub-system1/Sub-system6'],...
		'hide name',0,...
		'position',[30,361,135,409])


%     Subsystem  'Channel/Sub-system1/Sub-system5'.

new_system([sys,'/','Channel/Sub-system1/Sub-system5'])
set_param([sys,'/','Channel/Sub-system1/Sub-system5'],'Location',[568,271,976,714])

add_block('built-in/Constant',[sys,'/','Channel/Sub-system1/Sub-system5/Switch Key'])
set_param([sys,'/','Channel/Sub-system1/Sub-system5/Switch Key'],...
		'position',[100,85,120,105])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system1/Sub-system5/out_1'])
set_param([sys,'/','Channel/Sub-system1/Sub-system5/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel/Sub-system1/Sub-system5'],[125,95;290,95])
set_param([sys,'/','Channel/Sub-system1/Sub-system5'],...
		'Mask Display','Terrestrial Noise')


%     Finished composite block 'Channel/Sub-system1/Sub-system5'.

set_param([sys,'/','Channel/Sub-system1/Sub-system5'],...
		'hide name',0,...
		'position',[30,291,135,339])


%     Subsystem  'Channel/Sub-system1/Sub-system4'.

new_system([sys,'/','Channel/Sub-system1/Sub-system4'])
set_param([sys,'/','Channel/Sub-system1/Sub-system4'],'Location',[568,271,976,714])

add_block('built-in/Constant',[sys,'/','Channel/Sub-system1/Sub-system4/Switch Key'])
set_param([sys,'/','Channel/Sub-system1/Sub-system4/Switch Key'],...
		'Value','2',...
		'position',[95,80,115,100])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system1/Sub-system4/out_1'])
set_param([sys,'/','Channel/Sub-system1/Sub-system4/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel/Sub-system1/Sub-system4'],[120,90;200,90;200,95;290,95])
set_param([sys,'/','Channel/Sub-system1/Sub-system4'],...
		'Mask Display','IM Noise')


%     Finished composite block 'Channel/Sub-system1/Sub-system4'.

set_param([sys,'/','Channel/Sub-system1/Sub-system4'],...
		'hide name',0,...
		'position',[30,231,135,279])


%     Subsystem  'Channel/Sub-system1/Sub-system3'.

new_system([sys,'/','Channel/Sub-system1/Sub-system3'])
set_param([sys,'/','Channel/Sub-system1/Sub-system3'],'Location',[568,271,976,714])

add_block('built-in/Constant',[sys,'/','Channel/Sub-system1/Sub-system3/Switch Key'])
set_param([sys,'/','Channel/Sub-system1/Sub-system3/Switch Key'],...
		'position',[110,85,130,105])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system1/Sub-system3/out_1'])
set_param([sys,'/','Channel/Sub-system1/Sub-system3/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel/Sub-system1/Sub-system3'],[135,95;290,95])
set_param([sys,'/','Channel/Sub-system1/Sub-system3'],...
		'Mask Display','Atmosphere Noise')


%     Finished composite block 'Channel/Sub-system1/Sub-system3'.

set_param([sys,'/','Channel/Sub-system1/Sub-system3'],...
		'hide name',0,...
		'position',[30,171,135,219])


%     Subsystem  'Channel/Sub-system1/Sub-system2'.

new_system([sys,'/','Channel/Sub-system1/Sub-system2'])
set_param([sys,'/','Channel/Sub-system1/Sub-system2'],'Location',[568,271,976,714])

add_block('built-in/Constant',[sys,'/','Channel/Sub-system1/Sub-system2/Switch Key'])
set_param([sys,'/','Channel/Sub-system1/Sub-system2/Switch Key'],...
		'position',[130,85,150,105])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system1/Sub-system2/out_1'])
set_param([sys,'/','Channel/Sub-system1/Sub-system2/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel/Sub-system1/Sub-system2'],[155,95;290,95])
set_param([sys,'/','Channel/Sub-system1/Sub-system2'],...
		'Mask Display','Random Noise')


%     Finished composite block 'Channel/Sub-system1/Sub-system2'.

set_param([sys,'/','Channel/Sub-system1/Sub-system2'],...
		'hide name',0,...
		'position',[30,101,120,149])


%     Subsystem  'Channel/Sub-system1/Sub-system1'.

new_system([sys,'/','Channel/Sub-system1/Sub-system1'])
set_param([sys,'/','Channel/Sub-system1/Sub-system1'],'Location',[185,298,593,741])

add_block('built-in/Constant',[sys,'/','Channel/Sub-system1/Sub-system1/Switch Key'])
set_param([sys,'/','Channel/Sub-system1/Sub-system1/Switch Key'],...
		'position',[115,100,135,120])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system1/Sub-system1/out_1'])
set_param([sys,'/','Channel/Sub-system1/Sub-system1/out_1'],...
		'position',[295,85,315,105])
add_line([sys,'/','Channel/Sub-system1/Sub-system1'],[140,110;210,110;210,95;290,95])
set_param([sys,'/','Channel/Sub-system1/Sub-system1'],...
		'Mask Display','LO phase noise')


%     Finished composite block 'Channel/Sub-system1/Sub-system1'.

set_param([sys,'/','Channel/Sub-system1/Sub-system1'],...
		'hide name',0,...
		'position',[30,26,120,74])
add_line([sys,'/','Channel/Sub-system1'],[350,225;360,225])
add_line([sys,'/','Channel/Sub-system1'],[275,340;280,340;280,235;320,235])
add_line([sys,'/','Channel/Sub-system1'],[260,225;320,225])
add_line([sys,'/','Channel/Sub-system1'],[270,100;280,100;280,215;320,215])
add_line([sys,'/','Channel/Sub-system1'],[140,385;180,385;180,345;230,345])
add_line([sys,'/','Channel/Sub-system1'],[140,315;180,315;180,330;230,330])
add_line([sys,'/','Channel/Sub-system1'],[140,255;170,255;170,230;215,230])
add_line([sys,'/','Channel/Sub-system1'],[140,195;170,195;170,215;215,215])
add_line([sys,'/','Channel/Sub-system1'],[125,125;170,125;170,105;225,105])
add_line([sys,'/','Channel/Sub-system1'],[125,50;170,50;170,90;225,90])
set_param([sys,'/','Channel/Sub-system1'],...
		'Mask Display','Noise')


%     Finished composite block 'Channel/Sub-system1'.

set_param([sys,'/','Channel/Sub-system1'],...
		'hide name',0,...
		'position',[165,10,235,60])

add_block('built-in/Note',[sys,'/','Channel/Fiber Optic Communications'])
set_param([sys,'/','Channel/Fiber Optic Communications'],...
		'position',[80,240,85,245])

add_block('built-in/Note',[sys,'/','Channel/Satellite Communications'])
set_param([sys,'/','Channel/Satellite Communications'],...
		'position',[70,215,75,220])


%     Subsystem  'Channel/Sub-system5'.

new_system([sys,'/','Channel/Sub-system5'])
set_param([sys,'/','Channel/Sub-system5'],'Location',[213,332,807,610])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system5/out_1'])
set_param([sys,'/','Channel/Sub-system5/out_1'],...
		'position',[395,55,415,75])

add_block('built-in/Mux',[sys,'/','Channel/Sub-system5/Mux'])
set_param([sys,'/','Channel/Sub-system5/Mux'],...
		'inputs','2',...
		'position',[270,46,305,79])


%     Subsystem  'Channel/Sub-system5/Sub-system7'.

new_system([sys,'/','Channel/Sub-system5/Sub-system7'])
set_param([sys,'/','Channel/Sub-system5/Sub-system7'],'Location',[196,225,790,503])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system5/Sub-system7/out_1'])
set_param([sys,'/','Channel/Sub-system5/Sub-system7/out_1'],...
		'position',[395,35,415,55])
set_param([sys,'/','Channel/Sub-system5/Sub-system7'],...
		'Mask Display','Co-channel interference')


%     Finished composite block 'Channel/Sub-system5/Sub-system7'.

set_param([sys,'/','Channel/Sub-system5/Sub-system7'],...
		'hide name',0,...
		'position',[30,142,200,178])


%     Subsystem  'Channel/Sub-system5/Sub-system6'.

new_system([sys,'/','Channel/Sub-system5/Sub-system6'])
set_param([sys,'/','Channel/Sub-system5/Sub-system6'],'Location',[196,225,790,503])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system5/Sub-system6/out_1'])
set_param([sys,'/','Channel/Sub-system5/Sub-system6/out_1'],...
		'position',[395,35,415,55])
set_param([sys,'/','Channel/Sub-system5/Sub-system6'],...
		'Mask Display','Adjacent channel interference')


%     Finished composite block 'Channel/Sub-system5/Sub-system6'.

set_param([sys,'/','Channel/Sub-system5/Sub-system6'],...
		'hide name',0,...
		'position',[30,82,200,118])


%     Subsystem  'Channel/Sub-system5/Sub-system5'.

new_system([sys,'/','Channel/Sub-system5/Sub-system5'])
set_param([sys,'/','Channel/Sub-system5/Sub-system5'],'Location',[196,225,790,503])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system5/Sub-system5/out_1'])
set_param([sys,'/','Channel/Sub-system5/Sub-system5/out_1'],...
		'position',[395,35,415,55])
set_param([sys,'/','Channel/Sub-system5/Sub-system5'],...
		'Mask Display','Intersymbol Interference')


%     Finished composite block 'Channel/Sub-system5/Sub-system5'.

set_param([sys,'/','Channel/Sub-system5/Sub-system5'],...
		'hide name',0,...
		'position',[30,25,200,65])
add_line([sys,'/','Channel/Sub-system5'],[310,65;390,65])
add_line([sys,'/','Channel/Sub-system5'],[205,100;230,100;230,70;265,70])
add_line([sys,'/','Channel/Sub-system5'],[205,45;230,45;230,55;265,55])
set_param([sys,'/','Channel/Sub-system5'],...
		'Mask Display','Interference')


%     Finished composite block 'Channel/Sub-system5'.

set_param([sys,'/','Channel/Sub-system5'],...
		'hide name',0,...
		'position',[165,141,235,189])

add_block('built-in/Inport',[sys,'/','Channel/in_1'])
set_param([sys,'/','Channel/in_1'],...
		'position',[35,85,55,105])


%     Subsystem  'Channel/Sub-system4'.

new_system([sys,'/','Channel/Sub-system4'])
set_param([sys,'/','Channel/Sub-system4'],'Location',[586,358,1012,641])

add_block('built-in/Outport',[sys,'/','Channel/Sub-system4/out_1'])
set_param([sys,'/','Channel/Sub-system4/out_1'],...
		'position',[145,135,165,155])

add_block('built-in/Inport',[sys,'/','Channel/Sub-system4/in_1'])
set_param([sys,'/','Channel/Sub-system4/in_1'],...
		'position',[35,135,55,155])
add_line([sys,'/','Channel/Sub-system4'],[60,145;140,145])
set_param([sys,'/','Channel/Sub-system4'],...
		'Mask Display','Loss')


%     Finished composite block 'Channel/Sub-system4'.

set_param([sys,'/','Channel/Sub-system4'],...
		'hide name',0,...
		'position',[165,73,235,117])
add_line([sys,'/','Channel'],[365,95;450,95])
add_line([sys,'/','Channel'],[240,95;335,95])
add_line([sys,'/','Channel'],[240,165;295,165;295,105;335,105])
add_line([sys,'/','Channel'],[240,35;295,35;295,85;335,85])
add_line([sys,'/','Channel'],[60,95;160,95])
set_param([sys,'/','Channel'],...
		'Mask Display','Channel',...
		'Mask Dialogue','eval(''com_chan;'')')


%     Finished composite block 'Channel'.

set_param([sys,'/','Channel'],...
		'hide name',0,...
		'move name',0,...
		'position',[460,310,540,360])

add_block('built-in/Note',[sys,'/','Done'])
set_param([sys,'/','Done'],...
		'position',[289,380,295,385])


%     Subsystem  'Format'.

new_system([sys,'/','Format'])
set_param([sys,'/','Format'],'Location',[196,122,458,241])

add_block('built-in/Outport',[sys,'/','Format/out_1'])
set_param([sys,'/','Format/out_1'],...
		'position',[175,55,195,75])

add_block('built-in/Inport',[sys,'/','Format/in_1'])
set_param([sys,'/','Format/in_1'],...
		'position',[35,55,55,75])
add_line([sys,'/','Format'],[60,65;170,65])
set_param([sys,'/','Format'],...
		'Mask Display','Source\ncode',...
		'Mask Dialogue','eval(''com_frmt;'')')


%     Finished composite block 'Format'.

set_param([sys,'/','Format'],...
		'hide name',0,...
		'position',[245,410,335,460])


%     Subsystem  ['Store N',13,'Display1'].

new_system([sys,'/',['Store N',13,'Display1']])
set_param([sys,'/',['Store N',13,'Display1']],'Location',[427,463,684,617])

add_block('built-in/Inport',[sys,'/',['Store N',13,'Display1/in_2']])
set_param([sys,'/',['Store N',13,'Display1/in_2']],...
		'Port','2',...
		'position',[50,90,70,110])

add_block('built-in/Inport',[sys,'/',['Store N',13,'Display1/in_1']])
set_param([sys,'/',['Store N',13,'Display1/in_1']],...
		'position',[55,45,75,65])
set_param([sys,'/',['Store N',13,'Display1']],...
		'Mask Display','Store N\ndisplay',...
		'Mask Dialogue','eval(''com_sour;'');')


%     Finished composite block ['Store N',13,'Display1'].

set_param([sys,'/',['Store N',13,'Display1']],...
		'orientation',2,...
		'hide name',0,...
		'position',[245,607,335,658])


%     Subsystem  'Click_here'.

new_system([sys,'/','Click_here'])
set_param([sys,'/','Click_here'],'Location',[136,230,381,439])
set_param([sys,'/','Click_here'],...
		'Mask Display','help\ncomcmds',...
		'Mask Dialogue','eval(''help comcmds'')')


%     Finished composite block 'Click_here'.

set_param([sys,'/','Click_here'],...
		'BackGround',7,...
		'Font Angle','italic',...
		'position',[245,680,335,730])
add_line(sys,[325,335;345,335])
add_line(sys,[435,335;455,335])
add_line(sys,[545,335;565,335])
add_line(sys,[655,335;675,335])
add_line(sys,[560,3100;580,3100;580,3090;615,3090])
add_line(sys,[230,0;230,2305;175,2305;175,3050])
add_line(sys,[230,375;900,375;920,375])
add_line(sys,[230,375;0,375;-10,375])
add_line(sys,[230,2305;885,2305;910,2305])
add_line(sys,[175,2305;0,2305;-20,2305])
add_line(sys,[230,1150;895,1150;920,1150])
add_line(sys,[230,1150;5,1150;-15,1150])
add_line(sys,[230,760;900,760;925,760])
add_line(sys,[230,760;5,760;-10,760])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
