function [ret,x0,str,ts,xts]=com_sour(t,x,u,flag);
%COM_SOUR	is the M-file description of the SIMULINK system named COM_SOUR.
%	The block-diagram can be displayed by typing: COM_SOUR.
%
%	SYS=COM_SOUR(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_SOUR to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_SOUR with a FLAG of zero:
%	[SIZES]=COM_SOUR([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[111,54,843,688])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','Source//Sink Library'])
set_param([sys,'/','Source//Sink Library'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[325,5,330,10])


%     Subsystem  ['Triggered write',13,'to file'].

new_system([sys,'/',['Triggered write',13,'to file']])
set_param([sys,'/',['Triggered write',13,'to file']],'Location',[105,608,345,754])

add_block('built-in/Inport',[sys,'/',['Triggered write',13,'to file/in_2']])
set_param([sys,'/',['Triggered write',13,'to file/in_2']],...
		'Port','2',...
		'position',[15,75,35,95])

add_block('built-in/Inport',[sys,'/',['Triggered write',13,'to file/in_1']])
set_param([sys,'/',['Triggered write',13,'to file/in_1']],...
		'position',[15,60,35,80])

add_block('built-in/Mux',[sys,'/',['Triggered write',13,'to file/Mux']])
set_param([sys,'/',['Triggered write',13,'to file/Mux']],...
		'inputs','2',...
		'position',[65,61,100,94])

add_block('built-in/S-Function',[sys,'/',['Triggered write',13,'to file/S-function']])
set_param([sys,'/',['Triggered write',13,'to file/S-function']],...
		'function name','swritfil',...
		'parameters','filename, datatype, nump, threshold',...
		'position',[135,70,185,90])
add_line([sys,'/',['Triggered write',13,'to file']],[40,85;60,85])
add_line([sys,'/',['Triggered write',13,'to file']],[40,70;60,70])
add_line([sys,'/',['Triggered write',13,'to file']],[105,80;130,80])
set_param([sys,'/',['Triggered write',13,'to file']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Wt file',...
		'Mask Type','Write to file')
set_param([sys,'/',['Triggered write',13,'to file']],...
		'Mask Dialogue','The rising edge of the signal from the\n2nd port triggers the block to write\nanother row into the specified file.|File name (string, include extension):|Data type (''ascii'', ''float'', ''integer''):|Number of trigger pulses between saved data:|Threshold in detecting trigger signal:')
set_param([sys,'/',['Triggered write',13,'to file']],...
		'Mask Translate','filename=@1;datatype=@2;nump=@3;threshold=@4;[x,y]=srcsicon(8);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered write',13,'to file']],...
		'Mask Help','This block writes the data inputted from the first port to the next row of the specified file at the rising edge of the second input trigger pulse. The first pulse triggers to write the first record. You can specify the number of pulses between writting records. When you specify ASCII format, there is no return added between two records.')
set_param([sys,'/',['Triggered write',13,'to file']],...
		'Mask Entries','''junk.dat''\/''ascii''\/0\/0.5\/')


%     Finished composite block ['Triggered write',13,'to file'].

set_param([sys,'/',['Triggered write',13,'to file']],...
		'position',[175,113,255,157])


%     Subsystem  ['QASK Mo//Dem',13,'demo4'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo4']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo4']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo4']],...
		'Mask Display','Triggered\nfile I/O\ndemo',...
		'Mask Dialogue','eval(''junk=magic(5);ttrigfil;save(''''junk.tmp'''',''''junk'''',''''-ascii'''')'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo4'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo4']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,113,395,157])


%     Subsystem  ['Eye-diagram',13,'scatter plot'].

new_system([sys,'/',['Eye-diagram',13,'scatter plot']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],'Location',[165,242,460,428])

add_block('built-in/Inport',[sys,'/',['Eye-diagram',13,'scatter plot/in_1']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Eye-diagram',13,'scatter plot/in_2']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/in_2']],...
		'Port','2',...
		'position',[20,115,40,135])

add_block('built-in/Mux',[sys,'/',['Eye-diagram',13,'scatter plot/Mux']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/Mux']],...
		'inputs','2',...
		'position',[65,70,100,105])

add_block('built-in/S-Function',[sys,'/',['Eye-diagram',13,'scatter plot/Plot1']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/Plot1']],...
		'function name','eyediasi',...
		'parameters','time_range, boundary, kept_length, eye_line, scatter_line, two_d_line',...
		'position',[130,70,200,110])
add_line([sys,'/',['Eye-diagram',13,'scatter plot']],[40,65;45,65;45,80;60,80])
add_line([sys,'/',['Eye-diagram',13,'scatter plot']],[45,125;50,125;60,95])
add_line([sys,'/',['Eye-diagram',13,'scatter plot']],[105,90;125,90])
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);',...
		'Mask Type','Eye-diagram/scatter plot')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Dialogue','Produce eye-pattern diagram/scatter\nplot/x-y plot with the rising edge of the second input as the decision line.|Eye-pattern plot time frame:|Lower and upper bound of in-coming signal (1x2 vector):|Number of saved traces:|Line-type for eye-pattern diagram (0 for no plot):|Line-type for scatter plot (0 for no plot):|Line-type for x-y plot (0 for no plot):')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Translate','time_range=@1;boundary=@2;kept_length=@3;eye_line=@4;scatter_line=@5;two_d_line=@6;[x,y]=srcsicon(10);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Help','This plot opens one, two, or three plots by assigning the line type parameters. The scatter plot point is selected by the rising edge of a trigger signal. A decision line is drawn at the rising edge of the trigger signal.')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Entries','pi\/[-1.1 1.1]\/10\/''r-/g--/b-.''\/''r+/gx/b*''\/''r-/g--/b-.''\/')


%     Finished composite block ['Eye-diagram',13,'scatter plot'].

set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'position',[175,188,255,232])


%     Subsystem  ['QASK Mo//Dem',13,'demo3'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo3']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo3']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo3']],...
		'Mask Display','Eye-pattern\ndemo',...
		'Mask Dialogue','eval(''ts=.01;Fc=100/pi/2;[num,den]=butter(2,Fc*2*ts);td=.1;M=16;tsteyesc'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo3'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo3']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,188,395,232])


%     Subsystem  ['Gaussian noise',13,'generator'].

new_system([sys,'/',['Gaussian noise',13,'generator']])
set_param([sys,'/',['Gaussian noise',13,'generator']],'Location',[371,386,719,591])

add_block('built-in/White Noise',[sys,'/',['Gaussian noise',13,'generator/Random',13,'Number']])
set_param([sys,'/',['Gaussian noise',13,'generator/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['Gaussian noise',13,'generator/Constant']])
set_param([sys,'/',['Gaussian noise',13,'generator/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['Gaussian noise',13,'generator/Sum']])
set_param([sys,'/',['Gaussian noise',13,'generator/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['Gaussian noise',13,'generator/out_1']])
set_param([sys,'/',['Gaussian noise',13,'generator/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['Gaussian noise',13,'generator/Matrix',13,'Gain']])
set_param([sys,'/',['Gaussian noise',13,'generator/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Gaussian noise',13,'generator/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Gaussian noise',13,'generator/Matrix',13,'Gain']],...
		'position',[210,81,235,109])
add_line([sys,'/',['Gaussian noise',13,'generator']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['Gaussian noise',13,'generator']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Gaussian noise',13,'generator']],[165,95;205,95])
add_line([sys,'/',['Gaussian noise',13,'generator']],[240,95;290,95])
set_param([sys,'/',['Gaussian noise',13,'generator']],...
		'Mask Display','plot(0,0,100,100,x,y);Gaussian',...
		'Mask Type','Gaussian noise generator')
set_param([sys,'/',['Gaussian noise',13,'generator']],...
		'Mask Dialogue','Generate Gaussian distributed noise with\ngiven mean and variance value.|Mean value:|Variance (vector or matrix):|Initial seed:')
set_param([sys,'/',['Gaussian noise',13,'generator']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);[x,y]=srcsicon(3);')
set_param([sys,'/',['Gaussian noise',13,'generator']],...
		'Mask Help','When the mean value and seed are vectors, the output of this block is a vector. The length of the vector is the same as the length of the mean value vector or the length of the seed. When the variance entry is a vector, the variance is a diagonal matrix.')
set_param([sys,'/',['Gaussian noise',13,'generator']],...
		'Mask Entries','[0 1]\/[1 1]\/[100 200]\/')


%     Finished composite block ['Gaussian noise',13,'generator'].

set_param([sys,'/',['Gaussian noise',13,'generator']],...
		'position',[455,113,535,157])


%     Subsystem  ['Random-integer',13,'generator'].

new_system([sys,'/',['Random-integer',13,'generator']])
set_param([sys,'/',['Random-integer',13,'generator']],'Location',[98,518,454,687])

add_block('built-in/S-Function',[sys,'/',['Random-integer',13,'generator/Uniform',13,'number']])
set_param([sys,'/',['Random-integer',13,'generator/Uniform',13,'number']],...
		'function name','srandint',...
		'parameters','seed,mul',...
		'position',[65,45,135,85])

add_block('built-in/Outport',[sys,'/',['Random-integer',13,'generator/out_1']])
set_param([sys,'/',['Random-integer',13,'generator/out_1']],...
		'position',[165,55,185,75])
add_line([sys,'/',['Random-integer',13,'generator']],[140,65;160,65])
set_param([sys,'/',['Random-integer',13,'generator']],...
		'Mask Display','plot(0,0,100,100,x,y);Random int',...
		'Mask Type','Random integer generator')
set_param([sys,'/',['Random-integer',13,'generator']],...
		'Mask Dialogue','Generate integers randomly distributed in range [0, M-1], where M is the M-ary number.|M-ary number:|Seed:',...
		'Mask Translate','seed=@2;mul=@1;[x,y]=srcsicon(4);')
set_param([sys,'/',['Random-integer',13,'generator']],...
		'Mask Help','This block generates an integer number in the range [0 M-1], where M is the M-ary number. The probability of the appearance for each number is equal.')
set_param([sys,'/',['Random-integer',13,'generator']],...
		'Mask Entries','8\/[1 2]\/')


%     Finished composite block ['Random-integer',13,'generator'].

set_param([sys,'/',['Random-integer',13,'generator']],...
		'position',[455,188,535,232])


%     Subsystem  ['QASK Mo//Dem',13,'demo8'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo8']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo8']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo8']],...
		'Mask Display','Gaussian\nrandom\ndemo',...
		'Mask Dialogue','eval(''td=.1;tgrand'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo8'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo8']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[595,113,675,157])


%     Subsystem  ['QASK Mo//Dem',13,'demo9'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo9']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo9']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo9']],...
		'Mask Display','Poisson\nrandom\ndemo',...
		'Mask Dialogue','eval(''td=.1;tprand'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo9'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo9']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[595,263,675,307])


%     Subsystem  ['QASK Mo//Dem',13,'demo10'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo10']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo10']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo10']],...
		'Mask Display','Binary\nvector\ndemo',...
		'Mask Dialogue','eval(''tbrand'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo10'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo10']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[595,338,675,382])


%     Subsystem  ['QASK Mo//Dem',13,'demo11'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo11']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo11']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo11']],...
		'Mask Display','Uniform\ninteger\ndemo',...
		'Mask Dialogue','eval(''td=.1;tirand'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo11'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo11']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[595,188,675,232])


%     Subsystem  ['QASK Mo//Dem',13,'demo12'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo12']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo12']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo12']],...
		'Mask Display','Rayleigh\nrandom\ndemo',...
		'Mask Dialogue','eval(''td=.1;tstrayl'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo12'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo12']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[595,413,675,457])


%     Subsystem  ['QASK Mo//Dem',13,'demo13'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo13']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo13']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo13']],...
		'Mask Display','Rician\nrandom\ndemo',...
		'Mask Dialogue','eval(''td=.1;tstricia'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo13'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo13']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[595,488,675,532])


%     Subsystem  ['Poisson int',13,'generator'].

new_system([sys,'/',['Poisson int',13,'generator']])
set_param([sys,'/',['Poisson int',13,'generator']],'Location',[391,74,676,237])

add_block('built-in/S-Function',[sys,'/',['Poisson int',13,'generator/Poisson distribution',13,'number']])
set_param([sys,'/',['Poisson int',13,'generator/Poisson distribution',13,'number']],...
		'function name','srandpoi',...
		'parameters','seed,lambda',...
		'position',[65,55,135,95])

add_block('built-in/Outport',[sys,'/',['Poisson int',13,'generator/out_1']])
set_param([sys,'/',['Poisson int',13,'generator/out_1']],...
		'position',[165,65,185,85])
add_line([sys,'/',['Poisson int',13,'generator']],[140,75;160,75])
set_param([sys,'/',['Poisson int',13,'generator']],...
		'Mask Display','plot(0,0,100,100,x,y);Poisson int',...
		'Mask Type','Poisson random integer generator',...
		'Mask Dialogue','Generate Poisson distributed random integers.|Lambda:|Seed:')
set_param([sys,'/',['Poisson int',13,'generator']],...
		'Mask Translate','seed=@2;lambda=@1;[x,y]=srcsicon(4);')
set_param([sys,'/',['Poisson int',13,'generator']],...
		'Mask Help','This block generates Poisson distributed integer values. The output size is the same as the seed vector size. The variance and mean value equal to Lambda. Add a limiter to the output of this block to generate binary noise.')
set_param([sys,'/',['Poisson int',13,'generator']],...
		'Mask Entries','[.1 3]\/[1 2]\/')


%     Finished composite block ['Poisson int',13,'generator'].

set_param([sys,'/',['Poisson int',13,'generator']],...
		'position',[455,263,535,307])


%     Subsystem  ['Pulses divide',13,'sample time'].

new_system([sys,'/',['Pulses divide',13,'sample time']])
set_param([sys,'/',['Pulses divide',13,'sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Pulses divide',13,'sample time/S-function1']])
set_param([sys,'/',['Pulses divide',13,'sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Pulses divide',13,'sample time/Outport']])
set_param([sys,'/',['Pulses divide',13,'sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Pulses divide',13,'sample time']],[110,45;155,45])
set_param([sys,'/',['Pulses divide',13,'sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Pulses divide',13,'sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Pulses divide',13,'sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Pulses divide',13,'sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Pulses divide',13,'sample time']],...
		'Mask Entries','1\/[1 3 5 1 3 5]\/[0 0 0 4.1 2.1 4.1]\/')


%     Finished composite block ['Pulses divide',13,'sample time'].

set_param([sys,'/',['Pulses divide',13,'sample time']],...
		'position',[35,263,115,307])


%     Subsystem  'Sources'.

new_system([sys,'/','Sources'])
set_param([sys,'/','Sources'],'Location',[15,243,212,738])

add_block('built-in/Note',[sys,'/','Sources/Signal Source Library'])
set_param([sys,'/','Sources/Signal Source Library'],...
		'position',[100,0,105,5])
set_param([sys,'/','Sources'],...
		'Mask Display','SIMULINK\nsource\nblocks',...
		'Mask Dialogue','eval(''com_clos;com_smsc;'')')


%     Finished composite block 'Sources'.

set_param([sys,'/','Sources'],...
		'position',[35,413,115,457])


%     Subsystem  ['Sampled read with',13,'synchronized pulse'].

new_system([sys,'/',['Sampled read with',13,'synchronized pulse']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],'Location',[355,527,737,674])


%     Subsystem  ['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/out_1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/out_1']],...
		'position',[295,65,315,85])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/out_2']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/out_2']],...
		'Port','2',...
		'position',[195,115,215,135])

add_block('built-in/S-Function',[sys,'/',['Sampled read with',13,'synchronized pulse/Message source']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[260,75;290,75])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[115,75;175,75])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[135,75;135,125;190,125])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Dialogue','Read from a workspace variable at sample time.|Variable (column_number=block_output_length):|Data output sample time (sec):|Repeat flag (1: repeat read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);[v,w]=trigicon(1,75,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reaches the end of the variable (eof), the block will cyclically output from the first row of the variable or output zeros based on the repeat flag entree. The second output is the synchronization pulse, which outputs a spike when the data is refreshed.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Entries','randint(100,1,16)\/1\/1\/0\/')


%     Finished composite block ['Sampled read with',13,'synchronized pulse'].

set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'position',[35,338,115,382])


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Repeat flag (1: repeat read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reaches the end of the variable (eof), the block will cyclically output from the first row of the variable or output zeros based on the repeat flag entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(100,1,16)\/1\/1\/10\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'position',[35,188,115,232])

add_block('built-in/S-Function',[sys,'/',['Triggered read',13,'from file']])
set_param([sys,'/',['Triggered read',13,'from file']],...
		'function name','sreadfil',...
		'parameters','filename,datatype,nump,numout,recursive,threshold',...
		'Mask Display','plot(0,0,100,100,x,y,v,w);  Rd file')
set_param([sys,'/',['Triggered read',13,'from file']],...
		'Mask Type','Read from file')
set_param([sys,'/',['Triggered read',13,'from file']],...
		'Mask Dialogue','The rising edge of the signal from the\n2nd port triggers the block to read the next row of the specified file.|File name (string, include extension):|Data type (''ascii'',''float'',''integer''):|Number of trigger pulse between saved data:|Output vector length:|Repeat flag (1: repeat read, 0: output zeros after eof):|Threshold in detecting trigger signal:')
set_param([sys,'/',['Triggered read',13,'from file']],...
		'Mask Translate','filename=@1;datatype=@2;nump=@3;numout=@4;recursive=@5;threshold=@6;[x,y]=srcsicon(6);[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered read',13,'from file']],...
		'Mask Help','This block reads the data from a file. The output is refreshed on the rising edge of the input pulse. When the simulation reaches the end of the file (eof), the block will cyclically output from the first record of the file or output zeros based on the repeat flag entree.')
set_param([sys,'/',['Triggered read',13,'from file']],...
		'Mask Entries','''junk.tmp''\/''ascii''\/0\/1\/0\/.3\/',...
		'position',[35,113,115,157])


%     Subsystem  ['Uniform noise',13,'generator'].

new_system([sys,'/',['Uniform noise',13,'generator']])
set_param([sys,'/',['Uniform noise',13,'generator']],'Location',[420,594,637,734])

add_block('built-in/S-Function',[sys,'/',['Uniform noise',13,'generator/Uniform',13,'noise']])
set_param([sys,'/',['Uniform noise',13,'generator/Uniform',13,'noise']],...
		'function name','surandom',...
		'parameters','seed,up,low',...
		'position',[65,55,135,95])

add_block('built-in/Outport',[sys,'/',['Uniform noise',13,'generator/out_1']])
set_param([sys,'/',['Uniform noise',13,'generator/out_1']],...
		'position',[165,65,185,85])
add_line([sys,'/',['Uniform noise',13,'generator']],[140,75;160,75])
set_param([sys,'/',['Uniform noise',13,'generator']],...
		'Mask Display','plot(0,0,100,100,x,y);Uniform',...
		'Mask Type','Uniform noise generator')
set_param([sys,'/',['Uniform noise',13,'generator']],...
		'Mask Dialogue','Generate uniformly distributed noise\nbetween the upper and lower bounds.|Noise lower bound:|Noise upper bound:|Seed:')
set_param([sys,'/',['Uniform noise',13,'generator']],...
		'Mask Translate','seed=@3;up=@2;low=@1;[x,y]=srcsicon(3);')
set_param([sys,'/',['Uniform noise',13,'generator']],...
		'Mask Help','This block generates a uniformly distributed noise between the given lower and upper bounds. The output size is the same as the vector length of the seed. The upper bound and lower bound can be scalar or vectors with their lengths the same as the length for the seed. The vector length of upper bound must be the same as length of lower bound.')
set_param([sys,'/',['Uniform noise',13,'generator']],...
		'Mask Entries','[0 1]\/[1 2]\/[12345 54321]\/')


%     Finished composite block ['Uniform noise',13,'generator'].

set_param([sys,'/',['Uniform noise',13,'generator']],...
		'position',[455,38,535,82])

add_block('built-in/S-Function',[sys,'/',['Triggered read',13,'from wksp']])
set_param([sys,'/',['Triggered read',13,'from wksp']],...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','plot(0,0,100,100,x,y,v,w);   Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Triggered read',13,'from wksp']],...
		'Mask Dialogue','The rising edge of the input pulse triggers\nthe block to output the next row from the specified workspace variable.|Workspace variable:|Threshold for the input trigger pulse:|Repeat flag (1: repeat read, 0: output zeros after eof):|Output value before first trigger:')
set_param([sys,'/',['Triggered read',13,'from wksp']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;[x,y]=srcsicon(7);[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered read',13,'from wksp']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the rising edge of the input pulse. When the simulation reaches the end of the variable (eof), the block will cyclically output from the first row of the variable or output zeros based on the repeat flag entree.')
set_param([sys,'/',['Triggered read',13,'from wksp']],...
		'Mask Entries','[10:-1:0;1:11]''\/.1\/1\/10\/',...
		'position',[35,38,115,82])


%     Subsystem  ['QASK Mo//Dem',13,'demo7'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo7']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo7']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo7']],...
		'Mask Display','Uniform\nrandom\ndemo',...
		'Mask Dialogue','eval(''td=.1;turand'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo7'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo7']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[595,38,675,82])


%     Subsystem  ['QASK Mo//Dem',13,'demo5'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo5']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo5']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo5']],...
		'Mask Display','Triggered\nwksp I/O\ndemo',...
		'Mask Dialogue','eval(''ttrigwks'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo5'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo5']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,38,395,82])


%     Subsystem  ['Triggered write',13,'to wksp'].

new_system([sys,'/',['Triggered write',13,'to wksp']])
set_param([sys,'/',['Triggered write',13,'to wksp']],'Location',[105,608,345,754])

add_block('built-in/S-Function',[sys,'/',['Triggered write',13,'to wksp/S-function']])
set_param([sys,'/',['Triggered write',13,'to wksp/S-function']],...
		'function name','swritwks',...
		'parameters','filename, datatype, nump, max_rec, cut_type, threshold',...
		'position',[135,70,185,90])

add_block('built-in/Mux',[sys,'/',['Triggered write',13,'to wksp/Mux']])
set_param([sys,'/',['Triggered write',13,'to wksp/Mux']],...
		'inputs','2',...
		'position',[65,61,100,94])

add_block('built-in/Inport',[sys,'/',['Triggered write',13,'to wksp/in_1']])
set_param([sys,'/',['Triggered write',13,'to wksp/in_1']],...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/',['Triggered write',13,'to wksp/in_2']])
set_param([sys,'/',['Triggered write',13,'to wksp/in_2']],...
		'Port','2',...
		'position',[15,75,35,95])
add_line([sys,'/',['Triggered write',13,'to wksp']],[105,80;130,80])
add_line([sys,'/',['Triggered write',13,'to wksp']],[40,70;60,70])
add_line([sys,'/',['Triggered write',13,'to wksp']],[40,85;60,85])
set_param([sys,'/',['Triggered write',13,'to wksp']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Wt wksp',...
		'Mask Type','Write to workspace')
set_param([sys,'/',['Triggered write',13,'to wksp']],...
		'Mask Dialogue','The rising edge of the signal from the\nsecond port triggers the block to write\nanother row into the specified\nworkspace variable.|Variable name (string variable, include extension):|Data type (''ascii'', ''data''):|Number of trigger pulses between saved data:|Maximum row number:|Section to keep after max row (0: begin,1: end):|Threshold in detecting trigger signal:')
set_param([sys,'/',['Triggered write',13,'to wksp']],...
		'Mask Translate','filename=@1;datatype=@2;nump=@3;max_rec=@4;cut_type=@5;threshold=@6;[x,y]=srcsicon(9);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered write',13,'to wksp']],...
		'Mask Help','This block writes the data inputted from the first port to the next row of the specified workspace variable at the rising edge of the second input trigger pulse. The first pulse triggers to write the first record. You can specify the number of pulses between writting records. When you specify ASCII format, there is no return added between two records.')
set_param([sys,'/',['Triggered write',13,'to wksp']],...
		'Mask Entries','''XX''\/''data''\/0\/100\/0\/.5\/')


%     Finished composite block ['Triggered write',13,'to wksp'].

set_param([sys,'/',['Triggered write',13,'to wksp']],...
		'position',[175,38,255,82])


%     Subsystem  ['Binary vector',13,'noise generator'].

new_system([sys,'/',['Binary vector',13,'noise generator']])
set_param([sys,'/',['Binary vector',13,'noise generator']],'Location',[36,445,326,560])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'noise generator/S-function']])
set_param([sys,'/',['Binary vector',13,'noise generator/S-function']],...
		'function name','srandbit',...
		'parameters','n, prob, seed',...
		'position',[90,35,140,55])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'noise generator/out_1']])
set_param([sys,'/',['Binary vector',13,'noise generator/out_1']],...
		'position',[190,35,210,55])
add_line([sys,'/',['Binary vector',13,'noise generator']],[145,45;185,45])
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Display','plot(0,0,100,100,x,y);B-vector',...
		'Mask Type','Binary noise generator')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Dialogue','Generate a binary vector with control over the number of  "1"s.|Binary vector length:|Probability of a "one", two "ones",three "ones"...:|Seed:')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Translate','n=@1;prob=@2;seed=@3;[x,y]=srcsicon(5);')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Help','This block outputs a zero vector with "1"s randomly distributed the vector. The maximum number of "1"s in the vector is the same as the length of the vector probability. The value of the ith element of the probability is the probability of i number of "1"s in the vector, e.g. [1/4 1/4 1/4] means probability of single "1", double "1"s, three "1"s or no "1" in the vector is 1/4.')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Entries','7\/1/2\/12345\/')


%     Finished composite block ['Binary vector',13,'noise generator'].

set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'position',[455,338,535,382])


%     Subsystem  ['QASK Mo//Dem',13,'demo2'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo2']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],...
		'Mask Display','Error-rate\nmeter\ndemo',...
		'Mask Dialogue','eval(''ts=.01;Fc=100/pi/2;[num,den]=butter(2,Fc*2*ts);td=.1;M=16;tstbterr'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo2'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,338,395,382])


%     Subsystem  'Error rate'.

new_system([sys,'/','Error rate'])
set_param([sys,'/','Error rate'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate/in_2'])
set_param([sys,'/','Error rate/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate/in_1'])
set_param([sys,'/','Error rate/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate/Mux'])
set_param([sys,'/','Error rate/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate/S-function'])
set_param([sys,'/','Error rate/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate'],[40,70;60,70])
add_line([sys,'/','Error rate'],[40,55;60,55])
add_line([sys,'/','Error rate'],[105,65;125,65])
set_param([sys,'/','Error rate'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd signal.|Bit per symbol:|Number of digits on display:|Delay between 1st port and 2nd port:|Sample time (sec):')
set_param([sys,'/','Error rate'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a delay to the first port signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate'],...
		'Mask Entries','5\/10\/0\/1\/')


%     Finished composite block 'Error rate'.

set_param([sys,'/','Error rate'],...
		'position',[175,338,255,382])


%     Subsystem  'Sink'.

new_system([sys,'/','Sink'])
set_param([sys,'/','Sink'],'Location',[15,243,212,738])
set_param([sys,'/','Sink'],...
		'Mask Display','SIMULINK\nsink\nblocks',...
		'Mask Dialogue','eval(''com_clos;com_smsk;'')')


%     Finished composite block 'Sink'.

set_param([sys,'/','Sink'],...
		'position',[175,413,255,457])


%     Subsystem  'Analysis'.

new_system([sys,'/','Analysis'])
set_param([sys,'/','Analysis'],'Location',[15,243,212,738])
set_param([sys,'/','Analysis'],...
		'Mask Display','SIMULINK\nanalysis\nblocks',...
		'Mask Dialogue','eval(''com_clos;extrdisp;'')')


%     Finished composite block 'Analysis'.

set_param([sys,'/','Analysis'],...
		'position',[175,488,255,532])


%     Subsystem  ['Sample-time',13,'eye-diagram scatter'].

new_system([sys,'/',['Sample-time',13,'eye-diagram scatter']])
set_param([sys,'/',['Sample-time',13,'eye-diagram scatter']],'Location',[165,242,460,428])

add_block('built-in/S-Function',[sys,'/',['Sample-time',13,'eye-diagram scatter/Plot1']])
set_param([sys,'/',['Sample-time',13,'eye-diagram scatter/Plot1']],...
		'function name','eyesampl',...
		'parameters','time_range, boundary, kept_length, eye_line, scatter_line, two_d_line',...
		'position',[130,70,200,110])

add_block('built-in/Inport',[sys,'/',['Sample-time',13,'eye-diagram scatter/in_1']])
set_param([sys,'/',['Sample-time',13,'eye-diagram scatter/in_1']],...
		'position',[75,80,95,100])
add_line([sys,'/',['Sample-time',13,'eye-diagram scatter']],[100,90;125,90])
set_param([sys,'/',['Sample-time',13,'eye-diagram scatter']],...
		'Mask Display','plot(0,0,100,100,x,y);',...
		'Mask Type','Eye-diagram/scatter plot')
set_param([sys,'/',['Sample-time',13,'eye-diagram scatter']],...
		'Mask Dialogue','Produce eye-pattern diagram and/or scatter plot.|[Symbol interval, plot offset, decision point offset]:|Lower and upper bound of in-coming signal (1x2 vector):|Number of saved traces:|Line-type for eye-pattern diagram (0 for no plot):|Line-type for scatter plot (0 for no plot):|Plot update sample time:')
set_param([sys,'/',['Sample-time',13,'eye-diagram scatter']],...
		'Mask Translate','time_range=@1;boundary=@2;kept_length=@3;eye_line=@4;scatter_line=@5;two_d_line=@6;[x,y]=srcsicon(10);')
set_param([sys,'/',['Sample-time',13,'eye-diagram scatter']],...
		'Mask Help','This plot opens one, or two plots by assigning the line type parameters. The scatter plot point is selected by the decision point in the first parameter entry. A decision line is drawn in the eye-pattern diagram. The plot is updated at the plot update sample time point.')
set_param([sys,'/',['Sample-time',13,'eye-diagram scatter']],...
		'Mask Entries','[.2, .05 .2]\/[-1.5 1.5]\/5\/''y-/r-''\/''y./g*''\/.01\/')


%     Finished composite block ['Sample-time',13,'eye-diagram scatter'].

set_param([sys,'/',['Sample-time',13,'eye-diagram scatter']],...
		'position',[175,263,255,307])


%     Subsystem  ['QASK Mo//Dem',13,'demo6'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo6']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo6']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo6']],...
		'Mask Display','Eye-pattern\ndemo2',...
		'Mask Dialogue','eval(''ts=.01;Fc=100/pi/2;[num,den]=butter(2,Fc*2*ts);td=.1;M=16;tsteyes2'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo6'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo6']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,263,395,307])


%     Subsystem  ['Rayleigh noise',13,'generator'].

new_system([sys,'/',['Rayleigh noise',13,'generator']])
set_param([sys,'/',['Rayleigh noise',13,'generator']],'Location',[137,530,696,645])


%     Subsystem  ['Rayleigh noise',13,'generator/Gaussian',13,'noise'].

new_system([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']])
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']],'Location',[582,754,930,959])

add_block('built-in/State-Space',[sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Variance:|Initial Seed(s):')
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Entries','0\/alpha\/seed\/')


%     Finished composite block ['Rayleigh noise',13,'generator/Gaussian',13,'noise'].

set_param([sys,'/',['Rayleigh noise',13,'generator/Gaussian',13,'noise']],...
		'position',[45,40,120,80])

add_block('built-in/Product',[sys,'/',['Rayleigh noise',13,'generator/Product']])
set_param([sys,'/',['Rayleigh noise',13,'generator/Product']],...
		'position',[160,48,190,72])

add_block('built-in/Demux',[sys,'/',['Rayleigh noise',13,'generator/Demux']])
set_param([sys,'/',['Rayleigh noise',13,'generator/Demux']],...
		'outputs','2',...
		'position',[235,41,275,74])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise',13,'generator/Sum']])
set_param([sys,'/',['Rayleigh noise',13,'generator/Sum']],...
		'position',[315,44,340,71])

add_block('built-in/S-Function',[sys,'/',['Rayleigh noise',13,'generator/Array',13,'function']])
set_param([sys,'/',['Rayleigh noise',13,'generator/Array',13,'function']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['Rayleigh noise',13,'generator/Array',13,'function']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10,sgn.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['Rayleigh noise',13,'generator/Array',13,'function']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sqrt''\/',...
		'position',[370,38,445,82])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise',13,'generator/out_1']])
set_param([sys,'/',['Rayleigh noise',13,'generator/out_1']],...
		'position',[490,50,510,70])
add_line([sys,'/',['Rayleigh noise',13,'generator']],[450,60;485,60])
add_line([sys,'/',['Rayleigh noise',13,'generator']],[345,60;365,60])
add_line([sys,'/',['Rayleigh noise',13,'generator']],[125,60;135,60;135,55;155,55])
add_line([sys,'/',['Rayleigh noise',13,'generator']],[135,60;135,65;155,65])
add_line([sys,'/',['Rayleigh noise',13,'generator']],[195,60;230,60])
add_line([sys,'/',['Rayleigh noise',13,'generator']],[280,50;310,50])
add_line([sys,'/',['Rayleigh noise',13,'generator']],[280,65;310,65])
set_param([sys,'/',['Rayleigh noise',13,'generator']],...
		'Mask Display','plot(0,0,100,100,x,y);Rayleigh',...
		'Mask Type','Rayleigh noise generator')
set_param([sys,'/',['Rayleigh noise',13,'generator']],...
		'Mask Dialogue','Generate Rayleigh distributed noise.The output vector size of this block is the same as the vector size of the seed.|sigma:|Initial seed:')
set_param([sys,'/',['Rayleigh noise',13,'generator']],...
		'Mask Translate','alpha=@1;alpha=alpha^2;seed=@2;seed=[seed(:);seed(:)+max(seed)];if length(alpha)>1, alpha=[alpha(:);alpha(:)];end;[x,y]=srcsicon(3);')
set_param([sys,'/',['Rayleigh noise',13,'generator']],...
		'Mask Help','This block generates Rayleigh noise with the given sigma value. The sigma value is the standard deviations of the zero mean Gaussian noise components in generating the Rayleigh noise. The output vector size of this block is the same as the vector size of the seed.')
set_param([sys,'/',['Rayleigh noise',13,'generator']],...
		'Mask Entries','1\/17658\/')


%     Finished composite block ['Rayleigh noise',13,'generator'].

set_param([sys,'/',['Rayleigh noise',13,'generator']],...
		'position',[455,413,535,457])


%     Subsystem  ['Rician noise',13,'generator'].

new_system([sys,'/',['Rician noise',13,'generator']])
set_param([sys,'/',['Rician noise',13,'generator']],'Location',[445,114,914,317])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator/out_1']])
set_param([sys,'/',['Rician noise',13,'generator/out_1']],...
		'position',[410,55,430,75])

add_block('built-in/S-Function',[sys,'/',['Rician noise',13,'generator/Array',13,'function']])
set_param([sys,'/',['Rician noise',13,'generator/Array',13,'function']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['Rician noise',13,'generator/Array',13,'function']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10,sgn.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['Rician noise',13,'generator/Array',13,'function']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sqrt''\/',...
		'position',[295,43,370,87])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator/Sum']])
set_param([sys,'/',['Rician noise',13,'generator/Sum']],...
		'position',[245,55,265,75])


%     Subsystem  ['Rician noise',13,'generator/Gaussian',13,'noise1'].

new_system([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],'Location',[582,754,930,959])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/',...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/out_1']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Sum']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Constant']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],[240,95;290,95])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],...
		'Mask Entries','0\/s\/seed+max(seed)\/')


%     Finished composite block ['Rician noise',13,'generator/Gaussian',13,'noise1'].

set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],...
		'position',[45,110,120,150])

add_block('built-in/Product',[sys,'/',['Rician noise',13,'generator/Product1']])
set_param([sys,'/',['Rician noise',13,'generator/Product1']],...
		'position',[165,118,195,142])

add_block('built-in/Product',[sys,'/',['Rician noise',13,'generator/Product']])
set_param([sys,'/',['Rician noise',13,'generator/Product']],...
		'position',[160,48,190,72])


%     Subsystem  ['Rician noise',13,'generator/Gaussian',13,'noise'].

new_system([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],'Location',[582,754,930,959])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/',...
		'position',[210,81,235,109])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],[240,95;290,95])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Entries','m\/s\/seed\/')


%     Finished composite block ['Rician noise',13,'generator/Gaussian',13,'noise'].

set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],...
		'position',[45,40,120,80])
add_line([sys,'/',['Rician noise',13,'generator']],[375,65;405,65])
add_line([sys,'/',['Rician noise',13,'generator']],[270,65;290,65])
add_line([sys,'/',['Rician noise',13,'generator']],[200,130;210,130;210,70;240,70])
add_line([sys,'/',['Rician noise',13,'generator']],[125,130;135,130;135,125;160,125])
add_line([sys,'/',['Rician noise',13,'generator']],[135,130;135,135;160,135])
add_line([sys,'/',['Rician noise',13,'generator']],[195,60;240,60])
add_line([sys,'/',['Rician noise',13,'generator']],[125,60;135,60;135,55;155,55])
add_line([sys,'/',['Rician noise',13,'generator']],[135,60;135,65;155,65])
set_param([sys,'/',['Rician noise',13,'generator']],...
		'Mask Display','plot(0,0,100,100,x,y);Rician (K)',...
		'Mask Type','Rician noise generator')
set_param([sys,'/',['Rician noise',13,'generator']],...
		'Mask Dialogue','Generate Rician distributed noise.\nThe output vector size of this block is the same as the vector size of the seed.|Rician K-factor:|sigma:|Seed:')
set_param([sys,'/',['Rician noise',13,'generator']],...
		'Mask Translate','K=@1;s=@2;seed=@3;m=sqrt(2*K(:)).*s;[x,y]=srcsicon(3);')
set_param([sys,'/',['Rician noise',13,'generator']],...
		'Mask Help','The Rician noise is composed with two independant Gaussian noises. These two Gaussain noises have a same std, sigma. Their mean values are m1 and m2 respectively. The Rician K-factor=(m1^2+m2^2)/2/sigma^2. The output vector size of this block is the same as the vector size of the seed.')
set_param([sys,'/',['Rician noise',13,'generator']],...
		'Mask Entries','2\/1\/66423\/')


%     Finished composite block ['Rician noise',13,'generator'].

set_param([sys,'/',['Rician noise',13,'generator']],...
		'position',[455,488,535,532])


%     Subsystem  ['Rician noise',13,'generator2'].

new_system([sys,'/',['Rician noise',13,'generator2']])
set_param([sys,'/',['Rician noise',13,'generator2']],'Location',[535,122,1004,325])


%     Subsystem  ['Rician noise',13,'generator2/Gaussian',13,'noise'].

new_system([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],'Location',[582,754,930,959])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/',...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],...
		'Mask Entries','m1\/s\/seed\/')


%     Finished composite block ['Rician noise',13,'generator2/Gaussian',13,'noise'].

set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],...
		'position',[45,40,120,80])

add_block('built-in/Product',[sys,'/',['Rician noise',13,'generator2/Product']])
set_param([sys,'/',['Rician noise',13,'generator2/Product']],...
		'position',[160,48,190,72])

add_block('built-in/Product',[sys,'/',['Rician noise',13,'generator2/Product1']])
set_param([sys,'/',['Rician noise',13,'generator2/Product1']],...
		'position',[165,118,195,142])


%     Subsystem  ['Rician noise',13,'generator2/Gaussian',13,'noise1'].

new_system([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],'Location',[582,754,930,959])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Constant']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Sum']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/out_1']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'position',[210,81,235,109])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],[240,95;290,95])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],...
		'Mask Entries','m2\/s\/seed+max(seed)\/')


%     Finished composite block ['Rician noise',13,'generator2/Gaussian',13,'noise1'].

set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],...
		'position',[45,110,120,150])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator2/Sum']])
set_param([sys,'/',['Rician noise',13,'generator2/Sum']],...
		'position',[245,55,265,75])

add_block('built-in/S-Function',[sys,'/',['Rician noise',13,'generator2/Array',13,'function']])
set_param([sys,'/',['Rician noise',13,'generator2/Array',13,'function']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['Rician noise',13,'generator2/Array',13,'function']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10,sgn.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['Rician noise',13,'generator2/Array',13,'function']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sqrt''\/',...
		'position',[295,43,370,87])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator2/out_1']])
set_param([sys,'/',['Rician noise',13,'generator2/out_1']],...
		'position',[410,55,430,75])
add_line([sys,'/',['Rician noise',13,'generator2']],[125,60;135,60;135,55;155,55])
add_line([sys,'/',['Rician noise',13,'generator2']],[135,60;135,65;155,65])
add_line([sys,'/',['Rician noise',13,'generator2']],[195,60;240,60])
add_line([sys,'/',['Rician noise',13,'generator2']],[125,130;135,130;135,125;160,125])
add_line([sys,'/',['Rician noise',13,'generator2']],[135,130;135,135;160,135])
add_line([sys,'/',['Rician noise',13,'generator2']],[200,130;210,130;210,70;240,70])
add_line([sys,'/',['Rician noise',13,'generator2']],[270,65;290,65])
add_line([sys,'/',['Rician noise',13,'generator2']],[375,65;405,65])
set_param([sys,'/',['Rician noise',13,'generator2']],...
		'Mask Display','plot(0,0,100,100,x,y);Rician (m)',...
		'Mask Type','Rician noise generator')
set_param([sys,'/',['Rician noise',13,'generator2']],...
		'Mask Dialogue','Generate Rician distributed noise.\nThe output vector size of this block is the same as the vector size of the seed.|In-phase component m:|Quadrature component m:|sigma:|Seed:')
set_param([sys,'/',['Rician noise',13,'generator2']],...
		'Mask Translate','m1=@1;m2=@2;s=@3;seed=@4;[x,y]=srcsicon(3);')
set_param([sys,'/',['Rician noise',13,'generator2']],...
		'Mask Help','The Rician noise is composed with two independant Gaussian noises. These two Gaussain noises have a same std, sigma. Their mean values are m1 and m2 respectively.  The output vector size of this block is the same as the vector size of the seed.')
set_param([sys,'/',['Rician noise',13,'generator2']],...
		'Mask Entries','sqrt(2)\/sqrt(2)\/1\/654731\/')


%     Finished composite block ['Rician noise',13,'generator2'].

set_param([sys,'/',['Rician noise',13,'generator2']],...
		'position',[455,563,535,607])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
