function [ret,x0,str,ts,xts]=com_sync(t,x,u,flag);
%COM_SYNC	is the M-file description of the SIMULINK system named COM_SYNC.
%	The block-diagram can be displayed by typing: COM_SYNC.
%
%	SYS=COM_SYNC(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_SYNC to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_SYNC with a FLAG of zero:
%	[SIZES]=COM_SYNC([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[183,146,575,374])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Phase-Locked',13,'Loop demo'].

new_system([sys,'/',['Phase-Locked',13,'Loop demo']])
set_param([sys,'/',['Phase-Locked',13,'Loop demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Phase-Locked',13,'Loop demo']],...
		'Mask Display','PLL\ndemo',...
		'Mask Dialogue','eval(''tstpll'')')


%     Finished composite block ['Phase-Locked',13,'Loop demo'].

set_param([sys,'/',['Phase-Locked',13,'Loop demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[280,48,360,92])


%     Subsystem  ['Baseband model',13,'for PLL'].

new_system([sys,'/',['Baseband model',13,'for PLL']])
set_param([sys,'/',['Baseband model',13,'for PLL']],'Location',[372,67,987,246])

add_block('built-in/Gain',[sys,'/',['Baseband model',13,'for PLL/Gain1']])
set_param([sys,'/',['Baseband model',13,'for PLL/Gain1']],...
		'Gain','pi2',...
		'position',[145,13,175,47])

add_block('built-in/Gain',[sys,'/',['Baseband model',13,'for PLL/Gain']])
set_param([sys,'/',['Baseband model',13,'for PLL/Gain']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[260,88,290,122])

add_block('built-in/Transfer Fcn',[sys,'/',['Baseband model',13,'for PLL/Filter']])
set_param([sys,'/',['Baseband model',13,'for PLL/Filter']],...
		'Numerator','Fn',...
		'Denominator','Fd',...
		'position',[420,16,470,54])

add_block('built-in/Inport',[sys,'/',['Baseband model',13,'for PLL/in_1']])
set_param([sys,'/',['Baseband model',13,'for PLL/in_1']],...
		'position',[15,20,35,40])


%     Subsystem  ['Baseband model',13,'for PLL/Module',13,'integrator1'].

new_system([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/in_1']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/in_1']],...
		'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/Memory']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/module']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/Reset',13,'integrator']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/one']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/Sum']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/out_1']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1/out_1']],...
		'position',[370,30,390,50])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],[205,90;180,90;190,45])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],[155,35;190,35])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],[220,40;230,40])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],[330,40;365,40])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],[60,25;105,25])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],[80,50;80,35;105,35])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],[340,40;340,90;265,90])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator',...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['Baseband model',13,'for PLL/Module',13,'integrator1'].

set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator1']],...
		'orientation',2,...
		'position',[330,85,380,125])

add_block('built-in/Outport',[sys,'/',['Baseband model',13,'for PLL/Estimated',13,'phase']])
set_param([sys,'/',['Baseband model',13,'for PLL/Estimated',13,'phase']],...
		'position',[580,25,600,45])

add_block('built-in/Gain',[sys,'/',['Baseband model',13,'for PLL/Gain3']])
set_param([sys,'/',['Baseband model',13,'for PLL/Gain3']],...
		'Gain','G',...
		'position',[520,22,545,48])


%     Subsystem  ['Baseband model',13,'for PLL/Module',13,'integrator'].

new_system([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],'Location',[196,490,621,627])

add_block('built-in/Outport',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/out_1']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/out_1']],...
		'position',[370,30,390,50])

add_block('built-in/Sum',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/Sum']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Constant',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/one']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Reset Integrator',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/Reset',13,'integrator']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Fcn',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/module']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Memory',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/Memory']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Inport',[sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/in_1']])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator/in_1']],...
		'position',[35,15,55,35])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],[330,40;365,40])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],[340,40;340,90;265,90])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],[60,25;105,25])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],[155,35;190,35])
add_line([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],[205,90;180,90;190,45])
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator',...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['Baseband model',13,'for PLL/Module',13,'integrator'].

set_param([sys,'/',['Baseband model',13,'for PLL/Module',13,'integrator']],...
		'position',[65,12,115,48])

add_block('built-in/Sum',[sys,'/',['Baseband model',13,'for PLL/Sum']])
set_param([sys,'/',['Baseband model',13,'for PLL/Sum']],...
		'inputs','+-',...
		'position',[220,25,240,45])

add_block('built-in/Gain',[sys,'/',['Baseband model',13,'for PLL/Gain2']])
set_param([sys,'/',['Baseband model',13,'for PLL/Gain2']],...
		'Gain','Kc',...
		'position',[340,20,385,50])

add_block('built-in/Fcn',[sys,'/',['Baseband model',13,'for PLL/Fcn']])
set_param([sys,'/',['Baseband model',13,'for PLL/Fcn']],...
		'position',[270,25,310,45])
add_line([sys,'/',['Baseband model',13,'for PLL']],[315,35;335,35])
add_line([sys,'/',['Baseband model',13,'for PLL']],[245,35;265,35])
add_line([sys,'/',['Baseband model',13,'for PLL']],[475,35;505,35;505,105;385,105])
add_line([sys,'/',['Baseband model',13,'for PLL']],[505,35;515,35])
add_line([sys,'/',['Baseband model',13,'for PLL']],[325,105;295,105])
add_line([sys,'/',['Baseband model',13,'for PLL']],[120,30;140,30])
add_line([sys,'/',['Baseband model',13,'for PLL']],[550,35;575,35])
add_line([sys,'/',['Baseband model',13,'for PLL']],[390,35;415,35])
add_line([sys,'/',['Baseband model',13,'for PLL']],[180,30;215,30])
add_line([sys,'/',['Baseband model',13,'for PLL']],[255,105;200,105;200,40;215,40])
add_line([sys,'/',['Baseband model',13,'for PLL']],[40,30;60,30])
set_param([sys,'/',['Baseband model',13,'for PLL']],...
		'Mask Display','Baseband\nPLL',...
		'Mask Type','Baseband PLL model')
set_param([sys,'/',['Baseband model',13,'for PLL']],...
		'Mask Dialogue','Output the phase shifting of the input\nsignal from the oscillation frequency.|Lowpass filter numerator:|Lowpass filter denominator:|Oscillation frequency (Hz):|Oscillation amplitude:|Gain at the output:')
set_param([sys,'/',['Baseband model',13,'for PLL']],...
		'Mask Translate','Fn=@1;Fd=@2;Fc=@3;pi2=2*pi;Kc=@4/2;G=@5;')
set_param([sys,'/',['Baseband model',13,'for PLL']],...
		'Mask Help','this block is used to detect the phase shifting of the input signal. The input to this block is an oscillation signal with possible phase shifting. The block detects the phase shifting value using the PLL technique. Design the lowpass filter to pass the phase changing signal and to eliminate the oscillation signal.')
set_param([sys,'/',['Baseband model',13,'for PLL']],...
		'Mask Entries','[3.0002,  0, 40002]\/[1, 67.46, 2270.9, 40002]\/100/2/pi\/1\/2\/')


%     Finished composite block ['Baseband model',13,'for PLL'].

set_param([sys,'/',['Baseband model',13,'for PLL']],...
		'position',[155,48,235,92])


%     Subsystem  ['Phase-locked',13,'loop'].

new_system([sys,'/',['Phase-locked',13,'loop']])
set_param([sys,'/',['Phase-locked',13,'loop']],'Location',[318,187,773,431])

add_block('built-in/Outport',[sys,'/',['Phase-locked',13,'loop/out_1']])
set_param([sys,'/',['Phase-locked',13,'loop/out_1']],...
		'position',[405,70,425,90])

add_block('built-in/Gain',[sys,'/',['Phase-locked',13,'loop/Gain']])
set_param([sys,'/',['Phase-locked',13,'loop/Gain']],...
		'Gain','G',...
		'position',[350,67,375,93])


%     Subsystem  ['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator'].

new_system([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],'Location',[422,82,872,213])

add_block('built-in/Constant',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Carrier',13,'frequency']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Carrier',13,'frequency']],...
		'Value','Fc',...
		'position',[90,75,110,95])

add_block('built-in/Fcn',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/sin']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/sin']],...
		'Expr','Ac*sin(u[1]*pi2+Ph)',...
		'position',[270,25,395,55])


%     Subsystem  ['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator'].

new_system([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],'Location',[529,321,954,458])

add_block('built-in/Inport',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/in_1']],...
		'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/module']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/one']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator/out_1']],...
		'position',[370,30,390,50])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator'].

set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
		'position',[195,24,250,56])

add_block('built-in/Sum',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Sum']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Sum']],...
		'position',[150,30,170,50])

add_block('built-in/Inport',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/in_1']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/in_1']],...
		'position',[20,25,40,45])

add_block('built-in/Gain',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Sensitivity']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/Sensitivity']],...
		'Gain','Kc',...
		'position',[65,21,105,49])

add_block('built-in/Outport',[sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/out_1']])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator/out_1']],...
		'position',[410,30,430,50])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],[400,40;405,40])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],[175,40;190,40])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],[115,85;125,85;125,45;145,45])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],[110,35;145,35])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],[45,35;60,35])
add_line([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],[255,40;265,40])
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],...
		'Mask Display','VCO',...
		'Mask Type','VCO')
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],...
		'Mask Dialogue','Voltage-Controlled Oscilator:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):')
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],...
		'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;')
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],...
		'Mask Help','The VCO block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],...
		'Mask Entries','Ac\/Fc\/1\/Ph\/')


%     Finished composite block ['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator'].

set_param([sys,'/',['Phase-locked',13,'loop/Voltage-controlled',13,'oscilator']],...
		'orientation',2,...
		'position',[175,137,230,173])

add_block('built-in/Transfer Fcn',[sys,'/',['Phase-locked',13,'loop/Lowpass',13,'filter']])
set_param([sys,'/',['Phase-locked',13,'loop/Lowpass',13,'filter']],...
		'Numerator','Fn',...
		'Denominator','Fd',...
		'position',[225,59,275,101])

add_block('built-in/Product',[sys,'/',['Phase-locked',13,'loop/Multiplier',13,'phase detector']])
set_param([sys,'/',['Phase-locked',13,'loop/Multiplier',13,'phase detector']],...
		'position',[140,70,165,90])

add_block('built-in/Inport',[sys,'/',['Phase-locked',13,'loop/in_1']])
set_param([sys,'/',['Phase-locked',13,'loop/in_1']],...
		'position',[45,65,65,85])

add_block('built-in/Outport',[sys,'/',['Phase-locked',13,'loop/out_2']])
set_param([sys,'/',['Phase-locked',13,'loop/out_2']],...
		'Port','2',...
		'position',[305,25,325,45])

add_block('built-in/Outport',[sys,'/',['Phase-locked',13,'loop/out_3']])
set_param([sys,'/',['Phase-locked',13,'loop/out_3']],...
		'Port','3',...
		'position',[315,195,335,215])
add_line([sys,'/',['Phase-locked',13,'loop']],[380,80;400,80])
add_line([sys,'/',['Phase-locked',13,'loop']],[280,80;320,80;320,155;235,155])
add_line([sys,'/',['Phase-locked',13,'loop']],[320,80;345,80])
add_line([sys,'/',['Phase-locked',13,'loop']],[170,155;95,155;95,85;135,85])
add_line([sys,'/',['Phase-locked',13,'loop']],[170,80;220,80])
add_line([sys,'/',['Phase-locked',13,'loop']],[70,75;135,75])
add_line([sys,'/',['Phase-locked',13,'loop']],[190,80;190,35;300,35])
add_line([sys,'/',['Phase-locked',13,'loop']],[95,155;95,205;310,205])
set_param([sys,'/',['Phase-locked',13,'loop']],...
		'Mask Display','PLL',...
		'Mask Type','Simple form PLL')
set_param([sys,'/',['Phase-locked',13,'loop']],...
		'Mask Dialogue','Output the phase shifting signal at 1st\nport; the detected phase error at 2nd\nport; VOC output at 3rd port.|Lowpass filter numerator:|Lowpass filter denominator:|Oscillation frequency:|Oscillation Phase:|Oscillation Amplitude:|Gain at the output:')
set_param([sys,'/',['Phase-locked',13,'loop']],...
		'Mask Translate','Fn=@1;Fd=@2;Fc=@3;Ph=@4;Ac=@5;G=@6;')
set_param([sys,'/',['Phase-locked',13,'loop']],...
		'Mask Help','This block detects the phase shifting of the input signal. This block uses a multiplier phase detector. The first output is the detected phase shift. The second output is the detected phase error output from phase detector. The third output is the matching signal for the input. Note a 180 degree phase difference between the input signal and the matching signal.')
set_param([sys,'/',['Phase-locked',13,'loop']],...
		'Mask Entries','[3.0002,  0, 40002]\/[1, 67.46, 2270.9, 40002]\/100/2/pi\/pi/2\/1\/2\/')


%     Finished composite block ['Phase-locked',13,'loop'].

set_param([sys,'/',['Phase-locked',13,'loop']],...
		'position',[30,48,110,92])


%     Subsystem  ['Charge pump',13,'PLL'].

new_system([sys,'/',['Charge pump',13,'PLL']])
set_param([sys,'/',['Charge pump',13,'PLL']],'Location',[156,174,638,416])

add_block('built-in/Gain',[sys,'/',['Charge pump',13,'PLL/Gain']])
set_param([sys,'/',['Charge pump',13,'PLL/Gain']],...
		'Gain','G',...
		'position',[355,67,380,93])

add_block('built-in/Outport',[sys,'/',['Charge pump',13,'PLL/out_1']])
set_param([sys,'/',['Charge pump',13,'PLL/out_1']],...
		'position',[415,70,435,90])

add_block('built-in/Inport',[sys,'/',['Charge pump',13,'PLL/in_1']])
set_param([sys,'/',['Charge pump',13,'PLL/in_1']],...
		'position',[40,60,60,80])


%     Subsystem  ['Charge pump',13,'PLL/Phase//freq',13,'detector'].

new_system([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],'Location',[14,335,990,748])

add_block('built-in/Note',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/true table:logic=[0 0;0 1;1 0;1 0;0 1;0 1;0 0;0 0;1 0;0 0;1 0;0 0;1 0;0 0;0 0;0 0]']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/true table:logic=[0 0;0 1;1 0;1 0;0 1;0 1;0 0;0 0;1 0;0 0;1 0;0 0;1 0;0 0;0 0;0 0]']],...
		'position',[495,350,500,355])

add_block('built-in/Note',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/There are three different output combinations: HL, LL, LH, where H is one and L is zero.']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/There are three different output combinations: HL, LL, LH, where H is one and L is zero.']],...
		'position',[520,290,525,295])

add_block('built-in/Note',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/The state of the output is changed when one of the input changes from positive to negative.']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/The state of the output is changed when one of the input changes from positive to negative.']],...
		'position',[530,305,535,310])

add_block('built-in/Note',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/The left hand side block diagram is to detect the signal crossing from positive to negative.',13,'The right hand side of the block diagram is to switch from one state to another.               ']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/The left hand side block diagram is to detect the signal crossing from positive to negative.',13,'The right hand side of the block diagram is to switch from one state to another.               ']],...
		'position',[525,320,530,325])

add_block('built-in/Note',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Functionality of phase flip-flop:']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Functionality of phase flip-flop:']],...
		'position',[355,270,360,275])

add_block('built-in/Note',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/charge pump']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/charge pump']],...
		'position',[900,105,905,110])

add_block('built-in/Note',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Compensater for the phase pi']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Compensater for the phase pi']],...
		'position',[325,20,330,25])

add_block('built-in/Relational Operator',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Relational',13,'Operator3']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Relational',13,'Operator3']],...
		'Operator','<',...
		'position',[240,48,270,72])

add_block('built-in/Sum',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Sum']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Sum']],...
		'inputs','-+',...
		'position',[345,55,365,75])

add_block('built-in/Demux',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Demux']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Demux']],...
		'outputs','2',...
		'position',[410,45,450,80])

add_block('built-in/Gain',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Gain']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Gain']],...
		'Gain','-1',...
		'position',[475,60,495,80])

add_block('built-in/Relational Operator',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Relational',13,'Operator2']],...
		'Operator','<=',...
		'position',[240,183,270,207])

add_block('built-in/Memory',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Delay',13,'one step']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Delay',13,'one step']],...
		'position',[160,175,200,205])

add_block('built-in/Mux',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Mux']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Mux']],...
		'inputs','2',...
		'position',[105,105,135,145])

add_block('built-in/Inport',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/in_2']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/in_2']],...
		'Port','2',...
		'position',[65,125,85,145])

add_block('built-in/Inport',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/in_1']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/in_1']],...
		'position',[30,105,50,125])

add_block('built-in/Relational Operator',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Relational',13,'Operator']],...
		'Operator','>',...
		'position',[315,123,345,147])

add_block('built-in/Relational Operator',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Relational',13,'Operator1']],...
		'Operator','<=',...
		'position',[240,118,270,142])

add_block('built-in/Memory',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Memory1']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Memory1']],...
		'orientation',2,...
		'position',[645,190,685,220])

add_block('built-in/Mux',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Mux3']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Mux3']],...
		'inputs','[2 1]',...
		'position',[565,135,595,175])

add_block('built-in/Fcn',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Fcn']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Fcn']],...
		'Expr','(u[1]>0)+u[3]*((u[1]<=0)&&(u[2]<=0))',...
		'position',[610,140,825,170])

add_block('built-in/Switch',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Switch']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Switch']],...
		'Threshold','eps',...
		'position',[860,139,885,171])

add_block('built-in/Gain',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Gain1']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Gain1']],...
		'Gain','Cu',...
		'position',[900,145,920,165])

add_block('built-in/Outport',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/out_1']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/out_1']],...
		'position',[940,145,960,165])

add_block('built-in/Memory',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Memory']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Memory']],...
		'orientation',2,...
		'position',[425,205,465,235])

add_block('built-in/Mux',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Mux2']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Mux2']],...
		'inputs','[2 2]',...
		'position',[390,125,420,165])

add_block('built-in/Combinatorial Logic',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/phase',13,' flip-flop']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/phase',13,' flip-flop']],...
		'Truth Table','lo',...
		'position',[440,125,495,165])

add_block('built-in/Constant',[sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Constant1']])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector/Constant1']],...
		'Value','[Thre; Thre]',...
		'position',[130,272,205,298])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[140,125;145,125;145,55;235,55])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[140,125;145,125;155,190])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[890,155;895,155])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[455,55;845,55;855,145])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[500,70;835,70;835,165;855,165])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[455,70;470,70])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[370,65;405,65])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[500,145;530,145;530,220;470,220])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[530,145;560,145])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[530,145;530,110;330,110;340,70])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[275,60;340,60])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[830,155;855,155])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[830,155;830,205;690,205])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[600,155;605,155])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[640,205;550,205;560,165])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[210,285;210,65;235,65])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[210,200;235,200])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[210,135;235,135])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[140,125;235,125])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[420,220;365,220;365,155;385,155])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[925,155;935,155])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[275,195;290,195;290,140;310,140])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[275,130;310,130])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[205,190;235,190])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[425,145;435,145])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[350,135;385,135])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[90,135;100,135])
add_line([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],[55,115;100,115])
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],...
		'Mask Display','Phase\nfrequency\ndetector',...
		'Mask Type','Phase Detector',...
		'Mask Dialogue','Phase detector:|Cross zero line threshold:|Charge pump current:')
set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],...
		'Mask Translate','Thre=@1;Cu=@2;lo=[0 0;0 1;1 0;1 0;0 1;0 1;0 0;0 0;1 0;0 0;1 0;0 0;1 0;0 0;0 0;0 0];',...
		'Mask Entries','-sqrt(eps)\/Cu\/')


%     Finished composite block ['Charge pump',13,'PLL/Phase//freq',13,'detector'].

set_param([sys,'/',['Charge pump',13,'PLL/Phase//freq',13,'detector']],...
		'position',[135,59,195,101])


%     Subsystem  ['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator'].

new_system([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],'Location',[422,82,872,213])

add_block('built-in/Constant',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Carrier',13,'frequency']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Carrier',13,'frequency']],...
		'Value','Fc',...
		'position',[90,75,110,95])

add_block('built-in/Fcn',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/sin']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/sin']],...
		'Expr','Ac*sin(u[1]*pi2+Ph)',...
		'position',[270,25,395,55])


%     Subsystem  ['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator'].

new_system([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],'Location',[529,321,954,458])

add_block('built-in/Inport',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/in_1']],...
		'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/module']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/one']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator/out_1']],...
		'position',[370,30,390,50])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator'].

set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
		'position',[195,24,250,56])

add_block('built-in/Sum',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Sum']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Sum']],...
		'position',[150,30,170,50])

add_block('built-in/Inport',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/in_1']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/in_1']],...
		'position',[20,25,40,45])

add_block('built-in/Gain',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Sensitivity']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/Sensitivity']],...
		'Gain','Kc',...
		'position',[65,21,105,49])

add_block('built-in/Outport',[sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/out_1']])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator/out_1']],...
		'position',[410,30,430,50])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],[400,40;405,40])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],[175,40;190,40])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],[115,85;125,85;125,45;145,45])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],[110,35;145,35])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],[45,35;60,35])
add_line([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],[255,40;265,40])
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],...
		'Mask Display','VCO',...
		'Mask Type','VCO')
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],...
		'Mask Dialogue','Voltage-Controlled Oscilator:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):')
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],...
		'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;')
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],...
		'Mask Help','The VCO block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],...
		'Mask Entries','Ac\/Fc\/1\/Ph\/')


%     Finished composite block ['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator'].

set_param([sys,'/',['Charge pump',13,'PLL/Voltage-controlled',13,'oscilator']],...
		'orientation',2,...
		'position',[165,137,220,173])

add_block('built-in/Transfer Fcn',[sys,'/',['Charge pump',13,'PLL/Transfer Fcn']])
set_param([sys,'/',['Charge pump',13,'PLL/Transfer Fcn']],...
		'Numerator','Fn',...
		'Denominator','Fd',...
		'position',[240,59,290,101])

add_block('built-in/Outport',[sys,'/',['Charge pump',13,'PLL/out_3']])
set_param([sys,'/',['Charge pump',13,'PLL/out_3']],...
		'Port','3',...
		'position',[370,205,390,225])

add_block('built-in/Outport',[sys,'/',['Charge pump',13,'PLL/out_2']])
set_param([sys,'/',['Charge pump',13,'PLL/out_2']],...
		'Port','2',...
		'position',[320,25,340,45])
add_line([sys,'/',['Charge pump',13,'PLL']],[295,80;350,80])
add_line([sys,'/',['Charge pump',13,'PLL']],[310,80;310,155;225,155])
add_line([sys,'/',['Charge pump',13,'PLL']],[200,80;235,80])
add_line([sys,'/',['Charge pump',13,'PLL']],[385,80;410,80])
add_line([sys,'/',['Charge pump',13,'PLL']],[160,155;110,155;110,90;130,90])
add_line([sys,'/',['Charge pump',13,'PLL']],[65,70;130,70])
add_line([sys,'/',['Charge pump',13,'PLL']],[110,155;110,215;365,215])
add_line([sys,'/',['Charge pump',13,'PLL']],[210,80;210,35;315,35])
set_param([sys,'/',['Charge pump',13,'PLL']],...
		'Mask Display','Charge\npump\nPLL',...
		'Mask Type','Charge pump PLL')
set_param([sys,'/',['Charge pump',13,'PLL']],...
		'Mask Dialogue','Output the phase shifting signal at 1st\nport; the detected phase error at 2nd\nport; VOC output at 3rd port.|Lowpass filter numerator:|Lowpass filter Denominator:|Oscillation frequency (Hz):|Oscillation Phase (rad):|Oscillation Amplitude:|Gain at the output:')
set_param([sys,'/',['Charge pump',13,'PLL']],...
		'Mask Translate','Fn=@1;Fd=@2;Fc=@3;Ph=@4;Ac=@5;G=@6;Cu=1;')
set_param([sys,'/',['Charge pump',13,'PLL']],...
		'Mask Help','This block uses a digital charge pump to detect the phase shifting from the oscillation signal. The first output is the detected phase shift. The second output is the detected phase error output from phase detector. The third output is the matching signal for the input. Note a 180 degree phase difference between the input signal and the matching signal.')
set_param([sys,'/',['Charge pump',13,'PLL']],...
		'Mask Entries','[3.0002,  0, 40002]\/[1, 67.46, 2270.9, 40002]\/100/2/pi\/pi\/1\/3\/')


%     Finished composite block ['Charge pump',13,'PLL'].

set_param([sys,'/',['Charge pump',13,'PLL']],...
		'position',[30,128,110,172])


%     Subsystem  ['Linearized baseband',13,'model for PLL'].

new_system([sys,'/',['Linearized baseband',13,'model for PLL']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL']],'Location',[94,80,709,266])

add_block('built-in/Gain',[sys,'/',['Linearized baseband',13,'model for PLL/Gain1']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Gain1']],...
		'Gain','pi2',...
		'position',[140,18,175,52])

add_block('built-in/Gain',[sys,'/',['Linearized baseband',13,'model for PLL/Gain']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Gain']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[255,95,290,125])

add_block('built-in/Gain',[sys,'/',['Linearized baseband',13,'model for PLL/Gain2']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Gain2']],...
		'Gain','Kc',...
		'position',[325,25,370,55])

add_block('built-in/Sum',[sys,'/',['Linearized baseband',13,'model for PLL/Sum']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Sum']],...
		'inputs','+-',...
		'position',[220,30,240,50])


%     Subsystem  ['Linearized baseband',13,'model for PLL/Module',13,'integrator'].

new_system([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/in_1']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/in_1']],...
		'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/Memory']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/module']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/Reset',13,'integrator']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/one']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/Sum']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/out_1']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator/out_1']],...
		'position',[370,30,390,50])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],[155,35;190,35])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],[60,25;105,25])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],[330,40;365,40])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['Linearized baseband',13,'model for PLL/Module',13,'integrator'].

set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator']],...
		'position',[65,17,115,53])

add_block('built-in/Outport',[sys,'/',['Linearized baseband',13,'model for PLL/Estimated',13,'phase']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Estimated',13,'phase']],...
		'position',[580,30,600,50])


%     Subsystem  ['Linearized baseband',13,'model for PLL/Module',13,'integrator1'].

new_system([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],'Location',[196,490,621,627])

add_block('built-in/Outport',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/out_1']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/out_1']],...
		'position',[370,30,390,50])

add_block('built-in/Sum',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/Sum']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Constant',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/one']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Reset Integrator',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/Reset',13,'integrator']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Fcn',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/module']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Memory',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/Memory']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Inport',[sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/in_1']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1/in_1']],...
		'position',[35,15,55,35])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],[330,40;365,40])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],[340,40;340,90;265,90])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],[80,50;80,35;105,35])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],[60,25;105,25])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],[220,40;230,40])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],[155,35;190,35])
add_line([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],[205,90;180,90;190,45])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['Linearized baseband',13,'model for PLL/Module',13,'integrator1'].

set_param([sys,'/',['Linearized baseband',13,'model for PLL/Module',13,'integrator1']],...
		'orientation',2,...
		'position',[330,90,380,130])

add_block('built-in/Inport',[sys,'/',['Linearized baseband',13,'model for PLL/in_1']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Transfer Fcn',[sys,'/',['Linearized baseband',13,'model for PLL/Filter']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Filter']],...
		'Numerator','Fn',...
		'Denominator','Fd',...
		'position',[420,21,470,59])

add_block('built-in/Gain',[sys,'/',['Linearized baseband',13,'model for PLL/Gain3']])
set_param([sys,'/',['Linearized baseband',13,'model for PLL/Gain3']],...
		'Gain','G',...
		'position',[520,27,545,53])
add_line([sys,'/',['Linearized baseband',13,'model for PLL']],[40,35;60,35])
add_line([sys,'/',['Linearized baseband',13,'model for PLL']],[475,40;505,40;505,110;385,110])
add_line([sys,'/',['Linearized baseband',13,'model for PLL']],[250,110;190,110;190,45;215,45])
add_line([sys,'/',['Linearized baseband',13,'model for PLL']],[180,35;215,35])
add_line([sys,'/',['Linearized baseband',13,'model for PLL']],[375,40;415,40])
add_line([sys,'/',['Linearized baseband',13,'model for PLL']],[550,40;575,40])
add_line([sys,'/',['Linearized baseband',13,'model for PLL']],[120,35;135,35])
add_line([sys,'/',['Linearized baseband',13,'model for PLL']],[325,110;295,110])
add_line([sys,'/',['Linearized baseband',13,'model for PLL']],[505,40;515,40])
add_line([sys,'/',['Linearized baseband',13,'model for PLL']],[245,40;320,40])
set_param([sys,'/',['Linearized baseband',13,'model for PLL']],...
		'Mask Display','Linearized\nbaseband\nPLL',...
		'Mask Type','Linearized baseband PLL model')
set_param([sys,'/',['Linearized baseband',13,'model for PLL']],...
		'Mask Dialogue','Output the phase shifting of the input\nsignal from the oscillation frequency.|Lowpass filter numerator:|Lowpass filter denominator:|Oscillation frequency (Hz):|Oscillation amplitude:|Gain at the output:')
set_param([sys,'/',['Linearized baseband',13,'model for PLL']],...
		'Mask Translate','Fn=@1;Fd=@2;Fc=@3;pi2=2*pi;Kc=@4/2;G=@5;')
set_param([sys,'/',['Linearized baseband',13,'model for PLL']],...
		'Mask Help','This block detects the phase shifting of the input signal. The input to this block is an oscillation signal with possible phase shifting. The block detects the phase shifting value using PLL technique. Design the lowpass filter to pass the phase changing signal and to eliminate the oscillation signal.')
set_param([sys,'/',['Linearized baseband',13,'model for PLL']],...
		'Mask Entries','[3.0002,  0, 40002]\/[1, 67.46, 2270.9, 40002]\/100/2/pi\/1\/2\/')


%     Finished composite block ['Linearized baseband',13,'model for PLL'].

set_param([sys,'/',['Linearized baseband',13,'model for PLL']],...
		'position',[155,128,235,172])

add_block('built-in/Note',[sys,'/','Synchronization Library'])
set_param([sys,'/','Synchronization Library'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[185,6,190,11])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
