function [ret,x0,str,ts,xts]=com_util(t,x,u,flag);
%COM_UTIL	is the M-file description of the SIMULINK system named COM_UTIL.
%	The block-diagram can be displayed by typing: COM_UTIL.
%
%	SYS=COM_UTIL(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_UTIL to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_UTIL with a FLAG of zero:
%	[SIZES]=COM_UTIL([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[490,42,968,748])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Nonreal-time start time','')
set_param(sys,'Real-time algorithm','')


%     Subsystem  ['Voltage-controlled',13,'oscillator'].

new_system([sys,'/',['Voltage-controlled',13,'oscillator']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator']],'Location',[290,299,749,446])

add_block('built-in/Fcn',[sys,'/',['Voltage-controlled',13,'oscillator/sin']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/sin']],...
		'Expr','Ac*sin(u[1]*pi2+Ph)',...
		'position',[285,25,410,55])


%     Subsystem  ['Voltage-controlled',13,'oscillator/Module',13,'Integrator'].

new_system([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],'Location',[329,75,754,212])

add_block('built-in/Outport',[sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/out_1']],...
		'position',[370,30,390,50])

add_block('built-in/Sum',[sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Constant',[sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/one']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Reset Integrator',[sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Fcn',[sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/module']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Memory',[sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Inport',[sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator/in_1']],...
		'position',[35,15,55,35])
add_line([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],[340,40;340,90;265,90])
add_line([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],[205,90;180,90;190,45])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['Voltage-controlled',13,'oscillator/Module',13,'Integrator'].

set_param([sys,'/',['Voltage-controlled',13,'oscillator/Module',13,'Integrator']],...
		'position',[210,24,265,56])

add_block('built-in/Sum',[sys,'/',['Voltage-controlled',13,'oscillator/Sum']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Sum']],...
		'position',[165,30,185,50])

add_block('built-in/Constant',[sys,'/',['Voltage-controlled',13,'oscillator/Carrier',13,'frequency']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Carrier',13,'frequency']],...
		'Value','Fc',...
		'position',[95,85,115,105])

add_block('built-in/Inport',[sys,'/',['Voltage-controlled',13,'oscillator/in_1']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/in_1']],...
		'position',[35,25,55,45])

add_block('built-in/Gain',[sys,'/',['Voltage-controlled',13,'oscillator/Sensitivity']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/Sensitivity']],...
		'Gain','Kc',...
		'position',[80,21,120,49])

add_block('built-in/Outport',[sys,'/',['Voltage-controlled',13,'oscillator/out_1']])
set_param([sys,'/',['Voltage-controlled',13,'oscillator/out_1']],...
		'position',[425,30,445,50])
add_line([sys,'/',['Voltage-controlled',13,'oscillator']],[60,35;75,35])
add_line([sys,'/',['Voltage-controlled',13,'oscillator']],[125,35;160,35])
add_line([sys,'/',['Voltage-controlled',13,'oscillator']],[120,95;140,95;140,45;160,45])
add_line([sys,'/',['Voltage-controlled',13,'oscillator']],[190,40;205,40])
add_line([sys,'/',['Voltage-controlled',13,'oscillator']],[270,40;280,40])
add_line([sys,'/',['Voltage-controlled',13,'oscillator']],[415,40;420,40])
set_param([sys,'/',['Voltage-controlled',13,'oscillator']],...
		'Mask Display','VCO',...
		'Mask Type','Voltage-controlled oscillator')
set_param([sys,'/',['Voltage-controlled',13,'oscillator']],...
		'Mask Dialogue','The frequency of the output signal\nchanges with the input signal.|Output amplitude:|Oscillation frequency (Hz):|Input sensitivity:|Initial phase (rad):')
set_param([sys,'/',['Voltage-controlled',13,'oscillator']],...
		'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;')
set_param([sys,'/',['Voltage-controlled',13,'oscillator']],...
		'Mask Help','This block causes the frequency of the sinusoidal oscillation signal to change with the input signal voltage. The input sensitivity is the preamplifier added to the input signal.')
set_param([sys,'/',['Voltage-controlled',13,'oscillator']],...
		'Mask Entries','1\/10\/1\/0\/')


%     Finished composite block ['Voltage-controlled',13,'oscillator'].

set_param([sys,'/',['Voltage-controlled',13,'oscillator']],...
		'position',[175,118,255,162])


%     Subsystem  ['Discrete-time',13,'VCO'].

new_system([sys,'/',['Discrete-time',13,'VCO']])
set_param([sys,'/',['Discrete-time',13,'VCO']],'Location',[53,560,655,675])

add_block('built-in/Fcn',[sys,'/',['Discrete-time',13,'VCO/module1']])
set_param([sys,'/',['Discrete-time',13,'VCO/module1']],...
		'Expr','rem(u[1],pi2)',...
		'position',[220,29,310,51])

add_block('built-in/Sum',[sys,'/',['Discrete-time',13,'VCO/Sum1']])
set_param([sys,'/',['Discrete-time',13,'VCO/Sum1']],...
		'inputs','+++',...
		'position',[175,22,195,58])

add_block('built-in/Constant',[sys,'/',['Discrete-time',13,'VCO/Phase1']])
set_param([sys,'/',['Discrete-time',13,'VCO/Phase1']],...
		'Value','Fc',...
		'position',[80,65,100,85])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-time',13,'VCO/Unit Delay1']])
set_param([sys,'/',['Discrete-time',13,'VCO/Unit Delay1']],...
		'Sample time','ts',...
		'position',[330,30,380,50])

add_block('built-in/Gain',[sys,'/',['Discrete-time',13,'VCO/Sensitivity']])
set_param([sys,'/',['Discrete-time',13,'VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[75,15,125,45])

add_block('built-in/Inport',[sys,'/',['Discrete-time',13,'VCO/in_1']])
set_param([sys,'/',['Discrete-time',13,'VCO/in_1']],...
		'position',[20,20,40,40])

add_block('built-in/Fcn',[sys,'/',['Discrete-time',13,'VCO/sin']])
set_param([sys,'/',['Discrete-time',13,'VCO/sin']],...
		'Expr','Ac*sin(u[1]+Ph)',...
		'position',[415,28,530,52])

add_block('built-in/Outport',[sys,'/',['Discrete-time',13,'VCO/out_1']])
set_param([sys,'/',['Discrete-time',13,'VCO/out_1']],...
		'position',[555,30,575,50])
add_line([sys,'/',['Discrete-time',13,'VCO']],[200,40;215,40])
add_line([sys,'/',['Discrete-time',13,'VCO']],[315,40;325,40])
add_line([sys,'/',['Discrete-time',13,'VCO']],[385,40;410,40])
add_line([sys,'/',['Discrete-time',13,'VCO']],[45,30;70,30])
add_line([sys,'/',['Discrete-time',13,'VCO']],[130,30;170,30])
add_line([sys,'/',['Discrete-time',13,'VCO']],[535,40;550,40])
add_line([sys,'/',['Discrete-time',13,'VCO']],[105,75;150,75;150,40;170,40])
add_line([sys,'/',['Discrete-time',13,'VCO']],[385,40;395,40;395,80;155,80;155,50;170,50])
set_param([sys,'/',['Discrete-time',13,'VCO']],...
		'Mask Display','Discrete\nVCO',...
		'Mask Type','Voltage-controlled oscillator')
set_param([sys,'/',['Discrete-time',13,'VCO']],...
		'Mask Dialogue','The frequency of the output signal\nchanges with the input signal.|Output amplitude:|Oscillation frequency (Hz):|Input sensitivity:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Discrete-time',13,'VCO']],...
		'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;ts=@5;Kc=Kc*pi2*ts(1);Fc=Fc*pi2;')
set_param([sys,'/',['Discrete-time',13,'VCO']],...
		'Mask Help','This block causes the frequency of the sinusoidal oscillation signal to change with the input signal voltage. The input sensitivity is the preamplifier added to the input signal. This block uses a discrete-time integrator.')
set_param([sys,'/',['Discrete-time',13,'VCO']],...
		'Mask Entries','1\/10\/1\/0\/.01\/')


%     Finished composite block ['Discrete-time',13,'VCO'].

set_param([sys,'/',['Discrete-time',13,'VCO']],...
		'position',[175,43,255,87])


%     Subsystem  ['Vector',13,'redistributor'].

new_system([sys,'/',['Vector',13,'redistributor']])
set_param([sys,'/',['Vector',13,'redistributor']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector',13,'redistributor']],...
		'Mask Display','Vector\nre-arrange\ndemo',...
		'Mask Dialogue','eval(''tstdist'')')


%     Finished composite block ['Vector',13,'redistributor'].

set_param([sys,'/',['Vector',13,'redistributor']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[175,568,255,612])


%     Subsystem  ['Register-shift',13,'demo'].

new_system([sys,'/',['Register-shift',13,'demo']])
set_param([sys,'/',['Register-shift',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Register-shift',13,'demo']],...
		'Mask Display','Register\nshift\ndemo',...
		'Mask Dialogue','eval(''testregi'')')


%     Finished composite block ['Register-shift',13,'demo'].

set_param([sys,'/',['Register-shift',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[175,493,255,537])


%     Subsystem  ['Envelope',13,'detector'].

new_system([sys,'/',['Envelope',13,'detector']])
set_param([sys,'/',['Envelope',13,'detector']],'Location',[86,374,853,617])

add_block('built-in/Memory',[sys,'/',['Envelope',13,'detector/Memory1']])
set_param([sys,'/',['Envelope',13,'detector/Memory1']],...
		'position',[285,125,325,155])

add_block('built-in/Inport',[sys,'/',['Envelope',13,'detector/in_1']])
set_param([sys,'/',['Envelope',13,'detector/in_1']],...
		'position',[30,100,50,120])

add_block('built-in/Gain',[sys,'/',['Envelope',13,'detector/Gain']])
set_param([sys,'/',['Envelope',13,'detector/Gain']],...
		'Gain','g',...
		'position',[75,100,95,120])

add_block('built-in/Memory',[sys,'/',['Envelope',13,'detector/Memory']])
set_param([sys,'/',['Envelope',13,'detector/Memory']],...
		'position',[120,35,160,65])

add_block('built-in/Relational Operator',[sys,'/',['Envelope',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Envelope',13,'detector/Relational',13,'Operator']],...
		'position',[210,93,240,117])

add_block('built-in/Relational Operator',[sys,'/',['Envelope',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Envelope',13,'detector/Relational',13,'Operator1']],...
		'Operator','>',...
		'position',[345,98,375,122])

add_block('built-in/Switch',[sys,'/',['Envelope',13,'detector/Switch']])
set_param([sys,'/',['Envelope',13,'detector/Switch']],...
		'Threshold','eps',...
		'position',[420,94,445,126])

add_block('built-in/Memory',[sys,'/',['Envelope',13,'detector/Memory2']])
set_param([sys,'/',['Envelope',13,'detector/Memory2']],...
		'orientation',2,...
		'position',[410,155,450,185])

add_block('built-in/Switch',[sys,'/',['Envelope',13,'detector/Switch1']])
set_param([sys,'/',['Envelope',13,'detector/Switch1']],...
		'Threshold','eps',...
		'position',[575,99,600,131])

add_block('built-in/Gain',[sys,'/',['Envelope',13,'detector/Gain1']])
set_param([sys,'/',['Envelope',13,'detector/Gain1']],...
		'Gain','g',...
		'position',[635,105,655,125])

add_block('built-in/Outport',[sys,'/',['Envelope',13,'detector/out_1']])
set_param([sys,'/',['Envelope',13,'detector/out_1']],...
		'position',[690,105,710,125])

add_block('built-in/Relational Operator',[sys,'/',['Envelope',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Envelope',13,'detector/Relational',13,'Operator2']],...
		'position',[495,103,525,127])
add_line([sys,'/',['Envelope',13,'detector']],[660,115;685,115])
add_line([sys,'/',['Envelope',13,'detector']],[100,110;105,110;115,50])
add_line([sys,'/',['Envelope',13,'detector']],[100,110;205,110])
add_line([sys,'/',['Envelope',13,'detector']],[55,110;70,110])
add_line([sys,'/',['Envelope',13,'detector']],[405,170;395,170;395,120;415,120])
add_line([sys,'/',['Envelope',13,'detector']],[380,110;415,110])
add_line([sys,'/',['Envelope',13,'detector']],[245,105;270,105;280,140])
add_line([sys,'/',['Envelope',13,'detector']],[270,105;340,105])
add_line([sys,'/',['Envelope',13,'detector']],[330,140;340,115])
add_line([sys,'/',['Envelope',13,'detector']],[165,50;195,50;205,100])
add_line([sys,'/',['Envelope',13,'detector']],[195,50;395,50;395,100;415,100])
add_line([sys,'/',['Envelope',13,'detector']],[450,110;470,110;470,170;455,170])
add_line([sys,'/',['Envelope',13,'detector']],[605,115;630,115])
add_line([sys,'/',['Envelope',13,'detector']],[470,110;490,110])
add_line([sys,'/',['Envelope',13,'detector']],[530,115;570,115])
add_line([sys,'/',['Envelope',13,'detector']],[470,110;470,85;550,85;550,105;570,105])
set_param([sys,'/',['Envelope',13,'detector']],...
		'Mask Display','Envelope\ndetector',...
		'Mask Type','Envelope detector',...
		'Mask Dialogue','Output the upper or lower boundary of\nthe input signal.|Boundary side (''upper'' or ''lower''):')
set_param([sys,'/',['Envelope',13,'detector']],...
		'Mask Translate','x=@1;if length(x)<2, error(''Error in Envelop Detector'');end;x=x(1:2);g=1;if x==''lo'', g=-1;end;')
set_param([sys,'/',['Envelope',13,'detector']],...
		'Mask Help','This block detects the upper or lower boundary of the envelope of the input signal. This block finds the maximum or minimum value of the input signal. The block is noise sensitive.')
set_param([sys,'/',['Envelope',13,'detector']],...
		'Mask Entries','''upper''\/')


%     Finished composite block ['Envelope',13,'detector'].

set_param([sys,'/',['Envelope',13,'detector']],...
		'position',[175,193,255,237])


%     Subsystem  ['Rising edge',13,'detector'].

new_system([sys,'/',['Rising edge',13,'detector']])
set_param([sys,'/',['Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Rising edge',13,'detector/one1']])
set_param([sys,'/',['Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Rising edge',13,'detector']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Edge det.',...
		'Mask Type','Edge detection')
set_param([sys,'/',['Rising edge',13,'detector']],...
		'Mask Dialogue','Detect the rising edge of the input\nsignal. Output one when the rising\nedge is detected.|Threshold:')
set_param([sys,'/',['Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rising edge',13,'detector']],...
		'Mask Help','This block outputs one when the input signal reaches a value larger than or equal to the given threshold value at the current time and the value was below the threshold one time step before. Otherwise, the block outputs zero.')
set_param([sys,'/',['Rising edge',13,'detector']],...
		'Mask Entries','0.5\/')


%     Finished composite block ['Rising edge',13,'detector'].

set_param([sys,'/',['Rising edge',13,'detector']],...
		'position',[175,268,255,312])


%     Subsystem  ['Error',13,'counter'].

new_system([sys,'/',['Error',13,'counter']])
set_param([sys,'/',['Error',13,'counter']],'Location',[85,438,594,606])

add_block('built-in/Inport',[sys,'/',['Error',13,'counter/in_1']])
set_param([sys,'/',['Error',13,'counter/in_1']],...
		'position',[40,15,60,35])


%     Subsystem  ['Error',13,'counter/Counter'].

new_system([sys,'/',['Error',13,'counter/Counter']])
set_param([sys,'/',['Error',13,'counter/Counter']],'Location',[378,106,972,431])

add_block('built-in/Constant',[sys,'/',['Error',13,'counter/Counter/Constant']])
set_param([sys,'/',['Error',13,'counter/Counter/Constant']],...
		'ForeGround',3,...
		'Value','thld',...
		'position',[105,100,135,120])

add_block('built-in/Relational Operator',[sys,'/',['Error',13,'counter/Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Error',13,'counter/Counter/Relational',13,'Operator1']],...
		'ForeGround',2,...
		'Operator','>',...
		'position',[225,53,255,77])

add_block('built-in/Sum',[sys,'/',['Error',13,'counter/Counter/Sum']])
set_param([sys,'/',['Error',13,'counter/Counter/Sum']],...
		'ForeGround',3,...
		'position',[295,100,315,120])

add_block('built-in/Switch',[sys,'/',['Error',13,'counter/Counter/Switch2']])
set_param([sys,'/',['Error',13,'counter/Counter/Switch2']],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[345,149,370,181])

add_block('built-in/Inport',[sys,'/',['Error',13,'counter/Counter/in_1']])
set_param([sys,'/',['Error',13,'counter/Counter/in_1']],...
		'position',[15,50,35,70])

add_block('built-in/Inport',[sys,'/',['Error',13,'counter/Counter/in_2']])
set_param([sys,'/',['Error',13,'counter/Counter/in_2']],...
		'Port','2',...
		'position',[15,155,35,175])


%     Subsystem  ['Error',13,'counter/Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Error',13,'counter/Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector']],...
		'ForeGround',4,...
		'position',[80,148,140,182])

add_block('built-in/Outport',[sys,'/',['Error',13,'counter/Counter/out_1']])
set_param([sys,'/',['Error',13,'counter/Counter/out_1']],...
		'position',[550,145,570,165])

add_block('built-in/Switch',[sys,'/',['Error',13,'counter/Counter/Switch3']])
set_param([sys,'/',['Error',13,'counter/Counter/Switch3']],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[470,139,495,171])

add_block('built-in/Memory',[sys,'/',['Error',13,'counter/Counter/Memory3']])
set_param([sys,'/',['Error',13,'counter/Counter/Memory3']],...
		'orientation',2,...
		'ForeGround',3,...
		'position',[400,205,440,235])

add_block('built-in/Inport',[sys,'/',['Error',13,'counter/Counter/in_3']])
set_param([sys,'/',['Error',13,'counter/Counter/in_3']],...
		'Port','3',...
		'position',[315,60,335,80])


%     Subsystem  ['Error',13,'counter/Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],[300,35;335,35])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Error',13,'counter/Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Error',13,'counter/Counter/Rising edge',13,'detector1']],...
		'ForeGround',4,...
		'position',[375,53,435,87])
add_line([sys,'/',['Error',13,'counter/Counter']],[440,70;450,70;450,155;465,155])
add_line([sys,'/',['Error',13,'counter/Counter']],[395,220;275,220;275,175;340,175])
add_line([sys,'/',['Error',13,'counter/Counter']],[275,175;275,115;290,115])
add_line([sys,'/',['Error',13,'counter/Counter']],[145,165;340,165])
add_line([sys,'/',['Error',13,'counter/Counter']],[260,65;275,65;275,105;290,105])
add_line([sys,'/',['Error',13,'counter/Counter']],[140,110;190,110;190,70;220,70])
add_line([sys,'/',['Error',13,'counter/Counter']],[320,110;330,110;340,155])
add_line([sys,'/',['Error',13,'counter/Counter']],[40,60;220,60])
add_line([sys,'/',['Error',13,'counter/Counter']],[40,165;75,165])
add_line([sys,'/',['Error',13,'counter/Counter']],[340,70;370,70])
add_line([sys,'/',['Error',13,'counter/Counter']],[375,165;465,165])
add_line([sys,'/',['Error',13,'counter/Counter']],[500,155;545,155])
add_line([sys,'/',['Error',13,'counter/Counter']],[520,155;520,220;445,220])
set_param([sys,'/',['Error',13,'counter/Counter']],...
		'Mask Display','Number\nCounter',...
		'Mask Type','Number Counter',...
		'Mask Dialogue','Number counter:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Error',13,'counter/Counter']],...
		'Mask Help','If the signal at the first port is larger than the given threshold at the time of the clock raising edge, the counter increases one. The clock signl is provided at the second port. The raising edge of the third port clears the counter, which enforces the counter to be zero regardless the signal in port one and two.')
set_param([sys,'/',['Error',13,'counter/Counter']],...
		'Mask Entries','.2\/')


%     Finished composite block ['Error',13,'counter/Counter'].

set_param([sys,'/',['Error',13,'counter/Counter']],...
		'position',[365,43,425,87])

add_block('built-in/Relational Operator',[sys,'/',['Error',13,'counter/Relational',13,'Operator']])
set_param([sys,'/',['Error',13,'counter/Relational',13,'Operator']],...
		'Operator','>',...
		'position',[270,38,300,62])

add_block('built-in/Abs',[sys,'/',['Error',13,'counter/Abs']])
set_param([sys,'/',['Error',13,'counter/Abs']],...
		'position',[195,33,225,57])

add_block('built-in/Sum',[sys,'/',['Error',13,'counter/Sum']])
set_param([sys,'/',['Error',13,'counter/Sum']],...
		'inputs','+-',...
		'position',[140,35,160,55])

add_block('built-in/Inport',[sys,'/',['Error',13,'counter/in_2']])
set_param([sys,'/',['Error',13,'counter/in_2']],...
		'Port','2',...
		'position',[80,40,100,60])

add_block('built-in/Outport',[sys,'/',['Error',13,'counter/out_1']])
set_param([sys,'/',['Error',13,'counter/out_1']],...
		'position',[460,55,480,75])

add_block('built-in/Inport',[sys,'/',['Error',13,'counter/in_3']])
set_param([sys,'/',['Error',13,'counter/in_3']],...
		'Port','3',...
		'position',[250,95,270,115])

add_block('built-in/Constant',[sys,'/',['Error',13,'counter/Constant']])
set_param([sys,'/',['Error',13,'counter/Constant']],...
		'Value','tol',...
		'position',[185,80,205,100])

add_block('built-in/Inport',[sys,'/',['Error',13,'counter/in_4']])
set_param([sys,'/',['Error',13,'counter/in_4']],...
		'Port','4',...
		'position',[295,115,315,135])
add_line([sys,'/',['Error',13,'counter']],[65,25;110,25;110,40;135,40])
add_line([sys,'/',['Error',13,'counter']],[105,50;135,50])
add_line([sys,'/',['Error',13,'counter']],[165,45;190,45])
add_line([sys,'/',['Error',13,'counter']],[230,45;265,45])
add_line([sys,'/',['Error',13,'counter']],[210,90;235,90;235,55;265,55])
add_line([sys,'/',['Error',13,'counter']],[305,50;360,50])
add_line([sys,'/',['Error',13,'counter']],[275,105;315,105;315,65;360,65])
add_line([sys,'/',['Error',13,'counter']],[320,125;335,125;335,80;360,80])
add_line([sys,'/',['Error',13,'counter']],[430,65;455,65])
set_param([sys,'/',['Error',13,'counter']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Err count',...
		'Mask Type','Error counter')
set_param([sys,'/',['Error',13,'counter']],...
		'Mask Dialogue','If the 1st and 2nd inport values do\nnot match at the rising edge of the\n3rd inport, the counter increases by one.|Threshold:|Tolerance:')
set_param([sys,'/',['Error',13,'counter']],...
		'Mask Translate','thld=@1;tol=@2;[v,w]=trigicon(0,35,get_param(gcb,''orientation''),2);[x,y]=trigicon(0,15,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Error',13,'counter']],...
		'Mask Help','If the signals at the 1st and 2nd inport do not match at the rising edge of the 3rd inport pulse, the counter increases by one. The rising edge of the 4th inport resets the counter to zero.')
set_param([sys,'/',['Error',13,'counter']],...
		'Mask Entries','0.2\/eps\/')


%     Finished composite block ['Error',13,'counter'].

set_param([sys,'/',['Error',13,'counter']],...
		'position',[175,418,255,462])

add_block('built-in/S-Function',[sys,'/',['Modulo',13,'operation']])
set_param([sys,'/',['Modulo',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Modulo',13,'operation']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Modulo',13,'operation']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.',...
		'Mask Entries','2\/')
set_param([sys,'/',['Modulo',13,'operation']],...
		'position',[335,343,415,387])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar']])
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Entries','2\/',...
		'position',[335,268,415,312])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector']])
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter',...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Entries','5\/2\/',...
		'position',[335,193,415,237])

add_block('built-in/S-Function',[sys,'/',['Min//max',13,'index']])
set_param([sys,'/',['Min//max',13,'index']],...
		'function name','arymimai',...
		'parameters','mima',...
		'Mask Display','Min/Max\nindex',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/',['Min//max',13,'index']],...
		'Mask Dialogue','Choose the index of the input vector with\nmaximum or minimum value.|''max'' or ''min'':',...
		'Mask Translate','mima=@1;')
set_param([sys,'/',['Min//max',13,'index']],...
		'Mask Help','Given a vector input, this block outputs the index of the element in the input vector, which has the minimum or maximum value. When more than one value meets the same criterion, this block outputs the smallest index number.')
set_param([sys,'/',['Min//max',13,'index']],...
		'Mask Entries','''min''\/',...
		'position',[335,43,415,87])


%     Subsystem  'Mean and std'.

new_system([sys,'/','Mean and std'])
set_param([sys,'/','Mean and std'],'Location',[16,148,871,412])

add_block('built-in/Fcn',[sys,'/','Mean and std/Fcn4'])
set_param([sys,'/','Mean and std/Fcn4'],...
		'Expr','u[1]*u[1]',...
		'position',[555,107,620,133])

add_block('built-in/Mux',[sys,'/','Mean and std/Mux2'])
set_param([sys,'/','Mean and std/Mux2'],...
		'inputs','2',...
		'position',[515,101,545,134])

add_block('built-in/Fcn',[sys,'/','Mean and std/Fcn1'])
set_param([sys,'/','Mean and std/Fcn1'],...
		'Expr','sqrt(u[1])',...
		'position',[690,132,755,158])

add_block('built-in/Outport',[sys,'/',['Mean and std/Mean',13,'Squared',13,'Error1']])
set_param([sys,'/',['Mean and std/Mean',13,'Squared',13,'Error1']],...
		'Port','2',...
		'position',[790,135,810,155])

add_block('built-in/Sum',[sys,'/','Mean and std/Sum'])
set_param([sys,'/','Mean and std/Sum'],...
		'inputs','-+',...
		'position',[645,135,665,155])

add_block('built-in/Fcn',[sys,'/','Mean and std/Fcn'])
set_param([sys,'/','Mean and std/Fcn'],...
		'Expr','(u[3]*(u[2]-1) + u[1]*u[1])/u[2]',...
		'position',[290,136,465,164])

add_block('built-in/Unit Delay',[sys,'/','Mean and std/Unit Delay'])
set_param([sys,'/','Mean and std/Unit Delay'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[345,192,395,208])

add_block('built-in/Mux',[sys,'/','Mean and std/Mux'])
set_param([sys,'/','Mean and std/Mux'],...
		'inputs','3',...
		'position',[235,134,265,166])

add_block('built-in/Fcn',[sys,'/','Mean and std/Fcn3'])
set_param([sys,'/','Mean and std/Fcn3'],...
		'Expr','(u[3]*(u[2]-1) + u[1])/u[2]',...
		'position',[290,41,465,69])

add_block('built-in/Mux',[sys,'/','Mean and std/Mux1'])
set_param([sys,'/','Mean and std/Mux1'],...
		'inputs','3',...
		'position',[235,39,265,71])

add_block('built-in/Outport',[sys,'/','Mean and std/mean value'])
set_param([sys,'/','Mean and std/mean value'],...
		'position',[545,45,565,65])

add_block('built-in/Unit Delay',[sys,'/','Mean and std/Unit Delay1'])
set_param([sys,'/','Mean and std/Unit Delay1'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[350,87,400,103])

add_block('built-in/Fcn',[sys,'/','Mean and std/Fcn2'])
set_param([sys,'/','Mean and std/Fcn2'],...
		'Expr','u[1]/Ts +1',...
		'position',[105,83,165,107])

add_block('built-in/Digital Clock',[sys,'/','Mean and std/Digital Clock'])
set_param([sys,'/','Mean and std/Digital Clock'],...
		'Sample time','Ts',...
		'position',[45,80,80,110])

add_block('built-in/Inport',[sys,'/','Mean and std/Actual'])
set_param([sys,'/','Mean and std/Actual'],...
		'position',[25,35,45,55])
add_line([sys,'/','Mean and std'],[550,120;550,120])
add_line([sys,'/','Mean and std'],[170,95;190,95;190,150;230,150])
add_line([sys,'/','Mean and std'],[190,125;510,125])
add_line([sys,'/','Mean and std'],[470,55;540,55])
add_line([sys,'/','Mean and std'],[495,55;495,95;405,95])
add_line([sys,'/','Mean and std'],[495,95;495,110;510,110])
add_line([sys,'/','Mean and std'],[625,120;625,140;640,140])
add_line([sys,'/','Mean and std'],[470,150;480,150;480,200;400,200])
add_line([sys,'/','Mean and std'],[480,150;640,150])
add_line([sys,'/','Mean and std'],[670,145;685,145])
add_line([sys,'/','Mean and std'],[50,45;230,45])
add_line([sys,'/','Mean and std'],[200,45;200,140;230,140])
add_line([sys,'/','Mean and std'],[345,95;210,95;210,65;230,65])
add_line([sys,'/','Mean and std'],[190,95;190,55;230,55])
add_line([sys,'/','Mean and std'],[760,145;785,145])
add_line([sys,'/','Mean and std'],[270,55;285,55])
add_line([sys,'/','Mean and std'],[270,150;285,150])
add_line([sys,'/','Mean and std'],[340,200;220,200;230,160])
add_line([sys,'/','Mean and std'],[85,95;100,95])
set_param([sys,'/','Mean and std'],...
		'Mask Display','Mean\n& std',...
		'Mask Type','Running mean and std',...
		'Mask Dialogue','Output the running mean to 1st outport\nand running standard deviation to 2nd outport.|Sample time (sec):')
set_param([sys,'/','Mean and std'],...
		'Mask Translate','Ts=@1;')
set_param([sys,'/','Mean and std'],...
		'Mask Help','This block updates the running mean and standard deviation (std) value at sampling time point. The mean and std are outputted into 1st and 2nd outports respectively.')
set_param([sys,'/','Mean and std'],...
		'Mask Entries','td\/')


%     Finished composite block 'Mean and std'.

set_param([sys,'/','Mean and std'],...
		'position',[335,418,415,462])


%     Subsystem  'Mean and var'.

new_system([sys,'/','Mean and var'])
set_param([sys,'/','Mean and var'],'Location',[16,148,774,399])

add_block('built-in/Inport',[sys,'/','Mean and var/Actual'])
set_param([sys,'/','Mean and var/Actual'],...
		'position',[25,35,45,55])

add_block('built-in/Digital Clock',[sys,'/','Mean and var/Digital Clock'])
set_param([sys,'/','Mean and var/Digital Clock'],...
		'Sample time','Ts',...
		'position',[45,80,80,110])

add_block('built-in/Fcn',[sys,'/','Mean and var/Fcn2'])
set_param([sys,'/','Mean and var/Fcn2'],...
		'Expr','u[1]/Ts +1',...
		'position',[105,83,165,107])

add_block('built-in/Unit Delay',[sys,'/','Mean and var/Unit Delay1'])
set_param([sys,'/','Mean and var/Unit Delay1'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[350,87,400,103])

add_block('built-in/Outport',[sys,'/','Mean and var/mean value'])
set_param([sys,'/','Mean and var/mean value'],...
		'position',[545,45,565,65])

add_block('built-in/Mux',[sys,'/','Mean and var/Mux1'])
set_param([sys,'/','Mean and var/Mux1'],...
		'inputs','3',...
		'position',[235,39,265,71])

add_block('built-in/Fcn',[sys,'/','Mean and var/Fcn3'])
set_param([sys,'/','Mean and var/Fcn3'],...
		'Expr','(u[3]*(u[2]-1) + u[1])/u[2]',...
		'position',[290,41,465,69])

add_block('built-in/Mux',[sys,'/','Mean and var/Mux'])
set_param([sys,'/','Mean and var/Mux'],...
		'inputs','3',...
		'position',[235,134,265,166])

add_block('built-in/Unit Delay',[sys,'/','Mean and var/Unit Delay'])
set_param([sys,'/','Mean and var/Unit Delay'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[345,192,395,208])

add_block('built-in/Fcn',[sys,'/','Mean and var/Fcn'])
set_param([sys,'/','Mean and var/Fcn'],...
		'Expr','(u[3]*(u[2]-1) + u[1]*u[1])/u[2]',...
		'position',[290,136,465,164])

add_block('built-in/Sum',[sys,'/','Mean and var/Sum'])
set_param([sys,'/','Mean and var/Sum'],...
		'inputs','-+',...
		'position',[645,135,665,155])

add_block('built-in/Mux',[sys,'/','Mean and var/Mux2'])
set_param([sys,'/','Mean and var/Mux2'],...
		'inputs','2',...
		'position',[515,101,545,134])

add_block('built-in/Fcn',[sys,'/','Mean and var/Fcn4'])
set_param([sys,'/','Mean and var/Fcn4'],...
		'Expr','u[1]*u[1]',...
		'position',[555,107,620,133])

add_block('built-in/Outport',[sys,'/',['Mean and var/Mean',13,'Squared',13,'Error1']])
set_param([sys,'/',['Mean and var/Mean',13,'Squared',13,'Error1']],...
		'Port','2',...
		'position',[700,135,720,155])
add_line([sys,'/','Mean and var'],[85,95;100,95])
add_line([sys,'/','Mean and var'],[340,200;220,200;230,160])
add_line([sys,'/','Mean and var'],[170,95;190,95;190,150;230,150])
add_line([sys,'/','Mean and var'],[270,150;285,150])
add_line([sys,'/','Mean and var'],[270,55;285,55])
add_line([sys,'/','Mean and var'],[470,55;540,55])
add_line([sys,'/','Mean and var'],[50,45;230,45])
add_line([sys,'/','Mean and var'],[190,95;190,55;230,55])
add_line([sys,'/','Mean and var'],[495,55;495,95;405,95])
add_line([sys,'/','Mean and var'],[345,95;210,95;210,65;230,65])
add_line([sys,'/','Mean and var'],[200,45;200,140;230,140])
add_line([sys,'/','Mean and var'],[470,150;480,150;480,200;400,200])
add_line([sys,'/','Mean and var'],[480,150;640,150])
add_line([sys,'/','Mean and var'],[625,120;625,140;640,140])
add_line([sys,'/','Mean and var'],[495,95;495,110;510,110])
add_line([sys,'/','Mean and var'],[190,125;510,125])
add_line([sys,'/','Mean and var'],[550,120;550,120])
add_line([sys,'/','Mean and var'],[670,145;695,145])
set_param([sys,'/','Mean and var'],...
		'Mask Display','Mean\n& var',...
		'Mask Type','Running mean and var',...
		'Mask Dialogue','Output the running mean to 1st outport\nand running variant to 2nd outport.|Sample time (sec):')
set_param([sys,'/','Mean and var'],...
		'Mask Translate','Ts=@1;',...
		'Mask Help','This block updates the running mean and variant value at sampling time point. The mean and var values are outputted into 1st and 2nd outports respectively.')
set_param([sys,'/','Mean and var'],...
		'Mask Entries','td\/')


%     Finished composite block 'Mean and var'.

set_param([sys,'/','Mean and var'],...
		'position',[335,493,415,537])

add_block('built-in/S-Function',[sys,'/',['Array',13,'function']])
set_param([sys,'/',['Array',13,'function']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nfunction',...
		'Mask Type','Array function')
set_param([sys,'/',['Array',13,'function']],...
		'Mask Dialogue','Array function block for sin, cos, tan, exp, asin, acos, ln, log10, sgn, abs,\nfloor, ceil, and round.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['Array',13,'function']],...
		'Mask Help','This block calculates the given function value. The vector length of the output is the same as the input.',...
		'Mask Entries','''sin''\/',...
		'position',[335,118,415,162])

add_block('built-in/Note',[sys,'/','Utility//Miscellany Library'])
set_param([sys,'/','Utility//Miscellany Library'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[210,6,215,11])


%     Subsystem  'Counter'.

new_system([sys,'/','Counter'])
set_param([sys,'/','Counter'],'Location',[128,50,722,374])


%     Subsystem  ['Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[300,35;335,35])
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'ForeGround',4,...
		'position',[375,53,435,87])

add_block('built-in/Inport',[sys,'/','Counter/in_3'])
set_param([sys,'/','Counter/in_3'],...
		'Port','3',...
		'position',[315,60,335,80])

add_block('built-in/Memory',[sys,'/','Counter/Memory3'])
set_param([sys,'/','Counter/Memory3'],...
		'orientation',2,...
		'ForeGround',3,...
		'position',[400,205,440,235])

add_block('built-in/Switch',[sys,'/','Counter/Switch3'])
set_param([sys,'/','Counter/Switch3'],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[470,139,495,171])

add_block('built-in/Outport',[sys,'/','Counter/out_1'])
set_param([sys,'/','Counter/out_1'],...
		'position',[550,145,570,165])


%     Subsystem  ['Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'ForeGround',4,...
		'position',[80,148,140,182])

add_block('built-in/Inport',[sys,'/','Counter/in_2'])
set_param([sys,'/','Counter/in_2'],...
		'Port','2',...
		'position',[15,155,35,175])

add_block('built-in/Inport',[sys,'/','Counter/in_1'])
set_param([sys,'/','Counter/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Switch',[sys,'/','Counter/Switch2'])
set_param([sys,'/','Counter/Switch2'],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[345,149,370,181])

add_block('built-in/Sum',[sys,'/','Counter/Sum'])
set_param([sys,'/','Counter/Sum'],...
		'ForeGround',3,...
		'position',[295,100,315,120])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Relational',13,'Operator1']],...
		'ForeGround',2,...
		'Operator','>',...
		'position',[225,53,255,77])

add_block('built-in/Constant',[sys,'/','Counter/Constant'])
set_param([sys,'/','Counter/Constant'],...
		'ForeGround',3,...
		'Value','thld',...
		'position',[105,100,135,120])
add_line([sys,'/','Counter'],[500,155;545,155])
add_line([sys,'/','Counter'],[520,155;520,220;445,220])
add_line([sys,'/','Counter'],[375,165;465,165])
add_line([sys,'/','Counter'],[340,70;370,70])
add_line([sys,'/','Counter'],[40,165;75,165])
add_line([sys,'/','Counter'],[40,60;220,60])
add_line([sys,'/','Counter'],[320,110;330,110;340,155])
add_line([sys,'/','Counter'],[395,220;275,220;275,175;340,175])
add_line([sys,'/','Counter'],[140,110;190,110;190,70;220,70])
add_line([sys,'/','Counter'],[260,65;275,65;275,105;290,105])
add_line([sys,'/','Counter'],[145,165;340,165])
add_line([sys,'/','Counter'],[275,175;275,115;290,115])
add_line([sys,'/','Counter'],[440,70;450,70;450,155;465,155])
set_param([sys,'/','Counter'],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Counter',...
		'Mask Type','Resettable number counter')
set_param([sys,'/','Counter'],...
		'Mask Dialogue','If the 1st inport value is larger than the threshold, the counter increases one at the rising edge of the 2nd inport pulse.|Threshold:')
set_param([sys,'/','Counter'],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(0,20,get_param(gcb,''orientation''),2);')
set_param([sys,'/','Counter'],...
		'Mask Help','If the signal at the 1st inport is larger than or equal to the given threshold at the rising edge of the 2nd inport, the counter increases by one. The rising edge of the 3rd port resets the counter to zero.')
set_param([sys,'/','Counter'],...
		'Mask Entries','.2\/')


%     Finished composite block 'Counter'.

set_param([sys,'/','Counter'],...
		'position',[180,353,260,397])


%     Subsystem  ['Modulo',13,'integrator'].

new_system([sys,'/',['Modulo',13,'integrator']])
set_param([sys,'/',['Modulo',13,'integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['Modulo',13,'integrator/in_1']])
set_param([sys,'/',['Modulo',13,'integrator/in_1']],...
		'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['Modulo',13,'integrator/Memory']])
set_param([sys,'/',['Modulo',13,'integrator/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['Modulo',13,'integrator/module']])
set_param([sys,'/',['Modulo',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['Modulo',13,'integrator/Reset',13,'integrator']])
set_param([sys,'/',['Modulo',13,'integrator/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['Modulo',13,'integrator/one']])
set_param([sys,'/',['Modulo',13,'integrator/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['Modulo',13,'integrator/Sum']])
set_param([sys,'/',['Modulo',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['Modulo',13,'integrator/out_1']])
set_param([sys,'/',['Modulo',13,'integrator/out_1']],...
		'position',[370,30,390,50])
add_line([sys,'/',['Modulo',13,'integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['Modulo',13,'integrator']],[155,35;190,35])
add_line([sys,'/',['Modulo',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['Modulo',13,'integrator']],[330,40;365,40])
add_line([sys,'/',['Modulo',13,'integrator']],[60,25;105,25])
add_line([sys,'/',['Modulo',13,'integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Modulo',13,'integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['Modulo',13,'integrator']],...
		'Mask Display','Modulo\nintegrator',...
		'Mask Type','Modulo integrator')
set_param([sys,'/',['Modulo',13,'integrator']],...
		'Mask Dialogue','When the absolute value of the state\nexceeds the modulo bound, the state is\nreset to be the remainder of the state\ndivided by the modulo bound.|Modulo bound:|Initial state:')
set_param([sys,'/',['Modulo',13,'integrator']],...
		'Mask Translate','init=@2;modu=@1;')
set_param([sys,'/',['Modulo',13,'integrator']],...
		'Mask Help','This block calculate the integration of the input signal. The absolute value of this integrator will not exceed the specified module bound. The state value is reset to be the remainder of the state divided by the modulo bound. This block can only be used for scale value calculation. This block is a continuous-time integration block.')
set_param([sys,'/',['Modulo',13,'integrator']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['Modulo',13,'integrator'].

set_param([sys,'/',['Modulo',13,'integrator']],...
		'position',[30,118,110,162])


%     Subsystem  'Signal switch'.

new_system([sys,'/','Signal switch'])
set_param([sys,'/','Signal switch'],'Location',[174,522,554,686])

add_block('built-in/Inport',[sys,'/','Signal switch/in_1'])
set_param([sys,'/','Signal switch/in_1'],...
		'position',[65,20,85,40])

add_block('built-in/Mux',[sys,'/','Signal switch/Mux'])
set_param([sys,'/','Signal switch/Mux'],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Outport',[sys,'/','Signal switch/out_1'])
set_param([sys,'/','Signal switch/out_1'],...
		'position',[320,65,340,85])

add_block('built-in/Inport',[sys,'/','Signal switch/in_2'])
set_param([sys,'/','Signal switch/in_2'],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/S-Function',[sys,'/','Signal switch/S-function'])
set_param([sys,'/','Signal switch/S-function'],...
		'function name','switchbx',...
		'parameters','sw,df',...
		'position',[205,60,275,90])
add_line([sys,'/','Signal switch'],[90,30;120,30;120,65;140,65])
add_line([sys,'/','Signal switch'],[85,85;140,85])
add_line([sys,'/','Signal switch'],[180,75;200,75])
add_line([sys,'/','Signal switch'],[280,75;315,75])
set_param([sys,'/','Signal switch'],...
		'Mask Display','Switch\nbox',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/','Signal switch'],...
		'Mask Dialogue','The output distribution pattern follows the ith row of the switch box, where i is the input from the second port.|Switch box (column number equals block output length):|Default value:')
set_param([sys,'/','Signal switch'],...
		'Mask Translate','sw=@1;df=@2;')
set_param([sys,'/','Signal switch'],...
		'Mask Help','This block follows the switch pattern of ith row in the switch box when the second input port has value i.  When the value in the second input is larger than the switch box row number or less than 1, the block outputs the defualt value.')
set_param([sys,'/','Signal switch'],...
		'Mask Entries','[1 2;2 3;3 1]\/[0 0]\/')


%     Finished composite block 'Signal switch'.

set_param([sys,'/','Signal switch'],...
		'position',[30,643,110,687])


%     Subsystem  ['Triggered',13,'signal switch'].

new_system([sys,'/',['Triggered',13,'signal switch']])
set_param([sys,'/',['Triggered',13,'signal switch']],'Location',[624,516,1004,680])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'signal switch/in_1']])
set_param([sys,'/',['Triggered',13,'signal switch/in_1']],...
		'position',[65,20,85,40])

add_block('built-in/Mux',[sys,'/',['Triggered',13,'signal switch/Mux']])
set_param([sys,'/',['Triggered',13,'signal switch/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Outport',[sys,'/',['Triggered',13,'signal switch/out_1']])
set_param([sys,'/',['Triggered',13,'signal switch/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'signal switch/in_2']])
set_param([sys,'/',['Triggered',13,'signal switch/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/S-Function',[sys,'/',['Triggered',13,'signal switch/S-function']])
set_param([sys,'/',['Triggered',13,'signal switch/S-function']],...
		'function name','stdmamux',...
		'parameters','sw,ke,in,tt',...
		'position',[205,60,275,90])
add_line([sys,'/',['Triggered',13,'signal switch']],[90,30;120,30;120,65;140,65])
add_line([sys,'/',['Triggered',13,'signal switch']],[85,85;140,85])
add_line([sys,'/',['Triggered',13,'signal switch']],[180,75;200,75])
add_line([sys,'/',['Triggered',13,'signal switch']],[280,75;315,75])
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Display','plot(0,0,100,100,v,w);Vct re-arr',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Dialogue','The rising edge from the 2nd inport\ntriggers the output of this block to follow the rule of the next row in the switch box.|Switch box (column number equals block output length):|Keeping value (flag 0 element in switch box):|Initial value (before the 1st trigger is detected):|Trigger threshold:')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Translate','sw=@1;ke=@2;in=@3;tt=@4;[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Help','When the ith element in the current row of the switch box is j, the ith element in the output vector equals jth input element. When j=0, the output keeps the last output value if keep_value >= 0; it equals ini_val otherwise. The switch box column number must be same as the lengths of output, keep_value, and init_value. The rising edge of the 2nd inport triggers the distribution pattern to follow the next row of the switch box.')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Entries','[1 2 3;2 3 1;3 1 2]\/[-1 -1 -1]\/[0 0 0]\/.1\/')


%     Finished composite block ['Triggered',13,'signal switch'].

set_param([sys,'/',['Triggered',13,'signal switch']],...
		'position',[30,568,110,612])


%     Subsystem  ['Disc modulo',13,'integrator'].

new_system([sys,'/',['Disc modulo',13,'integrator']])
set_param([sys,'/',['Disc modulo',13,'integrator']],'Location',[524,538,1137,667])

add_block('built-in/Outport',[sys,'/',['Disc modulo',13,'integrator/out_1']])
set_param([sys,'/',['Disc modulo',13,'integrator/out_1']],...
		'position',[425,30,445,50])

add_block('built-in/Unit Delay',[sys,'/',['Disc modulo',13,'integrator/Unit Delay']])
set_param([sys,'/',['Disc modulo',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Inport',[sys,'/',['Disc modulo',13,'integrator/in_1']])
set_param([sys,'/',['Disc modulo',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['Disc modulo',13,'integrator/module']])
set_param([sys,'/',['Disc modulo',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['Disc modulo',13,'integrator/Sum']])
set_param([sys,'/',['Disc modulo',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Gain',[sys,'/',['Disc modulo',13,'integrator/Gain1']])
set_param([sys,'/',['Disc modulo',13,'integrator/Gain1']],...
		'Gain','ts(1)',...
		'position',[100,20,130,50])
add_line([sys,'/',['Disc modulo',13,'integrator']],[400,40;420,40])
add_line([sys,'/',['Disc modulo',13,'integrator']],[410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['Disc modulo',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['Disc modulo',13,'integrator']],[135,35;190,35])
add_line([sys,'/',['Disc modulo',13,'integrator']],[40,35;95,35])
add_line([sys,'/',['Disc modulo',13,'integrator']],[220,40;230,40])
set_param([sys,'/',['Disc modulo',13,'integrator']],...
		'Mask Display','Discrete\nmod-int',...
		'Mask Type','Discrete-time modulo integrator')
set_param([sys,'/',['Disc modulo',13,'integrator']],...
		'Mask Dialogue','When the absolute value of the state\nexceeds the modulo bound, the state is\nreset to be the remainder of the state\ndivided by the modulo bound.|Modulo bound:|Initial state:|Sample time (sec):')
set_param([sys,'/',['Disc modulo',13,'integrator']],...
		'Mask Translate','init=@2;modu=@1;ts=@3;')
set_param([sys,'/',['Disc modulo',13,'integrator']],...
		'Mask Help','This block calculate the integration of the input signal. The absolute value of this integrator will not exceed the specified module bound. The state value is reset to be the remainder of the state divided by the modulo bound. This block can only be used for scale value calculation. This block is a discrete-time integration block.')
set_param([sys,'/',['Disc modulo',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['Disc modulo',13,'integrator'].

set_param([sys,'/',['Disc modulo',13,'integrator']],...
		'position',[30,43,110,87])


%     Subsystem  ['K-step',13,'delay'].

new_system([sys,'/',['K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay']],'Location',[12,432,357,702])

add_block('built-in/Relational Operator',[sys,'/',['K-step',13,'delay/Relational',13,'Operator']])
set_param([sys,'/',['K-step',13,'delay/Relational',13,'Operator']],...
		'position',[150,168,180,192])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant1']])
set_param([sys,'/',['K-step',13,'delay/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant']])
set_param([sys,'/',['K-step',13,'delay/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Switch',[sys,'/',['K-step',13,'delay/Switch']])
set_param([sys,'/',['K-step',13,'delay/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Filter',[sys,'/',['K-step',13,'delay/K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Outport',[sys,'/',['K-step',13,'delay/out_1']])
set_param([sys,'/',['K-step',13,'delay/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Inport',[sys,'/',['K-step',13,'delay/in_1']])
set_param([sys,'/',['K-step',13,'delay/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Digital Clock',[sys,'/',['K-step',13,'delay/Digital Clock']])
set_param([sys,'/',['K-step',13,'delay/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])
add_line([sys,'/',['K-step',13,'delay']],[185,180;220,180;220,130;265,130])
add_line([sys,'/',['K-step',13,'delay']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['K-step',13,'delay']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['K-step',13,'delay']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['K-step',13,'delay']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['K-step',13,'delay']],[45,90;55,90])
add_line([sys,'/',['K-step',13,'delay']],[300,130;320,130])
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay',...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.',...
		'Mask Entries','1\/td\/ceil(M/2)\/')


%     Finished composite block ['K-step',13,'delay'].

set_param([sys,'/',['K-step',13,'delay']],...
		'position',[30,193,110,237])

add_block('built-in/S-Function',[sys,'/',['Limited-length',13,'integrator']])
set_param([sys,'/',['Limited-length',13,'integrator']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nintegrator',...
		'Mask Type','Windowed integration')
set_param([sys,'/',['Limited-length',13,'integrator']],...
		'Mask Dialogue','Output the integration of the input from time t-T to t, where T is the size of the integration window.|Input vector size:|Integration window length:|Sample time (sec):|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Limited-length',13,'integrator']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Limited-length',13,'integrator']],...
		'Mask Help','This block outputs\n t\n int u(t) dt\n t-T\n The output vector length is the same as the input vector length. You can choose forward, backward, or first order integration methods.')
set_param([sys,'/',['Limited-length',13,'integrator']],...
		'Mask Entries','2\/1\/.1\/''first order''\/',...
		'position',[30,268,110,312])


%     Subsystem  ['Triggered',13,'buffer down'].

new_system([sys,'/',['Triggered',13,'buffer down']])
set_param([sys,'/',['Triggered',13,'buffer down']],'Location',[22,58,460,228])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Triggered',13,'buffer down']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Buffer dwn',...
		'Mask Type','Triggered buffer down')
set_param([sys,'/',['Triggered',13,'buffer down']],...
		'Mask Dialogue','Rising edge of the 2nd port triggers 1st port vector signal in. Rising edge of the 3rd port triggers 1st outport signal out.|Input signal vector size:|Initial index (integer vector):|Increment for each index (integer vector):|Trigger threshold:|When index exceed register size, 1: cyclic out, 0: zero out:')
set_param([sys,'/',['Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1;ini_idx=@2;idx_inc=@3;thrshld=@4;cycl_flag=@5;out_size=length(ini_idx);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,75,get_param(gcb,''orientation''),2);[u,z]=trigicon(0,50,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered',13,'buffer down']],...
		'Mask Help','The block refreshes its registers with the vector input from the 1st inport at the rising edge of the 2nd inport pulse. The 1st outport outputs the elements of the registers starting with the given initial index. The rising edge of the 3rd inport pulse triggers the 1st output to output the register value with the index increasing the increment value. The second outport outputs a spike pulse when the internal register is refreshed.')
set_param([sys,'/',['Triggered',13,'buffer down']],...
		'Mask Entries','128\/[0 0 0]\/[1 2 3]\/.1\/1\/')


%     Finished composite block ['Triggered',13,'buffer down'].

set_param([sys,'/',['Triggered',13,'buffer down']],...
		'position',[30,493,110,537])


%     Subsystem  'Register-shift'.

new_system([sys,'/','Register-shift'])
set_param([sys,'/','Register-shift'],'Location',[19,610,374,740])

add_block('built-in/Demux',[sys,'/','Register-shift/Demux'])
set_param([sys,'/','Register-shift/Demux'],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/','Register-shift/S-function'])
set_param([sys,'/','Register-shift/S-function'],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/','Register-shift/Mux'])
set_param([sys,'/','Register-shift/Mux'],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/','Register-shift/out_1'])
set_param([sys,'/','Register-shift/out_1'],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/','Register-shift/out_2'])
set_param([sys,'/','Register-shift/out_2'],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/','Register-shift/in_1'])
set_param([sys,'/','Register-shift/in_1'],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/','Register-shift/in_2'])
set_param([sys,'/','Register-shift/in_2'],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/','Register-shift'],[120,75;145,75])
add_line([sys,'/','Register-shift'],[205,75;255,75])
add_line([sys,'/','Register-shift'],[305,65;325,65])
add_line([sys,'/','Register-shift'],[305,80;325,80])
add_line([sys,'/','Register-shift'],[55,65;75,65])
add_line([sys,'/','Register-shift'],[55,80;75,80])
set_param([sys,'/','Register-shift'],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Reg. shift',...
		'Mask Type','Register-shift')
set_param([sys,'/','Register-shift'],...
		'Mask Dialogue','The rising edge of the 2nd port pulse\ntriggers the block to input the 1st port data and to shift the register.|Delay steps (output length is same as this vector size):|Threshold in detecting the rising edge of the pulse:')
set_param([sys,'/','Register-shift'],...
		'Mask Translate','shft_out=@1;thrhld=@2;len_rg=length(@1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,75,get_param(gcb,''orientation''),2);')
set_param([sys,'/','Register-shift'],...
		'Mask Help','This block stores the scalar input signal from the 1st input port at the rising edge of the pulse from the 2nd port. The 1st outport outputs a vector with its size the same as the "Delay steps" entree of this block. The maximum delay is the register size of this block. The second outport outputs a positive pulse when the register is\nrefreshed.')
set_param([sys,'/','Register-shift'],...
		'Mask Entries','[127:-1:0]\/.1\/')


%     Finished composite block 'Register-shift'.

set_param([sys,'/','Register-shift'],...
		'position',[30,418,110,462])

add_block('built-in/S-Function',[sys,'/',['Scheduled',13,'reset-int']])
set_param([sys,'/',['Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Scheduled\nreset-int',...
		'Mask Type','Scheduled reset integration')
set_param([sys,'/',['Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the\nscheduled reset sample point.|Scheduled reset time interval and offset (sec):|Computation sample time and offset (sec):|Modulo bound:')
set_param([sys,'/',['Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the reset time points. The reset interval can be a two-element vector with the second element as offset. The computation sample time must be smaller than the reset interval. The block resets the state value to be the remainder of the state divided by the modulo bound when the absolute value of the state is larger than the modulo bound.')
set_param([sys,'/',['Scheduled',13,'reset-int']],...
		'Mask Entries','Inf\/.05\/2\/',...
		'position',[30,343,110,387])


%     Subsystem  ['Vector',13,'redistributor1'].

new_system([sys,'/',['Vector',13,'redistributor1']])
set_param([sys,'/',['Vector',13,'redistributor1']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector',13,'redistributor1']],...
		'Mask Display','Switch\nbox\ndemo',...
		'Mask Dialogue','eval(''tstswitc'')')


%     Finished composite block ['Vector',13,'redistributor1'].

set_param([sys,'/',['Vector',13,'redistributor1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[175,643,255,687])

add_block('built-in/S-Function',[sys,'/','Complex filter'])
set_param([sys,'/','Complex filter'],...
		'function name','cmplxflt',...
		'parameters','num, den, ts',...
		'Mask Display','plot(0,0,100,100,x,y,u,v);Filter',...
		'Mask Type','Complex filter')
set_param([sys,'/','Complex filter'],...
		'Mask Dialogue','Vector expression for numerator and\ndenominator. Complex coefficients are in ascending power of 1/z.|Numerator:|Denominator:|Sample time:')
set_param([sys,'/','Complex filter'],...
		'Mask Translate','num=@1;den=@2;ts=@3;num=[real(num(:))'';imag(num(:))''];den=[real(den(:))'';imag(den(:))''];if max(abs(den(2,:))) <=0, den=den(1,:); end;if max(abs(num(2,:))) <=0, num=num(1,:); end;[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));[x,y]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/','Complex filter'],...
		'Mask Help','This block takes real or complex signal input and outputs complex signal. The numerator can be a real or a complex vector with the coeficient ordered in ascending power of 1/z. Same for the denominator.')
set_param([sys,'/','Complex filter'],...
		'Mask Entries','[3 2 1]/3+sqrt(-1)*[4 2 1]/4\/1\/.1\/',...
		'position',[335,570,415,610])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
