function [ret,x0,str,ts,xts]=comcdbch(t,x,u,flag);
%COMCDBCH	is the M-file description of the SIMULINK system named COMCDBCH.
%	The block-diagram can be displayed by typing: COMCDBCH.
%
%	SYS=COMCDBCH(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COMCDBCH to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COMCDBCH with a FLAG of zero:
%	[SIZES]=COMCDBCH([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[57,336,579,559])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Binary vector',13,'BCH decode'].

new_system([sys,'/',['Binary vector',13,'BCH decode']])
set_param([sys,'/',['Binary vector',13,'BCH decode']],'Location',[157,499,740,659])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'BCH decode/Memory']])
set_param([sys,'/',['Binary vector',13,'BCH decode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,k+1)',...
		'position',[295,95,335,125])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'BCH decode/Switch']])
set_param([sys,'/',['Binary vector',13,'BCH decode/Switch']],...
		'Threshold','0.5',...
		'position',[295,44,325,76])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'BCH decode/S-function']])
set_param([sys,'/',['Binary vector',13,'BCH decode/S-function']],...
		'function name','simbchdc',...
		'parameters','n, k, t,tp,dim',...
		'position',[170,20,235,40])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'BCH decode/Mux']])
set_param([sys,'/',['Binary vector',13,'BCH decode/Mux']],...
		'inputs','[n, 1]',...
		'position',[80,41,115,74])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'BCH decode/in_1']])
set_param([sys,'/',['Binary vector',13,'BCH decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'BCH decode/in_2']])
set_param([sys,'/',['Binary vector',13,'BCH decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Demux',[sys,'/',['Binary vector',13,'BCH decode/Demux']])
set_param([sys,'/',['Binary vector',13,'BCH decode/Demux']],...
		'outputs','[k, 1]',...
		'position',[395,40,435,75])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'BCH decode/out_1']])
set_param([sys,'/',['Binary vector',13,'BCH decode/out_1']],...
		'position',[495,30,515,50])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'BCH decode/out_2']])
set_param([sys,'/',['Binary vector',13,'BCH decode/out_2']],...
		'Port','2',...
		'position',[495,95,515,115])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[330,60;390,60])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[360,60;360,110;340,110])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[440,65;455,65;455,105;490,105])
set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);BCH de',...
		'Mask Type','Vector I/O BCH decode')
set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'Mask Dialogue','BCH decode with input codeword vector\nlength N, output message vector length K, and error-correction capability T. (N,K,T) must be a valid BCH code combination.|Codeword length N (N=2^M-1. M is a >2 integer):|Message length K (check BCHPOLY for valid K):|Error-correction capability T (0 for unknown):')
set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'Mask Translate','n=@1;k=@2;t=@3;if t<=0, [x1,x2,x3,x4,t]=bchpoly(n,k);end;dim=3;pow_dim=7;while pow_dim<n,dim=dim+1;pow_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using BCH code. The block refreshes its decoding output when the enable signal at the second inport has positive value. The second outport outputs the number of errors detected in the process. A negative value indicates the block found more error in the codeword than T.')
set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'Mask Entries','15\/5\/3\/')


%     Finished composite block ['Binary vector',13,'BCH decode'].

set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'position',[165,58,245,102])


%     Subsystem  ['Vector BCH',13,'Co//Dec demo'].

new_system([sys,'/',['Vector BCH',13,'Co//Dec demo']])
set_param([sys,'/',['Vector BCH',13,'Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector BCH',13,'Co//Dec demo']],...
		'Mask Display','Vector\nco/dec\ndemo',...
		'Mask Dialogue','eval(''N_bch_demo=15;K_bch_demo=5;T_bch_demo=3;tstbchcd'')')


%     Finished composite block ['Vector BCH',13,'Co//Dec demo'].

set_param([sys,'/',['Vector BCH',13,'Co//Dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,58,375,102])


%     Subsystem  ['Binary sequence',13,'BCH decode'].

new_system([sys,'/',['Binary sequence',13,'BCH decode']])
set_param([sys,'/',['Binary sequence',13,'BCH decode']],'Location',[88,100,698,253])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Demux']],...
		'outputs','2',...
		'position',[110,80,150,115])


%     Subsystem  ['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n, k]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[25,81,85,119])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/sequential',13,'message-out']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/sequential',13,'message-out']],...
		'position',[560,30,580,50])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/sequential',13,'code-word-in']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/sequential',13,'code-word-in']],...
		'position',[100,25,120,45])


%     Subsystem  ['Binary sequence',13,'BCH decode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/in_1']],...
		'position',[10,55,30,75])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[35,65;75,65])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[65,80;75,80])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'BCH decode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'BackGround',3,...
		'position',[185,25,240,65])


%     Subsystem  ['Binary sequence',13,'BCH decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'BCH decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[445,28,505,72])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/out_2']],...
		'Port','2',...
		'position',[370,45,390,65])


%     Subsystem  ['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode'].

new_system([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],'Location',[157,499,740,659])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/out_2']],...
		'Port','2',...
		'position',[495,95,515,115])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/out_1']],...
		'position',[495,30,515,50])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Demux']],...
		'outputs','[k, 1]',...
		'position',[395,40,435,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/in_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Mux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Mux']],...
		'inputs','[n, 1]',...
		'position',[80,41,115,74])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/S-function']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/S-function']],...
		'function name','simbchdc',...
		'parameters','n, k, t,tp,dim',...
		'position',[170,20,235,40])

add_block('built-in/Switch',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Switch']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Switch']],...
		'Threshold','0.5',...
		'position',[295,44,325,76])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Memory']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,k+1)',...
		'position',[295,95,335,125])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[440,65;455,65;455,105;490,105])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[330,60;390,60])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[360,60;360,110;340,110])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);BCH de',...
		'Mask Type','Vector I/O BCH decode')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'Mask Dialogue','Codeword length N, message length K, T\nerror-correction BCH decode. (N,K,T) must be a valid BCH code combination.|Codeword length (N=2^M-1. M is a >2 integer):|Message length K (check BCHPOLY for valid K):|Error-correction capability (0 for unknown):')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'Mask Translate','n=@1;k=@2;t=@3;if t<=0, [x1,x2,x3,x4,t]=bchpoly(n,k);end;dim=3;pow_dim=7;while pow_dim<n,dim=dim+1;pow_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using BCH code. The block refreshes its decoding output only if the enable signal at the second inport is high. The second outport outputs the error detected in the process. A negative output indicates more error than the capability.')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'Mask Entries','n\/k\/t\/')


%     Finished composite block ['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode'].

set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'position',[275,26,345,64])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[155,90;160,90;160,55;180,55])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[245,55;270,55])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[245,55;260,55;260,100;415,100;415,50;440,50])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[245,35;270,35])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[350,55;365,55])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[350,35;440,35])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[125,35;180,35])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[90,100;105,100])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[510,40;555,40])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[155,105;425,105;425,65;440,65])
set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'Mask Display','plot(0,0,100,100,x,y);BCH de',...
		'Mask Type','Sequence I/O BCH decode')
set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'Mask Dialogue','BCH decode with codeword length N,\nmessage length K, and error-correction capability T. (N,K,T) must be a valid BCH code combination.|Codeword length N (N=2^M-1. M is a >2 integer):|Message length K (check BCHPOLY for valid K):|Error-correction capability T (0 for unknown):|Output sample time T_out (sec):')
set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'Mask Translate','n=@1;k=@2;t=@3;samp=@4;[x,y]=codeicon(4);')
set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'Mask Help','This block decodes length N binary codeword into length K message using BCH code. The block uses sequential input/output format. The input sequence sample time is K*T_out/N. The block causes a K*T_out delay. The second outport outputs the number of errors detected in the process. A negative value indicates the block found more error in the codeword than T.')
set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'Mask Entries','15\/5\/3\/1/5\/')


%     Finished composite block ['Binary sequence',13,'BCH decode'].

set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'position',[165,133,245,177])


%     Subsystem  ['Sequence BCH',13,'Co//Dec demo'].

new_system([sys,'/',['Sequence BCH',13,'Co//Dec demo']])
set_param([sys,'/',['Sequence BCH',13,'Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Sequence BCH',13,'Co//Dec demo']],...
		'Mask Display','Sequence\nco/dec\ndemo',...
		'Mask Dialogue','eval(''N_bch_demo=15;K_bch_demo=5;T_bch_demo=3;tstbchsq'')')


%     Finished composite block ['Sequence BCH',13,'Co//Dec demo'].

set_param([sys,'/',['Sequence BCH',13,'Co//Dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,133,375,177])


%     Subsystem  ['Vector BCH',13,'Co//Dec demo1'].

new_system([sys,'/',['Vector BCH',13,'Co//Dec demo1']])
set_param([sys,'/',['Vector BCH',13,'Co//Dec demo1']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector BCH',13,'Co//Dec demo1']],...
		'Mask Display','Vector\nco/dec\ndemo2',...
		'Mask Dialogue','eval(''tutbchcd'')')


%     Finished composite block ['Vector BCH',13,'Co//Dec demo1'].

set_param([sys,'/',['Vector BCH',13,'Co//Dec demo1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[425,58,505,102])


%     Subsystem  ['Binary vector',13,'BCH encode'].

new_system([sys,'/',['Binary vector',13,'BCH encode']])
set_param([sys,'/',['Binary vector',13,'BCH encode']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'BCH encode/out_1']])
set_param([sys,'/',['Binary vector',13,'BCH encode/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'BCH encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'BCH encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulus operation:|Modulus base:')
set_param([sys,'/',['Binary vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'BCH encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'BCH encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'BCH encode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'BCH encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'BCH encode/in_1']])
set_param([sys,'/',['Binary vector',13,'BCH encode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary vector',13,'BCH encode']],[245,45;285,45])
add_line([sys,'/',['Binary vector',13,'BCH encode']],[140,45;175,45])
add_line([sys,'/',['Binary vector',13,'BCH encode']],[55,45;105,45])
set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'Mask Display','plot(0,0,100,100,x,y);BCH en',...
		'Mask Type','Vector I/O BCH encode')
set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'Mask Dialogue','BCH encode with input message vector\nlength K and output codeword vector length\nN. (N, K) must be a valid BCH code pair.|Codeword length N (N=2^M-1. M is a >2 integer):|Message length K (check BCHPOLY for valid K):')
set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'Mask Translate','n=@1;k=@2;pg = bchpoly(n,k);[h,G]=cyclgen(n,pg);G=G'';[x,y]=codeicon(1);')
set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using BCH code. Use function BCHPOLY to view the valid N, K, and error-corr ection capability T combination.')
set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'Mask Entries','15\/5\/')


%     Finished composite block ['Binary vector',13,'BCH encode'].

set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'position',[35,58,115,102])


%     Subsystem  ['Binary sequence',13,'BCH encode'].

new_system([sys,'/',['Binary sequence',13,'BCH encode']])
set_param([sys,'/',['Binary sequence',13,'BCH encode']],'Location',[248,302,892,459])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/out_2']],...
		'Port','2',...
		'position',[535,45,555,65])


%     Subsystem  ['Binary sequence',13,'BCH encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'Mask Entries','n\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'BCH encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[445,28,505,62])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/out_1']],...
		'position',[575,30,595,50])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Demux']],...
		'outputs','2',...
		'position',[140,80,180,115])


%     Subsystem  ['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k, n]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[45,81,105,119])


%     Subsystem  ['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode'].

new_system([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],[245,45;285,45])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],[140,45;175,45])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],[55,45;105,45])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'Mask Display','BCH\nencode',...
		'Mask Type','BCH encoding')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'Mask Dialogue','Code word N, message length K multi-error-correction BCH code.|Code length (N=2^M-1. M is a >2 integer):|Message length (check BCHPOLY for valid number):')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'Mask Translate','n=@1; k=@2; pg = bchpoly(n,k);[h,G]=cyclgen(n,pg); G=G'';')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'Mask Help','This block encodes the K-ary binary message signal into N-ary binary code word using BCH code. Use MATLAB command BCHPOLY to view the valid code-word length N and message length K combination.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'Mask Entries','n\/k\/')


%     Finished composite block ['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode'].

set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'BackGround',5,...
		'position',[340,15,400,55])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/in_1']],...
		'position',[55,25,75,45])


%     Subsystem  ['Binary sequence',13,'BCH encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[55,80;75,80])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'BCH encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'BackGround',3,...
		'position',[230,26,285,59])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[510,55;530,55])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[510,40;570,40])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[405,35;440,35])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[290,35;335,35])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[80,35;225,35])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[290,50;305,50;305,85;410,85;410,45;440,45])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[110,100;135,100])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[185,90;195,90;195,50;225,50])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[185,105;420,105;420,55;440,55])
set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);BCH en',...
		'Mask Type','Sequence I/O BCH encode')
set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'Mask Dialogue','BCH encode with codeword length N,\nand message length K. (N, K) must be a valid BCH code pair.|Codeword length N (N=2^M-1. M is a >2 integer):|Message length K (check BCHPOLY for valid K):|Input sample time T_in (sec):')
set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'Mask Translate','n=@1;k=@2;samp=@3;[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'Mask Help','This block encodes length K binary message into length N binary codeword using BCH code. The block uses sequence input/output format. The output sequential sample time is K*T_in/N. The block causes a K*T_in delay. The second outport outputs a pulse when Kth message signal is received. Use function BCHPOLY to view the valid N, K, and error-corr ection capability T combination.')
set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'Mask Entries','15\/5\/1/5\/')


%     Finished composite block ['Binary sequence',13,'BCH encode'].

set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'position',[35,133,115,177])


%     Subsystem  ['BCH code',13,'length table'].

new_system([sys,'/',['BCH code',13,'length table']])
set_param([sys,'/',['BCH code',13,'length table']],'Location',[-10,380,117,533])
set_param([sys,'/',['BCH code',13,'length table']],...
		'Mask Display','BCH code\nview table',...
		'Mask Dialogue','eval(''bchpoly'')')


%     Finished composite block ['BCH code',13,'length table'].

set_param([sys,'/',['BCH code',13,'length table']],...
		'BackGround',5,...
		'hide name',0,...
		'position',[425,133,505,177])

add_block('built-in/Note',[sys,'/','BCH Coding//Decoding Library'])
set_param([sys,'/','BCH Coding//Decoding Library'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[280,15,285,20])
add_line(sys,[120,145;135,145;135,155;160,155])
add_line(sys,[120,80;140,80;140,70;160,70])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
