function [ret,x0,str,ts,xts]=comcdcon(t,x,u,flag);
%COMCDCON	is the M-file description of the SIMULINK system named COMCDCON.
%	The block-diagram can be displayed by typing: COMCDCON.
%
%	SYS=COMCDCON(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COMCDCON to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COMCDCON with a FLAG of zero:
%	[SIZES]=COMCDCON([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[188,291,1004,517])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','Convolution Coding//Decoding Library'])
set_param([sys,'/','Convolution Coding//Decoding Library'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[245,5,250,10])


%     Subsystem  ['Vector convolution',13,'co//dec demo2'].

new_system([sys,'/',['Vector convolution',13,'co//dec demo2']])
set_param([sys,'/',['Vector convolution',13,'co//dec demo2']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector convolution',13,'co//dec demo2']],...
		'Mask Display','Convolution\nco/dec\ndemo',...
		'Mask Dialogue','eval(''exconvcd;tf=sim2tran(''''exconvcd'''');tutconcd'')')


%     Finished composite block ['Vector convolution',13,'co//dec demo2'].

set_param([sys,'/',['Vector convolution',13,'co//dec demo2']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[425,58,505,102])


%     Subsystem  ['Vector convolution',13,'co//dec demo'].

new_system([sys,'/',['Vector convolution',13,'co//dec demo']])
set_param([sys,'/',['Vector convolution',13,'co//dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector convolution',13,'co//dec demo']],...
		'Mask Display','Convolution\nco/dec\ndemo',...
		'Mask Dialogue','eval(''fig_10_9;tf=sim2tran(''''fig_10_9'''');N_con_demo=tf(1,size(tf,2));K_con_demo=tf(2,size(tf,2));tstconcd'')')


%     Finished composite block ['Vector convolution',13,'co//dec demo'].

set_param([sys,'/',['Vector convolution',13,'co//dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,58,375,102])


%     Subsystem  ['Sequence convolution',13,'co//dec demo'].

new_system([sys,'/',['Sequence convolution',13,'co//dec demo']])
set_param([sys,'/',['Sequence convolution',13,'co//dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Sequence convolution',13,'co//dec demo']],...
		'Mask Display','Convolution\nco/dec\ndemo',...
		'Mask Dialogue','eval(''fig_10_9;tf=sim2tran(''''fig_10_9'''');leng=10;tstconsq'')')


%     Finished composite block ['Sequence convolution',13,'co//dec demo'].

set_param([sys,'/',['Sequence convolution',13,'co//dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,138,375,182])


%     Subsystem  ['Binary sequence',13,'convolution encode'].

new_system([sys,'/',['Binary sequence',13,'convolution encode']])
set_param([sys,'/',['Binary sequence',13,'convolution encode']],'Location',[65,476,709,633])


%     Subsystem  ['Binary sequence',13,'convolution encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'convolution encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'convolution encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'convolution encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],...
		'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'convolution encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'convolution encode/Register-shift']],...
		'BackGround',3,...
		'position',[230,25,285,65])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/in_1']],...
		'position',[55,25,75,45])


%     Subsystem  ['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k, n]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'convolution encode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[45,81,105,119])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'convolution encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Demux']],...
		'outputs','2',...
		'position',[140,80,180,115])


%     Subsystem  ['Binary sequence',13,'convolution encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],...
		'Mask Entries','n\/0\/1\/.2\/0\/')


%     Finished composite block ['Binary sequence',13,'convolution encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'convolution encode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[445,38,505,72])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/out_1']],...
		'position',[575,40,595,60])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/out_2']],...
		'Port','2',...
		'position',[535,55,555,75])


%     Subsystem  ['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode'].

new_system([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],'Location',[268,346,980,597])

add_block('built-in/Switch',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Switch']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Switch']],...
		'Threshold','.1',...
		'position',[215,70,245,100])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Memory']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Memory']],...
		'ForeGround',2,...
		'x0','zeros(n_st, 1)',...
		'position',[265,70,305,100])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/in_2']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/in_2']],...
		'Port','2',...
		'position',[420,180,440,200])


%     Subsystem  ['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'Mask Entries','thd\/')


%     Finished composite block ['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'BackGround',5,...
		'position',[470,172,525,208])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain2']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain2']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','C',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain2']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','c\/')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain2']],...
		'position',[420,71,445,99])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/out_1']],...
		'position',[690,80,710,100])

add_block('built-in/Switch',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Switch1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Switch1']],...
		'Threshold','.1',...
		'position',[610,74,640,106])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Memory1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Memory1']],...
		'orientation',2,...
		'ForeGround',2,...
		'x0','zeros(1,n)',...
		'position',[610,135,650,165])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Modulo',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Modulo',13,'operation']],...
		'ForeGround',3,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Modulo',13,'operation']],...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Modulo',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Modulo',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[500,65,545,95])

add_block('built-in/Sum',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Sum1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Sum1']],...
		'position',[465,70,485,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Modulo',13,'operation1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Modulo',13,'operation1']],...
		'ForeGround',3,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Modulo',13,'operation1']],...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Modulo',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Modulo',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[345,70,390,100])

add_block('built-in/Sum',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Sum']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Sum']],...
		'position',[155,65,175,85])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','B',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain1']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain1']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','b\/')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain1']],...
		'position',[100,56,125,84])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/in_1']],...
		'position',[25,60,45,80])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain']],...
		'orientation',2,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','A')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain']],...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','a\/')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain']],...
		'position',[240,170,270,200])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain3']])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain3']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','D',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain3']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain3']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode/Matrix',13,'Gain3']],...
		'position',[250,6,275,34])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[530,190;545,190;545,90;605,90])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[545,150;185,150;185,85;210,85])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[445,190;465,190])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[645,90;685,90])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[645,90;665,90;655,150])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[550,80;605,80])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[490,80;495,80])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[50,70;95,70])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[75,70;75,20;245,20])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[605,150;585,150;585,100;605,100])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[450,85;460,85])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[280,20;450,20;460,75])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[130,70;150,70])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[395,85;415,85])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[250,85;260,85])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[310,85;320,85;320,125;195,125;195,95;210,95])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[320,85;340,85])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[180,75;210,75])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[395,85;405,85;405,185;275,185])
add_line([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],[235,185;135,185;135,80;150,80])
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl en',...
		'Mask Type','Vector I/O convolution encode')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],...
		'Mask Dialogue','Convolution encode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Trigger signal threshold:')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],...
		'Mask Translate','tf=@1;[a,b,c,d,n,k,n_st,m]=simviter(tf);thd=@2;[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using convolution code. The block refreshes its register memory and output at the rising edge of the second inport pulse. You can also use a SIMULINK block diagram to define the convolution code transfer function.')
set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],...
		'Mask Entries','tf\/.5\/')


%     Finished composite block ['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode'].

set_param([sys,'/',['Binary sequence',13,'convolution encode/Binary vector',13,'convol encode']],...
		'hide name',0,...
		'position',[325,23,405,67])
add_line([sys,'/',['Binary sequence',13,'convolution encode']],[185,105;420,105;420,65;440,65])
add_line([sys,'/',['Binary sequence',13,'convolution encode']],[185,90;195,90;195,55;225,55])
add_line([sys,'/',['Binary sequence',13,'convolution encode']],[110,100;135,100])
add_line([sys,'/',['Binary sequence',13,'convolution encode']],[290,55;305,55;305,85;410,85;410,55;440,55])
add_line([sys,'/',['Binary sequence',13,'convolution encode']],[80,35;225,35])
add_line([sys,'/',['Binary sequence',13,'convolution encode']],[290,35;320,35])
add_line([sys,'/',['Binary sequence',13,'convolution encode']],[410,45;440,45])
add_line([sys,'/',['Binary sequence',13,'convolution encode']],[510,50;570,50])
add_line([sys,'/',['Binary sequence',13,'convolution encode']],[510,65;530,65])
add_line([sys,'/',['Binary sequence',13,'convolution encode']],[305,55;320,55])
set_param([sys,'/',['Binary sequence',13,'convolution encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl en',...
		'Mask Type','Sequence I/O convolution encode')
set_param([sys,'/',['Binary sequence',13,'convolution encode']],...
		'Mask Dialogue','Convolution encode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Input sample time T_in (sec):')
set_param([sys,'/',['Binary sequence',13,'convolution encode']],...
		'Mask Translate','tf=@1;if isstr(tf), tf=sim2tran(tf);end;n=tf(1,size(tf,2));k=tf(2,size(tf,2));samp=@2;[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'convolution encode']],...
		'Mask Help','This block encodes length K binary message into length K binary codeword using convolutio n code. The block uses sequential input/output format. The output sequence sample time is K*T_in/N. The block causes a K*T_in delay. The second outport outputs a pulse when Kth message signal is received. You can also use a SIMULINK block diagram to define the convolution code transfer function.')
set_param([sys,'/',['Binary sequence',13,'convolution encode']],...
		'Mask Entries','[1 1 1 3;0 1 0 2;0 0 1 1;1 0 1 -Inf]\/1/2\/')


%     Finished composite block ['Binary sequence',13,'convolution encode'].

set_param([sys,'/',['Binary sequence',13,'convolution encode']],...
		'position',[35,138,115,182])


%     Subsystem  'transfer function'.

new_system([sys,'/','transfer function'])
set_param([sys,'/','transfer function'],'Location',[436,197,856,343])
set_param([sys,'/','transfer function'],...
		'Mask Display','Generate\ntran_func',...
		'Mask Dialogue','eval(''fig_10_9; tf = sim2tran(''''fig_10_9'''');N_con_demo=tf(1,size(tf,2));K_con_demo=tf(2,size(tf,2));'')')


%     Finished composite block 'transfer function'.

set_param([sys,'/','transfer function'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[425,140,505,187])


%     Subsystem  ['Vector convolution',13,'co//dec demo3'].

new_system([sys,'/',['Vector convolution',13,'co//dec demo3']])
set_param([sys,'/',['Vector convolution',13,'co//dec demo3']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector convolution',13,'co//dec demo3']],...
		'Mask Display','Convolution\nco/dec\ndemo',...
		'Mask Dialogue','eval(''tutconc2'')')


%     Finished composite block ['Vector convolution',13,'co//dec demo3'].

set_param([sys,'/',['Vector convolution',13,'co//dec demo3']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[540,58,620,102])


%     Subsystem  ['Vector convolution',13,'co//dec demo4'].

new_system([sys,'/',['Vector convolution',13,'co//dec demo4']])
set_param([sys,'/',['Vector convolution',13,'co//dec demo4']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector convolution',13,'co//dec demo4']],...
		'Mask Display','Convolution\nco/dec\ndemo',...
		'Mask Dialogue','eval(''K_con_demo=2;N_con_demo=3;connonli;tf=sim2tran(''''connonli'''');tutconc3'')')


%     Finished composite block ['Vector convolution',13,'co//dec demo4'].

set_param([sys,'/',['Vector convolution',13,'co//dec demo4']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[660,58,740,102])


%     Subsystem  ['Binary vector',13,'convolution encode'].

new_system([sys,'/',['Binary vector',13,'convolution encode']])
set_param([sys,'/',['Binary vector',13,'convolution encode']],'Location',[214,496,617,630])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convolution encode/in_2']])
set_param([sys,'/',['Binary vector',13,'convolution encode/in_2']],...
		'Port','2',...
		'position',[40,65,60,85])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convolution encode/in_1']])
set_param([sys,'/',['Binary vector',13,'convolution encode/in_1']],...
		'position',[40,20,60,40])


%     Subsystem  ['Binary vector',13,'convolution encode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thd\/')


%     Finished composite block ['Binary vector',13,'convolution encode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary vector',13,'convolution encode/Rising edge',13,'detector']],...
		'position',[90,57,145,93])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'convolution encode/Mux']])
set_param([sys,'/',['Binary vector',13,'convolution encode/Mux']],...
		'inputs','2',...
		'Mask Display','',...
		'position',[190,21,225,54])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'convolution encode/Modulo',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'convolution encode/Modulo',13,'operation1']],...
		'function name','sconvenc',...
		'parameters','tf',...
		'position',[255,25,315,55])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convolution encode/out_1']])
set_param([sys,'/',['Binary vector',13,'convolution encode/out_1']],...
		'position',[350,30,370,50])
add_line([sys,'/',['Binary vector',13,'convolution encode']],[320,40;345,40])
add_line([sys,'/',['Binary vector',13,'convolution encode']],[65,30;185,30])
add_line([sys,'/',['Binary vector',13,'convolution encode']],[65,75;85,75])
add_line([sys,'/',['Binary vector',13,'convolution encode']],[150,75;160,75;160,45;185,45])
add_line([sys,'/',['Binary vector',13,'convolution encode']],[230,40;250,40])
set_param([sys,'/',['Binary vector',13,'convolution encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl en',...
		'Mask Type','Vector I/O convolution encode')
set_param([sys,'/',['Binary vector',13,'convolution encode']],...
		'Mask Dialogue','Convolution encode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Trigger signal threshold:')
set_param([sys,'/',['Binary vector',13,'convolution encode']],...
		'Mask Translate','tf=@1;tf=simviter(tf);thd=@2;[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Binary vector',13,'convolution encode']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using convolution code. The block refreshes its register memory and output at the rising edge of the second inport pulse. You can also use a SIMULINK block diagram to define the convolution code transfer function.')
set_param([sys,'/',['Binary vector',13,'convolution encode']],...
		'Mask Entries','[1 1 1 3;0 1 0 2;0 0 1 1;1 0 1 -Inf]\/.5\/')


%     Finished composite block ['Binary vector',13,'convolution encode'].

set_param([sys,'/',['Binary vector',13,'convolution encode']],...
		'position',[35,63,115,107])


%     Subsystem  ['Binary sequence',13,'convolution decode'].

new_system([sys,'/',['Binary sequence',13,'convolution decode']])
set_param([sys,'/',['Binary sequence',13,'convolution decode']],'Location',[319,153,929,306])


%     Subsystem  ['Binary sequence',13,'convolution decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],...
		'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'convolution decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'convolution decode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'hide name',0,...
		'position',[445,28,505,72])


%     Subsystem  ['Binary sequence',13,'convolution decode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution decode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution decode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'convolution decode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'convolution decode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'convolution decode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution decode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift/in_1']],...
		'position',[10,55,30,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution decode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],[65,80;75,80])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],[35,65;75,65])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],...
		'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'convolution decode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'convolution decode/Register-shift']],...
		'BackGround',3,...
		'hide name',0,...
		'position',[185,25,240,65])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution decode/sequential',13,'code-word-in']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/sequential',13,'code-word-in']],...
		'position',[100,25,120,45])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution decode/sequential',13,'message-out']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/sequential',13,'message-out']],...
		'position',[560,30,580,50])


%     Subsystem  ['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n, k]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'convolution decode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[25,81,85,119])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'convolution decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Demux']],...
		'hide name',0,...
		'outputs','2',...
		'position',[110,80,150,115])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution decode/out_2']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/out_2']],...
		'Port','2',...
		'position',[375,45,395,65])


%     Subsystem  ['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2'].

new_system([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],'Location',[719,297,1227,483])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/in_1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/in_1']],...
		'position',[65,35,85,55])


%     Subsystem  ['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector'].

new_system([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],...
		'Mask Entries','thd\/')


%     Finished composite block ['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector'].

set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Rising edge',13,'detector']],...
		'position',[75,112,130,148])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Mux']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Mux']],...
		'inputs','[tf(1,size(tf,2)), 1]',...
		'Mask Display','',...
		'position',[170,36,205,69])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Modulo',13,'operation1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Modulo',13,'operation1']],...
		'function name','sviterbi',...
		'parameters','tf, leng, tran_prob, plot_flag,v1,v2,v3,v4')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Modulo',13,'operation1']],...
		'position',[235,40,280,70])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/out_2']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/out_2']],...
		'Port','2',...
		'position',[445,65,465,85])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/out_1']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/out_1']],...
		'position',[405,35,425,55])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Demux']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/Demux']],...
		'outputs','[tf(2,size(tf,2)), 1]',...
		'position',[305,35,345,70])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/in_2']])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2/in_2']],...
		'Port','2',...
		'position',[30,120,50,140])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],[55,130;70,130])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],[285,55;300,55])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],[350,45;400,45])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],[350,60;375,60;375,75;440,75])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],[210,55;230,55])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],[90,45;165,45])
add_line([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],[135,130;140,130;140,60;165,60])
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl de',...
		'Mask Type','Vector I/O convolution decode')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],...
		'Mask Dialogue','Convolution decode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Path memory length (delay=path_length*K*T_out):|Transfer probability (3 row matrix, 0 for hard decision):|Trellis figure plot length (0 for no plot):|Trigger signal threshold:')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],...
		'Mask Translate','gen=@1;leng=@2;tran_prob=@3;plot_flag=@4;thd=@5;[tf,v2,v3,v4,v5,v6,M,nss]=simviter(gen);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);v1=zeros(7,1);v2=zeros(nss,1);v3=zeros(nss^2*leng,1);v4=zeros(nss,1);tf=simviter(gen);')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],...
		'Mask Help','This block decodes length N binary vector convolution code codeword into length K binary vector message using Viterbi algorithm. The block refreshes its register memory and decoding output at the rising edge of the second inport pulse. The second outport outputs the metric value for soft decision or the accumulative distance for hard\ndecision.')
set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],...
		'Mask Entries','gen\/leng\/tran_prob\/plot_flag\/.5\/')


%     Finished composite block ['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2'].

set_param([sys,'/',['Binary sequence',13,'convolution decode/Binary vector',13,'convol decode2']],...
		'hide name',0,...
		'position',[275,23,355,67])
add_line([sys,'/',['Binary sequence',13,'convolution decode']],[155,105;425,105;425,65;440,65])
add_line([sys,'/',['Binary sequence',13,'convolution decode']],[510,40;555,40])
add_line([sys,'/',['Binary sequence',13,'convolution decode']],[90,100;105,100])
add_line([sys,'/',['Binary sequence',13,'convolution decode']],[125,35;180,35])
add_line([sys,'/',['Binary sequence',13,'convolution decode']],[360,35;440,35])
add_line([sys,'/',['Binary sequence',13,'convolution decode']],[360,55;370,55])
add_line([sys,'/',['Binary sequence',13,'convolution decode']],[245,35;270,35])
add_line([sys,'/',['Binary sequence',13,'convolution decode']],[245,55;270,55])
add_line([sys,'/',['Binary sequence',13,'convolution decode']],[255,55;255,100;415,100;415,50;440,50])
add_line([sys,'/',['Binary sequence',13,'convolution decode']],[155,90;160,90;160,55;180,55])
set_param([sys,'/',['Binary sequence',13,'convolution decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Convl de',...
		'Mask Type','Sequence I/O convolution decode')
set_param([sys,'/',['Binary sequence',13,'convolution decode']],...
		'Mask Dialogue','Convolution decode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Path memory length (delay=path_length*K*T_out):|Transfer probability (3 row matrix, 0 for hard decision):|Trellis figure plot length (0 for no plot):|Output sample time T_out (sec):')
set_param([sys,'/',['Binary sequence',13,'convolution decode']],...
		'Mask Translate','gen=@1;if isstr(gen),gen=sim2tran(gen);end;k=gen(2,size(gen,2));n=gen(1,size(gen,2));leng=@2;tran_prob=@3;plot_flag=@4;samp=@5;[x,y]=codeicon(4);')
set_param([sys,'/',['Binary sequence',13,'convolution decode']],...
		'Mask Help','This block decodes length N binary convolution code codeword into length K message using Viterbi algorithm. The block uses sequence input/output format. The input sequential sample time is T_out*K/N. The block causes a K*T_out delay. The second outport outputs the metric value for soft decision or the accumulative distance for hard decision.')
set_param([sys,'/',['Binary sequence',13,'convolution decode']],...
		'Mask Entries','[1 1 1 3;0 1 0 2;0 0 1 1;1 0 1 -Inf]\/5\/0\/10\/1/2\/')


%     Finished composite block ['Binary sequence',13,'convolution decode'].

set_param([sys,'/',['Binary sequence',13,'convolution decode']],...
		'position',[160,138,240,182])


%     Subsystem  ['Binary vector',13,'convolution decode'].

new_system([sys,'/',['Binary vector',13,'convolution decode']])
set_param([sys,'/',['Binary vector',13,'convolution decode']],'Location',[719,297,1227,483])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convolution decode/in_2']])
set_param([sys,'/',['Binary vector',13,'convolution decode/in_2']],...
		'Port','2',...
		'position',[30,120,50,140])

add_block('built-in/Demux',[sys,'/',['Binary vector',13,'convolution decode/Demux']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Demux']],...
		'outputs','[tf(2,size(tf,2)), 1]',...
		'position',[305,35,345,70])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convolution decode/out_1']])
set_param([sys,'/',['Binary vector',13,'convolution decode/out_1']],...
		'position',[405,35,425,55])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convolution decode/out_2']])
set_param([sys,'/',['Binary vector',13,'convolution decode/out_2']],...
		'Port','2',...
		'position',[445,65,465,85])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'convolution decode/Modulo',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Modulo',13,'operation1']],...
		'function name','sviterbi',...
		'parameters','tf, leng, tran_prob, plot_flag,v1,v2,v3,v4',...
		'position',[235,40,280,70])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'convolution decode/Mux']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Mux']],...
		'inputs','[tf(1,size(tf,2)), 1]',...
		'Mask Display','',...
		'position',[170,36,205,69])


%     Subsystem  ['Binary vector',13,'convolution decode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thd\/')


%     Finished composite block ['Binary vector',13,'convolution decode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary vector',13,'convolution decode/Rising edge',13,'detector']],...
		'position',[75,112,130,148])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convolution decode/in_1']])
set_param([sys,'/',['Binary vector',13,'convolution decode/in_1']],...
		'position',[65,35,85,55])
add_line([sys,'/',['Binary vector',13,'convolution decode']],[135,130;140,130;140,60;165,60])
add_line([sys,'/',['Binary vector',13,'convolution decode']],[90,45;165,45])
add_line([sys,'/',['Binary vector',13,'convolution decode']],[210,55;230,55])
add_line([sys,'/',['Binary vector',13,'convolution decode']],[350,60;375,60;375,75;440,75])
add_line([sys,'/',['Binary vector',13,'convolution decode']],[350,45;400,45])
add_line([sys,'/',['Binary vector',13,'convolution decode']],[285,55;300,55])
add_line([sys,'/',['Binary vector',13,'convolution decode']],[55,130;70,130])
set_param([sys,'/',['Binary vector',13,'convolution decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl de',...
		'Mask Type','Vector I/O convolution decode')
set_param([sys,'/',['Binary vector',13,'convolution decode']],...
		'Mask Dialogue','Convolution decode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Path memory length (delay=path_length*K*T_out):|Transfer probability (3 row matrix, 0 for hard decision):|Trellis figure plot length (0 for no plot):|Trigger signal threshold:')
set_param([sys,'/',['Binary vector',13,'convolution decode']],...
		'Mask Translate','gen=@1;leng=@2;tran_prob=@3;plot_flag=@4;thd=@5;[tf,v2,v3,v4,v5,v6,M,nss]=simviter(gen);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);v1=zeros(7,1);v2=zeros(nss,1);v3=zeros(nss^2*leng,1);v4=zeros(nss,1);tf=simviter(gen);')
set_param([sys,'/',['Binary vector',13,'convolution decode']],...
		'Mask Help','This block decodes length N binary vector convolution code codeword into length K binary vector message using Viterbi algorithm. The block refreshes its register memory and decoding output at the rising edge of the second inport pulse. The second outport outputs the metric value for soft decision or the accumulative distance for hard\ndecision.')
set_param([sys,'/',['Binary vector',13,'convolution decode']],...
		'Mask Entries','[1 1 1 3;0 1 0 2;0 0 1 1;1 0 1 -Inf]\/10\/0\/18\/.5\/')


%     Finished composite block ['Binary vector',13,'convolution decode'].

set_param([sys,'/',['Binary vector',13,'convolution decode']],...
		'position',[160,58,240,102])
add_line(sys,[120,85;130,85;130,70;155,70])
add_line(sys,[120,150;130,150;130,160;155,160])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
