function [ret,x0,str,ts,xts]=comcdcyc(t,x,u,flag);
%COMCDCYC	is the M-file description of the SIMULINK system named COMCDCYC.
%	The block-diagram can be displayed by typing: COMCDCYC.
%
%	SYS=COMCDCYC(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COMCDCYC to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COMCDCYC with a FLAG of zero:
%	[SIZES]=COMCDCYC([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[136,428,554,655])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','Cyclic Coding//Decoding Library'])
set_param([sys,'/','Cyclic Coding//Decoding Library'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[200,10,205,15])


%     Subsystem  ['Vector cyclic',13,'co//dec demo'].

new_system([sys,'/',['Vector cyclic',13,'co//dec demo']])
set_param([sys,'/',['Vector cyclic',13,'co//dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector cyclic',13,'co//dec demo']],...
		'Mask Display','Cyclic\nco/dec\ndemo',...
		'Mask Dialogue','eval(''tstcyclc'')')


%     Finished composite block ['Vector cyclic',13,'co//dec demo'].

set_param([sys,'/',['Vector cyclic',13,'co//dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[290,58,370,102])


%     Subsystem  ['Binary vector',13,'cyclic encode'].

new_system([sys,'/',['Binary vector',13,'cyclic encode']])
set_param([sys,'/',['Binary vector',13,'cyclic encode']],'Location',[235,592,599,711])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'cyclic encode/in_1']])
set_param([sys,'/',['Binary vector',13,'cyclic encode/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'cyclic encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'cyclic encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'cyclic encode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'cyclic encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'cyclic encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'cyclic encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'cyclic encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'cyclic encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'cyclic encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'cyclic encode/out_1']])
set_param([sys,'/',['Binary vector',13,'cyclic encode/out_1']],...
		'position',[290,35,310,55])
add_line([sys,'/',['Binary vector',13,'cyclic encode']],[55,45;105,45])
add_line([sys,'/',['Binary vector',13,'cyclic encode']],[140,45;175,45])
add_line([sys,'/',['Binary vector',13,'cyclic encode']],[245,45;285,45])
set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'Mask Display','plot(0,0,100,100,x,y);Cyclic en',...
		'Mask Type','Vector I/O cyclic encode')
set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'Mask Dialogue','Cyclic encode with codeword length N\nand message length K.|Codeword length N:|Message length K, or generator polynomial Pg:')
set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'Mask Translate','n=@1;p=@2;if length(p)==1,p=cyclpoly(n,p,''min'');if isempty(p),error(''No such cyclic code exist'');end;end;[h,G]=cyclgen(n, p);G=G'';[x,y]=codeicon(1);')
set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using cyclic code. When Pg is specified instead of K, the block uses the user-defined cyclic polynomial Pg. Use function CYCLPOLY for a list of cyclic generator polynomials.')
set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'Mask Entries','7\/4\/')


%     Finished composite block ['Binary vector',13,'cyclic encode'].

set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'position',[50,58,130,102])


%     Subsystem  ['Binary vector',13,'cyclic decode'].

new_system([sys,'/',['Binary vector',13,'cyclic decode']])
set_param([sys,'/',['Binary vector',13,'cyclic decode']],'Location',[267,160,850,320])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'cyclic decode/in_1']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary vector',13,'cyclic decode/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/Sum',[sys,'/',['Binary vector',13,'cyclic decode/Sum']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain1']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation2']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'cyclic decode/out_1']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/out_1']],...
		'position',[535,90,555,110])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[130,45;135,45])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[205,45;220,45])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[55,45;95,45])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[330,100;335,100])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[405,100;410,100])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[445,100;450,100])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[520,100;530,100])
set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Cyclic de',...
		'Mask Type','Vector I/O cyclic decode')
set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'Mask Dialogue','Cyclic decode with codeword length N\nand message length K.|Codeword length N:|Message length K, or generator polynomial Pg:')
set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'Mask Translate','n=@1;p=@2;if length(p)==1, p=cyclpoly(n,p,''min'');end;if isempty(p),error(''No such cyclic code exist'');end;[H,G]=cyclgen(n,p);trt=htruthtb(G);[n,m]=size(G);G=[zeros(n,m-n),eye(n)];[x,y]=codeicon(2);')
set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using cyclic code. When Pg is specified instead of K, the block uses the user-defined cyclic polynomial Pg. Use function CYCLPOLY for a list of cyclic generator polynomials.')
set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'Mask Entries','7\/4\/')


%     Finished composite block ['Binary vector',13,'cyclic decode'].

set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'position',[170,58,250,102])


%     Subsystem  ['Binary sequence',13,'cyclic decode'].

new_system([sys,'/',['Binary sequence',13,'cyclic decode']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode']],'Location',[197,104,780,264])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic decode/sequential',13,'message-out']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/sequential',13,'message-out']],...
		'position',[530,30,550,50])


%     Subsystem  ['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],...
		'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'cyclic decode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[430,28,490,72])


%     Subsystem  ['Binary sequence',13,'cyclic decode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/in_1']],...
		'position',[10,55,30,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],[65,80;75,80])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],[35,65;75,65])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],...
		'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'cyclic decode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'cyclic decode/Register-shift']],...
		'BackGround',3,...
		'position',[195,25,250,65])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic decode/sequential',13,'code-word-in']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/sequential',13,'code-word-in']],...
		'position',[110,25,130,45])


%     Subsystem  ['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n, k]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'cyclic decode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[35,81,95,119])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'cyclic decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Demux']],...
		'outputs','2',...
		'position',[120,80,160,115])


%     Subsystem  ['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode'].

new_system([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],'Location',[267,160,850,320])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/out_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/out_1']],...
		'position',[535,90,555,110])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation2']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Matrix',13,'Gain1']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Matrix',13,'Gain1']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation1']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/Sum',[sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Sum']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/in_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],[520,100;530,100])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],[445,100;450,100])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],[405,100;410,100])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],[330,100;335,100])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],[55,45;95,45])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],[205,45;220,45])
add_line([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],[130,45;135,45])
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Cyclic de',...
		'Mask Type','Vector I/O cyclic decode')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],...
		'Mask Dialogue','Cyclic decode with codeword length N,\nmessage length K.|Codeword length N:|Message length K, or generator polynomial Pg:')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],...
		'Mask Translate','n=@1;p=@2;if length(p)==1, p=cyclpoly(n,p,''min'');end;if isempty(p),error(''No such cyclic code exist'');end;[H,G]=cyclgen(n,p);trt=htruthtb(G);[n,m]=size(G);G=[zeros(n,m-n),eye(n)];[x,y]=codeicon(2);')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using cyclic code. When Pg is specified instead of K, the block uses the user-defined cyclic polynomial Pg. Use function CYCLPOLY for the choice of cyclic generator polynomials.')
set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],...
		'Mask Entries','n\/p\/')


%     Finished composite block ['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode'].

set_param([sys,'/',['Binary sequence',13,'cyclic decode/Binary vector',13,'cyclic decode']],...
		'position',[285,13,365,57])
add_line([sys,'/',['Binary sequence',13,'cyclic decode']],[165,105;400,105;400,65;425,65])
add_line([sys,'/',['Binary sequence',13,'cyclic decode']],[495,40;525,40])
add_line([sys,'/',['Binary sequence',13,'cyclic decode']],[100,100;115,100])
add_line([sys,'/',['Binary sequence',13,'cyclic decode']],[135,35;190,35])
add_line([sys,'/',['Binary sequence',13,'cyclic decode']],[370,35;425,35])
add_line([sys,'/',['Binary sequence',13,'cyclic decode']],[255,35;280,35])
add_line([sys,'/',['Binary sequence',13,'cyclic decode']],[255,55;270,55;270,90;390,90;390,50;425,50])
add_line([sys,'/',['Binary sequence',13,'cyclic decode']],[165,90;170,90;170,55;190,55])
set_param([sys,'/',['Binary sequence',13,'cyclic decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Cyclic de',...
		'Mask Type','Sequence I/O cyclic decode')
set_param([sys,'/',['Binary sequence',13,'cyclic decode']],...
		'Mask Dialogue','Sequence decode with codeword length N\nand message length K.|Codeword length N:|Message length K, or generator polynomial Pg:|Output sample time T_out (sec):')
set_param([sys,'/',['Binary sequence',13,'cyclic decode']],...
		'Mask Translate','n=@1;p=@2;if length(p)==1, p=cyclpoly(n,p,''min'');end;if isempty(p),error(''No such cyclic code exist'');end;k=n-length(p)+1;samp=@3;[x,y]=codeicon(4);')
set_param([sys,'/',['Binary sequence',13,'cyclic decode']],...
		'Mask Help','This block decodes length N binary codeword into length K message using cyclic code. The block uses sequential input/output format. Use function CYCLPOLY for a list of cyclic generator polynomials. The input sequence sample time is K*T_out/N. The block causes a K*T_out delay.')
set_param([sys,'/',['Binary sequence',13,'cyclic decode']],...
		'Mask Entries','7\/4\/1/4\/')


%     Finished composite block ['Binary sequence',13,'cyclic decode'].

set_param([sys,'/',['Binary sequence',13,'cyclic decode']],...
		'position',[170,138,250,182])


%     Subsystem  ['Sequence cyclic',13,'co//dec demo'].

new_system([sys,'/',['Sequence cyclic',13,'co//dec demo']])
set_param([sys,'/',['Sequence cyclic',13,'co//dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Sequence cyclic',13,'co//dec demo']],...
		'Mask Display','Cyclic\nco/dec\ndemo',...
		'Mask Dialogue','eval(''N_cyc_demo=7;K_cyc_demo=4;tstcycsq'')')


%     Finished composite block ['Sequence cyclic',13,'co//dec demo'].

set_param([sys,'/',['Sequence cyclic',13,'co//dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[290,138,370,182])


%     Subsystem  ['Binary sequence',13,'cyclic encode'].

new_system([sys,'/',['Binary sequence',13,'cyclic encode']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode']],'Location',[149,109,788,279])


%     Subsystem  ['Binary sequence',13,'cyclic encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],...
		'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'cyclic encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'cyclic encode/Register-shift']],...
		'BackGround',3,...
		'position',[220,26,275,59])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/in_1']],...
		'position',[45,25,65,45])


%     Subsystem  ['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k, n]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'cyclic encode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[35,81,95,119])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'cyclic encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Demux']],...
		'outputs','2',...
		'position',[130,80,170,115])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/out_1']],...
		'position',[565,30,585,50])


%     Subsystem  ['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],...
		'Mask Entries','n\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'cyclic encode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[435,28,495,62])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/out_2']],...
		'Port','2',...
		'position',[525,45,545,65])


%     Subsystem  ['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode'].

new_system([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']],[245,45;285,45])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']],[140,45;175,45])
add_line([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']],[55,45;105,45])
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']],...
		'Mask Display','Cyclic\nencode',...
		'Mask Type','Cyclic encoding')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']],...
		'Mask Dialogue','Cyclic encoding:|Code word length:|Generator polynomial or message length:')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']],...
		'Mask Translate','n=@1;p=@2;if length(p)==1,p=cyclpoly(n,p,''min'');if isempty(p),error(''No such cyclic code exist'');end;end;[h,G]=cyclgen(n, p);G=G'';')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']],...
		'Mask Help','This block encodes the input binary signal using cyclic coding method. Let k=code_word_length - degree_of_generator_poly. The input of this block is a k-array binary message vector. The output of this block is an n-array binary code word vector. If the entry for "Generator polynomial" is a number instead of polynomial, the number is taken as the message length (input vector length).')
set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']],...
		'Mask Entries','n\/p\/')


%     Finished composite block ['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode'].

set_param([sys,'/',['Binary sequence',13,'cyclic encode/Binary-vector',13,'Cyclic encode']],...
		'position',[320,15,385,55])
add_line([sys,'/',['Binary sequence',13,'cyclic encode']],[175,105;410,105;410,55;430,55])
add_line([sys,'/',['Binary sequence',13,'cyclic encode']],[175,90;185,90;185,50;215,50])
add_line([sys,'/',['Binary sequence',13,'cyclic encode']],[100,100;125,100])
add_line([sys,'/',['Binary sequence',13,'cyclic encode']],[280,50;295,50;295,85;400,85;400,45;430,45])
add_line([sys,'/',['Binary sequence',13,'cyclic encode']],[70,35;215,35])
add_line([sys,'/',['Binary sequence',13,'cyclic encode']],[280,35;315,35])
add_line([sys,'/',['Binary sequence',13,'cyclic encode']],[390,35;430,35])
add_line([sys,'/',['Binary sequence',13,'cyclic encode']],[500,40;560,40])
add_line([sys,'/',['Binary sequence',13,'cyclic encode']],[500,55;520,55])
set_param([sys,'/',['Binary sequence',13,'cyclic encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Cyclic en',...
		'Mask Type','Sequence I/O cyclic encode')
set_param([sys,'/',['Binary sequence',13,'cyclic encode']],...
		'Mask Dialogue','Cyclic encode with codeword length N\nand message length K.|Codeword length N:|Message length K, or generator polynomial Pg:|Input sample time T_in (sec):')
set_param([sys,'/',['Binary sequence',13,'cyclic encode']],...
		'Mask Translate','n=@1;p=@2;if length(p)==1,p=cyclpoly(n,p,''min'');if isempty(p),error(''No such cyclic code exist'');end;end;k=n-length(p)+1;samp=@3;[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'cyclic encode']],...
		'Mask Help','This block encodes length K binary message into length N binary codeword using cyclic code. The block uses sequential input/output format. The output sequence sample time is K*T_in/N. The block causes a K*T_in delay. The second outport outputs a pulse when Kth message signal is received. Use function CYCLPOLY for a list of cyclic generator polynomials.')
set_param([sys,'/',['Binary sequence',13,'cyclic encode']],...
		'Mask Entries','7\/4\/1/4\/')


%     Finished composite block ['Binary sequence',13,'cyclic encode'].

set_param([sys,'/',['Binary sequence',13,'cyclic encode']],...
		'position',[50,138,130,182])
add_line(sys,[135,80;165,80])
add_line(sys,[135,150;145,150;145,160;165,160])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
