function [ret,x0,str,ts,xts]=comcdham(t,x,u,flag);
%COMCDHAM	is the M-file description of the SIMULINK system named COMCDHAM.
%	The block-diagram can be displayed by typing: COMCDHAM.
%
%	SYS=COMCDHAM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COMCDHAM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COMCDHAM with a FLAG of zero:
%	[SIZES]=COMCDHAM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[28,110,432,342])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Binary sequence',13,'Hamming encode'].

new_system([sys,'/',['Binary sequence',13,'Hamming encode']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],'Location',[68,475,675,670])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/out_2']],...
		'Port','2',...
		'position',[535,55,555,75])


%     Subsystem  ['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'Mask Entries','n\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[445,38,505,72])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/out_1']],...
		'position',[575,40,595,60])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Demux']],...
		'outputs','2',...
		'position',[140,90,180,125])


%     Subsystem  ['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k, n]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[45,91,105,129])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/in_1']],...
		'position',[55,35,75,55])


%     Subsystem  ['Binary sequence',13,'Hamming encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[55,80;75,80])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'Hamming encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'BackGround',3,...
		'position',[230,36,285,69])


%     Subsystem  ['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode'].

new_system([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],'Location',[235,592,599,711])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/out_1']],...
		'position',[290,35,310,55])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],[55,45;105,45])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],[140,45;175,45])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],[245,45;285,45])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'Mask Display','Hamming\nencode',...
		'Mask Type','Hamming encoding')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'Mask Dialogue','Single error-correction Hamming encode. For integer M>2, N=2^M-1; K=2^M-M-1.|Code-word length N:|Message length K or M-degree primitive polynomial:')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,p=k; k=n-length(k)+1;else,p=gfprimdf(n-k);end;[h,G]=hammgen(n-k,p);G=G'';')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'Mask Help','This block encodes the input binary signal using Hamming coding method.  The code length is N=2^M-1. The message length should be K=2^M-M-1. M is a integer no less than 3. The second entree of this block could also be a M-degree primitive polynomial, which can be found by using commands gfprimfd or gfprimdf. This block takes K-ary binary message input and results N-ary binary code-word output.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'Mask Entries','n\/p\/')


%     Finished composite block ['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode'].

set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'position',[330,25,395,65])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[510,65;530,65])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[510,50;570,50])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[400,45;440,45])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[290,45;325,45])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[80,45;225,45])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[290,60;305,60;305,95;410,95;410,55;440,55])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[110,110;135,110])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[185,100;195,100;195,60;225,60])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[185,115;420,115;420,65;440,65])
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Hamming en',...
		'Mask Type','Sequence I/O Hamming encode')
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'Mask Dialogue','Single error-correction Hamming encode with codeword length N=2^M-1, message length K=2^M-M-1, where M is a >=3 integer.|Codeword length N:|Message length K, or M-degree primitive polynomial:|Input sample time T_in (sec):')
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'Mask Translate','n=@1;k=@2;samp=@3;if length(k)>1,p=k;k=n-length(k)+1;else,p=gfprimdf(n-k);end;[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'Mask Help','This block encodes length K binary message into length N binary codeword using Hamming code. The block uses sequential input/output format. The output sequence sample time is K*T_in/N. The block causes a K*T_in delay. The second outport outputs a pulse when Kth message signal is received. Use function GFPRIMDF or GFPRIMFD to find M-degree\nprimitive polynomials.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'Mask Entries','7\/gfprimfd(3,''min'')\/1/4\/')


%     Finished composite block ['Binary sequence',13,'Hamming encode'].

set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'position',[35,143,115,187])


%     Subsystem  ['Binary vector',13,'Hamming decode'].

new_system([sys,'/',['Binary vector',13,'Hamming decode']])
set_param([sys,'/',['Binary vector',13,'Hamming decode']],'Location',[267,160,850,320])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'Hamming decode/out_1']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/out_1']],...
		'position',[535,90,555,110])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation2']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/Sum',[sys,'/',['Binary vector',13,'Hamming decode/Sum']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary vector',13,'Hamming decode/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'Hamming decode/in_1']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[520,100;530,100])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[445,100;450,100])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[405,100;410,100])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[330,100;335,100])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[55,45;95,45])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[205,45;220,45])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[130,45;135,45])
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Display','plot(0,0,100,100,[1 3 3 1 3 3 1 1 3 3 4 3 15 15 17 15 15 3 15 15 17 17 19 19 17 17 19]*5,[-5 -5 5 5 5 -15 -15 15 15 3 0 -3 -3 -7 0 7 3 3 3 7 0 10 10 -10 -10 0 0]+80);Hamming de')
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Type','Vector I/O Hamming decode')
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Dialogue','Hamming decode with input codeword vector length N=2^M-1, output message vector length K=2^M-M-1, where M is a >=3 integer.|Codeword length N:|Message length K, or M-degree primitive polynomial:')
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,p=k;k=n-length(p)+1;else,p=gfprimdf(n-k);end;[H,G]=hammgen(n-k,p);trt=htruthtb(G);[n,m]=size(G);G=[zeros(n,m-n),eye(n)];')
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using Hamming code. Use\nfunction GFPRIMDF or GFPRIMFD to find M-degree primitive polynomials.')
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Entries','7\/gfprimfd(3,''min'')\/')


%     Finished composite block ['Binary vector',13,'Hamming decode'].

set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'position',[165,58,245,102])


%     Subsystem  ['Binary vector',13,'Hamming encode'].

new_system([sys,'/',['Binary vector',13,'Hamming encode']])
set_param([sys,'/',['Binary vector',13,'Hamming encode']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'Hamming encode/out_1']])
set_param([sys,'/',['Binary vector',13,'Hamming encode/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'Hamming encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'Hamming encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'Hamming encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'Hamming encode/in_1']])
set_param([sys,'/',['Binary vector',13,'Hamming encode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary vector',13,'Hamming encode']],[245,45;285,45])
add_line([sys,'/',['Binary vector',13,'Hamming encode']],[140,45;175,45])
add_line([sys,'/',['Binary vector',13,'Hamming encode']],[55,45;105,45])
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Display','plot(0,0,100,100,[1 3 3 1 1 3 3 3 3 4 3 15 15 17 15 15 3 15 15 17 17 19 19 17 17 19 17 17 19]*5,[0 0 10 10 -10 -10 10 0 3 0 -3 -3 -7 0 7 3 3 3 7 0 15 15 -15 -15 5 5 5 -5 -5]+80);Hamming en')
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Type','Vector I/O Hamming encode')
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Dialogue','Hamming encode with input message vector length K=2^M-M-1, output codeword vector length N=2^M-1, where M is a >=3 integer.|Codeword length N:|Message length K, or M-degree primitive polynomial:')
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,p=k;k=n-length(k)+1;else,p=gfprimdf(n-k);end;[h,G]=hammgen(n-k,p);G=G'';')
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using Hamming code. Use function GFPRIMDF or GFPRIMFD to find M-degree primitive polynomials.')
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Entries','7\/gfprimfd(3,''min'')\/')


%     Finished composite block ['Binary vector',13,'Hamming encode'].

set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'position',[35,58,115,102])


%     Subsystem  ['Vector Hamming',13,'Co//Dec demo'].

new_system([sys,'/',['Vector Hamming',13,'Co//Dec demo']])
set_param([sys,'/',['Vector Hamming',13,'Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector Hamming',13,'Co//Dec demo']],...
		'Mask Display','Vector\nco/dec\ndemo',...
		'Mask Dialogue','eval(''tsthammc'')')


%     Finished composite block ['Vector Hamming',13,'Co//Dec demo'].

set_param([sys,'/',['Vector Hamming',13,'Co//Dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,58,375,102])


%     Subsystem  ['Sequential Hamming',13,'Co//Dec demo'].

new_system([sys,'/',['Sequential Hamming',13,'Co//Dec demo']])
set_param([sys,'/',['Sequential Hamming',13,'Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Sequential Hamming',13,'Co//Dec demo']],...
		'Mask Display','Sequence\nco/dec\ndemo',...
		'Mask Dialogue','eval(''N_ham_demo=7;K_ham_demo=4;tsthamsq'')')


%     Finished composite block ['Sequential Hamming',13,'Co//Dec demo'].

set_param([sys,'/',['Sequential Hamming',13,'Co//Dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,143,375,187])


%     Subsystem  ['Binary sequence',13,'Hamming decode'].

new_system([sys,'/',['Binary sequence',13,'Hamming decode']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],'Location',[284,88,882,241])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Demux']],...
		'outputs','2',...
		'position',[130,80,170,115])


%     Subsystem  ['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n, k]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[45,81,105,119])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/sequential',13,'code-word-in']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/sequential',13,'code-word-in']],...
		'position',[120,25,140,45])


%     Subsystem  ['Binary sequence',13,'Hamming decode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/in_1']],...
		'position',[10,55,30,75])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[35,65;75,65])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[65,80;75,80])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'Hamming decode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'BackGround',3,...
		'position',[205,25,260,65])


%     Subsystem  ['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[440,28,500,72])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/sequential',13,'message-out']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/sequential',13,'message-out']],...
		'position',[540,30,560,50])


%     Subsystem  ['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode'].

new_system([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],'Location',[267,160,850,320])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/Sum',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Sum']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation2']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/out_1']],...
		'position',[535,90,555,110])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[130,45;135,45])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[205,45;220,45])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[55,45;95,45])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[330,100;335,100])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[405,100;410,100])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[445,100;450,100])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[520,100;530,100])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'Mask Display','Hamming\ndecode',...
		'Mask Type','Hamming code')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'Mask Dialogue','Single error-correction Hamming decode. For M>2 integer, N=2^M-1; K=2^M-M-1.|Code word length N:|Message length K or M-degree primitive polynomial:')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,p=k;k=n-length(p)+1;else,p=gfprimdf(n-k);end;[H,G]=hammgen(n-k,p);trt=htruthtb(G);[n,m]=size(G);G=[zeros(n,m-n),eye(n)];')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'Mask Help','This block decodes code word binary vecotr using Hamming coding method. The code word has length N=2^M-1. The message has length K=2^M-M-1. M is an integernot less than 3. The second entree could be a M-degreee primitive polynomail, which can be found by using commands gfprimdf or gfprimfd. This block takes N-ary code word input and results K-ary message output.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'Mask Entries','n\/p\/')


%     Finished composite block ['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode'].

set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'position',[310,15,370,55])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[175,90;180,90;180,55;200,55])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[265,55;280,55;280,90;400,90;400,50;435,50])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[265,35;305,35])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[375,35;435,35])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[145,35;200,35])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[110,100;125,100])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[505,40;535,40])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[175,105;410,105;410,65;435,65])
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Hamming de',...
		'Mask Type','Sequence I/O Hamming decode')
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'Mask Dialogue','Single error-correction Hamming decode with codeword length N=2^M-1, message length K=2^M-M-1, where M is a >=3 integer.|Codeword length N:|Message length K, or M-degree primitive polynomial:|Input sample time T_out (sec):')
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,p=k;k=n-length(p)+1;else,p=gfprimdf(n-k);end;samp=@3;[x,y]=codeicon(4);')
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'Mask Help','This block decodes length N binary codeword into length K message using Hamming code. The block uses sequential input/output format. The input sequence sample time is K*T_out/N. The block causes a K*T_out delay. Use function GFPRIMDF or GFPRIMFD to find M-degree\nprimitive polynomials.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'Mask Entries','7\/gfprimfd(3,''min'')\/1/4\/')


%     Finished composite block ['Binary sequence',13,'Hamming decode'].

set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'position',[165,143,245,187])

add_block('built-in/Note',[sys,'/','Hamming Coding//Decoding Library'])
set_param([sys,'/','Hamming Coding//Decoding Library'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[200,10,205,15])
add_line(sys,[120,80;160,80])
add_line(sys,[120,155;135,155;135,165;160,165])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
