function [ret,x0,str,ts,xts]=comcdlin(t,x,u,flag);
%COMCDLIN	is the M-file description of the SIMULINK system named COMCDLIN.
%	The block-diagram can be displayed by typing: COMCDLIN.
%
%	SYS=COMCDLIN(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COMCDLIN to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COMCDLIN with a FLAG of zero:
%	[SIZES]=COMCDLIN([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[356,448,774,675])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Sequence lin-blk',13,'co//dec demo'].

new_system([sys,'/',['Sequence lin-blk',13,'co//dec demo']])
set_param([sys,'/',['Sequence lin-blk',13,'co//dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Sequence lin-blk',13,'co//dec demo']],...
		'Mask Display','Lin-blk\nco/dec\ndemo',...
		'Mask Dialogue','eval(''G_lin=[1 0 1 1;1 1 1 0;0 1 1 1;eye(4)];trt=0;tstlinsq'')')


%     Finished composite block ['Sequence lin-blk',13,'co//dec demo'].

set_param([sys,'/',['Sequence lin-blk',13,'co//dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,133,375,177])


%     Subsystem  ['Vector lin-blk',13,'co//dec demo'].

new_system([sys,'/',['Vector lin-blk',13,'co//dec demo']])
set_param([sys,'/',['Vector lin-blk',13,'co//dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector lin-blk',13,'co//dec demo']],...
		'Mask Display','Lin-blk\nco/dec\ndemo',...
		'Mask Dialogue','eval(''tstlinco'')')


%     Finished composite block ['Vector lin-blk',13,'co//dec demo'].

set_param([sys,'/',['Vector lin-blk',13,'co//dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,53,375,97])


%     Subsystem  ['Binary vector',13,'lin-blk encode'].

new_system([sys,'/',['Binary vector',13,'lin-blk encode']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],'Location',[235,592,599,711])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'lin-blk encode/in_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'lin-blk encode/out_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/out_1']],...
		'position',[290,35,310,55])
add_line([sys,'/',['Binary vector',13,'lin-blk encode']],[55,45;105,45])
add_line([sys,'/',['Binary vector',13,'lin-blk encode']],[140,45;175,45])
add_line([sys,'/',['Binary vector',13,'lin-blk encode']],[245,45;285,45])
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Display','plot(0,0,100,100,x,y);Linear en',...
		'Mask Type','Vector I/O linear block encode')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Dialogue','Linear block encode with input message\nvector length K and output codeword vector length N.|Generator matrix (binary K-by-N matrix):')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Translate','G=@1'';[x,y]=codeicon(1);')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Help','Linear block encode with input message vector length K and output codeword vector length N. The generator matrix is a K-by-N matrix. Linear block code is a generic code.')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Entries','[[1 1 0; 0 1 1; 1 1 1; 1 0 1] eye(4)]\/')


%     Finished composite block ['Binary vector',13,'lin-blk encode'].

set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'position',[35,53,115,97])

add_block('built-in/Note',[sys,'/','Linear Block Coding//Decoding Library'])
set_param([sys,'/','Linear Block Coding//Decoding Library'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[200,10,205,15])


%     Subsystem  ['Binary vector',13,'lin-blk decode'].

new_system([sys,'/',['Binary vector',13,'lin-blk decode']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],'Location',[267,160,850,320])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'lin-blk decode/in_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary vector',13,'lin-blk decode/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/Sum',[sys,'/',['Binary vector',13,'lin-blk decode/Sum']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'lin-blk decode/out_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/out_1']],...
		'position',[535,90,555,110])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[130,45;135,45])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[205,45;220,45])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[55,45;95,45])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[330,100;335,100])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[405,100;410,100])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[445,100;450,100])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[520,100;530,100])
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Linear de',...
		'Mask Type','Vector I/O linear block decode')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Dialogue','Linear block decode with input codeword vector length N and output message vector length K.|Generator matrix (binary K-by-N matrix):|Error-correction truth table (0 for single error-corr):')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Translate','G=@1;trt=@2;H=gen2par(G);if trt==0,trt=htruthtb(G);end;[n,m]=size(G);G=[zeros(n,m-n),eye(n)];[x,y]=codeicon(2);')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using linear block code. The generator matrix is a K-by-N matrix. Linear block code is a generic code. Use the HTRUTHTB function to generate a single error-correction truth table.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Entries','[[1 1 0; 0 1 1; 1 1 1;1 0 1] eye(4)]\/0\/')


%     Finished composite block ['Binary vector',13,'lin-blk decode'].

set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'position',[165,53,245,97])


%     Subsystem  ['Binary sequence',13,'lin-blk encode'].

new_system([sys,'/',['Binary sequence',13,'lin-blk encode']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],'Location',[159,155,829,298])


%     Subsystem  ['Binary sequence',13,'lin-blk encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'lin-blk encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'BackGround',3,...
		'position',[225,21,280,54])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/in_1']],...
		'position',[50,20,70,40])


%     Subsystem  ['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k, n]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[40,76,100,114])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Demux']],...
		'outputs','2',...
		'position',[135,75,175,110])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/out_1']],...
		'position',[570,25,590,45])


%     Subsystem  ['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'Mask Entries','n\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[440,23,500,57])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/out_2']],...
		'Port','2',...
		'position',[530,40,550,60])


%     Subsystem  ['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding'].

new_system([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],[245,45;285,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],[140,45;175,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],[55,45;105,45])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],...
		'Mask Display','Linear\nencode',...
		'Mask Type','Linear coding',...
		'Mask Dialogue','Linear block coding:|Generator matrix:')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],...
		'Mask Translate','G=@1'';')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],...
		'Mask Help','This block encodes the input binary signal using linear block coding method. The generator matrix has the dimension of m-by-n. The input of this block is a m-array binary message vector. The output of this block is an n-array code word vector. This is a generic style block for linear block coding.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],...
		'Mask Entries','G\/')


%     Finished composite block ['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding'].

set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],...
		'position',[325,11,390,49])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[180,100;415,100;415,50;435,50])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[180,85;190,85;190,45;220,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[105,95;130,95])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[285,45;300,45;300,80;405,80;405,40;435,40])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[75,30;220,30])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[285,30;320,30])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[395,30;435,30])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[505,35;565,35])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[505,50;525,50])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Linear en',...
		'Mask Type','Sequence I/O linear block encode')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'Mask Dialogue','Linear block encode with message length K and codeword length N.|Generator matrix (binary K-by-N matrix):|Input sample time T_in (sec):')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'Mask Translate','G=@1;samp=@2;[k, n]=size(G);[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'Mask Help','This block encodes length K binary message into length N binary codeword using linear block code. The block uses sequential input/output format. The output sequence sample time is K*T_in/N. The block causes a K*T_in delay. The second outport outputs a pulse when Kth message signal is received. The generator matrix is a K-by-N matrix. Linear block code is a generic code.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'Mask Entries','[[1 1 0; 0 1 1; 1 1 1; 1 0 1] eye(4)]\/1/4\/')


%     Finished composite block ['Binary sequence',13,'lin-blk encode'].

set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'position',[35,133,115,177])


%     Subsystem  ['Binary sequence',13,'lin-blk decode'].

new_system([sys,'/',['Binary sequence',13,'lin-blk decode']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],'Location',[267,160,850,320])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/sequential',13,'message-out']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/sequential',13,'message-out']],...
		'position',[525,30,545,50])


%     Subsystem  ['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[425,28,485,72])


%     Subsystem  ['Binary sequence',13,'lin-blk decode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/in_1']],...
		'position',[10,55,30,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[65,80;75,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[35,65;75,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'lin-blk decode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'BackGround',3,...
		'position',[190,25,245,65])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/sequential',13,'code-word-in']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/sequential',13,'code-word-in']],...
		'position',[105,25,125,45])


%     Subsystem  ['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n, k]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[30,81,90,119])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Demux']],...
		'outputs','2',...
		'position',[115,80,155,115])


%     Subsystem  ['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding'].

new_system([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],'Location',[267,160,850,320])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/out_1']],...
		'position',[535,90,555,110])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain1']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain1']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/Sum',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Sum']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[520,100;530,100])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[445,100;450,100])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[405,100;410,100])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[330,100;335,100])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[55,45;95,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[205,45;220,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[130,45;135,45])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'Mask Display','Linear\ndecode',...
		'Mask Type','Linear coding')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'Mask Dialogue','Linear block coding:|Generator matrix:|Error-correction truth table (0 for single error-correction default):')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'Mask Translate','G=@1;trt=@2;H=gen2par(G);if trt==0,trt=htruthtb(G);end;[n,m]=size(G);G=[zeros(n,m-n),eye(n)];')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'Mask Help','This block decodes code word binary vecotr using linear block coding method. The m-by-n generator matrix should match the generator matrix defined in the encode block. This block input n-array code word and output m-array message. This is a generic styke block for linear block code.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'Mask Entries','G\/trt\/')


%     Finished composite block ['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding'].

set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'position',[295,15,355,55])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[160,105;395,105;395,65;420,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[490,40;520,40])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[95,100;110,100])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[130,35;185,35])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[360,35;420,35])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[250,35;290,35])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[250,55;265,55;265,90;385,90;385,50;420,50])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[160,90;165,90;165,55;185,55])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Linear de',...
		'Mask Type','Sequence I/O linear block decode')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'Mask Dialogue','Linear block decode with message length K and codeword length N.|Generator matrix (binary K-by-N matrix):|Error-correction truth table (0 for single error-corr):|Output sample time T_out (sec):')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'Mask Translate','G=@1;trt=@2;samp=@3;[k,n]=size(G);[x,y]=codeicon(4);')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'Mask Help','This block decodes length N binary codeword into length K message using linear block code. The block uses sequential input/output format. The input sequence sample time is K*T_out/N. The block causes a K*T_out delay. The generator matrix is a K-by-N matrix. Linear block code is a generic code.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'Mask Entries','[[1 1 0; 0 1 1; 1 1 1; 1 0 1] eye(4)]\/0\/1/4\/')


%     Finished composite block ['Binary sequence',13,'lin-blk decode'].

set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'position',[165,138,245,182])
add_line(sys,[120,75;160,75])
add_line(sys,[120,145;135,145;135,160;160,160])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
