function [ret,x0,str,ts,xts]=comcdrs(t,x,u,flag);
%COMCDRS	is the M-file description of the SIMULINK system named COMCDRS.
%	The block-diagram can be displayed by typing: COMCDRS.
%
%	SYS=COMCDRS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COMCDRS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COMCDRS with a FLAG of zero:
%	[SIZES]=COMCDRS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[147,358,566,721])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Integer-vector',13,'RS Co//Dec demo'].

new_system([sys,'/',['Integer-vector',13,'RS Co//Dec demo']])
set_param([sys,'/',['Integer-vector',13,'RS Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Integer-vector',13,'RS Co//Dec demo']],...
		'Mask Display','Int vect\nRS co/dec\ndemo',...
		'Mask Dialogue','eval(''N_rs_demo=7;K_rs_demo=5;M_rs_demo=3;tstrscod'')')


%     Finished composite block ['Integer-vector',13,'RS Co//Dec demo'].

set_param([sys,'/',['Integer-vector',13,'RS Co//Dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,53,375,97])


%     Subsystem  ['Binary-vector',13,'RS Co//Dec demo'].

new_system([sys,'/',['Binary-vector',13,'RS Co//Dec demo']])
set_param([sys,'/',['Binary-vector',13,'RS Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Binary-vector',13,'RS Co//Dec demo']],...
		'Mask Display','Binary vect\nRS co/dec\ndemo',...
		'Mask Dialogue','eval(''N_rs_demo=7;K_rs_demo=5;M_rs_demo=3;tstrscbv'')')


%     Finished composite block ['Binary-vector',13,'RS Co//Dec demo'].

set_param([sys,'/',['Binary-vector',13,'RS Co//Dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,128,375,172])


%     Subsystem  ['Integer sequence',13,'RS Co//Dec demo'].

new_system([sys,'/',['Integer sequence',13,'RS Co//Dec demo']])
set_param([sys,'/',['Integer sequence',13,'RS Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Integer sequence',13,'RS Co//Dec demo']],...
		'Mask Display','Int sequ\nRS co/dec\ndemo',...
		'Mask Dialogue','eval(''N_rs_demo=7;K_rs_demo=5;M_rs_demo=3;tstrsinv'')')


%     Finished composite block ['Integer sequence',13,'RS Co//Dec demo'].

set_param([sys,'/',['Integer sequence',13,'RS Co//Dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,203,375,247])


%     Subsystem  ['Binary sequence',13,'RS Co//Dec demo'].

new_system([sys,'/',['Binary sequence',13,'RS Co//Dec demo']])
set_param([sys,'/',['Binary sequence',13,'RS Co//Dec demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Binary sequence',13,'RS Co//Dec demo']],...
		'Mask Display','Binary sequ\nRS co/dec\ndemo',...
		'Mask Dialogue','eval(''N_rs_demo=7;K_rs_demo=5;M_rs_demo=3;tstrsbnv'')')


%     Finished composite block ['Binary sequence',13,'RS Co//Dec demo'].

set_param([sys,'/',['Binary sequence',13,'RS Co//Dec demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,278,375,322])


%     Subsystem  ['Binary sequence',13,'RS encode'].

new_system([sys,'/',['Binary sequence',13,'RS encode']])
set_param([sys,'/',['Binary sequence',13,'RS encode']],'Location',[263,35,887,210])


%     Subsystem  ['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k n]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'position',[35,91,95,129])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Demux']],...
		'outputs','2',...
		'position',[125,90,170,125])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/out_1']],...
		'position',[685,55,705,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/out_2']],...
		'Port','2',...
		'position',[645,70,665,90])


%     Subsystem  ['Binary sequence',13,'RS encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Entries','n*m\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'RS encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'ForeGround',6,...
		'position',[540,53,600,87])


%     Subsystem  ['Binary sequence',13,'RS encode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','0.1\/')


%     Finished composite block ['Binary sequence',13,'RS encode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],...
		'ForeGround',2,...
		'position',[315,56,365,84])


%     Subsystem  ['Binary sequence',13,'RS encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'RS encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[55,80;75,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'Mask Entries','[k*m:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'RS encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'ForeGround',3,...
		'position',[225,40,280,80])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/in_1']],...
		'position',[115,40,135,60])


%     Subsystem  ['Binary sequence',13,'RS encode/Binary vector',13,'RS encode'].

new_system([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],'Location',[160,111,633,282])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/out_1']],...
		'position',[425,60,445,80])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/in_2']],...
		'Port','2',...
		'position',[20,110,40,130])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/in_1']],...
		'position',[30,25,50,45])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Mux']],...
		'inputs','2',...
		'position',[90,51,125,84])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/S-function']],...
		'function name','simrscbv',...
		'parameters','n, k, pg,tp,dim',...
		'position',[180,30,245,50])

add_block('built-in/Switch',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Switch']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Switch']],...
		'Threshold','0.5',...
		'position',[305,54,335,86])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Memory']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,n*dim)',...
		'position',[305,105,345,135])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[45,120;210,120;210,70;300,70])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[70,120;70,75;85,75])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[130,70;160,70;160,40;175,40])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[55,35;70,35;70,60;85,60])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[250,40;265,40;265,60;300,60])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[300,120;265,120;265,80;300,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[340,70;420,70])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[370,70;370,120;350,120])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Bnr RS en',...
		'Mask Type','Binary vector I/O RS encode')
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'Mask Dialogue','Reed-Solomon encode with binary input\nvector length K*M and binary output vector length N*M.|Code length N=2^M-1 (M is a >2 integer):|Message length K (< N):')
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,pg=k;k=n-length(pg)-1;else,pg=rspoly(n,k);end;dim=3;p_dim=7;while p_dim<n,dim=dim+1;p_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'Mask Help','This block encodes length K*M binary vector input into length N*M binary vector output using Reed-Solomon code. The codeword length is N=2^M-1. M is a integer larger than 2. The message length is K<N. The block refreshes its encoding output when the enable signal at the second inport has positive value.')
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'Mask Entries','n\/k\/')


%     Finished composite block ['Binary sequence',13,'RS encode/Binary vector',13,'RS encode'].

set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'position',[415,38,495,82])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[175,115;510,115;510,80;535,80])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[175,100;185,100;185,70;220,70])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[370,70;410,70])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[395,70;395,110;505,110;505,70;535,70])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[285,70;310,70])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[500,60;535,60])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[100,110;120,110])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[285,50;410,50])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[140,50;220,50])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[605,65;680,65])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[605,80;640,80])
set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);B-RS en',...
		'Mask Type','Binary sequence I/O RS encode')
set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'Mask Dialogue','RS encode with codeword length N, message\nlength K.|Code length N=2^M-1 (M is a >2 integer):|Message length K:|Input sample time T_in (sec):')
set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'Mask Translate','n=@1;k=@2;samp=@3;m=3;p_m=7;while p_m<n,m=m+1;p_m=2^m-1;end;[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'Mask Help','This block encodes length K binary message into length N binary codeword. The block uses sequential input/output format. The output sequence sample time is K*T_in/N. The block causes a K*M*T_in delay. The second outport outputs a pulse when (K*M)-th message signal is received.')
set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'Mask Entries','7\/5\/1/5/3\/')


%     Finished composite block ['Binary sequence',13,'RS encode'].

set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'position',[35,278,115,322])


%     Subsystem  ['Binary vector',13,'RS encode'].

new_system([sys,'/',['Binary vector',13,'RS encode']])
set_param([sys,'/',['Binary vector',13,'RS encode']],'Location',[160,111,633,282])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'RS encode/Memory']])
set_param([sys,'/',['Binary vector',13,'RS encode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,n*dim)',...
		'position',[305,105,345,135])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'RS encode/Switch']])
set_param([sys,'/',['Binary vector',13,'RS encode/Switch']],...
		'Threshold','0.5',...
		'position',[305,54,335,86])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'RS encode/S-function']])
set_param([sys,'/',['Binary vector',13,'RS encode/S-function']],...
		'function name','simrscbv',...
		'parameters','n, k, pg,tp,dim',...
		'position',[180,30,245,50])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'RS encode/Mux']])
set_param([sys,'/',['Binary vector',13,'RS encode/Mux']],...
		'inputs','2',...
		'position',[90,51,125,84])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'RS encode/in_1']])
set_param([sys,'/',['Binary vector',13,'RS encode/in_1']],...
		'position',[30,25,50,45])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'RS encode/in_2']])
set_param([sys,'/',['Binary vector',13,'RS encode/in_2']],...
		'Port','2',...
		'position',[20,110,40,130])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'RS encode/out_1']])
set_param([sys,'/',['Binary vector',13,'RS encode/out_1']],...
		'position',[425,60,445,80])
add_line([sys,'/',['Binary vector',13,'RS encode']],[340,70;420,70])
add_line([sys,'/',['Binary vector',13,'RS encode']],[370,70;370,120;350,120])
add_line([sys,'/',['Binary vector',13,'RS encode']],[300,120;265,120;265,80;300,80])
add_line([sys,'/',['Binary vector',13,'RS encode']],[250,40;265,40;265,60;300,60])
add_line([sys,'/',['Binary vector',13,'RS encode']],[55,35;70,35;70,60;85,60])
add_line([sys,'/',['Binary vector',13,'RS encode']],[130,70;160,70;160,40;175,40])
add_line([sys,'/',['Binary vector',13,'RS encode']],[45,120;210,120;210,70;300,70])
add_line([sys,'/',['Binary vector',13,'RS encode']],[70,120;70,75;85,75])
set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);B-RS en',...
		'Mask Type','Binary vector I/O RS encode')
set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'Mask Dialogue','Reed-Solomon encode with binary input\nvector length K*M and binary output\nvector length N*M.|Code length N=2^M-1 (M is a >2 integer):|Message length K (< N):')
set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,pg=k;k=n-length(pg)-1;else,pg=rspoly(n,k);end;dim=3;p_dim=7;while p_dim<n,dim=dim+1;p_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'Mask Help','This block encodes length K*M binary vector input into length N*M binary vector output. The codeword length is N=2^M-1. M is a integer larger than 2. The message length is K<N. The block refreshes its encoding output when the enable signal at the second inport has positive value.')
set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'Mask Entries','7\/5\/')


%     Finished composite block ['Binary vector',13,'RS encode'].

set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'position',[35,128,115,172])


%     Subsystem  ['Integer vector',13,'RS encode'].

new_system([sys,'/',['Integer vector',13,'RS encode']])
set_param([sys,'/',['Integer vector',13,'RS encode']],'Location',[315,420,618,590])

add_block('built-in/Inport',[sys,'/',['Integer vector',13,'RS encode/in_2']])
set_param([sys,'/',['Integer vector',13,'RS encode/in_2']],...
		'Port','2',...
		'position',[20,110,40,130])

add_block('built-in/Inport',[sys,'/',['Integer vector',13,'RS encode/in_1']])
set_param([sys,'/',['Integer vector',13,'RS encode/in_1']],...
		'position',[30,25,50,45])

add_block('built-in/Mux',[sys,'/',['Integer vector',13,'RS encode/Mux']])
set_param([sys,'/',['Integer vector',13,'RS encode/Mux']],...
		'inputs','2',...
		'position',[90,51,125,84])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'RS encode/S-function']])
set_param([sys,'/',['Integer vector',13,'RS encode/S-function']],...
		'function name','simrscod',...
		'parameters','n, k, pg,tp,dim',...
		'position',[155,60,220,80])

add_block('built-in/Outport',[sys,'/',['Integer vector',13,'RS encode/out_1']])
set_param([sys,'/',['Integer vector',13,'RS encode/out_1']],...
		'position',[260,60,280,80])
add_line([sys,'/',['Integer vector',13,'RS encode']],[45,120;70,120;70,75;85,75])
add_line([sys,'/',['Integer vector',13,'RS encode']],[130,70;150,70])
add_line([sys,'/',['Integer vector',13,'RS encode']],[55,35;70,35;70,60;85,60])
add_line([sys,'/',['Integer vector',13,'RS encode']],[225,70;255,70])
set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Int RS en',...
		'Mask Type','Integer vector I/O RS encode')
set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'Mask Dialogue','Reed-Solomon encode with integer input\nmessage vector length K and integer\noutput codeword vector length N.|Code length N=2^M-1 (M is a >=3 integer):|Message length K (< N):')
set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,pg=k;k=n-length(pg)-1;else,pg=rspoly(n,k);end;dim=3;p_dim=7;while p_dim<n,dim=dim+1;p_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'Mask Help','This block encodes length K integer vector message input into length N integer vector codeword output. The input/output integers are in range [0, N-1]. Code word length N=2^M-1, where M is a integer no less than 3. The message length is K<N. The error-correction capability is T=floor((N-K)/2). The block refreshes its decoding output when the enable signal at the second inport has positive value.')
set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'Mask Entries','7\/5\/')


%     Finished composite block ['Integer vector',13,'RS encode'].

set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'position',[35,53,115,97])


%     Subsystem  ['Integer vector',13,'RS decode'].

new_system([sys,'/',['Integer vector',13,'RS decode']])
set_param([sys,'/',['Integer vector',13,'RS decode']],'Location',[267,61,656,221])

add_block('built-in/Outport',[sys,'/',['Integer vector',13,'RS decode/out_1']])
set_param([sys,'/',['Integer vector',13,'RS decode/out_1']],...
		'position',[325,50,345,70])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'RS decode/S-function']])
set_param([sys,'/',['Integer vector',13,'RS decode/S-function']],...
		'function name','simrsdec',...
		'parameters','n, k, tp, dim',...
		'position',[170,50,235,70])

add_block('built-in/Inport',[sys,'/',['Integer vector',13,'RS decode/in_1']])
set_param([sys,'/',['Integer vector',13,'RS decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Inport',[sys,'/',['Integer vector',13,'RS decode/in_2']])
set_param([sys,'/',['Integer vector',13,'RS decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Mux',[sys,'/',['Integer vector',13,'RS decode/Mux']])
set_param([sys,'/',['Integer vector',13,'RS decode/Mux']],...
		'inputs','2',...
		'position',[80,40,115,75])

add_block('built-in/Demux',[sys,'/',['Integer vector',13,'RS decode/Demux']])
set_param([sys,'/',['Integer vector',13,'RS decode/Demux']],...
		'outputs','[k, 1]',...
		'position',[260,50,300,85])

add_block('built-in/Outport',[sys,'/',['Integer vector',13,'RS decode/out_2']])
set_param([sys,'/',['Integer vector',13,'RS decode/out_2']],...
		'Port','2',...
		'position',[325,100,345,120])
add_line([sys,'/',['Integer vector',13,'RS decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Integer vector',13,'RS decode']],[120,60;165,60])
add_line([sys,'/',['Integer vector',13,'RS decode']],[35,110;60,110;60,65;75,65])
add_line([sys,'/',['Integer vector',13,'RS decode']],[240,60;240,70;255,70])
add_line([sys,'/',['Integer vector',13,'RS decode']],[305,60;320,60])
add_line([sys,'/',['Integer vector',13,'RS decode']],[305,75;310,75;320,110])
set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Int RS de',...
		'Mask Type','Integer vector I/O RS decode')
set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'Mask Dialogue','Reed-Solomon decode with integer output\ncodeword vector length N and integer\ninput message vector length K.|Code word length N=2^M-1 (M is a >=3 integer):|Message length K (< N):')
set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'Mask Translate','n=@1;k=@2;dim=3;p_d=7;while p_d<n,dim=dim+1;p_d=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'Mask Help','This block decodes length N integer vector codeword input into length K integer vector message output. The input/output integers are in the range [0, N-1]. The block refreshes its decoding output when the enable signal at the second inport has positive value. The second outport outputs the number of errors detected in the process. If the codeword contains more errors than the correction capability, this output is negative.')
set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'Mask Entries','7\/5\/')


%     Finished composite block ['Integer vector',13,'RS decode'].

set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'position',[165,53,245,97])

add_block('built-in/Note',[sys,'/','Reed-Solomon Coding//Decoding Library'])
set_param([sys,'/','Reed-Solomon Coding//Decoding Library'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[200,10,205,15])


%     Subsystem  ['Integer sequence',13,'RS encode'].

new_system([sys,'/',['Integer sequence',13,'RS encode']])
set_param([sys,'/',['Integer sequence',13,'RS encode']],'Location',[15,70,755,245])


%     Subsystem  ['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k n]\/[0 0]\/')


%     Finished composite block ['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Integer sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'position',[35,91,95,129])

add_block('built-in/Demux',[sys,'/',['Integer sequence',13,'RS encode/Demux']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Demux']],...
		'outputs','2',...
		'position',[125,90,170,125])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS encode/out_1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/out_1']],...
		'position',[685,55,705,75])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS encode/out_2']])
set_param([sys,'/',['Integer sequence',13,'RS encode/out_2']],...
		'Port','2',...
		'position',[645,70,665,90])


%     Subsystem  ['Integer sequence',13,'RS encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Entries','n\/0\/1\/.1\/0\/')


%     Finished composite block ['Integer sequence',13,'RS encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Integer sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'ForeGround',6,...
		'position',[540,53,600,87])


%     Subsystem  ['Integer sequence',13,'RS encode/Rising edge',13,'detector'].

new_system([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','0.1\/')


%     Finished composite block ['Integer sequence',13,'RS encode/Rising edge',13,'detector'].

set_param([sys,'/',['Integer sequence',13,'RS encode/Rising edge',13,'detector']],...
		'ForeGround',2,...
		'position',[315,56,365,84])


%     Subsystem  ['Integer sequence',13,'RS encode/Register-shift'].

new_system([sys,'/',['Integer sequence',13,'RS encode/Register-shift']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS encode/Register-shift/in_2']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS encode/Register-shift/in_1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS encode/Register-shift/out_2']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS encode/Register-shift/out_1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Integer sequence',13,'RS encode/Register-shift/Mux']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Integer sequence',13,'RS encode/Register-shift/S-function']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Integer sequence',13,'RS encode/Register-shift/Demux']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])
add_line([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],[55,80;75,80])
add_line([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],...
		'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Integer sequence',13,'RS encode/Register-shift'].

set_param([sys,'/',['Integer sequence',13,'RS encode/Register-shift']],...
		'ForeGround',3,...
		'position',[225,40,280,80])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS encode/in_1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/in_1']],...
		'position',[115,40,135,60])


%     Subsystem  ['Integer sequence',13,'RS encode/Integer vector',13,'RS encode'].

new_system([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],'Location',[621,369,1006,585])

add_block('built-in/Memory',[sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/Memory']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,n)',...
		'position',[305,105,345,135])

add_block('built-in/Switch',[sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/Switch']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/Switch']],...
		'Threshold','0.5',...
		'position',[305,54,335,86])

add_block('built-in/S-Function',[sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/S-function']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/S-function']],...
		'function name','simrscod',...
		'parameters','n, k, pg,tp,dim',...
		'position',[180,30,245,50])

add_block('built-in/Mux',[sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/Mux']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/Mux']],...
		'inputs','2',...
		'position',[90,51,125,84])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/in_1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/in_1']],...
		'position',[30,25,50,45])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/in_2']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/in_2']],...
		'Port','2',...
		'position',[20,110,40,130])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/out_1']])
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode/out_1']],...
		'position',[425,60,445,80])
add_line([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],[340,70;420,70])
add_line([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],[370,70;370,120;350,120])
add_line([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],[300,120;265,120;265,80;300,80])
add_line([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],[250,40;265,40;265,60;300,60])
add_line([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],[55,35;70,35;70,60;85,60])
add_line([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],[130,70;160,70;160,40;175,40])
add_line([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],[45,120;210,120;210,70;300,70])
add_line([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],[70,120;70,75;85,75])
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Int RS en',...
		'Mask Type','Integer vector I/O RS encode')
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],...
		'Mask Dialogue','Reed-Solomon encode with integer input\nmessage vector length K and integer\noutput codeword vector length N.|Code length N=2^M-1 (M is a >=3 integer):|Message length K (< N):')
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,pg=k;k=n-length(pg)-1;else,pg=rspoly(n,k);end;dim=3;p_dim=7;while p_dim<n,dim=dim+1;p_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],...
		'Mask Help','This block encodes length K integer vector message input into length N integer vector codeword output using Reed-Solomon code. The input/output integers are in range [0, N-1]. Code word length N=2^M-1, where M is a integer no less than 3. The message length K<N. The block refreshes its decoding output when the enable signal at the second inport has positive value.')
set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],...
		'Mask Entries','n\/k\/')


%     Finished composite block ['Integer sequence',13,'RS encode/Integer vector',13,'RS encode'].

set_param([sys,'/',['Integer sequence',13,'RS encode/Integer vector',13,'RS encode']],...
		'position',[415,38,495,82])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[175,115;510,115;510,80;535,80])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[175,100;185,100;185,70;220,70])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[370,70;410,70])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[395,70;395,110;505,110;505,70;535,70])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[285,70;310,70])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[500,60;535,60])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[100,110;120,110])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[285,50;410,50])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[140,50;220,50])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[605,65;680,65])
add_line([sys,'/',['Integer sequence',13,'RS encode']],[605,80;640,80])
set_param([sys,'/',['Integer sequence',13,'RS encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Int RS en',...
		'Mask Type','Integer sequence I/O RS encode')
set_param([sys,'/',['Integer sequence',13,'RS encode']],...
		'Mask Dialogue','RS encode with codeword length N, message\nlength K. Input integers are in range\n[0, N-1].|Code length N=2^M-1 (M is a >2 integer):|Message length K:|Input sample time T_in (sec):')
set_param([sys,'/',['Integer sequence',13,'RS encode']],...
		'Mask Translate','n=@1;k=@2;samp=@3;m=3;p_m=7;while p_m<n,m=m+1;p_m=2^m-1;end;[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Integer sequence',13,'RS encode']],...
		'Mask Help','This block encodes length K integer message into length N integer codeword. The block uses sequential input/output format. The input integers are in range [0, N-1]. The output sequence sample time is K*T_in/N. The block causes a K*T_in delay. The second outport outputs a pulse when Kth message signal is received.')
set_param([sys,'/',['Integer sequence',13,'RS encode']],...
		'Mask Entries','7\/5\/1/5\/')


%     Finished composite block ['Integer sequence',13,'RS encode'].

set_param([sys,'/',['Integer sequence',13,'RS encode']],...
		'position',[35,203,115,247])


%     Subsystem  ['Integer sequence',13,'RS decode'].

new_system([sys,'/',['Integer sequence',13,'RS decode']])
set_param([sys,'/',['Integer sequence',13,'RS decode']],'Location',[43,589,882,748])

add_block('built-in/Zero-Order Hold',[sys,'/',['Integer sequence',13,'RS decode/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Zero-Order',13,'Hold1']],...
		'Sample time','samp',...
		'position',[735,34,770,66])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS decode/out_1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/out_1']],...
		'position',[795,40,815,60])

add_block('built-in/Zero-Order Hold',[sys,'/',['Integer sequence',13,'RS decode/Zero-Order',13,'Hold']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Zero-Order',13,'Hold']],...
		'Sample time','samp*k',...
		'position',[545,29,580,61])


%     Subsystem  ['Integer sequence',13,'RS decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Integer sequence',13,'RS decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Integer sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'ForeGround',6,...
		'position',[645,38,705,72])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS decode/out_2']])
set_param([sys,'/',['Integer sequence',13,'RS decode/out_2']],...
		'Port','2',...
		'position',[510,55,530,75])


%     Subsystem  ['Integer sequence',13,'RS decode/Rising edge',13,'detector'].

new_system([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','0.1\/')


%     Finished composite block ['Integer sequence',13,'RS decode/Rising edge',13,'detector'].

set_param([sys,'/',['Integer sequence',13,'RS decode/Rising edge',13,'detector']],...
		'ForeGround',2,...
		'position',[310,51,360,79])


%     Subsystem  ['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n k]\/[0 0]\/')


%     Finished composite block ['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Integer sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'position',[45,86,105,124])

add_block('built-in/Demux',[sys,'/',['Integer sequence',13,'RS decode/Demux']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Demux']],...
		'outputs','2',...
		'position',[125,85,170,120])


%     Subsystem  ['Integer sequence',13,'RS decode/Register-shift'].

new_system([sys,'/',['Integer sequence',13,'RS decode/Register-shift']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Demux',[sys,'/',['Integer sequence',13,'RS decode/Register-shift/Demux']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Integer sequence',13,'RS decode/Register-shift/S-function']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Integer sequence',13,'RS decode/Register-shift/Mux']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS decode/Register-shift/out_1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS decode/Register-shift/out_2']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS decode/Register-shift/in_1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS decode/Register-shift/in_2']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],...
		'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Integer sequence',13,'RS decode/Register-shift'].

set_param([sys,'/',['Integer sequence',13,'RS decode/Register-shift']],...
		'ForeGround',3,...
		'position',[225,35,280,75])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS decode/in_1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/in_1']],...
		'position',[130,35,150,55])


%     Subsystem  ['Integer sequence',13,'RS decode/Integer vector',13,'RS decode'].

new_system([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],'Location',[267,61,656,221])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/out_2']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/out_2']],...
		'Port','2',...
		'position',[325,100,345,120])

add_block('built-in/Demux',[sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/Demux']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/Demux']],...
		'outputs','[k, 1]',...
		'position',[260,50,300,85])

add_block('built-in/Mux',[sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/Mux']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/Mux']],...
		'inputs','2',...
		'position',[80,40,115,75])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/in_2']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/in_1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/S-Function',[sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/S-function']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/S-function']],...
		'function name','simrsdec',...
		'parameters','n, k, tp, dim',...
		'position',[170,50,235,70])

add_block('built-in/Outport',[sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/out_1']])
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode/out_1']],...
		'position',[325,50,345,70])
add_line([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],[305,75;310,75;320,110])
add_line([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],[305,60;320,60])
add_line([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],[240,60;240,70;255,70])
add_line([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],[35,110;60,110;60,65;75,65])
add_line([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],[120,60;165,60])
add_line([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],[45,25;60,25;60,50;75,50])
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Int RS de',...
		'Mask Type','Integer vector I/O RS decode')
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],...
		'Mask Dialogue','Reed-Solomon decode with integer output\ncodeword vector length N and integer\ninput message vector length K.|Code word length N=2^M-1 (M is a >=3 integer):|Message length K (< N):')
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],...
		'Mask Translate','n=@1;k=@2;dim=3;p_d=7;while p_d<n,dim=dim+1;p_d=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],...
		'Mask Help','This block decodes length N integer vector codeword input into length K integer vector message output using Reed-Solomon code. The input/output integers are in range [0, N-1]. The block refreshes its decoding output when the enable signal at the second inport has positive value. The second outport outputs the number of errors detected in the process. ')
set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],...
		'Mask Entries','n\/k\/')


%     Finished composite block ['Integer sequence',13,'RS decode/Integer vector',13,'RS decode'].

set_param([sys,'/',['Integer sequence',13,'RS decode/Integer vector',13,'RS decode']],...
		'position',[410,33,490,77])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[775,50;790,50])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[710,50;730,50])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[585,45;640,45])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[495,45;540,45])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[365,65;390,65;390,105;600,105;600,55;640,55])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[390,65;405,65])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[175,110;610,110;610,65;640,65])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[285,65;305,65])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[155,45;220,45])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[175,95;190,95;190,65;220,65])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[285,45;405,45])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[110,105;120,105])
add_line([sys,'/',['Integer sequence',13,'RS decode']],[495,65;505,65])
set_param([sys,'/',['Integer sequence',13,'RS decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Int RS de',...
		'Mask Type','Integer sequence I/O RS decode')
set_param([sys,'/',['Integer sequence',13,'RS decode']],...
		'Mask Dialogue','RS decode with codeword length N, message\nlength K. Input integers are in range\n[0, N-1].|Code length N=2^M-1 (M is a >2 integer):|Message length K:|Output sample time T_out (sec):')
set_param([sys,'/',['Integer sequence',13,'RS decode']],...
		'Mask Translate','n=@1;k=@2;samp=@3;m=3;p_d=7;while p_d<n,m=m+1;p_d=2^m-1;end;[x,y]=codeicon(4);')
set_param([sys,'/',['Integer sequence',13,'RS decode']],...
		'Mask Help','This block decodes length N integer codeword into length K integer message. The block uses sequential input/output format. The input integers are in range [0, N-1]. The input sequence sample time is K*T_out/N. The block causes a K*T_out delay. The second outport outputs the number of errors detected in the process. If the codeword contains more errors than the correction capability, this output is negative.')
set_param([sys,'/',['Integer sequence',13,'RS decode']],...
		'Mask Entries','7\/5\/1/5\/')


%     Finished composite block ['Integer sequence',13,'RS decode'].

set_param([sys,'/',['Integer sequence',13,'RS decode']],...
		'position',[165,203,245,247])


%     Subsystem  ['Binary vector',13,'RS decode'].

new_system([sys,'/',['Binary vector',13,'RS decode']])
set_param([sys,'/',['Binary vector',13,'RS decode']],'Location',[143,192,726,352])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'RS decode/Memory']])
set_param([sys,'/',['Binary vector',13,'RS decode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,k*dim+1)',...
		'position',[295,95,335,125])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'RS decode/Switch']])
set_param([sys,'/',['Binary vector',13,'RS decode/Switch']],...
		'Threshold','0.5',...
		'position',[295,44,325,76])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'RS decode/S-function']])
set_param([sys,'/',['Binary vector',13,'RS decode/S-function']],...
		'function name','simrsdbv',...
		'parameters','n, k, tp, dim',...
		'position',[170,20,235,40])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'RS decode/Mux']])
set_param([sys,'/',['Binary vector',13,'RS decode/Mux']],...
		'inputs','2',...
		'position',[80,41,115,74])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'RS decode/in_1']])
set_param([sys,'/',['Binary vector',13,'RS decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'RS decode/in_2']])
set_param([sys,'/',['Binary vector',13,'RS decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Demux',[sys,'/',['Binary vector',13,'RS decode/Demux']])
set_param([sys,'/',['Binary vector',13,'RS decode/Demux']],...
		'outputs','[k*dim,1]',...
		'position',[395,40,435,75])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'RS decode/out_1']])
set_param([sys,'/',['Binary vector',13,'RS decode/out_1']],...
		'position',[495,30,515,50])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'RS decode/out_2']])
set_param([sys,'/',['Binary vector',13,'RS decode/out_2']],...
		'Port','2',...
		'position',[495,95,515,115])
add_line([sys,'/',['Binary vector',13,'RS decode']],[330,60;390,60])
add_line([sys,'/',['Binary vector',13,'RS decode']],[360,60;360,110;340,110])
add_line([sys,'/',['Binary vector',13,'RS decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary vector',13,'RS decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary vector',13,'RS decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary vector',13,'RS decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary vector',13,'RS decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary vector',13,'RS decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary vector',13,'RS decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary vector',13,'RS decode']],[440,65;455,65;455,105;490,105])
set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);B-RS de',...
		'Mask Type','Binary vector I/O RS decode')
set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'Mask Dialogue','Reed-Solomon decode with binary input\nvector length N*M and binary output\nvector length K*M.|Code length N=2^M-1 (M is a >2 integer):|Message length K (< N):')
set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'Mask Translate','n=@1;k=@2;dim=3;p_d=7;while p_d<n,dim=dim+1;p_d=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'Mask Help','This block decodes length N*M binary vector input into length K*M binary vector output. The codeword length is N=2^M-1. M>2. The message length is K<N. The block refreshes its decoding output when the enable signal at the second inport has positive value. The second outport outputs the number of errors detected in the process. If the codeword contains more errors than the correction capability, this output is negative.')
set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'Mask Entries','7\/5\/')


%     Finished composite block ['Binary vector',13,'RS decode'].

set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'position',[165,128,245,172])


%     Subsystem  ['Binary sequence',13,'RS decode'].

new_system([sys,'/',['Binary sequence',13,'RS decode']])
set_param([sys,'/',['Binary sequence',13,'RS decode']],'Location',[108,572,804,731])


%     Subsystem  ['Binary sequence',13,'RS decode/Binary vector',13,'RS decode'].

new_system([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],'Location',[143,192,726,352])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Memory']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,k*dim+1)',...
		'position',[295,95,335,125])

add_block('built-in/Switch',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Switch']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Switch']],...
		'Threshold','0.5',...
		'position',[295,44,325,76])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/S-function']],...
		'function name','simrsdbv',...
		'parameters','n, k, tp, dim',...
		'position',[170,20,235,40])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Mux']],...
		'inputs','2',...
		'position',[80,41,115,74])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Demux']],...
		'outputs','[k*dim,1]',...
		'position',[395,40,435,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/out_1']],...
		'position',[495,30,515,50])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/out_2']],...
		'Port','2',...
		'position',[495,95,515,115])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[330,60;390,60])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[360,60;360,110;340,110])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[440,65;455,65;455,105;490,105])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);B-RS de',...
		'Mask Type','Binary vector I/O RS decode')
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'Mask Dialogue','Reed-Solomon decode with binary input\nvector length N*M and binary output\nvector length K*M.|Code length N=2^M-1 (M is a >2 integer):|Message length K (< N):')
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'Mask Translate','n=@1;k=@2;dim=3;p_d=7;while p_d<n,dim=dim+1;p_d=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'Mask Help','This block decodes length N*M binary vector input into length K*M binary vector output. The codeword length is N=2^M-1. M>2. The message length is K<N. The block refreshes its decoding output when the enable signal at the second inport has positive value. The second outport outputs the number of errors detected in the process. If the codeword contains more errors than the correction capability, this output is negative.')
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'Mask Entries','n\/k\/')


%     Finished composite block ['Binary sequence',13,'RS decode/Binary vector',13,'RS decode'].

set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'position',[380,33,460,77])


%     Subsystem  ['Binary sequence',13,'RS decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Entries','k*m\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'RS decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'ForeGround',6,...
		'position',[555,38,615,72])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/out_1']],...
		'position',[645,40,665,60])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/in_1']],...
		'position',[100,35,120,55])


%     Subsystem  ['Binary sequence',13,'RS decode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'RS decode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'Mask Entries','[n*m:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'RS decode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'ForeGround',3,...
		'position',[195,35,250,75])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Demux']],...
		'outputs','2',...
		'position',[95,85,140,120])


%     Subsystem  ['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n k]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'position',[15,86,75,124])


%     Subsystem  ['Binary sequence',13,'RS decode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','0.1\/')


%     Finished composite block ['Binary sequence',13,'RS decode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],...
		'ForeGround',2,...
		'position',[280,51,330,79])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/out_2']],...
		'Port','2',...
		'position',[480,55,500,75])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[620,50;640,50])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[465,45;550,45])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[335,65;360,65;360,105;520,105;520,55;550,55])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[360,65;375,65])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[145,110;525,110;525,65;550,65])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[255,65;275,65])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[125,45;190,45])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[145,95;160,95;160,65;190,65])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[255,45;375,45])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[80,105;90,105])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[465,65;475,65])
set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'Mask Display','plot(0,0,100,100,x,y);B-RS de',...
		'Mask Type','Binary sequence I/O RS decode')
set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'Mask Dialogue','RS decode with codeword length N, message\nlength K.|Code length N=2^M-1 (M is a >2 integer):|Message length K:|Output sample time T_out (sec):')
set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'Mask Translate','n=@1;k=@2;samp=@3;m=3;p_d=7;while p_d<n,m=m+1;p_d=2^m-1;end;[x,y]=codeicon(4);')
set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'Mask Help','This block decodes length N binary codeword into length K binary message. The block uses sequence input/output format. The input sequential sample time is K*T_out/N. The block causes a K*M*T_out delay. The second outport outputs the number of errors detected in the process. If the codeword contains more error than the correction capability, this output is nagative.')
set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'Mask Entries','7\/5\/1/5/3\/')


%     Finished composite block ['Binary sequence',13,'RS decode'].

set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'position',[165,283,245,327])
add_line(sys,[120,75;135,75;135,65;160,65])
add_line(sys,[120,150;135,150;135,140;160,140])
add_line(sys,[120,290;135,290;135,305;160,305])
add_line(sys,[120,215;135,215;135,225;160,225])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
