function [ret,x0,str,ts,xts]=commu(t,x,u,flag);
%COMMU	is the M-file description of the SIMULINK system named COMMU.
%	The block-diagram can be displayed by typing: COMMU.
%
%	SYS=COMMU(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COMMU to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COMMU with a FLAG of zero:
%	[SIZES]=COMMU([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[81,112,709,489])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Illustrative blocks'.

new_system([sys,'/','Illustrative blocks'])
set_param([sys,'/','Illustrative blocks'],'Location',[79,60,885,251])
set_param([sys,'/','Illustrative blocks'],...
		'Mask Display','.')


%     Finished composite block 'Illustrative blocks'.

set_param([sys,'/','Illustrative blocks'],...
		'orientation',1,...
		'ForeGround',6,...
		'position',[110,347,153,370])


%     Subsystem  'Demonstration blocks'.

new_system([sys,'/','Demonstration blocks'])
set_param([sys,'/','Demonstration blocks'],'Location',[89,142,895,373])

add_block('built-in/Note',[sys,'/','Demonstration blocks/The original test file is in comtest//comtest.m'])
set_param([sys,'/','Demonstration blocks/The original test file is in comtest//comtest.m'],...
		'position',[245,70,250,75])
set_param([sys,'/','Demonstration blocks'],...
		'Mask Display','.')


%     Finished composite block 'Demonstration blocks'.

set_param([sys,'/','Demonstration blocks'],...
		'orientation',1,...
		'BackGround',7,...
		'position',[60,326,103,349])


%     Subsystem  'Available blocks'.

new_system([sys,'/','Available blocks'])
set_param([sys,'/','Available blocks'],'Location',[79,60,885,176])

add_block('built-in/Note',[sys,'/',['Available blocks/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']])
set_param([sys,'/',['Available blocks/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']],...
		'position',[380,40,385,45])
set_param([sys,'/','Available blocks'],...
		'Mask Display','.')


%     Finished composite block 'Available blocks'.

set_param([sys,'/','Available blocks'],...
		'orientation',1,...
		'position',[10,305,53,328])


%     Subsystem  'information1'.

new_system([sys,'/','information1'])
set_param([sys,'/','information1'],'Location',[198,474,1004,748])

add_block('built-in/Note',[sys,'/','information1/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'])
set_param([sys,'/','information1/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'],...
		'position',[350,80,355,85])

add_block('built-in/Note',[sys,'/',['information1/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']])
set_param([sys,'/',['information1/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']],...
		'position',[335,115,340,120])

add_block('built-in/Note',[sys,'/',['information1/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']])
set_param([sys,'/',['information1/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']],...
		'position',[380,40,385,45])
set_param([sys,'/','information1'],...
		'Mask Display','Tutorial',...
		'Mask Dialogue','eval(''hthelp commhelp'')')


%     Finished composite block 'information1'.

set_param([sys,'/','information1'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[10,251,90,295])


%     Subsystem  ['Store N',13,'Display'].

new_system([sys,'/',['Store N',13,'Display']])
set_param([sys,'/',['Store N',13,'Display']],'Location',[427,463,684,617])

add_block('built-in/Inport',[sys,'/',['Store N',13,'Display/in_1']])
set_param([sys,'/',['Store N',13,'Display/in_1']],...
		'position',[55,45,75,65])
set_param([sys,'/',['Store N',13,'Display']],...
		'Mask Display','Sink',...
		'Mask Dialogue','eval(''com_sour;'');')


%     Finished composite block ['Store N',13,'Display'].

set_param([sys,'/',['Store N',13,'Display']],...
		'orientation',2,...
		'hide name',0,...
		'position',[10,188,90,232])


%     Subsystem  '15//11'.

new_system([sys,'/','15//11'])
set_param([sys,'/','15//11'],'Location',[185,105,363,240])

add_block('built-in/Outport',[sys,'/','15//11/out_1'])
set_param([sys,'/','15//11/out_1'],...
		'position',[110,60,130,80])
set_param([sys,'/','15//11'],...
		'Mask Display','Source',...
		'Mask Type','Source',...
		'Mask Dialogue','eval(''com_sour;'')')


%     Finished composite block '15//11'.

set_param([sys,'/','15//11'],...
		'hide name',0,...
		'position',[10,53,90,97])

add_block('built-in/Note',[sys,'/','COMMUNICATIONS TOOLBOX SIMULINK BLOCK LIBRARY'])
set_param([sys,'/','COMMUNICATIONS TOOLBOX SIMULINK BLOCK LIBRARY'],...
		'ForeGround',2,...
		'Font Name','times',...
		'Font Weight','bold',...
		'Font Angle','italic',...
		'Font Size',14,...
		'position',[305,10,310,15])


%     Subsystem  'information'.

new_system([sys,'/','information'])
set_param([sys,'/','information'],'Location',[79,60,855,183])

add_block('built-in/Note',[sys,'/','information/This library contains transmitter and receiver function blocks. The receiving part is almost reverse of the transmitting part.            '])
set_param([sys,'/','information/This library contains transmitter and receiver function blocks. The receiving part is almost reverse of the transmitting part.            '],...
		'position',[390,30,395,35])

add_block('built-in/Note',[sys,'/','information/The transmitting blocks have orientation from left to right. The receiving blocks have orientation from right to left.'])
set_param([sys,'/','information/The transmitting blocks have orientation from left to right. The receiving blocks have orientation from right to left.'],...
		'position',[335,70,340,75])

add_block('built-in/Note',[sys,'/','information/ For a clear relationship, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.'])
set_param([sys,'/','information/ For a clear relationship, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.'],...
		'position',[380,50,385,55])
set_param([sys,'/','information'],...
		'Mask Display','?')


%     Finished composite block 'information'.

set_param([sys,'/','information'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[425,251,475,295])


%     Subsystem  'Utility'.

new_system([sys,'/','Utility'])
set_param([sys,'/','Utility'],'Location',[136,230,381,439])
set_param([sys,'/','Utility'],...
		'Mask Display','Demos',...
		'Mask Dialogue','eval(''com_clos;com_case;%the old one is comtest'')')


%     Finished composite block 'Utility'.

set_param([sys,'/','Utility'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[320,251,400,295])


%     Subsystem  '21//2'.

new_system([sys,'/','21//2'])
set_param([sys,'/','21//2'],'Location',[136,230,381,439])
set_param([sys,'/','21//2'],...
		'Mask Display','Utilities\n/misc',...
		'Mask Dialogue','eval(''com_clos;com_util;'')')


%     Finished composite block '21//2'.

set_param([sys,'/','21//2'],...
		'hide name',0,...
		'position',[215,251,295,295])


%     Subsystem  '4//0'.

new_system([sys,'/','4//0'])
set_param([sys,'/','4//0'],'Location',[618,158,867,453])
set_param([sys,'/','4//0'],...
		'Mask Display','Synchronization',...
		'Mask Dialogue','eval(''com_clos;com_sync;'')')


%     Finished composite block '4//0'.

set_param([sys,'/','4//0'],...
		'hide name',0,...
		'position',[105,251,200,296])


%     Subsystem  '30//14'.

new_system([sys,'/','30//14'])
set_param([sys,'/','30//14'],'Location',[474,259,732,444])

add_block('built-in/Inport',[sys,'/','30//14/in_1'])
set_param([sys,'/','30//14/in_1'],...
		'position',[35,75,55,95])

add_block('built-in/Outport',[sys,'/','30//14/out_1'])
set_param([sys,'/','30//14/out_1'],...
		'position',[145,74,165,96])
add_line([sys,'/','30//14'],[60,85;140,85])
set_param([sys,'/','30//14'],...
		'Mask Display','Error\ncontrol\ncoding',...
		'Mask Dialogue','eval(''com_code;'');')


%     Finished composite block '30//14'.

set_param([sys,'/','30//14'],...
		'hide name',0,...
		'position',[205,53,285,97])


%     Subsystem  'R_Format'.

new_system([sys,'/','R_Format'])
set_param([sys,'/','R_Format'],'Location',[376,224,586,342])

add_block('built-in/Outport',[sys,'/','R_Format/out_1'])
set_param([sys,'/','R_Format/out_1'],...
		'orientation',2,...
		'position',[50,55,70,75])

add_block('built-in/Inport',[sys,'/','R_Format/in_1'])
set_param([sys,'/','R_Format/in_1'],...
		'orientation',2,...
		'position',[165,55,185,75])
add_line([sys,'/','R_Format'],[160,65;75,65])
set_param([sys,'/','R_Format'],...
		'Mask Display','Source\ndecoding',...
		'Mask Dialogue','eval(''com_frmt;'')')


%     Finished composite block 'R_Format'.

set_param([sys,'/','R_Format'],...
		'orientation',2,...
		'hide name',0,...
		'position',[105,188,185,232])


%     Subsystem  '10//3'.

new_system([sys,'/','10//3'])
set_param([sys,'/','10//3'],'Location',[196,122,458,241])

add_block('built-in/Inport',[sys,'/','10//3/in_1'])
set_param([sys,'/','10//3/in_1'],...
		'position',[35,55,55,75])

add_block('built-in/Outport',[sys,'/','10//3/out_1'])
set_param([sys,'/','10//3/out_1'],...
		'position',[175,55,195,75])
add_line([sys,'/','10//3'],[60,65;170,65])
set_param([sys,'/','10//3'],...
		'Mask Display','Source\ncoding',...
		'Mask Dialogue','eval(''com_frmt;'')')


%     Finished composite block '10//3'.

set_param([sys,'/','10//3'],...
		'hide name',0,...
		'position',[105,53,185,97])


%     Subsystem  ['Error-control',13,'decoding'].

new_system([sys,'/',['Error-control',13,'decoding']])
set_param([sys,'/',['Error-control',13,'decoding']],'Location',[642,563,1004,748])

add_block('built-in/Outport',[sys,'/',['Error-control',13,'decoding/out_1']])
set_param([sys,'/',['Error-control',13,'decoding/out_1']],...
		'orientation',2,...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Error-control',13,'decoding/in_1']])
set_param([sys,'/',['Error-control',13,'decoding/in_1']],...
		'orientation',2,...
		'position',[185,70,205,90])
add_line([sys,'/',['Error-control',13,'decoding']],[180,80;65,80])
set_param([sys,'/',['Error-control',13,'decoding']],...
		'Mask Display','Error\ncontrol\ndecoding',...
		'Mask Dialogue','eval(''com_code;'')')


%     Finished composite block ['Error-control',13,'decoding'].

set_param([sys,'/',['Error-control',13,'decoding']],...
		'orientation',2,...
		'hide name',0,...
		'position',[200,188,280,232])


%     Subsystem  '76//36'.

new_system([sys,'/','76//36'])
set_param([sys,'/','76//36'],'Location',[56,131,246,209])

add_block('built-in/Outport',[sys,'/','76//36/out_1'])
set_param([sys,'/','76//36/out_1'],...
		'position',[325,40,345,60])

add_block('built-in/Inport',[sys,'/','76//36/in_1'])
set_param([sys,'/','76//36/in_1'],...
		'position',[235,40,255,60])
add_line([sys,'/','76//36'],[260,50;320,50])
set_param([sys,'/','76//36'],...
		'Mask Display','Modulation',...
		'Mask Dialogue','eval(''com_modu;'')')


%     Finished composite block '76//36'.

set_param([sys,'/','76//36'],...
		'hide name',0,...
		'position',[300,53,380,97])


%     Subsystem  'From others'.

new_system([sys,'/','From others'])
set_param([sys,'/','From others'],'Location',[545,83,880,239])

add_block('built-in/Outport',[sys,'/','From others/out_1'])
set_param([sys,'/','From others/out_1'],...
		'position',[360,65,380,85])

add_block('built-in/Note',[sys,'/',['From others/There is no block in this block. All blocks which',13,'are possibly here have included in the catagory',13,'',13,'Source',13,'Format',13,'Signal compression',13,'Encrypt',13,'Channel coding']])
set_param([sys,'/',['From others/There is no block in this block. All blocks which',13,'are possibly here have included in the catagory',13,'',13,'Source',13,'Format',13,'Signal compression',13,'Encrypt',13,'Channel coding']],...
		'position',[145,15,150,20])
set_param([sys,'/','From others'],...
		'Mask Display','From other\nsource')


%     Finished composite block 'From others'.

set_param([sys,'/','From others'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[295,103,375,137])


%     Subsystem  'To others'.

new_system([sys,'/','To others'])
set_param([sys,'/','To others'],'Location',[305,118,636,286])

add_block('built-in/Inport',[sys,'/','To others/in_1'])
set_param([sys,'/','To others/in_1'],...
		'position',[350,75,370,95])

add_block('built-in/Note',[sys,'/',['To others/There is no block in this block. All blocks which',13,'are possibly here have included in the catagory',13,'',13,'Store and display',13,'Format',13,'Signal expanssion',13,'Decrypt',13,'Channel decoding']])
set_param([sys,'/',['To others/There is no block in this block. All blocks which',13,'are possibly here have included in the catagory',13,'',13,'Store and display',13,'Format',13,'Signal expanssion',13,'Decrypt',13,'Channel decoding']],...
		'position',[165,25,170,30])
set_param([sys,'/','To others'],...
		'Mask Display','To other\nsink')


%     Finished composite block 'To others'.

set_param([sys,'/','To others'],...
		'orientation',2,...
		'ForeGround',6,...
		'hide name',0,...
		'position',[295,149,375,181])


%     Subsystem  ['Analog',13,'Demodulation'].

new_system([sys,'/',['Analog',13,'Demodulation']])
set_param([sys,'/',['Analog',13,'Demodulation']],'Location',[388,518,582,620])

add_block('built-in/Inport',[sys,'/',['Analog',13,'Demodulation/in_1']])
set_param([sys,'/',['Analog',13,'Demodulation/in_1']],...
		'orientation',2,...
		'position',[120,20,140,40])

add_block('built-in/Outport',[sys,'/',['Analog',13,'Demodulation/out_1']])
set_param([sys,'/',['Analog',13,'Demodulation/out_1']],...
		'orientation',2,...
		'position',[40,20,60,40])
add_line([sys,'/',['Analog',13,'Demodulation']],[115,30;65,30])
set_param([sys,'/',['Analog',13,'Demodulation']],...
		'Mask Display','Demodulation',...
		'Mask Dialogue','eval(''com_modu;'')')


%     Finished composite block ['Analog',13,'Demodulation'].

set_param([sys,'/',['Analog',13,'Demodulation']],...
		'orientation',2,...
		'hide name',0,...
		'position',[300,188,380,232])


%     Subsystem  '4//4'.

new_system([sys,'/','4//4'])
set_param([sys,'/','4//4'],'Location',[165,401,464,518])

add_block('built-in/Outport',[sys,'/','4//4/out_1'])
set_param([sys,'/','4//4/out_1'],...
		'position',[245,30,265,50])

add_block('built-in/Inport',[sys,'/','4//4/in_2'])
set_param([sys,'/','4//4/in_2'],...
		'Port','2',...
		'position',[80,60,100,80])

add_block('built-in/Mux',[sys,'/','4//4/Mux'])
set_param([sys,'/','4//4/Mux'],...
		'inputs','2',...
		'position',[145,21,180,54])

add_block('built-in/Inport',[sys,'/','4//4/in_1'])
set_param([sys,'/','4//4/in_1'],...
		'position',[60,20,80,40])
add_line([sys,'/','4//4'],[185,40;240,40])
add_line([sys,'/','4//4'],[105,70;115,70;115,45;140,45])
add_line([sys,'/','4//4'],[85,30;140,30])
set_param([sys,'/','4//4'],...
		'Mask Display','Multiple\naccess',...
		'Mask Dialogue','eval(''com_mlac;'')')


%     Finished composite block '4//4'.

set_param([sys,'/','4//4'],...
		'hide name',0,...
		'position',[400,63,480,107])


%     Subsystem  'R_Multi_Access 1'.

new_system([sys,'/','R_Multi_Access 1'])
set_param([sys,'/','R_Multi_Access 1'],'Location',[237,76,591,202])

add_block('built-in/Inport',[sys,'/','R_Multi_Access 1/in_1'])
set_param([sys,'/','R_Multi_Access 1/in_1'],...
		'orientation',2,...
		'position',[285,50,305,70])

add_block('built-in/Demux',[sys,'/','R_Multi_Access 1/Demux'])
set_param([sys,'/','R_Multi_Access 1/Demux'],...
		'orientation',2,...
		'outputs','2',...
		'position',[155,40,195,75])

add_block('built-in/Outport',[sys,'/','R_Multi_Access 1/out_2'])
set_param([sys,'/','R_Multi_Access 1/out_2'],...
		'orientation',2,...
		'Port','2',...
		'position',[75,75,95,95])

add_block('built-in/Outport',[sys,'/','R_Multi_Access 1/out_1'])
set_param([sys,'/','R_Multi_Access 1/out_1'],...
		'orientation',2,...
		'position',[75,25,95,45])
add_line([sys,'/','R_Multi_Access 1'],[280,60;200,60])
add_line([sys,'/','R_Multi_Access 1'],[150,65;135,65;135,85;100,85])
add_line([sys,'/','R_Multi_Access 1'],[150,50;135,50;135,35;100,35])
set_param([sys,'/','R_Multi_Access 1'],...
		'Mask Display','Multiple\naccess',...
		'Mask Dialogue','eval(''com_mlac;'')')


%     Finished composite block 'R_Multi_Access 1'.

set_param([sys,'/','R_Multi_Access 1'],...
		'orientation',2,...
		'hide name',0,...
		'position',[400,178,480,222])


%     Subsystem  '4//1'.

new_system([sys,'/','4//1'])
set_param([sys,'/','4//1'],'Location',[126,473,408,606])

add_block('built-in/Inport',[sys,'/','4//1/in_1'])
set_param([sys,'/','4//1/in_1'],...
		'position',[35,45,55,65])

add_block('built-in/Outport',[sys,'/','4//1/out_1'])
set_param([sys,'/','4//1/out_1'],...
		'position',[190,45,210,65])
add_line([sys,'/','4//1'],[60,55;185,55])
set_param([sys,'/','4//1'],...
		'Mask Display','Transmitter\n/filters',...
		'Mask Dialogue','eval(''com_filt;'')')


%     Finished composite block '4//1'.

set_param([sys,'/','4//1'],...
		'hide name',0,...
		'position',[495,63,575,107])


%     Subsystem  'Receiver'.

new_system([sys,'/','Receiver'])
set_param([sys,'/','Receiver'],'Location',[384,427,663,590])

add_block('built-in/Outport',[sys,'/','Receiver/out_1'])
set_param([sys,'/','Receiver/out_1'],...
		'orientation',2,...
		'position',[80,50,100,70])

add_block('built-in/Inport',[sys,'/','Receiver/in_1'])
set_param([sys,'/','Receiver/in_1'],...
		'orientation',2,...
		'position',[215,50,235,70])
add_line([sys,'/','Receiver'],[210,60;105,60])
set_param([sys,'/','Receiver'],...
		'Mask Display','Receiver\n/filters',...
		'Mask Dialogue','eval(''com_filt;'')')


%     Finished composite block 'Receiver'.

set_param([sys,'/','Receiver'],...
		'orientation',2,...
		'hide name',0,...
		'position',[495,178,575,222])


%     Subsystem  '8//0'.

new_system([sys,'/','8//0'])
set_param([sys,'/','8//0'],'Location',[446,298,1025,565])


%     Subsystem  '8//0/Sub-system4'.

new_system([sys,'/','8//0/Sub-system4'])
set_param([sys,'/','8//0/Sub-system4'],'Location',[586,358,1012,641])

add_block('built-in/Inport',[sys,'/','8//0/Sub-system4/in_1'])
set_param([sys,'/','8//0/Sub-system4/in_1'],...
		'position',[35,135,55,155])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system4/out_1'])
set_param([sys,'/','8//0/Sub-system4/out_1'],...
		'position',[145,135,165,155])
add_line([sys,'/','8//0/Sub-system4'],[60,145;140,145])
set_param([sys,'/','8//0/Sub-system4'],...
		'Mask Display','Loss')


%     Finished composite block '8//0/Sub-system4'.

set_param([sys,'/','8//0/Sub-system4'],...
		'hide name',0,...
		'position',[165,73,235,117])

add_block('built-in/Inport',[sys,'/','8//0/in_1'])
set_param([sys,'/','8//0/in_1'],...
		'position',[35,85,55,105])


%     Subsystem  '8//0/Sub-system5'.

new_system([sys,'/','8//0/Sub-system5'])
set_param([sys,'/','8//0/Sub-system5'],'Location',[213,332,807,610])


%     Subsystem  '8//0/Sub-system5/Sub-system5'.

new_system([sys,'/','8//0/Sub-system5/Sub-system5'])
set_param([sys,'/','8//0/Sub-system5/Sub-system5'],'Location',[196,225,790,503])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system5/Sub-system5/out_1'])
set_param([sys,'/','8//0/Sub-system5/Sub-system5/out_1'],...
		'position',[395,35,415,55])
set_param([sys,'/','8//0/Sub-system5/Sub-system5'],...
		'Mask Display','Intersymbol Interference')


%     Finished composite block '8//0/Sub-system5/Sub-system5'.

set_param([sys,'/','8//0/Sub-system5/Sub-system5'],...
		'hide name',0,...
		'position',[30,25,200,65])


%     Subsystem  '8//0/Sub-system5/Sub-system6'.

new_system([sys,'/','8//0/Sub-system5/Sub-system6'])
set_param([sys,'/','8//0/Sub-system5/Sub-system6'],'Location',[196,225,790,503])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system5/Sub-system6/out_1'])
set_param([sys,'/','8//0/Sub-system5/Sub-system6/out_1'],...
		'position',[395,35,415,55])
set_param([sys,'/','8//0/Sub-system5/Sub-system6'],...
		'Mask Display','Adjacent channel interference')


%     Finished composite block '8//0/Sub-system5/Sub-system6'.

set_param([sys,'/','8//0/Sub-system5/Sub-system6'],...
		'hide name',0,...
		'position',[30,82,200,118])


%     Subsystem  '8//0/Sub-system5/Sub-system7'.

new_system([sys,'/','8//0/Sub-system5/Sub-system7'])
set_param([sys,'/','8//0/Sub-system5/Sub-system7'],'Location',[196,225,790,503])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system5/Sub-system7/out_1'])
set_param([sys,'/','8//0/Sub-system5/Sub-system7/out_1'],...
		'position',[395,35,415,55])
set_param([sys,'/','8//0/Sub-system5/Sub-system7'],...
		'Mask Display','Co-channel interference')


%     Finished composite block '8//0/Sub-system5/Sub-system7'.

set_param([sys,'/','8//0/Sub-system5/Sub-system7'],...
		'hide name',0,...
		'position',[30,142,200,178])

add_block('built-in/Mux',[sys,'/','8//0/Sub-system5/Mux'])
set_param([sys,'/','8//0/Sub-system5/Mux'],...
		'inputs','2',...
		'position',[270,46,305,79])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system5/out_1'])
set_param([sys,'/','8//0/Sub-system5/out_1'],...
		'position',[395,55,415,75])
add_line([sys,'/','8//0/Sub-system5'],[205,45;230,45;230,55;265,55])
add_line([sys,'/','8//0/Sub-system5'],[205,100;230,100;230,70;265,70])
add_line([sys,'/','8//0/Sub-system5'],[310,65;390,65])
set_param([sys,'/','8//0/Sub-system5'],...
		'Mask Display','Interference')


%     Finished composite block '8//0/Sub-system5'.

set_param([sys,'/','8//0/Sub-system5'],...
		'hide name',0,...
		'position',[165,141,235,189])

add_block('built-in/Note',[sys,'/','8//0/Satellite Communications'])
set_param([sys,'/','8//0/Satellite Communications'],...
		'position',[70,215,75,220])

add_block('built-in/Note',[sys,'/','8//0/Fiber Optic Communications'])
set_param([sys,'/','8//0/Fiber Optic Communications'],...
		'position',[80,240,85,245])


%     Subsystem  '8//0/Sub-system1'.

new_system([sys,'/','8//0/Sub-system1'])
set_param([sys,'/','8//0/Sub-system1'],'Location',[575,99,983,538])


%     Subsystem  '8//0/Sub-system1/Sub-system1'.

new_system([sys,'/','8//0/Sub-system1/Sub-system1'])
set_param([sys,'/','8//0/Sub-system1/Sub-system1'],'Location',[185,298,593,741])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system1/Sub-system1/out_1'])
set_param([sys,'/','8//0/Sub-system1/Sub-system1/out_1'],...
		'position',[295,85,315,105])

add_block('built-in/Constant',[sys,'/','8//0/Sub-system1/Sub-system1/Switch Key'])
set_param([sys,'/','8//0/Sub-system1/Sub-system1/Switch Key'],...
		'position',[115,100,135,120])
add_line([sys,'/','8//0/Sub-system1/Sub-system1'],[140,110;210,110;210,95;290,95])
set_param([sys,'/','8//0/Sub-system1/Sub-system1'],...
		'Mask Display','LO phase noise')


%     Finished composite block '8//0/Sub-system1/Sub-system1'.

set_param([sys,'/','8//0/Sub-system1/Sub-system1'],...
		'hide name',0,...
		'position',[30,26,120,74])


%     Subsystem  '8//0/Sub-system1/Sub-system2'.

new_system([sys,'/','8//0/Sub-system1/Sub-system2'])
set_param([sys,'/','8//0/Sub-system1/Sub-system2'],'Location',[568,271,976,714])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system1/Sub-system2/out_1'])
set_param([sys,'/','8//0/Sub-system1/Sub-system2/out_1'],...
		'position',[295,85,315,105])

add_block('built-in/Constant',[sys,'/','8//0/Sub-system1/Sub-system2/Switch Key'])
set_param([sys,'/','8//0/Sub-system1/Sub-system2/Switch Key'],...
		'position',[130,85,150,105])
add_line([sys,'/','8//0/Sub-system1/Sub-system2'],[155,95;290,95])
set_param([sys,'/','8//0/Sub-system1/Sub-system2'],...
		'Mask Display','Random Noise')


%     Finished composite block '8//0/Sub-system1/Sub-system2'.

set_param([sys,'/','8//0/Sub-system1/Sub-system2'],...
		'hide name',0,...
		'position',[30,101,120,149])


%     Subsystem  '8//0/Sub-system1/Sub-system3'.

new_system([sys,'/','8//0/Sub-system1/Sub-system3'])
set_param([sys,'/','8//0/Sub-system1/Sub-system3'],'Location',[568,271,976,714])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system1/Sub-system3/out_1'])
set_param([sys,'/','8//0/Sub-system1/Sub-system3/out_1'],...
		'position',[295,85,315,105])

add_block('built-in/Constant',[sys,'/','8//0/Sub-system1/Sub-system3/Switch Key'])
set_param([sys,'/','8//0/Sub-system1/Sub-system3/Switch Key'],...
		'position',[110,85,130,105])
add_line([sys,'/','8//0/Sub-system1/Sub-system3'],[135,95;290,95])
set_param([sys,'/','8//0/Sub-system1/Sub-system3'],...
		'Mask Display','Atmosphere Noise')


%     Finished composite block '8//0/Sub-system1/Sub-system3'.

set_param([sys,'/','8//0/Sub-system1/Sub-system3'],...
		'hide name',0,...
		'position',[30,171,135,219])


%     Subsystem  '8//0/Sub-system1/Sub-system4'.

new_system([sys,'/','8//0/Sub-system1/Sub-system4'])
set_param([sys,'/','8//0/Sub-system1/Sub-system4'],'Location',[568,271,976,714])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system1/Sub-system4/out_1'])
set_param([sys,'/','8//0/Sub-system1/Sub-system4/out_1'],...
		'position',[295,85,315,105])

add_block('built-in/Constant',[sys,'/','8//0/Sub-system1/Sub-system4/Switch Key'])
set_param([sys,'/','8//0/Sub-system1/Sub-system4/Switch Key'],...
		'Value','2',...
		'position',[95,80,115,100])
add_line([sys,'/','8//0/Sub-system1/Sub-system4'],[120,90;200,90;200,95;290,95])
set_param([sys,'/','8//0/Sub-system1/Sub-system4'],...
		'Mask Display','IM Noise')


%     Finished composite block '8//0/Sub-system1/Sub-system4'.

set_param([sys,'/','8//0/Sub-system1/Sub-system4'],...
		'hide name',0,...
		'position',[30,231,135,279])


%     Subsystem  '8//0/Sub-system1/Sub-system5'.

new_system([sys,'/','8//0/Sub-system1/Sub-system5'])
set_param([sys,'/','8//0/Sub-system1/Sub-system5'],'Location',[568,271,976,714])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system1/Sub-system5/out_1'])
set_param([sys,'/','8//0/Sub-system1/Sub-system5/out_1'],...
		'position',[295,85,315,105])

add_block('built-in/Constant',[sys,'/','8//0/Sub-system1/Sub-system5/Switch Key'])
set_param([sys,'/','8//0/Sub-system1/Sub-system5/Switch Key'],...
		'position',[100,85,120,105])
add_line([sys,'/','8//0/Sub-system1/Sub-system5'],[125,95;290,95])
set_param([sys,'/','8//0/Sub-system1/Sub-system5'],...
		'Mask Display','Terrestrial Noise')


%     Finished composite block '8//0/Sub-system1/Sub-system5'.

set_param([sys,'/','8//0/Sub-system1/Sub-system5'],...
		'hide name',0,...
		'position',[30,291,135,339])


%     Subsystem  '8//0/Sub-system1/Sub-system6'.

new_system([sys,'/','8//0/Sub-system1/Sub-system6'])
set_param([sys,'/','8//0/Sub-system1/Sub-system6'],'Location',[568,271,976,714])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system1/Sub-system6/out_1'])
set_param([sys,'/','8//0/Sub-system1/Sub-system6/out_1'],...
		'position',[295,85,315,105])

add_block('built-in/Constant',[sys,'/','8//0/Sub-system1/Sub-system6/Switch Key'])
set_param([sys,'/','8//0/Sub-system1/Sub-system6/Switch Key'],...
		'position',[65,85,85,105])
add_line([sys,'/','8//0/Sub-system1/Sub-system6'],[90,95;290,95])
set_param([sys,'/','8//0/Sub-system1/Sub-system6'],...
		'Mask Display','Receiver Noise')


%     Finished composite block '8//0/Sub-system1/Sub-system6'.

set_param([sys,'/','8//0/Sub-system1/Sub-system6'],...
		'hide name',0,...
		'position',[30,361,135,409])

add_block('built-in/Mux',[sys,'/','8//0/Sub-system1/Mux'])
set_param([sys,'/','8//0/Sub-system1/Mux'],...
		'inputs','2',...
		'position',[220,206,255,239])

add_block('built-in/Mux',[sys,'/','8//0/Sub-system1/Mux1'])
set_param([sys,'/','8//0/Sub-system1/Mux1'],...
		'inputs','2',...
		'position',[230,81,265,114])

add_block('built-in/Mux',[sys,'/','8//0/Sub-system1/Mux2'])
set_param([sys,'/','8//0/Sub-system1/Mux2'],...
		'inputs','2',...
		'position',[235,321,270,354])

add_block('built-in/Outport',[sys,'/','8//0/Sub-system1/out_1'])
set_param([sys,'/','8//0/Sub-system1/out_1'],...
		'position',[365,215,385,235])

add_block('built-in/Sum',[sys,'/','8//0/Sub-system1/Sum'])
set_param([sys,'/','8//0/Sub-system1/Sum'],...
		'inputs','+++',...
		'position',[325,207,345,243])
add_line([sys,'/','8//0/Sub-system1'],[125,50;170,50;170,90;225,90])
add_line([sys,'/','8//0/Sub-system1'],[125,125;170,125;170,105;225,105])
add_line([sys,'/','8//0/Sub-system1'],[140,195;170,195;170,215;215,215])
add_line([sys,'/','8//0/Sub-system1'],[140,255;170,255;170,230;215,230])
add_line([sys,'/','8//0/Sub-system1'],[140,315;180,315;180,330;230,330])
add_line([sys,'/','8//0/Sub-system1'],[140,385;180,385;180,345;230,345])
add_line([sys,'/','8//0/Sub-system1'],[270,100;280,100;280,215;320,215])
add_line([sys,'/','8//0/Sub-system1'],[260,225;320,225])
add_line([sys,'/','8//0/Sub-system1'],[275,340;280,340;280,235;320,235])
add_line([sys,'/','8//0/Sub-system1'],[350,225;360,225])
set_param([sys,'/','8//0/Sub-system1'],...
		'Mask Display','Noise')


%     Finished composite block '8//0/Sub-system1'.

set_param([sys,'/','8//0/Sub-system1'],...
		'hide name',0,...
		'position',[165,10,235,60])

add_block('built-in/Sum',[sys,'/','8//0/Sum'])
set_param([sys,'/','8//0/Sum'],...
		'inputs','+++',...
		'position',[340,77,360,113])

add_block('built-in/Outport',[sys,'/','8//0/out_1'])
set_param([sys,'/','8//0/out_1'],...
		'position',[455,85,475,105])
add_line([sys,'/','8//0'],[60,95;160,95])
add_line([sys,'/','8//0'],[240,35;295,35;295,85;335,85])
add_line([sys,'/','8//0'],[240,165;295,165;295,105;335,105])
add_line([sys,'/','8//0'],[240,95;335,95])
add_line([sys,'/','8//0'],[365,95;450,95])
set_param([sys,'/','8//0'],...
		'Mask Display','C\nh\na\nn\nn\ne\nl',...
		'Mask Dialogue','eval(''com_chan;'')')


%     Finished composite block '8//0'.

set_param([sys,'/','8//0'],...
		'orientation',1,...
		'hide name',0,...
		'move name',0,...
		'position',[588,100,622,195])
add_line(sys,[195,210;190,210])
add_line(sys,[490,200;485,200])
add_line(sys,[580,85;605,95])
add_line(sys,[605,200;580,200])
add_line(sys,[395,190;390,190;380,165])
add_line(sys,[380,120;385,120;395,95])
add_line(sys,[95,75;100,75])
add_line(sys,[100,210;95,210])
add_line(sys,[290,75;295,75])
add_line(sys,[485,85;490,85])
add_line(sys,[385,75;395,75])
add_line(sys,[295,210;285,210])
add_line(sys,[395,210;385,210])
add_line(sys,[190,75;200,75])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
