function [ret,x0,str,ts,xts]=comtest(t,x,u,flag);
%COMTEST	is the M-file description of the SIMULINK system named COMTEST.
%	The block-diagram can be displayed by typing: COMTEST.
%
%	SYS=COMTEST(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COMTEST to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COMTEST with a FLAG of zero:
%	[SIZES]=COMTEST([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[125,80,701,431])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['APK Mo//Dem',13,'demo'].

new_system([sys,'/',['APK Mo//Dem',13,'demo']])
set_param([sys,'/',['APK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['APK Mo//Dem',13,'demo']],...
		'Mask Display','APK\ndemo',...
		'Mask Dialogue','eval(''tstapk'')')


%     Finished composite block ['APK Mo//Dem',13,'demo'].

set_param([sys,'/',['APK Mo//Dem',13,'demo']],...
		'position',[365,195,435,236])


%     Subsystem  ['QASK Mo//Dem',13,'demo'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo']],...
		'Mask Display','QASK\ndemo',...
		'Mask Dialogue','eval(''tstqask'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo']],...
		'position',[235,195,305,236])


%     Subsystem  ['Digital Mo//Demo',13,'demo'].

new_system([sys,'/',['Digital Mo//Demo',13,'demo']])
set_param([sys,'/',['Digital Mo//Demo',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Digital Mo//Demo',13,'demo']],...
		'Mask Display','D-Mo/Dem\ndemo',...
		'Mask Dialogue','eval(''tstdimo'')')


%     Finished composite block ['Digital Mo//Demo',13,'demo'].

set_param([sys,'/',['Digital Mo//Demo',13,'demo']],...
		'position',[115,195,185,236])


%     Subsystem  ['Freq//Phase',13,'Mo//Dem demo'].

new_system([sys,'/',['Freq//Phase',13,'Mo//Dem demo']])
set_param([sys,'/',['Freq//Phase',13,'Mo//Dem demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Freq//Phase',13,'Mo//Dem demo']],...
		'Mask Display','FM/PM\ndemo',...
		'Mask Dialogue','eval(''tstfmpm'')')


%     Finished composite block ['Freq//Phase',13,'Mo//Dem demo'].

set_param([sys,'/',['Freq//Phase',13,'Mo//Dem demo']],...
		'position',[485,110,555,151])


%     Subsystem  ['Envelop Detector',13,'demo'].

new_system([sys,'/',['Envelop Detector',13,'demo']])
set_param([sys,'/',['Envelop Detector',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Envelop Detector',13,'demo']],...
		'Mask Display','Evelop-D\ndemo',...
		'Mask Dialogue','eval(''tstenv'')')


%     Finished composite block ['Envelop Detector',13,'demo'].

set_param([sys,'/',['Envelop Detector',13,'demo']],...
		'position',[240,25,310,66])


%     Subsystem  ['Quadrature Ampl',13,'Mo//Dem demo'].

new_system([sys,'/',['Quadrature Ampl',13,'Mo//Dem demo']])
set_param([sys,'/',['Quadrature Ampl',13,'Mo//Dem demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Quadrature Ampl',13,'Mo//Dem demo']],...
		'Mask Display','QAM\ndemo',...
		'Mask Dialogue','eval(''tstqam'')')


%     Finished composite block ['Quadrature Ampl',13,'Mo//Dem demo'].

set_param([sys,'/',['Quadrature Ampl',13,'Mo//Dem demo']],...
		'position',[365,110,435,151])


%     Subsystem  ['SSB Ampl',13,'Mo//Dem demo'].

new_system([sys,'/',['SSB Ampl',13,'Mo//Dem demo']])
set_param([sys,'/',['SSB Ampl',13,'Mo//Dem demo']],'Location',[175,552,335,697])
set_param([sys,'/',['SSB Ampl',13,'Mo//Dem demo']],...
		'Mask Display','SSAM\ndemo',...
		'Mask Dialogue','eval(''ts=.01;[num,den]=butter(2,100/pi/2*ts);testssba;'')')


%     Finished composite block ['SSB Ampl',13,'Mo//Dem demo'].

set_param([sys,'/',['SSB Ampl',13,'Mo//Dem demo']],...
		'position',[240,110,310,151])


%     Subsystem  ['DSB Ampl',13,'Mo//Dem demo'].

new_system([sys,'/',['DSB Ampl',13,'Mo//Dem demo']])
set_param([sys,'/',['DSB Ampl',13,'Mo//Dem demo']],'Location',[175,552,335,697])
set_param([sys,'/',['DSB Ampl',13,'Mo//Dem demo']],...
		'Mask Display','AM\ndemo',...
		'Mask Dialogue','eval(''tstam'')')


%     Finished composite block ['DSB Ampl',13,'Mo//Dem demo'].

set_param([sys,'/',['DSB Ampl',13,'Mo//Dem demo']],...
		'position',[115,110,185,151])


%     Subsystem  ['Phase-Locked',13,'Loop demo'].

new_system([sys,'/',['Phase-Locked',13,'Loop demo']])
set_param([sys,'/',['Phase-Locked',13,'Loop demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Phase-Locked',13,'Loop demo']],...
		'Mask Display','PLL\ndemo',...
		'Mask Dialogue','eval(''tstpll'')')


%     Finished composite block ['Phase-Locked',13,'Loop demo'].

set_param([sys,'/',['Phase-Locked',13,'Loop demo']],...
		'hide name',0,...
		'position',[115,25,185,66])

add_block('built-in/Note',[sys,'/',['Synchronization',13,'//Utilities']])
set_param([sys,'/',['Synchronization',13,'//Utilities']],...
		'position',[50,25,55,30])

add_block('built-in/Note',[sys,'/',['Analog',13,'Mo//Dem']])
set_param([sys,'/',['Analog',13,'Mo//Dem']],...
		'position',[50,110,55,115])

add_block('built-in/Note',[sys,'/',['Digital',13,'Mo//Dem']])
set_param([sys,'/',['Digital',13,'Mo//Dem']],...
		'position',[45,200,50,205])


%     Subsystem  ['Decimal//Binary',13,'conversion'].

new_system([sys,'/',['Decimal//Binary',13,'conversion']])
set_param([sys,'/',['Decimal//Binary',13,'conversion']],'Location',[175,552,335,697])
set_param([sys,'/',['Decimal//Binary',13,'conversion']],...
		'Mask Display','D/B convert\n demo',...
		'Mask Dialogue','eval(''tstbide'')')


%     Finished composite block ['Decimal//Binary',13,'conversion'].

set_param([sys,'/',['Decimal//Binary',13,'conversion']],...
		'ForeGround',4,...
		'position',[360,25,430,66])

add_block('built-in/Note',[sys,'/',['Encode',13,'Decode']])
set_param([sys,'/',['Encode',13,'Decode']],...
		'position',[40,280,45,285])


%     Subsystem  ['Raised cosine',13,'filter'].

new_system([sys,'/',['Raised cosine',13,'filter']])
set_param([sys,'/',['Raised cosine',13,'filter']],'Location',[175,552,335,697])
set_param([sys,'/',['Raised cosine',13,'filter']],...
		'Mask Display','R-cos-filter\n demo',...
		'Mask Dialogue','eval(''tstrcos'')')


%     Finished composite block ['Raised cosine',13,'filter'].

set_param([sys,'/',['Raised cosine',13,'filter']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[480,25,550,66])


%     Subsystem  ['Hamming Co//Dec',13,'demo'].

new_system([sys,'/',['Hamming Co//Dec',13,'demo']])
set_param([sys,'/',['Hamming Co//Dec',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Hamming Co//Dec',13,'demo']],...
		'Mask Display','Hamming\nCo/Dec',...
		'Mask Dialogue','eval(''tsthammc'')')


%     Finished composite block ['Hamming Co//Dec',13,'demo'].

set_param([sys,'/',['Hamming Co//Dec',13,'demo']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[235,272,305,311])


%     Subsystem  ['Cyclic Co//Dec',13,'demo'].

new_system([sys,'/',['Cyclic Co//Dec',13,'demo']])
set_param([sys,'/',['Cyclic Co//Dec',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Cyclic Co//Dec',13,'demo']],...
		'Mask Display','Cyclic\nCo/Dec',...
		'Mask Dialogue','eval(''tstcyclc'')')


%     Finished composite block ['Cyclic Co//Dec',13,'demo'].

set_param([sys,'/',['Cyclic Co//Dec',13,'demo']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[360,272,433,311])


%     Subsystem  ['Linear Co//Dec',13,'demo'].

new_system([sys,'/',['Linear Co//Dec',13,'demo']])
set_param([sys,'/',['Linear Co//Dec',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['Linear Co//Dec',13,'demo']],...
		'Mask Display','Linear\nCo/Dec',...
		'Mask Dialogue','eval(''tstlinco'')')


%     Finished composite block ['Linear Co//Dec',13,'demo'].

set_param([sys,'/',['Linear Co//Dec',13,'demo']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[110,272,186,311])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
