function [ret,x0,str,ts,xts]=elg(t,x,u,flag);
%ELG	is the M-file description of the SIMULINK system named ELG.
%	The block-diagram can be displayed by typing: ELG.
%
%	SYS=ELG(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes ELG to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling ELG with a FLAG of zero:
%	[SIZES]=ELG([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[122,326,758,706])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-23')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '1/12000/2')
set_param(sys,'Max step size', '1/12000/2')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback',['tss=1/12000;tdd=1/600;MM=2;Fc=1200;Fshift=1200;[f1num,f1den]=butter(4,2*pi*4000,''s'');f2num=fir1(127,(Fshift/2+1/tdd)*2*tss);f2den=[1,zeros(1,127)];']);


%     Subsystem  'MFSK mod'.

new_system([sys,'/','MFSK mod'])
set_param([sys,'/','MFSK mod'],'Location',[624,140,1004,330])

add_block('built-in/Outport',[sys,'/','MFSK mod/out_1'])
set_param([sys,'/','MFSK mod/out_1'],...
		'position',[290,60,310,80])

add_block('built-in/Inport',[sys,'/','MFSK mod/in_1'])
set_param([sys,'/','MFSK mod/in_1'],...
		'position',[15,60,35,80])


%     Subsystem  'MFSK mod/MFSK map'.

new_system([sys,'/','MFSK mod/MFSK map'])
set_param([sys,'/','MFSK mod/MFSK map'],'Location',[90,420,407,543])

add_block('built-in/Zero-Order Hold',[sys,'/',['MFSK mod/MFSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MFSK mod/MFSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[105,39,140,71])

add_block('built-in/Outport',[sys,'/','MFSK mod/MFSK map/out_1'])
set_param([sys,'/','MFSK mod/MFSK map/out_1'],...
		'position',[260,45,280,65])

add_block('built-in/Gain',[sys,'/','MFSK mod/MFSK map/Gain'])
set_param([sys,'/','MFSK mod/MFSK map/Gain'],...
		'Gain','Ton',...
		'position',[175,38,225,72])

add_block('built-in/Inport',[sys,'/','MFSK mod/MFSK map/in_1'])
set_param([sys,'/','MFSK mod/MFSK map/in_1'],...
		'position',[45,45,65,65])
add_line([sys,'/','MFSK mod/MFSK map'],[145,55;170,55])
add_line([sys,'/','MFSK mod/MFSK map'],[70,55;100,55])
add_line([sys,'/','MFSK mod/MFSK map'],[230,55;255,55])
set_param([sys,'/','MFSK mod/MFSK map'],...
		'Mask Display','MFSK\nmap',...
		'Mask Type','MFSK map')
set_param([sys,'/','MFSK mod/MFSK map'],...
		'Mask Dialogue','Map input digital signal to analog tone space for FM modulation. The tone space\nis the frequency distance between two \nconsective digit numbers.|Tone space (Hz):|Input symbol interval and offset (sec):')
set_param([sys,'/','MFSK mod/MFSK map'],...
		'Mask Translate','Ton=@1;td=@2;')
set_param([sys,'/','MFSK mod/MFSK map'],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the FM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. Tone space is the frequency separation between two consective digits for the input signal. After FM, the modulated signal has a frequency in the range of [Fc, Fc+B]. B is the bandwidth of the FSK, B=(M-1) * Tone_space.')
set_param([sys,'/','MFSK mod/MFSK map'],...
		'Mask Entries','Ton\/td\/')


%     Finished composite block 'MFSK mod/MFSK map'.

set_param([sys,'/','MFSK mod/MFSK map'],...
		'position',[75,48,155,92])


%     Subsystem  ['MFSK mod/FM',13,'passband'].

new_system([sys,'/',['MFSK mod/FM',13,'passband']])
set_param([sys,'/',['MFSK mod/FM',13,'passband']],'Location',[102,348,590,498])

add_block('built-in/Inport',[sys,'/',['MFSK mod/FM',13,'passband/in_1']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/in_1']],...
		'position',[60,40,80,60])

add_block('built-in/Outport',[sys,'/',['MFSK mod/FM',13,'passband/out_1']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/out_1']],...
		'position',[465,50,485,70])

add_block('built-in/Fcn',[sys,'/',['MFSK mod/FM',13,'passband/sin']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/sin']],...
		'Expr','cos(u[1]*pi2+Ph)',...
		'position',[290,45,430,75])

add_block('built-in/Constant',[sys,'/',['MFSK mod/FM',13,'passband/Constant']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/Constant']],...
		'Value','Fc',...
		'position',[40,85,60,105])

add_block('built-in/S-Function',[sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[200,39,260,81])

add_block('built-in/Sum',[sys,'/',['MFSK mod/FM',13,'passband/Sum']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/Sum']],...
		'position',[130,42,150,78])
add_line([sys,'/',['MFSK mod/FM',13,'passband']],[435,60;460,60])
add_line([sys,'/',['MFSK mod/FM',13,'passband']],[265,60;285,60])
add_line([sys,'/',['MFSK mod/FM',13,'passband']],[155,60;195,60])
add_line([sys,'/',['MFSK mod/FM',13,'passband']],[65,95;90,95;90,70;125,70])
add_line([sys,'/',['MFSK mod/FM',13,'passband']],[85,50;125,50])
set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);FM',...
		'Mask Type','Passband FM')
set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using FM method.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):|Symbol interval (sec; Use Inf for analog mod);')
set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2;pi2=2*pi;ts=@3;td=@4;if isinf(td),td=inf;end;[x,y]=moduicon(3);')
set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'Mask Help','This block modulates the input signal using frequency modulation method. The frequency of the output of the carrier signal depends on the amplitude of the input signal.')
set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'Mask Entries','Fc\/Ph\/ts\/td\/')


%     Finished composite block ['MFSK mod/FM',13,'passband'].

set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'ForeGround',4,...
		'position',[190,48,270,92])
add_line([sys,'/','MFSK mod'],[40,70;70,70])
add_line([sys,'/','MFSK mod'],[275,70;285,70])
add_line([sys,'/','MFSK mod'],[160,70;185,70])
set_param([sys,'/','MFSK mod'],...
		'Mask Display','plot(0,0,100,100,x,y);MFSK',...
		'Mask Type','Passband FSK modulation')
set_param([sys,'/','MFSK mod'],...
		'Mask Dialogue','Modulate the input digital signal using M-ary frequency shift keying method.|Tone space(Hz):|Symbol interval (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample frequency (sec):')
set_param([sys,'/','MFSK mod'],...
		'Mask Translate','Ton=@1;td=@2;Fc=@3;Ph=@4;ts=@5;[x,y]=moduicon(7);')
set_param([sys,'/','MFSK mod'],...
		'Mask Help','This block modulates a digital signal using FSK method. The modulation resets the modulation phase to be the specified initial phase at the beginning of each digit. Tone space is the frequency distance between two consecutive digits after modulation. The output signal has its frequency in the range [Fc, Fc + Tone_space*Max_In_Value], where Fc is the carrier frequency.')
set_param([sys,'/','MFSK mod'],...
		'Mask Entries','Fshift\/tdd\/Fc\/0\/tss\/')


%     Finished composite block 'MFSK mod'.

set_param([sys,'/','MFSK mod'],...
		'hide name',0,...
		'position',[180,23,260,67])


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(300,1,MM)\/tdd\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[20,23,100,67])

add_block('built-in/Transfer Fcn',[sys,'/',['Anti-Aliasing',13,'Filter']])
set_param([sys,'/',['Anti-Aliasing',13,'Filter']],...
		'Numerator','f1num',...
		'Denominator','f1den',...
		'position',[335,28,395,62])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'orientation',2,...
		'ForeGround',5,...
		'hide name',0,...
		'Gain','10',...
		'position',[275,197,300,223])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay']])
set_param([sys,'/',['Transport',13,'Delay']],...
		'orientation',2,...
		'ForeGround',3,...
		'hide name',0,...
		'Delay Time','tdd/4',...
		'position',[265,255,305,285])


%     Subsystem  ['Discrete',13,' Early-Late',13,' Gate'].

new_system([sys,'/',['Discrete',13,' Early-Late',13,' Gate']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],'Location',[69,258,640,580])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/in_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/in_1']],...
		'ForeGround',2,...
		'position',[15,130,35,150])


%     Subsystem  ['Discrete',13,' Early-Late',13,' Gate/Sign'].

new_system([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],'Location',[159,417,467,586])

add_block('built-in/Constant',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/Constant']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/Constant']],...
		'Value','0',...
		'position',[65,105,85,125])

add_block('built-in/Relational Operator',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/Relational',13,'Operator1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/Relational',13,'Operator1']],...
		'Operator','<',...
		'position',[140,92,170,123])

add_block('built-in/Sum',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/Sum']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/Sum']],...
		'inputs','+-',...
		'position',[215,64,235,91])

add_block('built-in/Relational Operator',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/Relational',13,'Operator']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/Relational',13,'Operator']],...
		'Operator','>',...
		'position',[140,32,170,63])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/in_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/in_1']],...
		'position',[35,30,55,50])

add_block('built-in/Outport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/out_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign/out_1']],...
		'position',[265,70,285,90])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],[240,80;260,80])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],[175,50;185,50;185,70;210,70])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],[175,110;185,110;185,85;210,85])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],[90,115;135,115])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],[110,115;110,55;135,55])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],[60,40;135,40])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],[95,40;95,100;135,100])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],...
		'Mask Display','plot(-50,-50,50,50,[-50,50],[0,0],[0,0],[-50,50],[-40,0],[-30,-30],[0,40],[30,30])',...
		'Mask Type','Sign',...
		'Mask Dialogue','y = sign(x)')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],...
		'Mask Help','Sign Function:\n\t\t\ty = 1 if x > 0\n\t\t\ty = 0 if x = 0\n\t\t\ty = -1 if x < 0')


%     Finished composite block ['Discrete',13,' Early-Late',13,' Gate/Sign'].

set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sign']],...
		'orientation',2,...
		'position',[340,130,370,160])


%     Subsystem  ['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO'].

new_system([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],'Location',[4,433,784,580])

add_block('built-in/Outport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/out_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/out_1']],...
		'position',[690,35,710,55])

add_block('built-in/Gain',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Sensitivity3']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Sensitivity3']],...
		'Gain','Ac',...
		'position',[605,30,655,60])

add_block('built-in/Fcn',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/sin']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/sin']],...
		'Expr','cos(u[1])',...
		'position',[510,32,585,58])

add_block('built-in/Constant',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Phase']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Phase']],...
		'Value','Ph',...
		'position',[400,100,420,120])

add_block('built-in/Sum',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Sum']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Sum']],...
		'inputs','+++',...
		'position',[465,27,485,63])

add_block('built-in/Gain',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Sensitivity2']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Sensitivity2']],...
		'Gain','Fc',...
		'position',[255,75,300,105])

add_block('built-in/Gain',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Sensitivity']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[105,15,155,45])

add_block('built-in/Sum',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Sum1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Sum1']],...
		'position',[230,25,250,45])

add_block('built-in/Unit Delay',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Unit Delay']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Unit Delay']],...
		'Sample time','ts',...
		'position',[300,25,350,45])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/in_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/in_1']],...
		'position',[35,20,55,40])

add_block('built-in/Digital Clock',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Digital Clock']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO/Digital Clock']],...
		'Sample time','ts',...
		'position',[160,75,195,105])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[660,45;685,45])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[590,45;600,45])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[425,110;435,110;435,55;460,55])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[355,35;460,35])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[370,35;370,70;205,70;205,40;225,40])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[305,90;425,90;425,45;460,45])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[200,90;250,90])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[490,45;505,45])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[255,35;295,35])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[160,30;225,30])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],[60,30;100,30])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],...
		'Mask Display','Discrete\nVCO',...
		'Mask Type','VCO')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],...
		'Mask Dialogue','Voltage-Controlled Oscilator:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],...
		'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;ts=@5;Kc=Kc*pi2*ts(1);Fc=Fc*pi2;')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],...
		'Mask Help','The VCO block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],...
		'Mask Entries','1\/1/tdd\/.0001\/0\/tss\/')


%     Finished composite block ['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO'].

set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete-time',13,'VCO']],...
		'orientation',2,...
		'hide name',0,...
		'position',[400,120,480,170])

add_block('built-in/Sum',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sum2']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sum2']],...
		'orientation',2,...
		'hide name',0,...
		'inputs','+-',...
		'position',[500,135,520,155])

add_block('built-in/Constant',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Constant']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Constant']],...
		'ForeGround',4,...
		'Value','-1',...
		'position',[90,135,110,155])

add_block('built-in/Product',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Product']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Product']],...
		'orientation',1,...
		'hide name',0,...
		'position',[170,160,205,180])

add_block('built-in/Sum',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sum1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sum1']],...
		'orientation',3,...
		'hide name',0,...
		'inputs','-+',...
		'position',[172,110,203,130])

add_block('built-in/Sum',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sum']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Sum']],...
		'orientation',1,...
		'hide name',0,...
		'inputs','-+',...
		'position',[167,200,198,220])

add_block('built-in/Abs',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Abs1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Abs1']],...
		'hide name',0,...
		'position',[490,253,520,277])

add_block('built-in/Gain',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Gain1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Gain1']],...
		'hide name',0,...
		'Gain','1/tdd',...
		'position',[365,237,390,263])

add_block('built-in/Abs',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Abs']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Abs']],...
		'hide name',0,...
		'position',[500,48,530,72])


%     Subsystem  ['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold'].

new_system([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']],'Location',[139,159,529,329])

add_block('built-in/Transport Delay',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Transport',13,'Delay']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Transport',13,'Delay']],...
		'hide name',0,...
		'Delay Time','tss/2',...
		'position',[80,25,120,55])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/in_2']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/in_2']],...
		'Port','2',...
		'position',[25,90,45,110])

add_block('built-in/Unit Delay',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Unit Delay']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Unit Delay']],...
		'hide name',0,...
		'Sample time','tss',...
		'position',[235,92,285,108])

add_block('built-in/Outport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/out_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/out_1']],...
		'position',[340,90,360,110])

add_block('built-in/Switch',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Switch']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Switch']],...
		'hide name',0,...
		'Threshold','.5',...
		'position',[180,84,210,116])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/in_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/in_1']],...
		'position',[25,30,45,50])


%     Subsystem  ['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1'].

new_system([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],[300,35;335,35])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],[45,25;45,95;120,95])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Edge det.',...
		'Mask Type','Edge detection')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],...
		'Mask Dialogue','Detect the rising edge of the input\nsignal. Output one when the rising\nedge is detected.|Threshold:')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],...
		'Mask Help','This block outputs one when the input signal reaches a value larger than or equal to the given threshold value at the current time and the value was below the threshold one time step before. Otherwise, the block outputs zero.')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],...
		'Mask Entries','0.5\/')


%     Finished composite block ['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1'].

set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold/Rising edge',13,'detector1']],...
		'position',[65,78,145,122])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']],[125,40;155,40;155,90;175,90])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']],[50,40;75,40])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']],[290,100;335,100])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']],[305,100;305,140;160,140;160,110;175,110])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']],[215,100;230,100])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']],[50,100;60,100])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']],[150,100;175,100])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']],...
		'Mask Display','Discrete\nSample\nand Hold',...
		'Mask Type','Discrete Sample and Hold')


%     Finished composite block ['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold'].

set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold']],...
		'hide name',0,...
		'position',[415,28,485,92])

add_block('built-in/Gain',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Gain']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Gain']],...
		'hide name',0,...
		'Gain','1/tdd',...
		'position',[370,32,395,58])


%     Subsystem  ['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4'].

new_system([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],'Location',[74,124,605,322])

add_block('built-in/Sum',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/Sum']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/Sum']],...
		'position',[185,30,205,50])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/reset value']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/reset value']],...
		'Port','3',...
		'position',[65,140,85,160])

add_block('built-in/Switch',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/Switch1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/Switch1']],...
		'Threshold','eps',...
		'position',[240,54,265,86])

add_block('built-in/Unit Delay',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/Unit Delay']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/Unit Delay']],...
		'Sample time','tss',...
		'position',[290,62,340,78])

add_block('built-in/Outport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/integrated',13,' output']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/integrated',13,' output']],...
		'position',[435,60,455,80])

add_block('built-in/Relational Operator',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/equal']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/equal']],...
		'Operator','==',...
		'position',[140,69,170,91])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/data']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/data']],...
		'position',[65,35,85,55])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/trigger']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4/trigger']],...
		'Port','2',...
		'position',[65,95,85,115])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],[270,70;275,70;275,100;395,100;395,70;430,70])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],[90,150;190,150;190,80;235,80])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],[210,40;215,40;215,60;235,60])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],[90,45;180,45])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],[345,70;380,70;380,15;160,15;160,35;180,35])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],[175,80;175,70;235,70])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],[270,70;285,70])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],[90,105;115,105;115,75;135,75])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],...
		'Mask Display','Discrete\nResettable\nintegrator',...
		'Mask Type','Discrete Resettable integrator')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],...
		'Mask Help','RESETTABLE INTEGRATOR  The resettable integrator is a masked function. This block has same functionality as the built-in RESET INTEGRATOR except that when input 2 is non-zero, the block stops integration.')


%     Finished composite block ['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4'].

set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator4']],...
		'hide name',0,...
		'position',[275,20,350,70])

add_block('built-in/Outport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/early gate']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/early gate']],...
		'hide name',0,...
		'position',[380,85,400,105])


%     Subsystem  ['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5'].

new_system([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],'Location',[0,38,784,584])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/trigger']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/trigger']],...
		'Port','2',...
		'position',[65,95,85,115])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/data']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/data']],...
		'position',[65,35,85,55])

add_block('built-in/Relational Operator',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/equal']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/equal']],...
		'Operator','==',...
		'position',[140,69,170,91])

add_block('built-in/Outport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/integrated',13,' output']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/integrated',13,' output']],...
		'position',[435,60,455,80])

add_block('built-in/Unit Delay',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/Unit Delay']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/Unit Delay']],...
		'Sample time','tss',...
		'position',[290,62,340,78])

add_block('built-in/Switch',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/Switch1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/Switch1']],...
		'Threshold','eps',...
		'position',[240,54,265,86])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/reset value']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/reset value']],...
		'Port','3',...
		'position',[65,140,85,160])

add_block('built-in/Sum',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/Sum']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5/Sum']],...
		'position',[185,30,205,50])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],[90,105;115,105;115,75;135,75])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],[270,70;285,70])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],[175,80;175,70;235,70])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],[345,70;380,70;380,15;160,15;160,35;180,35])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],[90,45;180,45])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],[210,40;215,40;215,60;235,60])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],[90,150;190,150;190,80;235,80])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],[270,70;275,70;275,100;395,100;395,70;430,70])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],...
		'Mask Display','Discrete\nResettable\nintegrator',...
		'Mask Type','Discrete Resettable integrator')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],...
		'Mask Help','RESETTABLE INTEGRATOR  The resettable integrator is a masked function. This block has same functionality as the built-in RESET INTEGRATOR except that when input 2 is non-zero, the block stops integration.')


%     Finished composite block ['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5'].

set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Descrete',13,' Resettable',13,'integrator5']],...
		'hide name',0,...
		'position',[270,225,345,275])


%     Subsystem  ['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1'].

new_system([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']],'Location',[139,159,529,329])


%     Subsystem  ['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1'].

new_system([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],[45,25;45,95;120,95])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],[300,35;335,35])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Edge det.',...
		'Mask Type','Edge detection')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],...
		'Mask Dialogue','Detect the rising edge of the input\nsignal. Output one when the rising\nedge is detected.|Threshold:')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],...
		'Mask Help','This block outputs one when the input signal reaches a value larger than or equal to the given threshold value at the current time and the value was below the threshold one time step before. Otherwise, the block outputs zero.')
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],...
		'Mask Entries','0.5\/')


%     Finished composite block ['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1'].

set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Rising edge',13,'detector1']],...
		'position',[65,78,145,122])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/in_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/in_1']],...
		'position',[25,30,45,50])

add_block('built-in/Switch',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Switch']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Switch']],...
		'hide name',0,...
		'Threshold','.5',...
		'position',[180,84,210,116])

add_block('built-in/Outport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/out_1']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/out_1']],...
		'position',[340,90,360,110])

add_block('built-in/Unit Delay',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Unit Delay']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Unit Delay']],...
		'hide name',0,...
		'Sample time','tss',...
		'position',[235,92,285,108])

add_block('built-in/Inport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/in_2']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/in_2']],...
		'Port','2',...
		'position',[25,90,45,110])

add_block('built-in/Transport Delay',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Transport',13,'Delay']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1/Transport',13,'Delay']],...
		'hide name',0,...
		'Delay Time','tss/2',...
		'position',[80,25,120,55])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']],[150,100;175,100])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']],[50,100;60,100])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']],[215,100;230,100])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']],[290,100;335,100])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']],[305,100;305,140;160,140;160,110;175,110])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']],[50,40;75,40])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']],[125,40;155,40;155,90;175,90])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']],...
		'Mask Display','Discrete\nSample\nand Hold',...
		'Mask Type','Discrete Sample and Hold')


%     Finished composite block ['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1'].

set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/Discrete',13,'trighold1']],...
		'hide name',0,...
		'position',[405,233,475,297])

add_block('built-in/Outport',[sys,'/',['Discrete',13,' Early-Late',13,' Gate/late gate']])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate/late gate']],...
		'hide name',0,...
		'Port','2',...
		'position',[540,295,560,315])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[395,250;400,250])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[350,250;360,250])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[355,45;365,45])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[400,45;410,45])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[40,140;60,140;60,30;270,30])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[480,265;485,265])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[395,145;375,145])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[495,145;485,145])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[490,60;495,60])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[535,60;525,140])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[525,265;535,265;525,150])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[185,225;185,305;535,305])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[190,185;190,195])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[190,105;190,45;270,45])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[335,145;195,135])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[195,145;195,155])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[115,145;180,155])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[135,145;135,185;175,195])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[190,95;375,95])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[180,145;180,135])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[60,140;60,235;265,235])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[185,250;265,250])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[350,305;350,280;400,280])
add_line([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],[360,95;360,75;410,75])
set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],...
		'Mask Display','ELG')


%     Finished composite block ['Discrete',13,' Early-Late',13,' Gate'].

set_param([sys,'/',['Discrete',13,' Early-Late',13,' Gate']],...
		'orientation',2,...
		'position',[325,223,365,287])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[330,135,360,185])


%     Subsystem  'Graph1'.

new_system([sys,'/','Graph1'])
set_param([sys,'/','Graph1'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph1/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph1/x'])
set_param([sys,'/','Graph1/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph1'],[90,65;125,65])
set_param([sys,'/','Graph1'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph1'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type:|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph1'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph1'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph1'],...
		'Mask Entries','5/600\/-10\/10\/''b-/y-/g--/c-./w:/m*/ro/b+''\/tss\/')


%     Finished composite block 'Graph1'.

set_param([sys,'/','Graph1'],...
		'hide name',0,...
		'position',[390,140,420,180])


%     Subsystem  'SNR Generator'.

new_system([sys,'/','SNR Generator'])
set_param([sys,'/','SNR Generator'],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/','SNR Generator/Message source'])
set_param([sys,'/','SNR Generator/Message source'],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/','SNR Generator/Message source'],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/','SNR Generator/Message source'],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;',...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/','SNR Generator/Message source'],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/','SNR Generator/out_1'])
set_param([sys,'/','SNR Generator/out_1'],...
		'position',[295,65,315,85])


%     Subsystem  ['SNR Generator/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['SNR Generator/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['SNR Generator/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/','SNR Generator'],[115,75;175,75])
add_line([sys,'/','SNR Generator'],[260,75;290,75])
set_param([sys,'/','SNR Generator'],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/','SNR Generator'],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/','SNR Generator'],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/','SNR Generator'],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/','SNR Generator'],...
		'Mask Entries','(-5:6)''\/tdd*20\/1\/0\/')


%     Finished composite block 'SNR Generator'.

set_param([sys,'/','SNR Generator'],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[180,90,260,130])


%     Subsystem  '.'.

new_system([sys,'/','.'])
set_param([sys,'/','.'],'Location',[44,367,780,580])

add_block('built-in/Inport',[sys,'/','./in_2'])
set_param([sys,'/','./in_2'],...
		'Port','2',...
		'position',[75,30,95,50])


%     Subsystem  ['./Pulses divide',13,'same sample time1'].

new_system([sys,'/',['./Pulses divide',13,'same sample time1']])
set_param([sys,'/',['./Pulses divide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['./Pulses divide',13,'same sample time1/S-function1']])
set_param([sys,'/',['./Pulses divide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['./Pulses divide',13,'same sample time1/Outport']])
set_param([sys,'/',['./Pulses divide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['./Pulses divide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['./Pulses divide',13,'same sample time1']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['./Pulses divide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['./Pulses divide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['./Pulses divide',13,'same sample time1']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['./Pulses divide',13,'same sample time1']],...
		'Mask Entries','tss\/1\/0\/')


%     Finished composite block ['./Pulses divide',13,'same sample time1'].

set_param([sys,'/',['./Pulses divide',13,'same sample time1']],...
		'position',[40,98,120,142])

add_block('built-in/Product',[sys,'/','./Product'])
set_param([sys,'/','./Product'],...
		'position',[450,98,480,122])

add_block('built-in/Gain',[sys,'/','./Gain'])
set_param([sys,'/','./Gain'],...
		'Gain','1/256',...
		'position',[390,92,415,118])


%     Subsystem  ['./Inner',13,'Product'].

new_system([sys,'/',['./Inner',13,'Product']])
set_param([sys,'/',['./Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['./Inner',13,'Product/Product']])
set_param([sys,'/',['./Inner',13,'Product/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['./Inner',13,'Product/Sum']])
set_param([sys,'/',['./Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['./Inner',13,'Product/out_1']])
set_param([sys,'/',['./Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['./Inner',13,'Product/in_2']])
set_param([sys,'/',['./Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['./Inner',13,'Product/in_1']])
set_param([sys,'/',['./Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['./Inner',13,'Product']],[40,100;60,70])
add_line([sys,'/',['./Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['./Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['./Inner',13,'Product']],[150,65;180,65])
set_param([sys,'/',['./Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['./Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['./Inner',13,'Product'].

set_param([sys,'/',['./Inner',13,'Product']],...
		'position',[325,94,345,116])


%     Subsystem  './Register-shift'.

new_system([sys,'/','./Register-shift'])
set_param([sys,'/','./Register-shift'],'Location',[19,450,374,580])

add_block('built-in/Demux',[sys,'/','./Register-shift/Demux'])
set_param([sys,'/','./Register-shift/Demux'],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/','./Register-shift/S-function'])
set_param([sys,'/','./Register-shift/S-function'],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/','./Register-shift/Mux'])
set_param([sys,'/','./Register-shift/Mux'],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/','./Register-shift/out_1'])
set_param([sys,'/','./Register-shift/out_1'],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/','./Register-shift/out_2'])
set_param([sys,'/','./Register-shift/out_2'],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/','./Register-shift/in_1'])
set_param([sys,'/','./Register-shift/in_1'],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/','./Register-shift/in_2'])
set_param([sys,'/','./Register-shift/in_2'],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/','./Register-shift'],[120,75;145,75])
add_line([sys,'/','./Register-shift'],[205,75;255,75])
add_line([sys,'/','./Register-shift'],[305,65;325,65])
add_line([sys,'/','./Register-shift'],[305,80;325,80])
add_line([sys,'/','./Register-shift'],[55,65;75,65])
add_line([sys,'/','./Register-shift'],[55,80;75,80])
set_param([sys,'/','./Register-shift'],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Reg. shift',...
		'Mask Type','Register-shift')
set_param([sys,'/','./Register-shift'],...
		'Mask Dialogue','The rising edge of the 2nd port pulse\ntriggers the block to input the 1st port data and to shift the register.|Delay steps (output length is same as this vector size):|Threshold in detecting the rising edge of the pulse:')
set_param([sys,'/','./Register-shift'],...
		'Mask Translate','shft_out=@1;thrhld=@2;len_rg=length(@1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,75,get_param(gcb,''orientation''),2);')
set_param([sys,'/','./Register-shift'],...
		'Mask Help','This block stores the scalar input signal from the 1st input port at the rising edge of the pulse from the 2nd port. The 1st outport outputs a vector with its size the same as the "Delay steps" entree of this block. The maximum delay is the register size of this block. The second outport outputs a positive pulse when the register is\nrefreshed.')
set_param([sys,'/','./Register-shift'],...
		'Mask Entries','[1:256]\/.5\/')


%     Finished composite block './Register-shift'.

set_param([sys,'/','./Register-shift'],...
		'position',[165,88,245,132])

add_block('built-in/Fcn',[sys,'/','./Fcn1'])
set_param([sys,'/','./Fcn1'],...
		'hide name',0,...
		'Expr','sqrt(u[1])',...
		'position',[495,100,550,120])

add_block('built-in/Outport',[sys,'/','./out_1'])
set_param([sys,'/','./out_1'],...
		'position',[695,75,715,95])


%     Subsystem  ['./AWGN',13,'w vary para'].

new_system([sys,'/',['./AWGN',13,'w vary para']])
set_param([sys,'/',['./AWGN',13,'w vary para']],'Location',[122,181,405,317])

add_block('built-in/Sum',[sys,'/',['./AWGN',13,'w vary para/Sum']])
set_param([sys,'/',['./AWGN',13,'w vary para/Sum']],...
		'position',[195,55,215,75])

add_block('built-in/Outport',[sys,'/',['./AWGN',13,'w vary para/out_1']])
set_param([sys,'/',['./AWGN',13,'w vary para/out_1']],...
		'position',[245,55,265,75])

add_block('built-in/Inport',[sys,'/',['./AWGN',13,'w vary para/in_1']])
set_param([sys,'/',['./AWGN',13,'w vary para/in_1']],...
		'position',[100,15,120,35])

add_block('built-in/Inport',[sys,'/',['./AWGN',13,'w vary para/in_2']])
set_param([sys,'/',['./AWGN',13,'w vary para/in_2']],...
		'Port','2',...
		'position',[10,50,30,70])


%     Subsystem  ['./AWGN',13,'w vary para/Gaussian',13,'noise'].

new_system([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise']])
set_param([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise']],'Location',[482,386,830,557])

add_block('built-in/Sum',[sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/White Noise',[sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[40,82,85,118])

add_block('built-in/Inport',[sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/in_1']])
set_param([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/in_1']],...
		'position',[55,35,75,55])

add_block('built-in/Inport',[sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/in_2']])
set_param([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/in_2']],...
		'Port','2',...
		'position',[170,35,190,55])

add_block('built-in/Outport',[sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/out_1']],...
		'position',[300,80,320,100])

add_block('built-in/Product',[sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/Product']])
set_param([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise/Product']],...
		'position',[240,80,265,100])
add_line([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise']],[80,45;110,45;110,90;135,90])
add_line([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise']],[90,100;135,100])
add_line([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise']],[270,90;295,90])
add_line([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise']],[165,95;235,95])
add_line([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise']],[195,45;210,45;210,85;235,85])
set_param([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Initial Seed(s):',...
		'Mask Translate','s=@1;')
set_param([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise']],...
		'Mask Help','The meanvalue is determined by value from the frist input. The standard deviation is determined by the second input. ',...
		'Mask Entries','s\/')


%     Finished composite block ['./AWGN',13,'w vary para/Gaussian',13,'noise'].

set_param([sys,'/',['./AWGN',13,'w vary para/Gaussian',13,'noise']],...
		'position',[75,50,150,90])

add_block('built-in/Inport',[sys,'/',['./AWGN',13,'w vary para/in_3']])
set_param([sys,'/',['./AWGN',13,'w vary para/in_3']],...
		'Port','3',...
		'position',[20,95,40,115])
add_line([sys,'/',['./AWGN',13,'w vary para']],[220,65;240,65])
add_line([sys,'/',['./AWGN',13,'w vary para']],[125,25;160,25;160,60;190,60])
add_line([sys,'/',['./AWGN',13,'w vary para']],[155,70;190,70])
add_line([sys,'/',['./AWGN',13,'w vary para']],[35,60;70,60])
add_line([sys,'/',['./AWGN',13,'w vary para']],[45,105;55,105;55,80;70,80])
set_param([sys,'/',['./AWGN',13,'w vary para']],...
		'Mask Display','plot(0,0,100,100,x,y);AWGN',...
		'Mask Type','AWGN channel, vary parameter')
set_param([sys,'/',['./AWGN',13,'w vary para']],...
		'Mask Dialogue','AWGN channel with varying mean (2nd\nport) and standard deviation (3rd port) as input. Seed vector size is the block output size.|Initial seed:')
set_param([sys,'/',['./AWGN',13,'w vary para']],...
		'Mask Translate','s=@1;[x,y]=chanicon;')
set_param([sys,'/',['./AWGN',13,'w vary para']],...
		'Mask Help','This block adds white Gaussian noise to the input signal. When the mean value and/or the seed is a vector, a vector noise is added to the input vector signal. The mean value and the standard deviation are inputted from the second port and the third port respectively. The mean and std input can be scalars or vectors with the same length as the input signal.')
set_param([sys,'/',['./AWGN',13,'w vary para']],...
		'Mask Entries','1234\/')


%     Finished composite block ['./AWGN',13,'w vary para'].

set_param([sys,'/',['./AWGN',13,'w vary para']],...
		'position',[585,63,665,107])

add_block('built-in/Fcn',[sys,'/','./Fcn'])
set_param([sys,'/','./Fcn'],...
		'hide name',0,...
		'Expr','1/10^(u[1]/10)',...
		'position',[300,155,410,175])

add_block('built-in/Inport',[sys,'/','./in_1'])
set_param([sys,'/','./in_1'],...
		'position',[235,155,255,175])

add_block('built-in/Constant',[sys,'/','./zero mean'])
set_param([sys,'/','./zero mean'],...
		'Value','0',...
		'position',[450,55,470,75])
add_line([sys,'/','.'],[475,65;540,65;550,85;580,85])
add_line([sys,'/','.'],[420,105;445,105])
add_line([sys,'/','.'],[100,40;555,40;580,70])
add_line([sys,'/','.'],[350,105;385,105])
add_line([sys,'/','.'],[250,100;320,100])
add_line([sys,'/','.'],[670,85;690,85])
add_line([sys,'/','.'],[125,120;160,120])
add_line([sys,'/','.'],[275,100;275,110;320,110])
add_line([sys,'/','.'],[135,40;135,100;160,100])
add_line([sys,'/','.'],[260,165;295,165])
add_line([sys,'/','.'],[415,165;425,165;425,115;445,115])
add_line([sys,'/','.'],[485,110;490,110])
add_line([sys,'/','.'],[555,110;565,100;580,100])
set_param([sys,'/','.'],...
		'Mask Display','AWGN \n SNR',...
		'Mask Type','channel')
set_param([sys,'/','.'],...
		'Mask Help','The input signal at input port 1 has AWGN added to it, and is output at the output port.  The noise power is determined by the input signal power and the SNR value of the 2nd input.  The 2nd input''s units are in dB.')


%     Finished composite block '.'.

set_param([sys,'/','.'],...
		'orientation',1,...
		'position',[557,140,628,180])


%     Subsystem  'Fmdetect'.

new_system([sys,'/','Fmdetect'])
set_param([sys,'/','Fmdetect'],'Location',[24,112,624,286])

add_block('built-in/Inport',[sys,'/','Fmdetect/in_1'])
set_param([sys,'/','Fmdetect/in_1'],...
		'position',[35,40,55,60])

add_block('built-in/Inport',[sys,'/','Fmdetect/in_2'])
set_param([sys,'/','Fmdetect/in_2'],...
		'Port','2',...
		'position',[35,95,55,115])

add_block('built-in/Fcn',[sys,'/','Fmdetect/atan2'])
set_param([sys,'/','Fmdetect/atan2'],...
		'hide name',0,...
		'Expr','atan2(u[2],u(1))',...
		'position',[140,50,180,70])

add_block('built-in/Unit Delay',[sys,'/','Fmdetect/Unit Delay'])
set_param([sys,'/','Fmdetect/Unit Delay'],...
		'hide name',0,...
		'Sample time','tss',...
		'position',[220,52,270,68])

add_block('built-in/Sum',[sys,'/','Fmdetect/Sum'])
set_param([sys,'/','Fmdetect/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[300,44,320,66])

add_block('built-in/Mux',[sys,'/','Fmdetect/Mux'])
set_param([sys,'/','Fmdetect/Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[90,41,120,74])

add_block('built-in/MATLAB Fcn',[sys,'/','Fmdetect/MATLAB Fcn1'])
set_param([sys,'/','Fmdetect/MATLAB Fcn1'],...
		'hide name',0,...
		'MATLAB Fcn','median',...
		'Output Width','1',...
		'position',[470,38,530,72])

add_block('built-in/Outport',[sys,'/','Fmdetect/out_1'])
set_param([sys,'/','Fmdetect/out_1'],...
		'position',[560,45,580,65])


%     Subsystem  ['Fmdetect/Pulses divide',13,'same sample time1'].

new_system([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1']])
set_param([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Fmdetect/Pulses divide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Fmdetect/Pulses divide',13,'same sample time1/Outport']])
set_param([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1']],...
		'Mask Entries','tss\/1\/0\/')


%     Finished composite block ['Fmdetect/Pulses divide',13,'same sample time1'].

set_param([sys,'/',['Fmdetect/Pulses divide',13,'same sample time1']],...
		'position',[205,83,285,127])


%     Subsystem  'Fmdetect/Register-shift'.

new_system([sys,'/','Fmdetect/Register-shift'])
set_param([sys,'/','Fmdetect/Register-shift'],'Location',[19,610,374,740])

add_block('built-in/Demux',[sys,'/','Fmdetect/Register-shift/Demux'])
set_param([sys,'/','Fmdetect/Register-shift/Demux'],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/','Fmdetect/Register-shift/S-function'])
set_param([sys,'/','Fmdetect/Register-shift/S-function'],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/','Fmdetect/Register-shift/Mux'])
set_param([sys,'/','Fmdetect/Register-shift/Mux'],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/','Fmdetect/Register-shift/out_1'])
set_param([sys,'/','Fmdetect/Register-shift/out_1'],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/','Fmdetect/Register-shift/out_2'])
set_param([sys,'/','Fmdetect/Register-shift/out_2'],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/','Fmdetect/Register-shift/in_1'])
set_param([sys,'/','Fmdetect/Register-shift/in_1'],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/','Fmdetect/Register-shift/in_2'])
set_param([sys,'/','Fmdetect/Register-shift/in_2'],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/','Fmdetect/Register-shift'],[120,75;145,75])
add_line([sys,'/','Fmdetect/Register-shift'],[205,75;255,75])
add_line([sys,'/','Fmdetect/Register-shift'],[305,65;325,65])
add_line([sys,'/','Fmdetect/Register-shift'],[305,80;325,80])
add_line([sys,'/','Fmdetect/Register-shift'],[55,65;75,65])
add_line([sys,'/','Fmdetect/Register-shift'],[55,80;75,80])
set_param([sys,'/','Fmdetect/Register-shift'],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Reg. shift',...
		'Mask Type','Register-shift')
set_param([sys,'/','Fmdetect/Register-shift'],...
		'Mask Dialogue','The rising edge of the 2nd port pulse\ntriggers the block to input the 1st port data and to shift the register.|Delay steps (output length is same as this vector size):|Threshold in detecting the rising edge of the pulse:')
set_param([sys,'/','Fmdetect/Register-shift'],...
		'Mask Translate','shft_out=@1;thrhld=@2;len_rg=length(@1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,75,get_param(gcb,''orientation''),2);')
set_param([sys,'/','Fmdetect/Register-shift'],...
		'Mask Help','This block stores the scalar input signal from the 1st input port at the rising edge of the pulse from the 2nd port. The 1st outport outputs a vector with its size the same as the "Delay steps" entree of this block. The maximum delay is the register size of this block. The second outport outputs a positive pulse when the register is\nrefreshed.')
set_param([sys,'/','Fmdetect/Register-shift'],...
		'Mask Entries','[1:5]\/.5\/')


%     Finished composite block 'Fmdetect/Register-shift'.

set_param([sys,'/','Fmdetect/Register-shift'],...
		'position',[355,43,435,87])
add_line([sys,'/','Fmdetect'],[535,55;555,55])
add_line([sys,'/','Fmdetect'],[440,55;465,55])
add_line([sys,'/','Fmdetect'],[290,105;330,105;350,75])
add_line([sys,'/','Fmdetect'],[325,55;350,55])
add_line([sys,'/','Fmdetect'],[125,60;135,60])
add_line([sys,'/','Fmdetect'],[275,60;295,60])
add_line([sys,'/','Fmdetect'],[185,60;215,60])
add_line([sys,'/','Fmdetect'],[185,60;195,60;195,40;280,40;280,50;295,50])
add_line([sys,'/','Fmdetect'],[60,50;85,50])
add_line([sys,'/','Fmdetect'],[60,105;70,105;70,65;85,65])
set_param([sys,'/','Fmdetect'],...
		'Mask Display','FM\nDetect',...
		'Mask Type','FMDETECT',...
		'Mask Help','Requires I Q input.  Outputs instantaneous Frequency')


%     Finished composite block 'Fmdetect'.

set_param([sys,'/','Fmdetect'],...
		'orientation',2,...
		'position',[400,233,480,277])


%     Subsystem  ['Integrate, Sample,',13,' and Threshold'].

new_system([sys,'/',['Integrate, Sample,',13,' and Threshold']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold']],'Location',[29,240,755,509])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/in_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/in_1']],...
		'position',[160,55,180,75])


%     Subsystem  ['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4'].

new_system([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],'Location',[65,313,626,598])

add_block('built-in/Sum',[sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/Sum']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/Sum']],...
		'position',[185,30,205,50])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/reset value']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/reset value']],...
		'Port','3',...
		'position',[65,140,85,160])

add_block('built-in/Switch',[sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/Switch1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/Switch1']],...
		'Threshold','eps',...
		'position',[240,54,265,86])

add_block('built-in/Unit Delay',[sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/Unit Delay']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/Unit Delay']],...
		'Sample time','tss',...
		'position',[290,62,340,78])

add_block('built-in/Outport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/integrated',13,' output']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/integrated',13,' output']],...
		'position',[435,60,455,80])

add_block('built-in/Relational Operator',[sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/equal']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/equal']],...
		'Operator','==',...
		'position',[140,69,170,91])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/data']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/data']],...
		'position',[65,35,85,55])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/trigger']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4/trigger']],...
		'Port','2',...
		'position',[65,95,85,115])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],[270,70;275,70;275,100;395,100;395,70;430,70])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],[90,150;190,150;190,80;235,80])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],[210,40;215,40;215,60;235,60])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],[90,45;180,45])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],[345,70;380,70;380,15;160,15;160,35;180,35])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],[175,80;175,70;235,70])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],[270,70;285,70])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],[90,105;115,105;115,75;135,75])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],...
		'Mask Display','Discrete\nResettable\nintegrator',...
		'Mask Type','Discrete Resettable integrator')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],...
		'Mask Dialogue','Integrates first input. If second input is not zero, integration stops and state is set to third input.|Initial value:|Sample Time')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],...
		'Mask Translate','init = @1;tss= @2;')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],...
		'Mask Help','RESETTABLE INTEGRATOR  The resettable integrator is a masked function. This block has same functionality as the built-in RESET INTEGRATOR except that when input 2 is non-zero, the block stops integration.')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],...
		'Mask Entries','0\/tss/2\/')


%     Finished composite block ['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4'].

set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Descrete',13,' Resettable',13,'integrator4']],...
		'hide name',0,...
		'position',[215,75,290,125])

add_block('built-in/Constant',[sys,'/',['Integrate, Sample,',13,' and Threshold/zero']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/zero']],...
		'Value','0',...
		'position',[165,105,185,125])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/in_2']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])


%     Subsystem  ['Integrate, Sample,',13,' and Threshold/1-step',13,'delay'].

new_system([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],'Location',[12,432,357,702])

add_block('built-in/Relational Operator',[sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/Relational',13,'Operator']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/Relational',13,'Operator']],...
		'position',[150,168,180,192])

add_block('built-in/Constant',[sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/Constant1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Constant',[sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/Constant']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Switch',[sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/Switch']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Filter',[sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/K-step',13,'delay']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Outport',[sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/out_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/in_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Digital Clock',[sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/Digital Clock']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],[185,180;220,180;220,130;265,130])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],[45,90;55,90])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],[300,130;320,130])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],...
		'Mask Dialogue','Output is K steps delay of the input signal.|Delay steps (integer):|Sample time (sec):|Inital condition:')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;',...
		'Mask Help','This block equivalent to K unit delay.')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],...
		'Mask Entries','1\/tss\/0\/')


%     Finished composite block ['Integrate, Sample,',13,' and Threshold/1-step',13,'delay'].

set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/1-step',13,'delay']],...
		'position',[345,97,390,123])

add_block('built-in/Constant',[sys,'/',['Integrate, Sample,',13,' and Threshold/Constant']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Constant']],...
		'position',[500,210,520,230])

add_block('built-in/Outport',[sys,'/',['Integrate, Sample,',13,' and Threshold/out_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/out_1']],...
		'position',[690,155,710,175])


%     Subsystem  ['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold'].

new_system([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']],'Location',[138,159,516,317])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/in_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/in_1']],...
		'position',[25,30,45,50])

add_block('built-in/Switch',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Switch']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Switch']],...
		'hide name',0,...
		'Threshold','.5',...
		'position',[180,84,210,116])

add_block('built-in/Outport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/out_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/out_1']],...
		'position',[340,90,360,110])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/in_2']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/in_2']],...
		'Port','2',...
		'position',[25,90,45,110])


%     Subsystem  ['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector'].

new_system([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],...
		'Mask Display','Edge det.',...
		'Mask Type','Edge detection')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],...
		'Mask Dialogue','Detect the rising edge of the input\nsignal. Output one when the rising\nedge is detected.|Threshold:')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],...
		'Mask Help','This block outputs one when the input signal reaches a value larger than or equal to the given threshold value at the current time and the value was below the threshold one time step before. Otherwise, the block outputs zero.')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],...
		'Mask Entries','0.5\/')


%     Finished composite block ['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector'].

set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Rising edge',13,'detector']],...
		'hide name',0,...
		'position',[65,78,145,122])

add_block('built-in/Transport Delay',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Transport',13,'Delay']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Transport',13,'Delay']],...
		'hide name',0,...
		'Delay Time','tss/2',...
		'position',[80,25,120,55])

add_block('built-in/Memory',[sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Memory']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold/Memory']],...
		'position',[240,85,280,115])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']],[150,100;175,100])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']],[50,100;60,100])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']],[215,100;235,100])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']],[285,100;335,100])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']],[305,100;305,140;160,140;160,110;175,110])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']],[50,40;75,40])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']],[125,40;155,40;155,90;175,90])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']],...
		'Mask Display','Sample\nand Hold',...
		'Mask Type','Sample and Hold')


%     Finished composite block ['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold'].

set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Discrete',13,'trighold']],...
		'hide name',0,...
		'position',[445,129,510,176])


%     Subsystem  ['Integrate, Sample,',13,' and Threshold/Sign'].

new_system([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],'Location',[159,417,467,586])

add_block('built-in/Constant',[sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/Constant']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/Constant']],...
		'Value','0',...
		'position',[65,105,85,125])

add_block('built-in/Relational Operator',[sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/Relational',13,'Operator1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/Relational',13,'Operator1']],...
		'Operator','<',...
		'position',[140,92,170,123])

add_block('built-in/Sum',[sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/Sum']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/Sum']],...
		'inputs','+-',...
		'position',[215,64,235,91])

add_block('built-in/Relational Operator',[sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/Relational',13,'Operator']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/Relational',13,'Operator']],...
		'Operator','>',...
		'position',[140,32,170,63])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/in_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/in_1']],...
		'position',[35,30,55,50])

add_block('built-in/Outport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/out_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign/out_1']],...
		'position',[265,70,285,90])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],[240,80;260,80])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],[175,50;185,50;185,70;210,70])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],[175,110;185,110;185,85;210,85])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],[90,115;135,115])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],[110,115;110,55;135,55])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],[60,40;135,40])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],[95,40;95,100;135,100])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],...
		'Mask Display','plot(-50,-50,50,50,[-50,50],[0,0],[0,0],[-50,50],[-40,0],[-30,-30],[0,40],[30,30])',...
		'Mask Type','Sign',...
		'Mask Dialogue','y = sign(x)')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],...
		'Mask Help','Sign Function:\n\t\t\ty = 1 if x > 0\n\t\t\ty = 0 if x = 0\n\t\t\ty = -1 if x < 0')


%     Finished composite block ['Integrate, Sample,',13,' and Threshold/Sign'].

set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sign']],...
		'position',[530,142,560,168])

add_block('built-in/Sum',[sys,'/',['Integrate, Sample,',13,' and Threshold/Sum']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Sum']],...
		'position',[580,155,600,175])

add_block('built-in/Gain',[sys,'/',['Integrate, Sample,',13,' and Threshold/Gain1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Gain1']],...
		'Gain','.5',...
		'position',[635,152,660,178])


%     Subsystem  ['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1'].

new_system([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],[300,35;335,35])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],[45,25;45,95;120,95])
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Edge det.',...
		'Mask Type','Edge detection')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],...
		'Mask Dialogue','Detect the rising edge of the input\nsignal. Output one when the rising\nedge is detected.|Threshold:')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],...
		'Mask Help','This block outputs one when the input signal reaches a value larger than or equal to the given threshold value at the current time and the value was below the threshold one time step before. Otherwise, the block outputs zero.')
set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],...
		'Mask Entries','0.5\/')


%     Finished composite block ['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1'].

set_param([sys,'/',['Integrate, Sample,',13,' and Threshold/Rising edge',13,'detector1']],...
		'position',[70,78,150,122])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[605,165;630,165])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[525,220;525,170;575,170])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[565,155;575,160])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[515,155;525,155])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[665,165;685,165])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[40,100;50,100;50,165;440,165])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[185,65;210,85])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[40,100;65,100])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[155,100;210,100])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[190,115;210,115])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[295,100;310,100;310,110;340,110])
add_line([sys,'/',['Integrate, Sample,',13,' and Threshold']],[395,110;410,110;410,140;440,140])


%     Finished composite block ['Integrate, Sample,',13,' and Threshold'].

set_param([sys,'/',['Integrate, Sample,',13,' and Threshold']],...
		'orientation',2,...
		'position',[145,223,180,287])


%     Subsystem  ['Digital Down',13,'Convert'].

new_system([sys,'/',['Digital Down',13,'Convert']])
set_param([sys,'/',['Digital Down',13,'Convert']],'Location',[134,68,780,297])

add_block('built-in/Inport',[sys,'/',['Digital Down',13,'Convert/analog',13,'in']])
set_param([sys,'/',['Digital Down',13,'Convert/analog',13,'in']],...
		'position',[135,95,155,115])

add_block('built-in/Outport',[sys,'/',['Digital Down',13,'Convert/quadrature']])
set_param([sys,'/',['Digital Down',13,'Convert/quadrature']],...
		'Port','2',...
		'position',[560,155,580,175])

add_block('built-in/Outport',[sys,'/',['Digital Down',13,'Convert/inphase']])
set_param([sys,'/',['Digital Down',13,'Convert/inphase']],...
		'position',[560,35,580,55])

add_block('built-in/Product',[sys,'/',['Digital Down',13,'Convert/Product']])
set_param([sys,'/',['Digital Down',13,'Convert/Product']],...
		'hide name',0,...
		'position',[375,33,405,57])

add_block('built-in/Product',[sys,'/',['Digital Down',13,'Convert/Product1']])
set_param([sys,'/',['Digital Down',13,'Convert/Product1']],...
		'hide name',0,...
		'position',[375,153,405,177])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Digital Down',13,'Convert/Discrete',13,'Transfer Fcn']])
set_param([sys,'/',['Digital Down',13,'Convert/Discrete',13,'Transfer Fcn']],...
		'Numerator','f2num',...
		'Denominator','f2den',...
		'Sample time','tss',...
		'position',[435,28,510,62])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Digital Down',13,'Convert/Discrete',13,'Transfer Fcn1']])
set_param([sys,'/',['Digital Down',13,'Convert/Discrete',13,'Transfer Fcn1']],...
		'Numerator','f2num',...
		'Denominator','f2den',...
		'Sample time','tss',...
		'position',[435,147,505,183])

add_block('built-in/Transfer Fcn',[sys,'/',['Digital Down',13,'Convert/Anti-aliasing',13,'Filter']])
set_param([sys,'/',['Digital Down',13,'Convert/Anti-aliasing',13,'Filter']],...
		'Numerator','f1num',...
		'Denominator','f1den',...
		'position',[195,88,250,122])

add_block('built-in/Zero-Order Hold',[sys,'/',['Digital Down',13,'Convert/Zero-Order',13,'Hold']])
set_param([sys,'/',['Digital Down',13,'Convert/Zero-Order',13,'Hold']],...
		'hide name',0,...
		'Sample time','tss',...
		'position',[280,89,315,121])

add_block('built-in/Digital Clock',[sys,'/',['Digital Down',13,'Convert/Digital Clock']])
set_param([sys,'/',['Digital Down',13,'Convert/Digital Clock']],...
		'Sample time','tss',...
		'position',[40,25,75,55])

add_block('built-in/Fcn',[sys,'/',['Digital Down',13,'Convert/Cos(wct)']])
set_param([sys,'/',['Digital Down',13,'Convert/Cos(wct)']],...
		'hide name',0,...
		'Expr','cos(2*pi*(Fc+Fshift/2)*u[1])',...
		'position',[160,30,330,50])

add_block('built-in/Fcn',[sys,'/',['Digital Down',13,'Convert/-Sin(wct)']])
set_param([sys,'/',['Digital Down',13,'Convert/-Sin(wct)']],...
		'hide name',0,...
		'Expr','-sin(2*pi*(Fc+Fshift/2)*u[1])',...
		'position',[155,157,335,183])

add_block('built-in/Note',[sys,'/',['Digital Down',13,'Convert/ADC']])
set_param([sys,'/',['Digital Down',13,'Convert/ADC']],...
		'position',[300,115,305,120])
add_line([sys,'/',['Digital Down',13,'Convert']],[510,165;555,165])
add_line([sys,'/',['Digital Down',13,'Convert']],[160,105;190,105])
add_line([sys,'/',['Digital Down',13,'Convert']],[515,45;555,45])
add_line([sys,'/',['Digital Down',13,'Convert']],[335,40;370,40])
add_line([sys,'/',['Digital Down',13,'Convert']],[340,170;370,170])
add_line([sys,'/',['Digital Down',13,'Convert']],[80,40;155,40])
add_line([sys,'/',['Digital Down',13,'Convert']],[80,40;115,40;115,170;150,170])
add_line([sys,'/',['Digital Down',13,'Convert']],[255,105;275,105])
add_line([sys,'/',['Digital Down',13,'Convert']],[320,105;350,105;350,50;370,50])
add_line([sys,'/',['Digital Down',13,'Convert']],[410,45;430,45])
add_line([sys,'/',['Digital Down',13,'Convert']],[410,165;430,165])
add_line([sys,'/',['Digital Down',13,'Convert']],[320,105;350,105;350,160;370,160])
set_param([sys,'/',['Digital Down',13,'Convert']],...
		'Mask Display','DDC',...
		'Mask Type','DDC',...
		'Mask Help','Down shifts signal by the Carrier Frequency.  Outputs inphase and quadrature components of converted input signal.')


%     Finished composite block ['Digital Down',13,'Convert'].

set_param([sys,'/',['Digital Down',13,'Convert']],...
		'orientation',2,...
		'position',[500,234,580,276])


%     Subsystem  'Error-Meter'.

new_system([sys,'/','Error-Meter'])
set_param([sys,'/','Error-Meter'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error-Meter/S-function'])
set_param([sys,'/','Error-Meter/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error-Meter/Mux'])
set_param([sys,'/','Error-Meter/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error-Meter/in_1'])
set_param([sys,'/','Error-Meter/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error-Meter/in_2'])
set_param([sys,'/','Error-Meter/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error-Meter'],[105,65;125,65])
add_line([sys,'/','Error-Meter'],[40,55;60,55])
add_line([sys,'/','Error-Meter'],[40,70;60,70])
set_param([sys,'/','Error-Meter'],...
		'Mask Display','Error Rate\nMeter',...
		'Mask Type','Symbol/Bit Error Counter.')
set_param([sys,'/','Error-Meter'],...
		'Mask Dialogue','Compare 2nd port input to scalar 1st port input. Compute the error rate.|Bit per symbol:|Number of digit on display:|Delay between input (1st port) and output (2nd port):|Sampling time (second):')
set_param([sys,'/','Error-Meter'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error-Meter'],...
		'Mask Help','The signal from the first port should be always be a scalar. The 2nd port input signal can be a vector with a same time delay to the input signal.',...
		'Mask Entries','1\/16\/tss*92\/tdd\/')


%     Finished composite block 'Error-Meter'.

set_param([sys,'/','Error-Meter'],...
		'orientation',2,...
		'hide name',0,...
		'position',[20,125,100,165])


%     Subsystem  'Utility1'.

new_system([sys,'/','Utility1'])
set_param([sys,'/','Utility1'],'Location',[136,230,381,439])
set_param([sys,'/','Utility1'],...
		'Mask Display','Reload\ndata')
set_param([sys,'/','Utility1'],...
		'Mask Dialogue','eval(''tss=1/12000;tdd=1/600;MM=2;Fc=1200;Fshift=1200;[f1num,f1den]=butter(4,2*pi*4000,''''s'''');f2num=fir1(127,(Fshift/2+1/tdd)*2*tss);f2den=[1,zeros(1,127)];'')')


%     Finished composite block 'Utility1'.

set_param([sys,'/','Utility1'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[490,326,570,370])


%     Subsystem  'information'.

new_system([sys,'/','information'])
set_param([sys,'/','information'],'Location',[38,63,508,494])


%     Subsystem  'information/information'.

new_system([sys,'/','information/information'])
set_param([sys,'/','information/information'],'Location',[4,60,788,251])

add_block('built-in/Note',[sys,'/','information/information/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'])
set_param([sys,'/','information/information/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'],...
		'position',[350,80,355,85])

add_block('built-in/Note',[sys,'/',['information/information/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']])
set_param([sys,'/',['information/information/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']],...
		'position',[335,115,340,120])

add_block('built-in/Note',[sys,'/',['information/information/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']])
set_param([sys,'/',['information/information/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']],...
		'position',[380,40,385,45])
set_param([sys,'/','information/information'],...
		'Mask Display','?')


%     Finished composite block 'information/information'.

set_param([sys,'/','information/information'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[465,200,510,241])


%     Subsystem  'information/information1'.

new_system([sys,'/','information/information1'])
set_param([sys,'/','information/information1'],'Location',[4,60,788,251])

add_block('built-in/Note',[sys,'/','information/information1/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'])
set_param([sys,'/','information/information1/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'],...
		'position',[350,80,355,85])

add_block('built-in/Note',[sys,'/',['information/information1/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']])
set_param([sys,'/',['information/information1/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']],...
		'position',[335,115,340,120])

add_block('built-in/Note',[sys,'/',['information/information1/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']])
set_param([sys,'/',['information/information1/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']],...
		'position',[380,40,385,45])
set_param([sys,'/','information/information1'],...
		'Mask Display','?')


%     Finished composite block 'information/information1'.

set_param([sys,'/','information/information1'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[485,220,530,261])

add_block('built-in/Note',[sys,'/',['information/This demo generates a 2 tone FSK signal.  It is then transmited',13,'and received.  An Early-Late Gate method of data schronization is ']])
set_param([sys,'/',['information/This demo generates a 2 tone FSK signal.  It is then transmited',13,'and received.  An Early-Late Gate method of data schronization is ']],...
		'position',[240,10,245,15])

add_block('built-in/Note',[sys,'/',['information/The resulting binary signal is compared with the original binary',13,'message and the results are displayed with the error meter block.']])
set_param([sys,'/',['information/The resulting binary signal is compared with the original binary',13,'message and the results are displayed with the error meter block.']],...
		'position',[235,130,240,135])

add_block('built-in/Note',[sys,'/',['information/The modulated FSK signal is passed through an AWGN',13,'channel.  The channel has a variable SNR input that ramps ',13,'between -5 and 10 dB.    ']])
set_param([sys,'/',['information/The modulated FSK signal is passed through an AWGN',13,'channel.  The channel has a variable SNR input that ramps ',13,'between -5 and 10 dB.    ']],...
		'position',[220,85,225,90])

add_block('built-in/Note',[sys,'/',['information/Design and implementation by Darrel Judd.',13,'Company: Harman Motive',13,'1201 So. Ohio ST.',13,'Martinsville, Indiana 46151',13,'email: drjudd@surf-ici.com',13,'phone 317-342-5551 ext 339']])
set_param([sys,'/',['information/Design and implementation by Darrel Judd.',13,'Company: Harman Motive',13,'1201 So. Ohio ST.',13,'Martinsville, Indiana 46151',13,'email: drjudd@surf-ici.com',13,'phone 317-342-5551 ext 339']],...
		'position',[165,325,170,330])

add_block('built-in/Note',[sys,'/',['information/The graph window shows the a plot of the instanaeous frequency output',13,'from the demodualtion process (yellow).  The syncing pulse from the ',13,'ELG block is shown in green.  The SNR level is graphed in blue.',13,' ']])
set_param([sys,'/',['information/The graph window shows the a plot of the instanaeous frequency output',13,'from the demodualtion process (yellow).  The syncing pulse from the ',13,'ELG block is shown in green.  The SNR level is graphed in blue.',13,' ']],...
		'position',[215,160,220,165])

add_block('built-in/Note',[sys,'/',['information/An error free region can be determined by varing the ',13,'Variable parameter in the SNR Generator block.']])
set_param([sys,'/',['information/An error free region can be determined by varing the ',13,'Variable parameter in the SNR Generator block.']],...
		'position',[200,215,205,220])

add_block('built-in/Note',[sys,'/',['information/used in the receiver. The schronization pulses generated by the ELG',13,'block are used reset the integrator and sample the signal']])
set_param([sys,'/',['information/used in the receiver. The schronization pulses generated by the ELG',13,'block are used reset the integrator and sample the signal']],...
		'position',[245,40,250,45])
set_param([sys,'/','information'],...
		'Mask Display','?')


%     Finished composite block 'information'.

set_param([sys,'/','information'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[415,325,460,366])
add_line(sys,[320,270;310,270])
add_line(sys,[365,160;385,160])
add_line(sys,[495,265;485,265])
add_line(sys,[495,245;485,245])
add_line(sys,[595,185;585,255])
add_line(sys,[395,255;370,255])
add_line(sys,[265,45;330,45])
add_line(sys,[105,45;175,45])
add_line(sys,[140,255;130,255;130,155;105,155])
add_line(sys,[260,270;185,270])
add_line(sys,[395,255;380,255;380,210;305,210])
add_line(sys,[270,210;225,210;225,240;185,240])
add_line(sys,[130,45;130,135;105,135])
add_line(sys,[400,45;610,45;610,135])
add_line(sys,[265,110;575,110;575,135])
add_line(sys,[225,210;225,160;325,160])
add_line(sys,[295,110;295,145;325,145])
add_line(sys,[235,270;235,175;325,175])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
