function [ret,x0,str,ts,xts]=fmrtw(t,x,u,flag);
%FMRTW	is the M-file description of the SIMULINK system named FMRTW.
%	The block-diagram can be displayed by typing: FMRTW.
%
%	SYS=FMRTW(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes FMRTW to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling FMRTW with a FLAG of zero:
%	[SIZES]=FMRTW([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[363,42,1004,193])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Euler')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '300')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '[t,x,y]')
set_param(sys,'AssignSampleTimeColors','on');
set_param(sys,'AssignWideVectorLines','on');
set_param(sys,'Nonreal-time algorithm','None')
set_param(sys,'Nonreal-time min step size','0.001')
set_param(sys,'Nonreal-time stop time','20')
set_param(sys,'Nonreal-time save workspace blocks','off')
set_param(sys,'Real-time algorithm','None')
set_param(sys,'Real-time step size','0.0005')
set_param(sys,'Real-time template makefile','rti31.cmm')
set_param(sys,'Real-time build command','make_rt OPTS=-Dinf=1.e30')


%     Subsystem  'DS1102DA'.

new_system([sys,'/','DS1102DA'])
set_param([sys,'/','DS1102DA'],'Location',[12,124,275,390])


%     Subsystem  'DS1102DA/DAC_#1'.

new_system([sys,'/','DS1102DA/DAC_#1'])
set_param([sys,'/','DS1102DA/DAC_#1'],'Location',[125,40,274,186])

add_block('built-in/Gain',[sys,'/','DS1102DA/DAC_#1/DS_BOARD'])
set_param([sys,'/','DS1102DA/DAC_#1/DS_BOARD'],...
		'Gain','range_key',...
		'position',[60,60,80,80])

add_block('built-in/Inport',[sys,'/','DS1102DA/DAC_#1/in_1'])
set_param([sys,'/','DS1102DA/DAC_#1/in_1'],...
		'position',[10,60,30,80])

add_block('built-in/Outport',[sys,'/','DS1102DA/DAC_#1/out_1'])
set_param([sys,'/','DS1102DA/DAC_#1/out_1'],...
		'position',[110,60,130,80])
add_line([sys,'/','DS1102DA/DAC_#1'],[35,70;55,70])
add_line([sys,'/','DS1102DA/DAC_#1'],[85,70;105,70])
set_param([sys,'/','DS1102DA/DAC_#1'],...
		'Mask Display','DA',...
		'Mask Type','DA Converter',...
		'Mask Dialogue','DA Converter|range_key',...
		'Mask Translate','range_key=@1;',...
		'Mask Entries','10\/')


%     Finished composite block 'DS1102DA/DAC_#1'.

set_param([sys,'/','DS1102DA/DAC_#1'],...
		'position',[105,40,145,60])

add_block('built-in/Inport',[sys,'/','DS1102DA/in_1'])
set_param([sys,'/','DS1102DA/in_1'],...
		'position',[55,40,75,60])

add_block('built-in/Outport',[sys,'/','DS1102DA/out_1'])
set_param([sys,'/','DS1102DA/out_1'],...
		'position',[175,40,195,60])
add_line([sys,'/','DS1102DA'],[80,50;100,50])
add_line([sys,'/','DS1102DA'],[150,50;170,50])
set_param([sys,'/','DS1102DA'],...
		'Mask Display','DAC\nUnit',...
		'Mask Type','DS1102DA v2.0',...
		'Mask Dialogue','Voltage range for all DAC channels:\n\n[-10 +10] Volts',...
		'Mask Translate',' ')


%     Finished composite block 'DS1102DA'.

set_param([sys,'/','DS1102DA'],...
		'ForeGround',4,...
		'position',[520,24,550,66])


%     Subsystem  'OutPlug'.

new_system([sys,'/','OutPlug'])
set_param([sys,'/','OutPlug'],'Location',[0,0,152,163])

add_block('built-in/Gain',[sys,'/','OutPlug/DS_SOP'])
set_param([sys,'/','OutPlug/DS_SOP'],...
		'position',[100,50,120,70])

add_block('built-in/Inport',[sys,'/','OutPlug/input'])
set_param([sys,'/','OutPlug/input'],...
		'position',[30,50,50,70])
add_line([sys,'/','OutPlug'],[55,60;95,60])
set_param([sys,'/','OutPlug'],...
		'Mask Display','    S    ',...
		'Mask Type','Single output plug v2.0',...
		'Mask Dialogue','Single output plug')


%     Finished composite block 'OutPlug'.

set_param([sys,'/','OutPlug'],...
		'ForeGround',4,...
		'position',[590,39,615,51])


%     Subsystem  ['FDM',13,'passband'].

new_system([sys,'/',['FDM',13,'passband']])
set_param([sys,'/',['FDM',13,'passband']],'Location',[30,490,489,666])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Sensitivity']])
set_param([sys,'/',['FDM',13,'passband/Sensitivity']],...
		'Gain','2',...
		'position',[75,25,115,55])

add_block('built-in/Product',[sys,'/',['FDM',13,'passband/Multiplier',13,'phase detector']])
set_param([sys,'/',['FDM',13,'passband/Multiplier',13,'phase detector']],...
		'position',[190,35,215,55])

add_block('built-in/Filter',[sys,'/',['FDM',13,'passband/Filter']])
set_param([sys,'/',['FDM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[275,26,330,64])


%     Subsystem  ['FDM',13,'passband/Discrete-time',13,'VCO'].

new_system([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],'Location',[93,129,873,276])

add_block('built-in/Outport',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/out_1']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/out_1']],...
		'position',[690,35,710,55])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity3']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity3']],...
		'Gain','Ac',...
		'position',[605,30,655,60])

add_block('built-in/Fcn',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/sin']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/sin']],...
		'Expr','cos(u[1])',...
		'position',[510,32,585,58])

add_block('built-in/Constant',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Phase']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Phase']],...
		'Value','Ph',...
		'position',[400,100,420,120])

add_block('built-in/Sum',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum']],...
		'inputs','+++',...
		'position',[465,27,485,63])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity2']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity2']],...
		'Gain','Fc',...
		'position',[255,75,300,105])

add_block('built-in/Clock',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Clock']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Clock']],...
		'position',[180,80,200,100])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[105,15,155,45])

add_block('built-in/Sum',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum1']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum1']],...
		'position',[230,25,250,45])

add_block('built-in/Unit Delay',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Unit Delay']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Unit Delay']],...
		'Sample time','ts',...
		'position',[300,25,350,45])

add_block('built-in/Inport',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/in_1']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/in_1']],...
		'position',[35,20,55,40])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[660,45;685,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[590,45;600,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[425,110;435,110;435,55;460,55])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[355,35;460,35])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[370,35;370,70;205,70;205,40;225,40])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[305,90;425,90;425,45;460,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[205,90;250,90])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[490,45;505,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[255,35;295,35])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[160,30;225,30])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[60,30;100,30])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Display','Discrete\nVCO',...
		'Mask Type','VCO')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Dialogue','Voltage-Controlled Oscilator:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;ts=@5;Kc=Kc*pi2*ts(1);Fc=Fc*pi2;')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Help','The VCO block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Entries','1\/Fc\/1\/Ph\/ts\/')


%     Finished composite block ['FDM',13,'passband/Discrete-time',13,'VCO'].

set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'orientation',2,...
		'position',[240,95,300,135])

add_block('built-in/Outport',[sys,'/',['FDM',13,'passband/out_1']])
set_param([sys,'/',['FDM',13,'passband/out_1']],...
		'position',[420,35,440,55])

add_block('built-in/Inport',[sys,'/',['FDM',13,'passband/in_1']])
set_param([sys,'/',['FDM',13,'passband/in_1']],...
		'position',[25,30,45,50])
add_line([sys,'/',['FDM',13,'passband']],[235,115;135,115;135,50;185,50])
add_line([sys,'/',['FDM',13,'passband']],[220,45;270,45])
add_line([sys,'/',['FDM',13,'passband']],[335,45;415,45])
add_line([sys,'/',['FDM',13,'passband']],[385,45;385,115;305,115])
add_line([sys,'/',['FDM',13,'passband']],[50,40;70,40])
add_line([sys,'/',['FDM',13,'passband']],[120,40;185,40])
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);FDM',...
		'Mask Type','Passabnd FDM')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Dialogue','Demodulate an FM modulated signal\nusing phase-locked loop.|VCO frequency (Hz):|VCO initial phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2+pi/2;num=@3;den=@4;ts=@5;[x,y]=moduicon(4);')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Help','This block recovers a FM modulated signal using a phase-locked loop method. The phase detector used in this block is a multiplier.')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Entries','100\/pi/4\/[0.0457    0.0914    0.0457]\/[1.0000   -1.3108    0.4936]\/.001\/')


%     Finished composite block ['FDM',13,'passband'].

set_param([sys,'/',['FDM',13,'passband']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[370,23,450,67])


%     Subsystem  ['FM',13,'passband'].

new_system([sys,'/',['FM',13,'passband']])
set_param([sys,'/',['FM',13,'passband']],'Location',[451,587,939,737])

add_block('built-in/Inport',[sys,'/',['FM',13,'passband/in_1']])
set_param([sys,'/',['FM',13,'passband/in_1']],...
		'position',[60,40,80,60])

add_block('built-in/Outport',[sys,'/',['FM',13,'passband/out_1']])
set_param([sys,'/',['FM',13,'passband/out_1']],...
		'position',[465,50,485,70])

add_block('built-in/Fcn',[sys,'/',['FM',13,'passband/sin']])
set_param([sys,'/',['FM',13,'passband/sin']],...
		'Expr','cos(u[1]*pi2+Ph)',...
		'position',[290,45,430,75])

add_block('built-in/Constant',[sys,'/',['FM',13,'passband/Constant']])
set_param([sys,'/',['FM',13,'passband/Constant']],...
		'Value','Fc',...
		'position',[40,85,60,105])

add_block('built-in/S-Function',[sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']])
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf/2\/',...
		'position',[200,39,260,81])

add_block('built-in/Sum',[sys,'/',['FM',13,'passband/Sum']])
set_param([sys,'/',['FM',13,'passband/Sum']],...
		'position',[130,42,150,78])
add_line([sys,'/',['FM',13,'passband']],[435,60;460,60])
add_line([sys,'/',['FM',13,'passband']],[265,60;285,60])
add_line([sys,'/',['FM',13,'passband']],[155,60;195,60])
add_line([sys,'/',['FM',13,'passband']],[65,95;90,95;90,70;125,70])
add_line([sys,'/',['FM',13,'passband']],[85,50;125,50])
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);FM',...
		'Mask Type','Passband FM')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using FM method.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):|Symbol interval (sec; Use Inf for analog mod);')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2;pi2=2*pi;ts=@3;td=@4;if isinf(td),td=td;end;[x,y]=moduicon(3);')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Help','This block modulates the input signal using frequency modulation method. The frequency of the output of the carrier signal depends on the amplitude of the input signal.')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Entries','100\/pi/4\/.001\/Inf\/')


%     Finished composite block ['FM',13,'passband'].

set_param([sys,'/',['FM',13,'passband']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[255,23,335,67])


%     Subsystem  'InPlug'.

new_system([sys,'/','InPlug'])
set_param([sys,'/','InPlug'],'Location',[0,200,300,310])

add_block('built-in/Outport',[sys,'/','InPlug/output'])
set_param([sys,'/','InPlug/output'],...
		'position',[165,50,185,70])

add_block('built-in/Constant',[sys,'/','InPlug/DS_SIP'])
set_param([sys,'/','InPlug/DS_SIP'],...
		'Mask Display','         ',...
		'position',[50,54,90,66])
add_line([sys,'/','InPlug'],[95,60;160,60])
set_param([sys,'/','InPlug'],...
		'Mask Display','S',...
		'Mask Type','Single input plug v2.0',...
		'Mask Dialogue','Single input plug')


%     Finished composite block 'InPlug'.

set_param([sys,'/','InPlug'],...
		'ForeGround',4,...
		'position',[20,35,45,45])


%     Subsystem  'DS1102AD'.

new_system([sys,'/','DS1102AD'])
set_param([sys,'/','DS1102AD'],'Location',[386,108,620,415])


%     Subsystem  'DS1102AD/ADC_#1'.

new_system([sys,'/','DS1102AD/ADC_#1'])
set_param([sys,'/','DS1102AD/ADC_#1'],'Location',[125,40,274,186])

add_block('built-in/Outport',[sys,'/','DS1102AD/ADC_#1/out_1'])
set_param([sys,'/','DS1102AD/ADC_#1/out_1'],...
		'position',[110,60,130,80])

add_block('built-in/Inport',[sys,'/','DS1102AD/ADC_#1/in_1'])
set_param([sys,'/','DS1102AD/ADC_#1/in_1'],...
		'position',[10,60,30,80])

add_block('built-in/Gain',[sys,'/','DS1102AD/ADC_#1/DS_BOARD'])
set_param([sys,'/','DS1102AD/ADC_#1/DS_BOARD'],...
		'Gain','range_key',...
		'position',[60,60,80,80])
add_line([sys,'/','DS1102AD/ADC_#1'],[85,70;105,70])
add_line([sys,'/','DS1102AD/ADC_#1'],[35,70;55,70])
set_param([sys,'/','DS1102AD/ADC_#1'],...
		'Mask Display','AD',...
		'Mask Type','Mux-AD Converter',...
		'Mask Dialogue','Mux-AD Converter|range_key',...
		'Mask Translate','range_key=@1;',...
		'Mask Entries','P(1)\/')


%     Finished composite block 'DS1102AD/ADC_#1'.

set_param([sys,'/','DS1102AD/ADC_#1'],...
		'position',[100,70,140,90])

add_block('built-in/Inport',[sys,'/','DS1102AD/in_1'])
set_param([sys,'/','DS1102AD/in_1'],...
		'position',[50,70,70,90])

add_block('built-in/Outport',[sys,'/','DS1102AD/out_1'])
set_param([sys,'/','DS1102AD/out_1'],...
		'position',[170,70,190,90])
add_line([sys,'/','DS1102AD'],[145,80;165,80])
add_line([sys,'/','DS1102AD'],[75,80;95,80])
set_param([sys,'/','DS1102AD'],...
		'Mask Display','ADC\nUnit',...
		'Mask Type','DS1102AD v2.0',...
		'Mask Dialogue','Voltage range for all ADC channels:\n\n[-10 +10] Volts',...
		'Mask Translate','for i=1: 4, P(i) = 0.1;  end;  end ')


%     Finished composite block 'DS1102AD'.

set_param([sys,'/','DS1102AD'],...
		'ForeGround',4,...
		'position',[75,16,110,64])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'position',[190,35,210,55])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'Peak','0.000000',...
		'Peak Range','5.000000',...
		'Freq','1.000000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads',...
		'position',[125,78,170,112])
add_line(sys,[455,45;515,45])
add_line(sys,[555,45;585,45])
add_line(sys,[50,40;70,40])
add_line(sys,[175,95;185,50])
add_line(sys,[215,45;250,45])
add_line(sys,[340,45;365,45])
add_line(sys,[115,40;185,40])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
