function [ret,x0,str,ts,xts]=hdslsimu(t,x,u,flag);
%HDSLSIMU	is the M-file description of the SIMULINK system named HDSLSIMU.
%	The block-diagram can be displayed by typing: HDSLSIMU.
%
%	SYS=HDSLSIMU(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes HDSLSIMU to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling HDSLSIMU with a FLAG of zero:
%	[SIZES]=HDSLSIMU([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[95,335,595,590])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '200')
set_param(sys,'Min step size', '0.002')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','hdsldata');

add_block('built-in/Note',[sys,'/','High-Bit-Rate Digital Subscriber Line'])
set_param([sys,'/','High-Bit-Rate Digital Subscriber Line'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[245,20,250,25])


%     Subsystem  ['K-step',13,'delay'].

new_system([sys,'/',['K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay']],'Location',[12,432,357,702])

add_block('built-in/Digital Clock',[sys,'/',['K-step',13,'delay/Digital Clock']])
set_param([sys,'/',['K-step',13,'delay/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])

add_block('built-in/Inport',[sys,'/',['K-step',13,'delay/in_1']])
set_param([sys,'/',['K-step',13,'delay/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['K-step',13,'delay/out_1']])
set_param([sys,'/',['K-step',13,'delay/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Filter',[sys,'/',['K-step',13,'delay/K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Switch',[sys,'/',['K-step',13,'delay/Switch']])
set_param([sys,'/',['K-step',13,'delay/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant']])
set_param([sys,'/',['K-step',13,'delay/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant1']])
set_param([sys,'/',['K-step',13,'delay/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Relational Operator',[sys,'/',['K-step',13,'delay/Relational',13,'Operator']])
set_param([sys,'/',['K-step',13,'delay/Relational',13,'Operator']],...
		'position',[150,168,180,192])
add_line([sys,'/',['K-step',13,'delay']],[300,130;320,130])
add_line([sys,'/',['K-step',13,'delay']],[45,90;55,90])
add_line([sys,'/',['K-step',13,'delay']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['K-step',13,'delay']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['K-step',13,'delay']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['K-step',13,'delay']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['K-step',13,'delay']],[185,180;220,180;220,130;265,130])
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay',...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.',...
		'Mask Entries','43\/.0025\/0\/')


%     Finished composite block ['K-step',13,'delay'].

set_param([sys,'/',['K-step',13,'delay']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[145,69,190,101])


%     Subsystem  ['K-step',13,'delay1'].

new_system([sys,'/',['K-step',13,'delay1']])
set_param([sys,'/',['K-step',13,'delay1']],'Location',[12,432,357,702])

add_block('built-in/Relational Operator',[sys,'/',['K-step',13,'delay1/Relational',13,'Operator']])
set_param([sys,'/',['K-step',13,'delay1/Relational',13,'Operator']],...
		'position',[150,168,180,192])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay1/Constant1']])
set_param([sys,'/',['K-step',13,'delay1/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay1/Constant']])
set_param([sys,'/',['K-step',13,'delay1/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Switch',[sys,'/',['K-step',13,'delay1/Switch']])
set_param([sys,'/',['K-step',13,'delay1/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Filter',[sys,'/',['K-step',13,'delay1/K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay1/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Outport',[sys,'/',['K-step',13,'delay1/out_1']])
set_param([sys,'/',['K-step',13,'delay1/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Inport',[sys,'/',['K-step',13,'delay1/in_1']])
set_param([sys,'/',['K-step',13,'delay1/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Digital Clock',[sys,'/',['K-step',13,'delay1/Digital Clock']])
set_param([sys,'/',['K-step',13,'delay1/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])
add_line([sys,'/',['K-step',13,'delay1']],[185,180;220,180;220,130;265,130])
add_line([sys,'/',['K-step',13,'delay1']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['K-step',13,'delay1']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['K-step',13,'delay1']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['K-step',13,'delay1']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['K-step',13,'delay1']],[45,90;55,90])
add_line([sys,'/',['K-step',13,'delay1']],[300,130;320,130])
set_param([sys,'/',['K-step',13,'delay1']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay',...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['K-step',13,'delay1']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['K-step',13,'delay1']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.',...
		'Mask Entries','43\/.0025\/0\/')


%     Finished composite block ['K-step',13,'delay1'].

set_param([sys,'/',['K-step',13,'delay1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[160,194,205,226])


%     Subsystem  'PAM Signal'.

new_system([sys,'/','PAM Signal'])
set_param([sys,'/','PAM Signal'],'Location',[113,193,448,317])


%     Subsystem  'PAM Signal/MASK map'.

new_system([sys,'/','PAM Signal/MASK map'])
set_param([sys,'/','PAM Signal/MASK map'],'Location',[520,162,902,335])

add_block('built-in/Constant',[sys,'/','PAM Signal/MASK map/Gain diff'])
set_param([sys,'/','PAM Signal/MASK map/Gain diff'],...
		'Value','Ac',...
		'position',[180,96,215,124])

add_block('built-in/Sum',[sys,'/','PAM Signal/MASK map/Sum1'])
set_param([sys,'/','PAM Signal/MASK map/Sum1'],...
		'inputs','+-',...
		'position',[250,63,270,87])

add_block('built-in/Gain',[sys,'/','PAM Signal/MASK map/Gain'])
set_param([sys,'/','PAM Signal/MASK map/Gain'],...
		'Gain','Kc',...
		'position',[180,25,220,55])

add_block('built-in/Inport',[sys,'/','PAM Signal/MASK map/in_1'])
set_param([sys,'/','PAM Signal/MASK map/in_1'],...
		'position',[40,30,60,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['PAM Signal/MASK map/Zero-Order',13,'Hold']])
set_param([sys,'/',['PAM Signal/MASK map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[100,24,135,56])

add_block('built-in/Outport',[sys,'/','PAM Signal/MASK map/out_1'])
set_param([sys,'/','PAM Signal/MASK map/out_1'],...
		'position',[315,65,335,85])
add_line([sys,'/','PAM Signal/MASK map'],[140,40;175,40])
add_line([sys,'/','PAM Signal/MASK map'],[65,40;95,40])
add_line([sys,'/','PAM Signal/MASK map'],[275,75;310,75])
add_line([sys,'/','PAM Signal/MASK map'],[220,110;230,110;230,80;245,80])
add_line([sys,'/','PAM Signal/MASK map'],[225,40;230,40;230,70;245,70])
set_param([sys,'/','PAM Signal/MASK map'],...
		'Mask Display','MASK\nmap',...
		'Mask Type','MASK map')
set_param([sys,'/','PAM Signal/MASK map'],...
		'Mask Dialogue','Map a digital symbol onto an analog\nsignal in the range [-1, 1] using M-ary\namplitude shift keying modulation mapping.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/','PAM Signal/MASK map'],...
		'Mask Translate','N=@1;Ac=1;Kc=Ac*2/(N-1);td=@2;')
set_param([sys,'/','PAM Signal/MASK map'],...
		'Mask Help','This block maps an input digit signal onto a signal in the range [-1, 1]. The coded signal can be modulated using analog\nmodulation blocks. Input digits are in the range [0, M-1], where M is the M-ary number. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/','PAM Signal/MASK map'],...
		'Mask Entries','2\/0.0025\/')


%     Finished composite block 'PAM Signal/MASK map'.

set_param([sys,'/','PAM Signal/MASK map'],...
		'hide name',0,...
		'position',[155,33,235,77])

add_block('built-in/Outport',[sys,'/','PAM Signal/out_1'])
set_param([sys,'/','PAM Signal/out_1'],...
		'position',[270,45,290,65])


%     Subsystem  ['PAM Signal/Sampled read',13,'from wksp'].

new_system([sys,'/',['PAM Signal/Sampled read',13,'from wksp']])
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['PAM Signal/Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Message source']],...
		'Mask Type','Read from workspace')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Message source']],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['PAM Signal/Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['PAM Signal/Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['PAM Signal/Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp']],...
		'Mask Entries','randint(300,1,2)\/0.0025\/1\/0\/')


%     Finished composite block ['PAM Signal/Sampled read',13,'from wksp'].

set_param([sys,'/',['PAM Signal/Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[40,33,120,77])

add_block('built-in/Outport',[sys,'/','PAM Signal/out_2'])
set_param([sys,'/','PAM Signal/out_2'],...
		'Port','2',...
		'position',[180,90,200,110])
add_line([sys,'/','PAM Signal'],[125,55;150,55])
add_line([sys,'/','PAM Signal'],[240,55;265,55])
add_line([sys,'/','PAM Signal'],[125,55;135,55;135,100;175,100])


%     Finished composite block 'PAM Signal'.

set_param([sys,'/','PAM Signal'],...
		'position',[20,130,50,185])


%     Subsystem  'Channel'.

new_system([sys,'/','Channel'])
set_param([sys,'/','Channel'],'Location',[417,524,780,716])

add_block('built-in/Sum',[sys,'/','Channel/Sum'])
set_param([sys,'/','Channel/Sum'],...
		'hide name',0,...
		'position',[230,115,250,135])


%     Subsystem  ['Channel/Band-Limited',13,'White Noise'].

new_system([sys,'/',['Channel/Band-Limited',13,'White Noise']])
set_param([sys,'/',['Channel/Band-Limited',13,'White Noise']],'Location',[54,341,339,470])

add_block('built-in/White Noise',[sys,'/',['Channel/Band-Limited',13,'White Noise/White Noise']])
set_param([sys,'/',['Channel/Band-Limited',13,'White Noise/White Noise']],...
		'Seed','seed',...
		'position',[25,40,45,60])

add_block('built-in/Zero-Order Hold',[sys,'/',['Channel/Band-Limited',13,'White Noise/Zero-Order',13,'Hold']])
set_param([sys,'/',['Channel/Band-Limited',13,'White Noise/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/Gain',[sys,'/',['Channel/Band-Limited',13,'White Noise/Gain']])
set_param([sys,'/',['Channel/Band-Limited',13,'White Noise/Gain']],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Outport',[sys,'/',['Channel/Band-Limited',13,'White Noise/Out_1']])
set_param([sys,'/',['Channel/Band-Limited',13,'White Noise/Out_1']],...
		'position',[230,40,250,60])
add_line([sys,'/',['Channel/Band-Limited',13,'White Noise']],[125,50;150,50])
add_line([sys,'/',['Channel/Band-Limited',13,'White Noise']],[200,50;225,50])
add_line([sys,'/',['Channel/Band-Limited',13,'White Noise']],[50,50;80,50])
set_param([sys,'/',['Channel/Band-Limited',13,'White Noise']],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/',['Channel/Band-Limited',13,'White Noise']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/',['Channel/Band-Limited',13,'White Noise']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/',['Channel/Band-Limited',13,'White Noise']],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Channel/Band-Limited',13,'White Noise']],...
		'Mask Entries','[1]\/0.002\/[23341]\/')


%     Finished composite block ['Channel/Band-Limited',13,'White Noise'].

set_param([sys,'/',['Channel/Band-Limited',13,'White Noise']],...
		'position',[40,32,85,68])

add_block('built-in/Outport',[sys,'/','Channel/out'])
set_param([sys,'/','Channel/out'],...
		'position',[275,115,295,135])

add_block('built-in/Filter',[sys,'/','Channel/Noise Shape'])
set_param([sys,'/','Channel/Noise Shape'],...
		'Numerator','nfilt',...
		'Denominator','[1]',...
		'Sample time','0.002',...
		'position',[125,31,185,69])

add_block('built-in/Filter',[sys,'/','Channel/Channel'])
set_param([sys,'/','Channel/Channel'],...
		'Numerator','chim',...
		'Denominator','[1]',...
		'Sample time','0.002',...
		'position',[125,111,185,149])

add_block('built-in/Inport',[sys,'/','Channel/in'])
set_param([sys,'/','Channel/in'],...
		'position',[60,120,80,140])
add_line([sys,'/','Channel'],[90,50;120,50])
add_line([sys,'/','Channel'],[190,50;210,50;210,120;225,120])
add_line([sys,'/','Channel'],[190,130;225,130])
add_line([sys,'/','Channel'],[255,125;270,125])
add_line([sys,'/','Channel'],[85,130;120,130])


%     Finished composite block 'Channel'.

set_param([sys,'/','Channel'],...
		'position',[180,119,210,171])


%     Subsystem  'Receiver'.

new_system([sys,'/','Receiver'])
set_param([sys,'/','Receiver'],'Location',[80,490,779,816])


%     Subsystem  'Receiver/Switch 2'.

new_system([sys,'/','Receiver/Switch 2'])
set_param([sys,'/','Receiver/Switch 2'],'Location',[95,218,471,387])

add_block('built-in/Inport',[sys,'/','Receiver/Switch 2/in_1'])
set_param([sys,'/','Receiver/Switch 2/in_1'],...
		'position',[35,55,55,75])

add_block('built-in/Gain',[sys,'/','Receiver/Switch 2/Gain2'])
set_param([sys,'/','Receiver/Switch 2/Gain2'],...
		'hide name',0,...
		'Gain','0',...
		'position',[110,108,155,142])

add_block('built-in/Gain',[sys,'/','Receiver/Switch 2/Gain3'])
set_param([sys,'/','Receiver/Switch 2/Gain3'],...
		'hide name',0,...
		'Gain','10',...
		'position',[110,48,155,82])

add_block('built-in/Outport',[sys,'/','Receiver/Switch 2/out_1'])
set_param([sys,'/','Receiver/Switch 2/out_1'],...
		'position',[300,80,320,100])

add_block('built-in/Switch',[sys,'/','Receiver/Switch 2/Switch'])
set_param([sys,'/','Receiver/Switch 2/Switch'],...
		'hide name',0,...
		'Threshold','0.5',...
		'position',[240,74,270,106])

add_block('built-in/Inport',[sys,'/','Receiver/Switch 2/in_2'])
set_param([sys,'/','Receiver/Switch 2/in_2'],...
		'Port','2',...
		'position',[165,80,185,100])
add_line([sys,'/','Receiver/Switch 2'],[60,65;105,65])
add_line([sys,'/','Receiver/Switch 2'],[95,65;105,125])
add_line([sys,'/','Receiver/Switch 2'],[275,90;295,90])
add_line([sys,'/','Receiver/Switch 2'],[190,90;235,90])
add_line([sys,'/','Receiver/Switch 2'],[160,65;205,65;205,80;235,80])
add_line([sys,'/','Receiver/Switch 2'],[160,125;200,125;200,100;235,100])


%     Finished composite block 'Receiver/Switch 2'.

set_param([sys,'/','Receiver/Switch 2'],...
		'position',[170,221,200,274])

add_block('built-in/Inport',[sys,'/','Receiver/in_2'])
set_param([sys,'/','Receiver/in_2'],...
		'Port','2',...
		'position',[105,225,125,245])


%     Subsystem  'Receiver/Switch 1'.

new_system([sys,'/','Receiver/Switch 1'])
set_param([sys,'/','Receiver/Switch 1'],'Location',[95,218,476,372])

add_block('built-in/Inport',[sys,'/','Receiver/Switch 1/in_2'])
set_param([sys,'/','Receiver/Switch 1/in_2'],...
		'Port','2',...
		'position',[165,55,185,75])

add_block('built-in/Switch',[sys,'/','Receiver/Switch 1/Switch'])
set_param([sys,'/','Receiver/Switch 1/Switch'],...
		'hide name',0,...
		'Threshold','0.5',...
		'position',[245,49,275,81])

add_block('built-in/Outport',[sys,'/','Receiver/Switch 1/out_1'])
set_param([sys,'/','Receiver/Switch 1/out_1'],...
		'position',[305,55,325,75])

add_block('built-in/Gain',[sys,'/','Receiver/Switch 1/Gain3'])
set_param([sys,'/','Receiver/Switch 1/Gain3'],...
		'hide name',0,...
		'Gain','0.0000000001',...
		'position',[110,23,155,57])

add_block('built-in/Gain',[sys,'/','Receiver/Switch 1/Gain2'])
set_param([sys,'/','Receiver/Switch 1/Gain2'],...
		'hide name',0,...
		'Gain','0.01',...
		'position',[110,83,155,117])

add_block('built-in/Inport',[sys,'/','Receiver/Switch 1/in_1'])
set_param([sys,'/','Receiver/Switch 1/in_1'],...
		'position',[35,30,55,50])
add_line([sys,'/','Receiver/Switch 1'],[60,40;105,40])
add_line([sys,'/','Receiver/Switch 1'],[95,40;105,100])
add_line([sys,'/','Receiver/Switch 1'],[280,65;300,65])
add_line([sys,'/','Receiver/Switch 1'],[190,65;240,65])
add_line([sys,'/','Receiver/Switch 1'],[160,40;205,40;205,55;240,55])
add_line([sys,'/','Receiver/Switch 1'],[160,100;205,100;205,75;240,75])


%     Finished composite block 'Receiver/Switch 1'.

set_param([sys,'/','Receiver/Switch 1'],...
		'position',[160,31,190,84])


%     Subsystem  ['Receiver/PAM',13,'Signal'].

new_system([sys,'/',['Receiver/PAM',13,'Signal']])
set_param([sys,'/',['Receiver/PAM',13,'Signal']],'Location',[4,566,364,696])

add_block('built-in/Outport',[sys,'/',['Receiver/PAM',13,'Signal/out_1']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/out_1']],...
		'position',[310,65,330,85])


%     Subsystem  ['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp'].

new_system([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp']],'Location',[355,528,737,675])


%     Subsystem  ['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Message source']],...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp/Message source']],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])
add_line([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp']],[260,75;290,75])
add_line([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp']],[115,75;175,75])
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp']],...
		'Mask Entries','randint(300,1,4)\/0.0025\/1\/0\/')


%     Finished composite block ['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp'].

set_param([sys,'/',['Receiver/PAM',13,'Signal/Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[45,53,125,97])


%     Subsystem  ['Receiver/PAM',13,'Signal/MASK map'].

new_system([sys,'/',['Receiver/PAM',13,'Signal/MASK map']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],'Location',[520,162,902,335])

add_block('built-in/Outport',[sys,'/',['Receiver/PAM',13,'Signal/MASK map/out_1']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map/out_1']],...
		'position',[315,65,335,85])

add_block('built-in/Zero-Order Hold',[sys,'/',['Receiver/PAM',13,'Signal/MASK map/Zero-Order',13,'Hold']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[100,24,135,56])

add_block('built-in/Inport',[sys,'/',['Receiver/PAM',13,'Signal/MASK map/in_1']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map/in_1']],...
		'position',[40,30,60,50])

add_block('built-in/Gain',[sys,'/',['Receiver/PAM',13,'Signal/MASK map/Gain']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map/Gain']],...
		'Gain','Kc',...
		'position',[180,25,220,55])

add_block('built-in/Sum',[sys,'/',['Receiver/PAM',13,'Signal/MASK map/Sum1']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map/Sum1']],...
		'inputs','+-',...
		'position',[250,63,270,87])

add_block('built-in/Constant',[sys,'/',['Receiver/PAM',13,'Signal/MASK map/Gain diff']])
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map/Gain diff']],...
		'Value','Ac',...
		'position',[180,96,215,124])
add_line([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],[225,40;230,40;230,70;245,70])
add_line([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],[220,110;230,110;230,80;245,80])
add_line([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],[275,75;310,75])
add_line([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],[65,40;95,40])
add_line([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],[140,40;175,40])
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],...
		'Mask Display','MASK\nmap',...
		'Mask Type','MASK map')
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],...
		'Mask Dialogue','Map a digital symbol onto an analog\nsignal in the range [-1, 1] using M-ary\namplitude shift keying modulation mapping.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],...
		'Mask Translate','N=@1;Ac=1;Kc=Ac*2/(N-1);td=@2;')
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],...
		'Mask Help','This block maps an input digit signal onto a signal in the range [-1, 1]. The coded signal can be modulated using analog\nmodulation blocks. Input digits are in the range [0, M-1], where M is the M-ary number. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],...
		'Mask Entries','4\/0.0025\/')


%     Finished composite block ['Receiver/PAM',13,'Signal/MASK map'].

set_param([sys,'/',['Receiver/PAM',13,'Signal/MASK map']],...
		'hide name',0,...
		'position',[185,53,265,97])
add_line([sys,'/',['Receiver/PAM',13,'Signal']],[270,75;305,75])
add_line([sys,'/',['Receiver/PAM',13,'Signal']],[130,75;180,75])


%     Finished composite block ['Receiver/PAM',13,'Signal'].

set_param([sys,'/',['Receiver/PAM',13,'Signal']],...
		'position',[85,90,115,140])

add_block('built-in/Step Fcn',[sys,'/','Receiver/Step Input'])
set_param([sys,'/','Receiver/Step Input'],...
		'ForeGround',6,...
		'Time','0',...
		'position',[30,285,50,305])

add_block('built-in/Inport',[sys,'/','Receiver/in_1'])
set_param([sys,'/','Receiver/in_1'],...
		'position',[415,225,435,245])


%     Subsystem  'Receiver/Switch 3'.

new_system([sys,'/','Receiver/Switch 3'])
set_param([sys,'/','Receiver/Switch 3'],'Location',[95,218,519,426])

add_block('built-in/Inport',[sys,'/','Receiver/Switch 3/in_1'])
set_param([sys,'/','Receiver/Switch 3/in_1'],...
		'position',[35,55,55,75])

add_block('built-in/Gain',[sys,'/','Receiver/Switch 3/Gain2'])
set_param([sys,'/','Receiver/Switch 3/Gain2'],...
		'hide name',0,...
		'Gain','0',...
		'position',[110,108,155,142])

add_block('built-in/Gain',[sys,'/','Receiver/Switch 3/Gain3'])
set_param([sys,'/','Receiver/Switch 3/Gain3'],...
		'hide name',0,...
		'position',[110,48,155,82])

add_block('built-in/Inport',[sys,'/','Receiver/Switch 3/in_2'])
set_param([sys,'/','Receiver/Switch 3/in_2'],...
		'Port','2',...
		'position',[175,85,195,105])

add_block('built-in/Switch',[sys,'/','Receiver/Switch 3/Switch'])
set_param([sys,'/','Receiver/Switch 3/Switch'],...
		'hide name',0,...
		'Threshold','0.5',...
		'position',[265,79,295,111])

add_block('built-in/Outport',[sys,'/','Receiver/Switch 3/out_1'])
set_param([sys,'/','Receiver/Switch 3/out_1'],...
		'position',[325,85,345,105])
add_line([sys,'/','Receiver/Switch 3'],[60,65;105,65])
add_line([sys,'/','Receiver/Switch 3'],[95,65;105,125])
add_line([sys,'/','Receiver/Switch 3'],[300,95;320,95])
add_line([sys,'/','Receiver/Switch 3'],[200,95;260,95])
add_line([sys,'/','Receiver/Switch 3'],[160,65;235,65;235,85;260,85])
add_line([sys,'/','Receiver/Switch 3'],[160,125;230,125;230,105;260,105])


%     Finished composite block 'Receiver/Switch 3'.

set_param([sys,'/','Receiver/Switch 3'],...
		'position',[465,221,495,274])


%     Subsystem  ['Receiver/Echo',13,'Canceler'].

new_system([sys,'/',['Receiver/Echo',13,'Canceler']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler']],'Location',[110,372,749,580])

add_block('built-in/Product',[sys,'/',['Receiver/Echo',13,'Canceler/Product1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Product1']],...
		'position',[170,68,200,92])

add_block('built-in/Inport',[sys,'/',['Receiver/Echo',13,'Canceler/in_1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/in_1']],...
		'position',[70,65,90,85])

add_block('built-in/Outport',[sys,'/',['Receiver/Echo',13,'Canceler/out_1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/out_1']],...
		'position',[385,45,405,65])

add_block('built-in/Sum',[sys,'/',['Receiver/Echo',13,'Canceler/Sum2']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Sum2']],...
		'position',[240,75,260,95])

add_block('built-in/Unit Delay',[sys,'/',['Receiver/Echo',13,'Canceler/Unit Delay2']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Unit Delay2']],...
		'Sample time','0.0025',...
		'x0','X3_ini',...
		'position',[305,75,345,95])

add_block('built-in/Outport',[sys,'/',['Receiver/Echo',13,'Canceler/out_2']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/out_2']],...
		'Port','2',...
		'position',[540,135,560,155])


%     Subsystem  ['Receiver/Echo',13,'Canceler/Inner',13,'Product1'].

new_system([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1/in_1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1/in_2']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1/out_1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1/Sum']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1/Product']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1']],[150,65;180,65])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1']],[95,65;120,65])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1']],[40,35;60,60])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1']],[40,100;60,70])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Receiver/Echo',13,'Canceler/Inner',13,'Product1'].

set_param([sys,'/',['Receiver/Echo',13,'Canceler/Inner',13,'Product1']],...
		'position',[405,134,425,156])

add_block('built-in/Inport',[sys,'/',['Receiver/Echo',13,'Canceler/in_2']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/in_2']],...
		'Port','2',...
		'position',[25,140,45,160])


%     Subsystem  ['Receiver/Echo',13,'Canceler/Delay Line2'].

new_system([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2']],'Location',[309,417,625,562])


%     Subsystem  ['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift'].

new_system([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Demux',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/Demux']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/S-function']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/Mux']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/out_1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/out_2']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/in_1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/in_2']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Reg. shift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],...
		'Mask Dialogue','The rising edge of the 2nd port pulse\ntriggers the block to input the 1st port data and to shift the register.|Delay steps (output length is same as this vector size):|Threshold in detecting the rising edge of the pulse:')
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],...
		'Mask Translate','shft_out=@1;thrhld=@2;len_rg=length(@1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,75,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],...
		'Mask Help','This block stores the scalar input signal from the 1st input port at the rising edge of the pulse from the 2nd port. The 1st outport outputs a vector with its size the same as the "Delay steps" entree of this block. The maximum delay is the register size of this block. The second outport outputs a positive pulse when the register is\nrefreshed.')
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],...
		'Mask Entries','[47:-1:0]\/.1\/')


%     Finished composite block ['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift'].

set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Register-shift']],...
		'position',[155,18,235,62])

add_block('built-in/Inport',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/in_1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/in_1']],...
		'position',[35,20,55,40])


%     Subsystem  ['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time'].

new_system([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Entries','.0025\/1\/0\/')


%     Finished composite block ['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time'].

set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/Pulses divide',13,'same sample time']],...
		'position',[30,58,110,102])

add_block('built-in/Outport',[sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/out_1']])
set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2/out_1']],...
		'position',[275,20,295,40])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2']],[240,30;270,30])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2']],[115,80;130,80;130,50;150,50])
add_line([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2']],[60,30;150,30])


%     Finished composite block ['Receiver/Echo',13,'Canceler/Delay Line2'].

set_param([sys,'/',['Receiver/Echo',13,'Canceler/Delay Line2']],...
		'position',[80,123,110,177])
add_line([sys,'/',['Receiver/Echo',13,'Canceler']],[50,150;75,150])
add_line([sys,'/',['Receiver/Echo',13,'Canceler']],[95,75;165,75])
add_line([sys,'/',['Receiver/Echo',13,'Canceler']],[265,85;300,85])
add_line([sys,'/',['Receiver/Echo',13,'Canceler']],[115,150;400,150])
add_line([sys,'/',['Receiver/Echo',13,'Canceler']],[130,150;130,85;165,85])
add_line([sys,'/',['Receiver/Echo',13,'Canceler']],[350,85;375,85;375,140;400,140])
add_line([sys,'/',['Receiver/Echo',13,'Canceler']],[430,145;535,145])
add_line([sys,'/',['Receiver/Echo',13,'Canceler']],[205,80;235,80])
add_line([sys,'/',['Receiver/Echo',13,'Canceler']],[285,85;285,55;380,55])
add_line([sys,'/',['Receiver/Echo',13,'Canceler']],[375,140;225,140;235,90])


%     Finished composite block ['Receiver/Echo',13,'Canceler'].

set_param([sys,'/',['Receiver/Echo',13,'Canceler']],...
		'position',[275,77,305,128])


%     Subsystem  ['Receiver/Digital-TDMA',13,'mux1'].

new_system([sys,'/',['Receiver/Digital-TDMA',13,'mux1']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],'Location',[7,588,411,722])


%     Subsystem  ['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'Mask Entries','td\/[1 N]\/[0 0]\/')


%     Finished composite block ['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'position',[35,66,100,104])

add_block('built-in/Demux',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Demux']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Demux']],...
		'outputs','2',...
		'position',[130,65,180,100])


%     Subsystem  ['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down'].

new_system([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'Mask Entries','N\/0\/1\/.1\/0\/')


%     Finished composite block ['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down'].

set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'position',[215,53,275,97])

add_block('built-in/Outport',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/out_1']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/out_1']],...
		'position',[310,55,330,75])

add_block('built-in/Inport',[sys,'/',['Receiver/Digital-TDMA',13,'mux1/in_1']])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1/in_1']],...
		'position',[115,20,135,40])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],[140,30;190,30;190,60;210,60])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],[280,65;305,65])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],[105,85;125,85])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],[185,75;210,75])
add_line([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],[185,90;210,90])
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],...
		'Mask Display','D-TDMA\nmux',...
		'Mask Type','Digital TDMA')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],...
		'Mask Dialogue','Input a vector digital signal. Output a scalar up-sampled digital signal.|Input symbol sample time (sec):|Input vector length:',...
		'Mask Translate','td=@1;N=@2;')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],...
		'Mask Help','This block inputs a length N_in vector input signal with sample time T_in. The output of this block is a vector with sample time T_in/N_in. For the output signal, a T_in time period is partitioned into N_in even time length sections. Each section contains the value of one element of the input vector. This block takes all elements from the input vector at the start point of the sample time.')
set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],...
		'Mask Entries','0.125\/48\/')


%     Finished composite block ['Receiver/Digital-TDMA',13,'mux1'].

set_param([sys,'/',['Receiver/Digital-TDMA',13,'mux1']],...
		'hide name',0,...
		'position',[345,68,425,112])


%     Subsystem  'Receiver/Equalizer'.

new_system([sys,'/','Receiver/Equalizer'])
set_param([sys,'/','Receiver/Equalizer'],'Location',[13,228,718,516])

add_block('built-in/Inport',[sys,'/','Receiver/Equalizer/in_2'])
set_param([sys,'/','Receiver/Equalizer/in_2'],...
		'Port','2',...
		'position',[25,105,45,125])

add_block('built-in/Inport',[sys,'/','Receiver/Equalizer/in_1'])
set_param([sys,'/','Receiver/Equalizer/in_1'],...
		'position',[235,125,255,145])

add_block('built-in/Scope',[sys,'/',['Receiver/Equalizer/Equalizer',13,'FBF view']])
set_param([sys,'/',['Receiver/Equalizer/Equalizer',13,'FBF view']],...
		'Vgain','1.500000',...
		'Hgain','0.160000',...
		'Vmax','3.000000',...
		'Hmax','0.320000',...
		'Window',[600,552,846,804],...
		'Mask Display','')
set_param([sys,'/',['Receiver/Equalizer/Equalizer',13,'FBF view']],...
		'position',[465,187,485,213])


%     Subsystem  ['Receiver/Equalizer/Digital-TDMA',13,'mux1'].

new_system([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],'Location',[7,588,411,722])


%     Subsystem  ['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'Mask Entries','td\/[1 N]\/[0 0]\/')


%     Finished composite block ['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Pulses deivide',13,'same sample time']],...
		'position',[35,66,100,104])

add_block('built-in/Demux',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Demux']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Demux']],...
		'outputs','2',...
		'position',[130,65,180,100])


%     Subsystem  ['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down'].

new_system([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'Mask Entries','N\/0\/1\/.1\/0\/')


%     Finished composite block ['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down'].

set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/Triggered',13,'buffer down']],...
		'position',[215,53,275,97])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/out_1']],...
		'position',[310,55,330,75])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1/in_1']],...
		'position',[115,20,135,40])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],[140,30;190,30;190,60;210,60])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],[280,65;305,65])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],[105,85;125,85])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],[185,75;210,75])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],[185,90;210,90])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],...
		'Mask Display','D-TDMA\nmux',...
		'Mask Type','Digital TDMA')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],...
		'Mask Dialogue','Input a vector digital signal. Output a scalar up-sampled digital signal.|Input symbol sample time (sec):|Input vector length:')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],...
		'Mask Translate','td=@1;N=@2;')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],...
		'Mask Help','This block inputs a length N_in vector input signal with sample time T_in. The output of this block is a vector with sample time T_in/N_in. For the output signal, a T_in time period is partitioned into N_in even time length sections. Each section contains the value of one element of the input vector. This block takes all elements from the input vector at the start point of the sample time.')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],...
		'Mask Entries','0.16\/32\/')


%     Finished composite block ['Receiver/Equalizer/Digital-TDMA',13,'mux1'].

set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux1']],...
		'hide name',0,...
		'position',[355,178,435,222])


%     Subsystem  ['Receiver/Equalizer/Feedback',13,'Filter'].

new_system([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],'Location',[79,281,631,497])

add_block('built-in/Sum',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Sum2']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Sum2']],...
		'position',[200,75,220,95])

add_block('built-in/Product',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Product1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Product1']],...
		'position',[145,68,175,92])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/in_1']],...
		'position',[70,65,90,85])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/in_2']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/in_2']],...
		'Port','2',...
		'position',[15,135,35,155])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/out_2']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/out_2']],...
		'Port','2',...
		'position',[430,130,450,150])


%     Subsystem  ['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1'].

new_system([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1/in_2']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1/Sum']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1/Product']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1']],[150,65;180,65])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1']],[95,65;120,65])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1']],[40,35;60,60])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1']],[40,100;60,70])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1'].

set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Inner',13,'Product1']],...
		'position',[365,129,385,151])

add_block('built-in/Unit Delay',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Unit Delay2']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Unit Delay2']],...
		'Sample time','0.0025',...
		'x0','X1_ini',...
		'position',[270,75,310,95])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/out_1']],...
		'position',[355,55,375,75])


%     Subsystem  ['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2'].

new_system([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2']],'Location',[182,127,498,272])


%     Subsystem  ['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift'].

new_system([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Demux',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/Demux']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/S-function']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/Mux']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/out_2']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/in_2']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Reg. shift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],...
		'Mask Dialogue','The rising edge of the 2nd port pulse\ntriggers the block to input the 1st port data and to shift the register.|Delay steps (output length is same as this vector size):|Threshold in detecting the rising edge of the pulse:')
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],...
		'Mask Translate','shft_out=@1;thrhld=@2;len_rg=length(@1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,75,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],...
		'Mask Help','This block stores the scalar input signal from the 1st input port at the rising edge of the pulse from the 2nd port. The 1st outport outputs a vector with its size the same as the "Delay steps" entree of this block. The maximum delay is the register size of this block. The second outport outputs a positive pulse when the register is\nrefreshed.')
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],...
		'Mask Entries','[31:-1:0]\/.1\/')


%     Finished composite block ['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift'].

set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Register-shift']],...
		'position',[155,18,235,62])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/in_1']],...
		'position',[35,20,55,40])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/out_1']],...
		'position',[275,20,295,40])


%     Subsystem  ['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time'].

new_system([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Entries','.0025\/1\/0\/')


%     Finished composite block ['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time'].

set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'position',[30,68,110,112])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2']],[240,30;270,30])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2']],[115,90;130,90;130,50;150,50])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2']],[60,30;150,30])


%     Finished composite block ['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2'].

set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter/Delay Line2']],...
		'position',[70,118,100,172])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],[40,145;65,145])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],[95,75;140,75])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],[225,85;265,85])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],[105,145;360,145])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],[130,145;140,85])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],[315,85;325,85;325,135;360,135])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],[390,140;425,140])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],[325,135;185,135;195,90])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],[180,80;195,80])
add_line([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],[240,85;240,65;350,65])


%     Finished composite block ['Receiver/Equalizer/Feedback',13,'Filter'].

set_param([sys,'/',['Receiver/Equalizer/Feedback',13,'Filter']],...
		'position',[295,212,325,263])

add_block('built-in/Unit Delay',[sys,'/','Receiver/Equalizer/Unit Delay3'])
set_param([sys,'/','Receiver/Equalizer/Unit Delay3'],...
		'hide name',0,...
		'Sample time','0.0025',...
		'position',[150,239,180,261])

add_block('built-in/Gain',[sys,'/','Receiver/Equalizer/Gain2'])
set_param([sys,'/','Receiver/Equalizer/Gain2'],...
		'orientation',1,...
		'hide name',0,...
		'Gain','-1',...
		'position',[212,165,238,195])

add_block('built-in/Scope',[sys,'/',['Receiver/Equalizer/Equalizer',13,'FFF view']])
set_param([sys,'/',['Receiver/Equalizer/Equalizer',13,'FFF view']],...
		'Vgain','4.000000',...
		'Hgain','0.160000',...
		'Vmax','8.000000',...
		'Hmax','0.320000',...
		'Window',[345,552,601,805],...
		'Mask Display','')
set_param([sys,'/',['Receiver/Equalizer/Equalizer',13,'FFF view']],...
		'position',[460,77,480,103])


%     Subsystem  ['Receiver/Equalizer/Digital-TDMA',13,'mux'].

new_system([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],'Location',[7,588,411,722])


%     Subsystem  ['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Entries','td\/[1 N]\/[0 0]\/')


%     Finished composite block ['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'position',[35,66,100,104])

add_block('built-in/Demux',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Demux']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Demux']],...
		'outputs','2',...
		'position',[130,65,180,100])


%     Subsystem  ['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down'].

new_system([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Entries','N\/0\/1\/.1\/0\/')


%     Finished composite block ['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down'].

set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'position',[215,53,275,97])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/out_1']],...
		'position',[310,55,330,75])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux/in_1']],...
		'position',[115,20,135,40])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],[140,30;190,30;190,60;210,60])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],[280,65;305,65])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],[105,85;125,85])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],[185,75;210,75])
add_line([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],[185,90;210,90])
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],...
		'Mask Display','D-TDMA\nmux',...
		'Mask Type','Digital TDMA')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],...
		'Mask Dialogue','Input a vector digital signal. Output a scalar up-sampled digital signal.|Input symbol sample time (sec):|Input vector length:')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],...
		'Mask Translate','td=@1;N=@2;')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],...
		'Mask Help','This block inputs a length N_in vector input signal with sample time T_in. The output of this block is a vector with sample time T_in/N_in. For the output signal, a T_in time period is partitioned into N_in even time length sections. Each section contains the value of one element of the input vector. This block takes all elements from the input vector at the start point of the sample time.')
set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],...
		'Mask Entries','0.16\/32\/')


%     Finished composite block ['Receiver/Equalizer/Digital-TDMA',13,'mux'].

set_param([sys,'/',['Receiver/Equalizer/Digital-TDMA',13,'mux']],...
		'hide name',0,...
		'position',[355,68,435,112])

add_block('built-in/Scope',[sys,'/','Receiver/Equalizer/Error'])
set_param([sys,'/','Receiver/Equalizer/Error'],...
		'ForeGround',2,...
		'Vgain','1.500000',...
		'Hgain','1.000000',...
		'Vmax','3.000000',...
		'Hmax','2.000000',...
		'Window',[535,7,843,225],...
		'position',[275,42,295,68])

add_block('built-in/Unit Delay',[sys,'/','Receiver/Equalizer/Unit Delay1'])
set_param([sys,'/','Receiver/Equalizer/Unit Delay1'],...
		'hide name',0,...
		'Sample time','0.0025',...
		'position',[185,44,215,66])

add_block('built-in/Sum',[sys,'/','Receiver/Equalizer/Sum1'])
set_param([sys,'/','Receiver/Equalizer/Sum1'],...
		'hide name',0,...
		'inputs','-+',...
		'position',[100,93,115,122])

add_block('built-in/Gain',[sys,'/','Receiver/Equalizer/Gain'])
set_param([sys,'/','Receiver/Equalizer/Gain'],...
		'hide name',0,...
		'Gain','0.01',...
		'position',[160,93,210,127])


%     Subsystem  ['Receiver/Equalizer/Feedforward',13,'Filter'].

new_system([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],'Location',[181,123,717,314])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/out_1']],...
		'position',[395,25,415,45])

add_block('built-in/Unit Delay',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Unit Delay2']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Unit Delay2']],...
		'Sample time','0.0025',...
		'x0','X2_ini',...
		'position',[315,45,355,65])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/in_1']],...
		'position',[70,35,90,55])

add_block('built-in/Product',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Product1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Product1']],...
		'position',[180,38,210,62])

add_block('built-in/Sum',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Sum2']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Sum2']],...
		'position',[245,45,265,65])


%     Subsystem  ['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1'].

new_system([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1/in_2']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1/Sum']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1/Product']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1']],[150,65;180,65])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1']],[95,65;120,65])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1']],[40,35;60,60])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1']],[40,100;60,70])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1'].

set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Inner',13,'Product1']],...
		'position',[400,104,420,126])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/out_2']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/out_2']],...
		'Port','2',...
		'position',[475,105,495,125])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/in_2']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/in_2']],...
		'Port','2',...
		'position',[15,110,35,130])


%     Subsystem  ['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2'].

new_system([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2']],'Location',[378,103,694,248])


%     Subsystem  ['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift'].

new_system([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Demux',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/Demux']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/S-function']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/Mux']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/out_2']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/in_2']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Reg. shift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],...
		'Mask Dialogue','The rising edge of the 2nd port pulse\ntriggers the block to input the 1st port data and to shift the register.|Delay steps (output length is same as this vector size):|Threshold in detecting the rising edge of the pulse:')
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],...
		'Mask Translate','shft_out=@1;thrhld=@2;len_rg=length(@1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,75,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],...
		'Mask Help','This block stores the scalar input signal from the 1st input port at the rising edge of the pulse from the 2nd port. The 1st outport outputs a vector with its size the same as the "Delay steps" entree of this block. The maximum delay is the register size of this block. The second outport outputs a positive pulse when the register is\nrefreshed.')
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],...
		'Mask Entries','[31:-1:0]\/.1\/')


%     Finished composite block ['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift'].

set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Register-shift']],...
		'position',[155,18,235,62])

add_block('built-in/Inport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/in_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/in_1']],...
		'position',[35,20,55,40])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/out_1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/out_1']],...
		'position',[275,20,295,40])


%     Subsystem  ['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time'].

new_system([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'Mask Entries','.0025\/1\/0\/')


%     Finished composite block ['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time'].

set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2/Pulses divide',13,'same sample time']],...
		'position',[30,73,110,117])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2']],[240,30;270,30])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2']],[115,95;130,95;130,50;150,50])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2']],[60,30;150,30])


%     Finished composite block ['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2'].

set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter/Delay Line2']],...
		'position',[75,93,105,147])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],[40,120;70,120])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],[95,45;175,45])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],[270,55;310,55])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],[110,120;395,120])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],[360,55;375,55;375,110;395,110])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],[425,115;470,115])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],[375,110;230,110;240,60])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],[215,50;240,50])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],[135,120;135,55;175,55])
add_line([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],[285,55;285,35;390,35])


%     Finished composite block ['Receiver/Equalizer/Feedforward',13,'Filter'].

set_param([sys,'/',['Receiver/Equalizer/Feedforward',13,'Filter']],...
		'position',[285,97,315,148])

add_block('built-in/Sum',[sys,'/','Receiver/Equalizer/Sum3'])
set_param([sys,'/','Receiver/Equalizer/Sum3'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[520,127,535,163])

add_block('built-in/Outport',[sys,'/','Receiver/Equalizer/out_1'])
set_param([sys,'/','Receiver/Equalizer/out_1'],...
		'position',[610,135,630,155])
add_line([sys,'/','Receiver/Equalizer'],[330,250;505,250;515,155])
add_line([sys,'/','Receiver/Equalizer'],[320,135;515,135])
add_line([sys,'/','Receiver/Equalizer'],[320,110;340,110;350,90])
add_line([sys,'/','Receiver/Equalizer'],[225,200;225,225;290,225])
add_line([sys,'/','Receiver/Equalizer'],[185,250;290,250])
add_line([sys,'/','Receiver/Equalizer'],[330,225;340,225;350,200])
add_line([sys,'/','Receiver/Equalizer'],[440,200;460,200])
add_line([sys,'/','Receiver/Equalizer'],[440,90;455,90])
add_line([sys,'/','Receiver/Equalizer'],[220,55;270,55])
add_line([sys,'/','Receiver/Equalizer'],[215,110;280,110])
add_line([sys,'/','Receiver/Equalizer'],[120,110;155,110])
add_line([sys,'/','Receiver/Equalizer'],[135,110;135,55;180,55])
add_line([sys,'/','Receiver/Equalizer'],[225,110;225,160])
add_line([sys,'/','Receiver/Equalizer'],[260,135;280,135])
add_line([sys,'/','Receiver/Equalizer'],[50,115;95,115])
add_line([sys,'/','Receiver/Equalizer'],[70,115;70,250;145,250])
add_line([sys,'/','Receiver/Equalizer'],[540,145;605,145])
add_line([sys,'/','Receiver/Equalizer'],[550,145;550,15;80,15;80,100;95,100])


%     Finished composite block 'Receiver/Equalizer'.

set_param([sys,'/','Receiver/Equalizer'],...
		'position',[545,162,575,213])

add_block('built-in/Sum',[sys,'/','Receiver/Sum'])
set_param([sys,'/','Receiver/Sum'],...
		'hide name',0,...
		'position',[265,163,285,192])

add_block('built-in/Zero-Pole',[sys,'/',['Receiver/Butterworth',13,'LP Filter']])
set_param([sys,'/',['Receiver/Butterworth',13,'LP Filter']],...
		'Zeros','z',...
		'Poles','p',...
		'Gain','k',...
		'Mask Display','plot(20*log10(w),20*log10(abs(h)))',...
		'Mask Type','buttap')
set_param([sys,'/',['Receiver/Butterworth',13,'LP Filter']],...
		'Mask Dialogue','Analog Butterworth low pass filter.\n\n(Requires Signal Processing Toolbox)|Cutoff frequency (rad/sec)|Order')
set_param([sys,'/',['Receiver/Butterworth',13,'LP Filter']],...
		'Mask Translate','[z,p,k]=buttap(@2); z=@1*z; p=@1*p; k=real(prod(-p)); [num,den]=zp2tf(z,p,k); w=logspace(log10(@1/10),log10(10*@1),20); h=freqs(num,den,w); ')
set_param([sys,'/',['Receiver/Butterworth',13,'LP Filter']],...
		'Mask Help','Butterworth low pass filter using MATLAB''s butter command.',...
		'Mask Entries','200*2*pi\/4\/',...
		'position',[315,158,375,202])

add_block('built-in/Sum',[sys,'/','Receiver/Sum1'])
set_param([sys,'/','Receiver/Sum1'],...
		'hide name',0,...
		'inputs','-+',...
		'position',[410,163,430,187])

add_block('built-in/Filter',[sys,'/','Receiver/Filter1'])
set_param([sys,'/','Receiver/Filter1'],...
		'Numerator','echop',...
		'Denominator','1',...
		'Sample time','.0025',...
		'position',[140,151,195,189])


%     Subsystem  'Receiver/MASK demap'.

new_system([sys,'/','Receiver/MASK demap'])
set_param([sys,'/','Receiver/MASK demap'],'Location',[187,342,628,482])

add_block('built-in/Zero-Order Hold',[sys,'/',['Receiver/MASK demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['Receiver/MASK demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[85,29,120,61])

add_block('built-in/Constant',[sys,'/','Receiver/MASK demap/Shift key'])
set_param([sys,'/','Receiver/MASK demap/Shift key'],...
		'Value','sft',...
		'position',[115,93,135,117])

add_block('built-in/Sum',[sys,'/','Receiver/MASK demap/Sum2'])
set_param([sys,'/','Receiver/MASK demap/Sum2'],...
		'inputs','+-',...
		'position',[180,38,200,67])

add_block('built-in/Abs',[sys,'/','Receiver/MASK demap/Abs'])
set_param([sys,'/','Receiver/MASK demap/Abs'],...
		'position',[235,42,270,68])

add_block('built-in/Outport',[sys,'/','Receiver/MASK demap/out_1'])
set_param([sys,'/','Receiver/MASK demap/out_1'],...
		'position',[400,45,420,65])

add_block('built-in/S-Function',[sys,'/','Receiver/MASK demap/Minimum'])
set_param([sys,'/','Receiver/MASK demap/Minimum'],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[315,45,370,65])

add_block('built-in/Inport',[sys,'/','Receiver/MASK demap/in_1'])
set_param([sys,'/','Receiver/MASK demap/in_1'],...
		'position',[30,35,50,55])
add_line([sys,'/','Receiver/MASK demap'],[55,45;80,45])
add_line([sys,'/','Receiver/MASK demap'],[275,55;310,55])
add_line([sys,'/','Receiver/MASK demap'],[125,45;175,45])
add_line([sys,'/','Receiver/MASK demap'],[375,55;395,55])
add_line([sys,'/','Receiver/MASK demap'],[140,105;155,105;155,60;175,60])
add_line([sys,'/','Receiver/MASK demap'],[205,55;230,55])
set_param([sys,'/','Receiver/MASK demap'],...
		'Mask Display','MASK\ndemap',...
		'Mask Type','MASK demap')
set_param([sys,'/','Receiver/MASK demap'],...
		'Mask Dialogue','Reverse the MASK mapping process\nConvert [-1 1] analog signal to [0, M-1] symbols.|M-ary number (digit integers in ranger [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/','Receiver/MASK demap'],...
		'Mask Translate','N=@1;Ac=1;sft=[0:N-1]*Ac*2/(N-1)-Ac;td=@2;')
set_param([sys,'/','Receiver/MASK demap'],...
		'Mask Help','This block demaps a MASK mapped signal back to digit symbols. You can place this block after a amplitude demodulation block. The input of this block is an analog signal in the range [-1, 1]. The demodulation decides the closest integer fitting in [0,M-1] range. When the input symbol interval is a two-elements vector, the second element is offset. The default offset value is 0.')
set_param([sys,'/','Receiver/MASK demap'],...
		'Mask Entries','2\/.0025\/')


%     Finished composite block 'Receiver/MASK demap'.

set_param([sys,'/','Receiver/MASK demap'],...
		'position',[580,58,660,102])

add_block('built-in/Unit Delay',[sys,'/','Receiver/Unit Delay'])
set_param([sys,'/','Receiver/Unit Delay'],...
		'hide name',0,...
		'Sample time','0.0025',...
		'position',[535,69,565,91])

add_block('built-in/Scope',[sys,'/',['Receiver/Echo Canceler',13,'Coef. view']])
set_param([sys,'/',['Receiver/Echo Canceler',13,'Coef. view']],...
		'Vgain','0.050000',...
		'Hgain','0.125000',...
		'Vmax','0.100000',...
		'Hmax','0.250000',...
		'Window',[104,551,347,805],...
		'Mask Display','')
set_param([sys,'/',['Receiver/Echo Canceler',13,'Coef. view']],...
		'position',[460,77,480,103])

add_block('built-in/Outport',[sys,'/','Receiver/out_1'])
set_param([sys,'/','Receiver/out_1'],...
		'position',[675,70,695,90])
add_line([sys,'/','Receiver'],[440,235;460,235])
add_line([sys,'/','Receiver'],[195,60;215,60;215,90;270,90])
add_line([sys,'/','Receiver'],[380,180;405,180])
add_line([sys,'/','Receiver'],[120,115;270,115])
add_line([sys,'/','Receiver'],[310,115;385,115;385,170;405,170])
add_line([sys,'/','Receiver'],[310,90;340,90])
add_line([sys,'/','Receiver'],[430,90;455,90])
add_line([sys,'/','Receiver'],[290,180;310,180])
add_line([sys,'/','Receiver'],[130,235;165,235])
add_line([sys,'/','Receiver'],[580,190;585,190;585,145;520,145;530,80])
add_line([sys,'/','Receiver'],[205,250;220,250;220,185;260,185])
add_line([sys,'/','Receiver'],[500,250;520,250;520,200;540,200])
add_line([sys,'/','Receiver'],[435,175;540,175])
add_line([sys,'/','Receiver'],[55,295;155,295;165,260])
add_line([sys,'/','Receiver'],[490,175;490,15;130,15;130,45;155,45])
add_line([sys,'/','Receiver'],[70,295;70,70;155,70])
add_line([sys,'/','Receiver'],[155,295;450,295;460,260])
add_line([sys,'/','Receiver'],[200,170;260,170])
add_line([sys,'/','Receiver'],[570,80;575,80])
add_line([sys,'/','Receiver'],[665,80;670,80])
add_line([sys,'/','Receiver'],[120,115;135,170])


%     Finished composite block 'Receiver'.

set_param([sys,'/','Receiver'],...
		'position',[260,105,290,160])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[335,126,370,159])


%     Subsystem  'Transmitter'.

new_system([sys,'/','Transmitter'])
set_param([sys,'/','Transmitter'],'Location',[437,260,692,383])

add_block('built-in/Inport',[sys,'/','Transmitter/in_1'])
set_param([sys,'/','Transmitter/in_1'],...
		'position',[15,60,35,80])

add_block('built-in/Outport',[sys,'/','Transmitter/out_1'])
set_param([sys,'/','Transmitter/out_1'],...
		'position',[215,60,235,80])


%     Subsystem  ['Transmitter/Raised cosine',13,'filter'].

new_system([sys,'/',['Transmitter/Raised cosine',13,'filter']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter']],'Location',[131,545,589,761])


%     Subsystem  ['Transmitter/Raised cosine',13,'filter/Memory Impulse'].

new_system([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],'Location',[541,520,939,745])

add_block('built-in/Inport',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/in_1']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/in_1']],...
		'position',[35,185,55,205])

add_block('built-in/Zero-Order Hold',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/Zero-Order',13,'Hold']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/Zero-Order',13,'Hold']],...
		'Sample time','ts',...
		'position',[205,84,240,116])

add_block('built-in/Product',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/Product']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/Product']],...
		'position',[155,90,180,110])

add_block('built-in/Outport',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/out_1']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/out_1']],...
		'position',[355,130,375,150])

add_block('built-in/Constant',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/Constant']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/Constant']],...
		'Value','x',...
		'position',[210,155,230,175])

add_block('built-in/Switch',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/Switch']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/Switch']],...
		'Threshold','.5',...
		'position',[295,124,320,156])


%     Subsystem  ['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

new_system([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],'Location',[419,521,808,713])

add_block('built-in/Relational Operator',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Constant',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Unit Delay',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']],...
		'Sample time','ts',...
		'position',[120,87,170,103])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[175,95;195,95])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[45,25;45,95;115,95])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Dialogue','Rising edge detection:|Threshold:|Sampling time:',...
		'Mask Translate','thld=@1;ts=@2;')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Entries','thr\/ts\/')


%     Finished composite block ['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'position',[65,26,120,54])

add_block('built-in/Inport',[sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/in_2']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse/in_2']],...
		'Port','2',...
		'position',[25,30,45,50])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],[245,100;260,100;260,130;290,130])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],[185,100;200,100])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],[60,195;280,195;290,150])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],[95,195;95,105;150,105])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],[325,140;350,140])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],[235,165;250,165;250,140;290,140])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],[125,40;130,40;130,95;150,95])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],[50,40;60,40])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],...
		'Mask Display','1/sinc',...
		'Mask Type','Impulse',...
		'Mask Dialogue','1/sinc filter:|Holding time:|Threshold for clock pulse: ')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],...
		'Mask Translate','ts=@1;thr=@2;x=thr>0;')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],...
		'Mask Help','When the threshold is greater than zero, this block outputs an impulse signal, which begins at the raising edge of the second input and lasts the holding time. The impulse holds a constant amplitude, which equals the amplitude of the first input at the begining of the impulse. A clock raising edge will trigger next impulse. When the threshold is less or equal to zero, this block faithfully outputs the first input.')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],...
		'Mask Entries','ts\/x\/')


%     Finished composite block ['Transmitter/Raised cosine',13,'filter/Memory Impulse'].

set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Memory Impulse']],...
		'position',[155,30,225,70])

add_block('built-in/Filter',[sys,'/',['Transmitter/Raised cosine',13,'filter/Filter']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,31,310,69])

add_block('built-in/Outport',[sys,'/',['Transmitter/Raised cosine',13,'filter/out_1']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/out_1']],...
		'position',[330,40,350,60])

add_block('built-in/Inport',[sys,'/',['Transmitter/Raised cosine',13,'filter/in_1']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/in_1']],...
		'position',[35,30,55,50])


%     Subsystem  ['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','td\/1\/off\/')


%     Finished composite block ['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Transmitter/Raised cosine',13,'filter/Pulses deivide',13,'same sample time1']],...
		'position',[35,71,95,109])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter']],[100,90;115,90;115,60;150,60])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter']],[230,50;250,50])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter']],[60,40;150,40])
add_line([sys,'/',['Transmitter/Raised cosine',13,'filter']],[315,50;325,50])
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter']],...
		'Mask Display','R-C\nfilter',...
		'Mask Type','R-C filter')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter']],...
		'Mask Dialogue','Design a raised cosine filter and use it to filter the input signal.|Symbol interval (sec):|Computation sampling time (sec):|Filter rolloff factor:|Delay step (integer to multiply symbol interval):|Filter type (FIR or IIR) / (Normal or Sqrt):|With or without sinc filter (1 or 0, suggest 1):')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter']],...
		'Mask Translate','td=@1;if length(td)>1,off=td(2);td=td(1);else,off=0;end;ts=@2;R=@3;delay=@4;fil=@5;[num,den]=rcosine(1/td(1),1/ts(1),fil,R,delay);x=@6/2;')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter']],...
		'Mask Help','This block designs a raised cosine filter using the specified parameter. The filter is used to filter the input signal. You can optionally use the sinc filter in the filtering computation.')
set_param([sys,'/',['Transmitter/Raised cosine',13,'filter']],...
		'Mask Entries','0.0025\/0.0005\/.15\/3\/''FIR''\/1\/')


%     Finished composite block ['Transmitter/Raised cosine',13,'filter'].

set_param([sys,'/',['Transmitter/Raised cosine',13,'filter']],...
		'hide name',0,...
		'position',[85,48,165,92])
add_line([sys,'/','Transmitter'],[40,70;80,70])
add_line([sys,'/','Transmitter'],[170,70;210,70])


%     Finished composite block 'Transmitter'.

set_param([sys,'/','Transmitter'],...
		'position',[115,119,145,171])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'Value','[.1 -1.1]',...
		'position',[310,65,365,85])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'position',[405,128,425,152])

add_block('built-in/Scope',[sys,'/',['Received',13,'signal']])
set_param([sys,'/',['Received',13,'signal']],...
		'Vgain','1.500000',...
		'Hgain','0.250000',...
		'Vmax','3.000000',...
		'Hmax','0.500000',...
		'Window',[95,26,619,237])
open_system([sys,'/',['Received',13,'signal']])
set_param([sys,'/',['Received',13,'signal']],...
		'position',[455,127,475,153])


%     Subsystem  'Utility2'.

new_system([sys,'/','Utility2'])
set_param([sys,'/','Utility2'],'Location',[136,230,381,439])
set_param([sys,'/','Utility2'],...
		'Mask Display','Reload\ndata',...
		'Mask Dialogue','eval(''hdsldata;'')')


%     Finished composite block 'Utility2'.

set_param([sys,'/','Utility2'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[395,196,475,240])


%     Subsystem  'information'.

new_system([sys,'/','information'])
set_param([sys,'/','information'],'Location',[121,441,591,671])


%     Subsystem  'information/information1'.

new_system([sys,'/','information/information1'])
set_param([sys,'/','information/information1'],'Location',[4,60,788,251])

add_block('built-in/Note',[sys,'/',['information/information1/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']])
set_param([sys,'/',['information/information1/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']],...
		'position',[380,40,385,45])

add_block('built-in/Note',[sys,'/',['information/information1/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']])
set_param([sys,'/',['information/information1/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']],...
		'position',[335,115,340,120])

add_block('built-in/Note',[sys,'/','information/information1/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'])
set_param([sys,'/','information/information1/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'],...
		'position',[350,80,355,85])
set_param([sys,'/','information/information1'],...
		'Mask Display','?')


%     Finished composite block 'information/information1'.

set_param([sys,'/','information/information1'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[485,220,530,261])


%     Subsystem  'information/information'.

new_system([sys,'/','information/information'])
set_param([sys,'/','information/information'],'Location',[4,60,788,251])

add_block('built-in/Note',[sys,'/',['information/information/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']])
set_param([sys,'/',['information/information/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']],...
		'position',[380,40,385,45])

add_block('built-in/Note',[sys,'/',['information/information/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']])
set_param([sys,'/',['information/information/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']],...
		'position',[335,115,340,120])

add_block('built-in/Note',[sys,'/','information/information/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'])
set_param([sys,'/','information/information/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'],...
		'position',[350,80,355,85])
set_param([sys,'/','information/information'],...
		'Mask Display','?')


%     Finished composite block 'information/information'.

set_param([sys,'/','information/information'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[465,200,510,241])

add_block('built-in/Note',[sys,'/',['information/Design and original  implementation by Walter Chen.',13,'Texas Instrument',13,'13510 North central Expressway',13,'Mail Stop 446',13,'Dallas TX 75265 ']])
set_param([sys,'/',['information/Design and original  implementation by Walter Chen.',13,'Texas Instrument',13,'13510 North central Expressway',13,'Mail Stop 446',13,'Dallas TX 75265 ']],...
		'position',[205,150,210,155])

add_block('built-in/Note',[sys,'/',['information/This example simulates digital transmission through a telephone line.',13,'A noise cancelation filter and an equalizer are included in the',13,'simulation example']])
set_param([sys,'/',['information/This example simulates digital transmission through a telephone line.',13,'A noise cancelation filter and an equalizer are included in the',13,'simulation example']],...
		'position',[220,25,225,30])

add_block('built-in/Note',[sys,'/',['information/This example uses a trained initial data. If you prefer to train the data',13,'yourself, set the Step time parameter in the Step input block in the',13,'Receiver subsystem to be 50.']])
set_param([sys,'/',['information/This example uses a trained initial data. If you prefer to train the data',13,'yourself, set the Step time parameter in the Step input block in the',13,'Receiver subsystem to be 50.']],...
		'position',[220,85,225,90])
set_param([sys,'/','information'],...
		'Mask Display','?')


%     Finished composite block 'information'.

set_param([sys,'/','information'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[330,200,375,241])
add_line(sys,[195,85;235,85;235,120;255,120])
add_line(sys,[150,145;175,145])
add_line(sys,[215,145;255,145])
add_line(sys,[55,145;110,145])
add_line(sys,[80,145;80,85;140,85])
add_line(sys,[55,170;95,170;95,210;155,210])
add_line(sys,[295,135;330,135])
add_line(sys,[210,210;305,210;305,150;330,150])
add_line(sys,[430,140;450,140])
add_line(sys,[375,145;400,145])
add_line(sys,[370,75;380,75;380,135;400,135])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
