function [ret,x0,str,ts,xts]=tbchcode(t,x,u,flag);
%TBCHCODE	is the M-file description of the SIMULINK system named TBCHCODE.
%	The block-diagram can be displayed by typing: TBCHCODE.
%
%	SYS=TBCHCODE(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TBCHCODE to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TBCHCODE with a FLAG of zero:
%	[SIZES]=TBCHCODE([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[39,403,1004,748])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Random-integer',13,'generator'].

new_system([sys,'/',['Random-integer',13,'generator']])
set_param([sys,'/',['Random-integer',13,'generator']],'Location',[373,639,729,808])

add_block('built-in/Constant',[sys,'/',['Random-integer',13,'generator/Constant']])
set_param([sys,'/',['Random-integer',13,'generator/Constant']],...
		'Value','x',...
		'position',[65,105,95,125])

add_block('built-in/State-Space',[sys,'/',['Random-integer',13,'generator/Matrix',13,'Gain']])
set_param([sys,'/',['Random-integer',13,'generator/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Random-integer',13,'generator/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','ones(1,N-1)\/')
set_param([sys,'/',['Random-integer',13,'generator/Matrix',13,'Gain']],...
		'position',[230,35,275,65])

add_block('built-in/Outport',[sys,'/',['Random-integer',13,'generator/out_1']])
set_param([sys,'/',['Random-integer',13,'generator/out_1']],...
		'position',[310,40,330,60])

add_block('built-in/Relational Operator',[sys,'/',['Random-integer',13,'generator/Relational',13,'Operator']])
set_param([sys,'/',['Random-integer',13,'generator/Relational',13,'Operator']],...
		'position',[155,38,185,62])

add_block('built-in/Signal Generator',[sys,'/',['Random-integer',13,'generator/Uniform',13,'noise gen.']])
set_param([sys,'/',['Random-integer',13,'generator/Uniform',13,'noise gen.']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1234.000000',...
		'Freq Range','6170.000000',...
		'Wave','Rnd',...
		'Units','Rads')
set_param([sys,'/',['Random-integer',13,'generator/Uniform',13,'noise gen.']],...
		'position',[35,28,80,62])
add_line([sys,'/',['Random-integer',13,'generator']],[85,45;150,45])
add_line([sys,'/',['Random-integer',13,'generator']],[100,115;115,115;115,55;150,55])
add_line([sys,'/',['Random-integer',13,'generator']],[190,50;225,50])
add_line([sys,'/',['Random-integer',13,'generator']],[280,50;305,50])
set_param([sys,'/',['Random-integer',13,'generator']],...
		'Mask Display','Random\nNumber',...
		'Mask Type','Random number generator.')
set_param([sys,'/',['Random-integer',13,'generator']],...
		'Mask Dialogue','Randomly generate integers in the range of [0,1,...,N-1]. N is the M-ary number defined below:|M-ary number:',...
		'Mask Translate','N=@1;x=[(2-N)/N:2/N:(N-2)/N];')
set_param([sys,'/',['Random-integer',13,'generator']],...
		'Mask Help','This block generate integer number 0 to M-1, where M is a integer. The probability of the apperance for each number is not guaranteed to be the same.')
set_param([sys,'/',['Random-integer',13,'generator']],...
		'Mask Entries','2^5\/')


%     Finished composite block ['Random-integer',13,'generator'].

set_param([sys,'/',['Random-integer',13,'generator']],...
		'BackGround',5,...
		'position',[25,45,85,85])


%     Subsystem  ['BCH',13,'encoding'].

new_system([sys,'/',['BCH',13,'encoding']])
set_param([sys,'/',['BCH',13,'encoding']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['BCH',13,'encoding/out_1']])
set_param([sys,'/',['BCH',13,'encoding/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['BCH',13,'encoding/Modulus',13,'operation']])
set_param([sys,'/',['BCH',13,'encoding/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulus operation:|Modulus base:')
set_param([sys,'/',['BCH',13,'encoding/Modulus',13,'operation']],...
		'Mask Translate','md = @1;')
set_param([sys,'/',['BCH',13,'encoding/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['BCH',13,'encoding/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['BCH',13,'encoding/Matrix',13,'Gain']])
set_param([sys,'/',['BCH',13,'encoding/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['BCH',13,'encoding/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['BCH',13,'encoding/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['BCH',13,'encoding/in_1']])
set_param([sys,'/',['BCH',13,'encoding/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['BCH',13,'encoding']],[245,45;285,45])
add_line([sys,'/',['BCH',13,'encoding']],[140,45;175,45])
add_line([sys,'/',['BCH',13,'encoding']],[55,45;105,45])
set_param([sys,'/',['BCH',13,'encoding']],...
		'Mask Display','BCH\nencode',...
		'Mask Type','BCH code',...
		'Mask Dialogue','Encode a message using BCH coding technique:|Code word length:|message length:')
set_param([sys,'/',['BCH',13,'encoding']],...
		'Mask Translate','n=@1;k=@2;pg=bchpoly(n,k);[h,G]=cyclgen(n,pg);G=G'';')
set_param([sys,'/',['BCH',13,'encoding']],...
		'Mask Help','This block encodes the input binary signal using BCH coding method. The output of this block is an n-array binary code word vector. The input of this block is a m-length binary message vector. ')
set_param([sys,'/',['BCH',13,'encoding']],...
		'Mask Entries','15\/5\/')


%     Finished composite block ['BCH',13,'encoding'].

set_param([sys,'/',['BCH',13,'encoding']],...
		'ForeGround',6,...
		'position',[265,46,335,84])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'position',[370,60,390,80])

add_block('built-in/S-Function',[sys,'/',['Modulus',13,'operation2']])
set_param([sys,'/',['Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulus operation:|Modulus base:')
set_param([sys,'/',['Modulus',13,'operation2']],...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[435,51,495,89])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','500\/-.2\/2^5+.2\/''yo/g+/r-/w-/w-/b+''\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'position',[845,56,875,94])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y',...
		'position',[855,152,905,168])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'inputs','+',...
		'position',[500,165,520,185])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'position',[395,121,425,149])


%     Subsystem  ['Binary vector',13,'noise generator'].

new_system([sys,'/',['Binary vector',13,'noise generator']])
set_param([sys,'/',['Binary vector',13,'noise generator']],'Location',[405,495,1004,748])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'noise generator/Constant']])
set_param([sys,'/',['Binary vector',13,'noise generator/Constant']],...
		'Value','x',...
		'position',[90,100,120,120])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'noise generator/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'noise generator/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'noise generator/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','y\/')
set_param([sys,'/',['Binary vector',13,'noise generator/Matrix',13,'Gain']],...
		'position',[255,30,300,60])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'noise generator/Relational',13,'Operator']])
set_param([sys,'/',['Binary vector',13,'noise generator/Relational',13,'Operator']],...
		'position',[180,33,210,57])

add_block('built-in/Signal Generator',[sys,'/',['Binary vector',13,'noise generator/Uniform',13,'noise gen.']])
set_param([sys,'/',['Binary vector',13,'noise generator/Uniform',13,'noise gen.']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1234.000000',...
		'Freq Range','6170.000000',...
		'Wave','Rnd',...
		'Units','Rads')
set_param([sys,'/',['Binary vector',13,'noise generator/Uniform',13,'noise gen.']],...
		'position',[60,23,105,57])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'noise generator/Constant1']])
set_param([sys,'/',['Binary vector',13,'noise generator/Constant1']],...
		'Value','p',...
		'position',[75,210,105,230])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'noise generator/Relational',13,'Operator1']])
set_param([sys,'/',['Binary vector',13,'noise generator/Relational',13,'Operator1']],...
		'position',[180,168,210,192])

add_block('built-in/Signal Generator',[sys,'/',['Binary vector',13,'noise generator/Uniform',13,'noise gen.1']])
set_param([sys,'/',['Binary vector',13,'noise generator/Uniform',13,'noise gen.1']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1234.000000',...
		'Freq Range','6170.000000',...
		'Wave','Rnd',...
		'Units','Rads')
set_param([sys,'/',['Binary vector',13,'noise generator/Uniform',13,'noise gen.1']],...
		'Mask Display','',...
		'position',[50,148,95,182])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'noise generator/Switch']])
set_param([sys,'/',['Binary vector',13,'noise generator/Switch']],...
		'Threshold','0.5',...
		'position',[450,164,480,196])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'noise generator/out_1']])
set_param([sys,'/',['Binary vector',13,'noise generator/out_1']],...
		'position',[535,170,555,190])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'noise generator/Constant2']])
set_param([sys,'/',['Binary vector',13,'noise generator/Constant2']],...
		'Value','zeros(1,n)',...
		'position',[300,206,370,234])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'noise generator/Integer scalar',13,'to vector',13,'converter']])
set_param([sys,'/',['Binary vector',13,'noise generator/Integer scalar',13,'to vector',13,'converter']],...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter')
set_param([sys,'/',['Binary vector',13,'noise generator/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Type','Scalar integer  to vector converter')
set_param([sys,'/',['Binary vector',13,'noise generator/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Dialogue','Positive decimal interger to binary converter.|Output vector length:|Output element base:')
set_param([sys,'/',['Binary vector',13,'noise generator/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Binary vector',13,'noise generator/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Help','This block converts scaler positive decimal integer input to an arbitrary base integer  vector output with specified vector length and output element base. The first element of the output vector is the lowest binary bit. For example, for a length two binary output, y(1)=0, y(2)=1 means the input is 1; y(0)=1, y(2)=0 means the input is 2.')
set_param([sys,'/',['Binary vector',13,'noise generator/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Entries','n\/2\/',...
		'position',[345,26,405,64])
add_line([sys,'/',['Binary vector',13,'noise generator']],[375,220;405,220;405,190;445,190])
add_line([sys,'/',['Binary vector',13,'noise generator']],[485,180;530,180])
add_line([sys,'/',['Binary vector',13,'noise generator']],[410,45;425,45;425,170;445,170])
add_line([sys,'/',['Binary vector',13,'noise generator']],[215,180;445,180])
add_line([sys,'/',['Binary vector',13,'noise generator']],[110,220;135,220;135,185;175,185])
add_line([sys,'/',['Binary vector',13,'noise generator']],[100,165;135,165;135,175;175,175])
add_line([sys,'/',['Binary vector',13,'noise generator']],[215,45;250,45])
add_line([sys,'/',['Binary vector',13,'noise generator']],[125,110;140,110;140,50;175,50])
add_line([sys,'/',['Binary vector',13,'noise generator']],[110,40;175,40])
add_line([sys,'/',['Binary vector',13,'noise generator']],[305,45;340,45])
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Display','Random\nB-vector',...
		'Mask Type','Binary vector noise generator.')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Dialogue','Generatea binary vector with at most given number of ones randomly distributed in the vector.|Vector length(can''t be changed during simulation):|Limit number of ones(can''t be changed during simulation):|Probability of all zeros (%):')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Translate','n=@1;m=@2;x=[1:2^n-1];id=find(sum(de2bi(x)'')<=m);x=x(id);lenx=length(x); y=x-[0,x(1:lenx-1)];x=[-1:2/lenx:(lenx-2)/lenx];p=@3/50-1;')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Help','This block outputs a binary vector with specified length. There are at most the given number of ones randomly distributed in the vector.')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Entries','5\/1\/50\/')


%     Finished composite block ['Binary vector',13,'noise generator'].

set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'position',[200,123,255,157])


%     Subsystem  ['Binary vector',13,'noise generator2'].

new_system([sys,'/',['Binary vector',13,'noise generator2']])
set_param([sys,'/',['Binary vector',13,'noise generator2']],'Location',[405,495,1004,748])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'noise generator2/Constant']])
set_param([sys,'/',['Binary vector',13,'noise generator2/Constant']],...
		'Value','x',...
		'position',[90,100,120,120])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'noise generator2/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'noise generator2/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'noise generator2/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','y\/')
set_param([sys,'/',['Binary vector',13,'noise generator2/Matrix',13,'Gain']],...
		'position',[255,30,300,60])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'noise generator2/Relational',13,'Operator']])
set_param([sys,'/',['Binary vector',13,'noise generator2/Relational',13,'Operator']],...
		'position',[180,33,210,57])

add_block('built-in/Signal Generator',[sys,'/',['Binary vector',13,'noise generator2/Uniform',13,'noise gen.']])
set_param([sys,'/',['Binary vector',13,'noise generator2/Uniform',13,'noise gen.']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1234.000000',...
		'Freq Range','6170.000000',...
		'Wave','Rnd',...
		'Units','Rads')
set_param([sys,'/',['Binary vector',13,'noise generator2/Uniform',13,'noise gen.']],...
		'position',[60,23,105,57])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'noise generator2/Constant1']])
set_param([sys,'/',['Binary vector',13,'noise generator2/Constant1']],...
		'Value','p',...
		'position',[75,210,105,230])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'noise generator2/Relational',13,'Operator1']])
set_param([sys,'/',['Binary vector',13,'noise generator2/Relational',13,'Operator1']],...
		'position',[180,168,210,192])

add_block('built-in/Signal Generator',[sys,'/',['Binary vector',13,'noise generator2/Uniform',13,'noise gen.1']])
set_param([sys,'/',['Binary vector',13,'noise generator2/Uniform',13,'noise gen.1']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1234.000000',...
		'Freq Range','6170.000000',...
		'Wave','Rnd',...
		'Units','Rads')
set_param([sys,'/',['Binary vector',13,'noise generator2/Uniform',13,'noise gen.1']],...
		'Mask Display','',...
		'position',[50,148,95,182])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'noise generator2/Switch']])
set_param([sys,'/',['Binary vector',13,'noise generator2/Switch']],...
		'Threshold','0.5',...
		'position',[450,164,480,196])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'noise generator2/out_1']])
set_param([sys,'/',['Binary vector',13,'noise generator2/out_1']],...
		'position',[535,170,555,190])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'noise generator2/Constant2']])
set_param([sys,'/',['Binary vector',13,'noise generator2/Constant2']],...
		'Value','zeros(1,n)',...
		'position',[300,206,370,234])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'noise generator2/Integer scalar',13,'to vector',13,'converter']])
set_param([sys,'/',['Binary vector',13,'noise generator2/Integer scalar',13,'to vector',13,'converter']],...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter')
set_param([sys,'/',['Binary vector',13,'noise generator2/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Type','Scalar integer  to vector converter')
set_param([sys,'/',['Binary vector',13,'noise generator2/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Dialogue','Positive decimal interger to binary converter.|Output vector length:|Output element base:')
set_param([sys,'/',['Binary vector',13,'noise generator2/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Binary vector',13,'noise generator2/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Help','This block converts scaler positive decimal integer input to an arbitrary base integer  vector output with specified vector length and output element base. The first element of the output vector is the lowest binary bit. For example, for a length two binary output, y(1)=0, y(2)=1 means the input is 1; y(0)=1, y(2)=0 means the input is 2.')
set_param([sys,'/',['Binary vector',13,'noise generator2/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Entries','n\/2\/',...
		'position',[345,26,405,64])
add_line([sys,'/',['Binary vector',13,'noise generator2']],[375,220;405,220;405,190;445,190])
add_line([sys,'/',['Binary vector',13,'noise generator2']],[485,180;530,180])
add_line([sys,'/',['Binary vector',13,'noise generator2']],[410,45;425,45;425,170;445,170])
add_line([sys,'/',['Binary vector',13,'noise generator2']],[215,180;445,180])
add_line([sys,'/',['Binary vector',13,'noise generator2']],[110,220;135,220;135,185;175,185])
add_line([sys,'/',['Binary vector',13,'noise generator2']],[100,165;135,165;135,175;175,175])
add_line([sys,'/',['Binary vector',13,'noise generator2']],[215,45;250,45])
add_line([sys,'/',['Binary vector',13,'noise generator2']],[125,110;140,110;140,50;175,50])
add_line([sys,'/',['Binary vector',13,'noise generator2']],[110,40;175,40])
add_line([sys,'/',['Binary vector',13,'noise generator2']],[305,45;340,45])
set_param([sys,'/',['Binary vector',13,'noise generator2']],...
		'Mask Display','Random\nB-vector',...
		'Mask Type','Binary vector noise generator.')
set_param([sys,'/',['Binary vector',13,'noise generator2']],...
		'Mask Dialogue','Generatea binary vector with at most given number of ones randomly distributed in the vector.|Vector length(can''t be changed during simulation):|Limit number of ones(can''t be changed during simulation):|Probability of all zeros (%):')
set_param([sys,'/',['Binary vector',13,'noise generator2']],...
		'Mask Translate','n=@1;m=@2;x=[1:2^n-1];id=find(sum(de2bi(x)'')<=m);x=x(id);lenx=length(x); y=x-[0,x(1:lenx-1)];x=[-1:2/lenx:(lenx-2)/lenx];p=@3/50-1;')
set_param([sys,'/',['Binary vector',13,'noise generator2']],...
		'Mask Help','This block outputs a binary vector with specified length. There are at most the given number of ones randomly distributed in the vector.')
set_param([sys,'/',['Binary vector',13,'noise generator2']],...
		'Mask Entries','5\/1\/50\/')


%     Finished composite block ['Binary vector',13,'noise generator2'].

set_param([sys,'/',['Binary vector',13,'noise generator2']],...
		'position',[195,268,250,302])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'position',[765,58,800,92])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'inputs','[5 5 5]',...
		'position',[325,208,360,242])


%     Subsystem  ['Binary vector',13,'noise generator1'].

new_system([sys,'/',['Binary vector',13,'noise generator1']])
set_param([sys,'/',['Binary vector',13,'noise generator1']],'Location',[405,495,1004,748])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'noise generator1/Constant2']])
set_param([sys,'/',['Binary vector',13,'noise generator1/Constant2']],...
		'Value','zeros(1,n)',...
		'position',[300,206,370,234])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'noise generator1/out_1']])
set_param([sys,'/',['Binary vector',13,'noise generator1/out_1']],...
		'position',[535,170,555,190])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'noise generator1/Switch']])
set_param([sys,'/',['Binary vector',13,'noise generator1/Switch']],...
		'Threshold','0.5',...
		'position',[450,164,480,196])

add_block('built-in/Signal Generator',[sys,'/',['Binary vector',13,'noise generator1/Uniform',13,'noise gen.1']])
set_param([sys,'/',['Binary vector',13,'noise generator1/Uniform',13,'noise gen.1']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1234.000000',...
		'Freq Range','6170.000000',...
		'Wave','Rnd',...
		'Units','Rads')
set_param([sys,'/',['Binary vector',13,'noise generator1/Uniform',13,'noise gen.1']],...
		'Mask Display','',...
		'position',[50,148,95,182])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'noise generator1/Relational',13,'Operator1']])
set_param([sys,'/',['Binary vector',13,'noise generator1/Relational',13,'Operator1']],...
		'position',[180,168,210,192])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'noise generator1/Constant1']])
set_param([sys,'/',['Binary vector',13,'noise generator1/Constant1']],...
		'Value','p',...
		'position',[75,210,105,230])

add_block('built-in/Signal Generator',[sys,'/',['Binary vector',13,'noise generator1/Uniform',13,'noise gen.']])
set_param([sys,'/',['Binary vector',13,'noise generator1/Uniform',13,'noise gen.']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1234.000000',...
		'Freq Range','6170.000000',...
		'Wave','Rnd',...
		'Units','Rads')
set_param([sys,'/',['Binary vector',13,'noise generator1/Uniform',13,'noise gen.']],...
		'position',[60,23,105,57])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'noise generator1/Relational',13,'Operator']])
set_param([sys,'/',['Binary vector',13,'noise generator1/Relational',13,'Operator']],...
		'position',[180,33,210,57])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'noise generator1/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'noise generator1/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'noise generator1/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','y\/')
set_param([sys,'/',['Binary vector',13,'noise generator1/Matrix',13,'Gain']],...
		'position',[255,30,300,60])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'noise generator1/Constant']])
set_param([sys,'/',['Binary vector',13,'noise generator1/Constant']],...
		'Value','x',...
		'position',[90,100,120,120])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'noise generator1/Integer scalar',13,'to vector',13,'converter']])
set_param([sys,'/',['Binary vector',13,'noise generator1/Integer scalar',13,'to vector',13,'converter']],...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter')
set_param([sys,'/',['Binary vector',13,'noise generator1/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Type','Scalar integer  to vector converter')
set_param([sys,'/',['Binary vector',13,'noise generator1/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Dialogue','Positive decimal interger to binary converter.|Output vector length:|Output element base:')
set_param([sys,'/',['Binary vector',13,'noise generator1/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Binary vector',13,'noise generator1/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Help','This block converts scaler positive decimal integer input to an arbitrary base integer  vector output with specified vector length and output element base. The first element of the output vector is the lowest binary bit. For example, for a length two binary output, y(1)=0, y(2)=1 means the input is 1; y(0)=1, y(2)=0 means the input is 2.')
set_param([sys,'/',['Binary vector',13,'noise generator1/Integer scalar',13,'to vector',13,'converter']],...
		'Mask Entries','n\/2\/',...
		'position',[350,26,410,64])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[305,45;345,45])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[110,40;175,40])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[125,110;140,110;140,50;175,50])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[215,45;250,45])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[100,165;135,165;135,175;175,175])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[110,220;135,220;135,185;175,185])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[215,180;445,180])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[415,45;425,45;425,170;445,170])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[485,180;530,180])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[375,220;405,220;405,190;445,190])
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Display','Random\nB-vector',...
		'Mask Type','Binary vector noise generator.')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Dialogue','Generatea binary vector with at most given number of ones randomly distributed in the vector.|Vector length(can''t be changed during simulation):|Limit number of ones(can''t be changed during simulation):|Probability of all zeros (%):')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Translate','n=@1;m=@2;x=[1:2^n-1];id=find(sum(de2bi(x)'')<=m);x=x(id);lenx=length(x); y=x-[0,x(1:lenx-1)];x=[-1:2/lenx:(lenx-2)/lenx];p=@3/50-1;')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Help','This block outputs a binary vector with specified length. There are at most the given number of ones randomly distributed in the vector.')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Entries','5\/1\/50\/')


%     Finished composite block ['Binary vector',13,'noise generator1'].

set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'position',[130,208,185,242])

add_block('built-in/S-Function',[sys,'/',['Integer vector  ',13,'to scalar',13,'converter']])
set_param([sys,'/',['Integer vector  ',13,'to scalar',13,'converter']],...
		'BackGround',3,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Vectro to scalar converter')
set_param([sys,'/',['Integer vector  ',13,'to scalar',13,'converter']],...
		'Mask Dialogue','Positive integer vector to scalar decimal integer converter:|Input element base:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector  ',13,'to scalar',13,'converter']],...
		'Mask Help','This block converts a binary vector to a scalar decimal integer. The block takes the first element input as the lowest binary bit. For example, if u(1)=1 and u(2)=0, the block outputs y=1; if u(1)=0 and u(2)=1, the block outputs y=2.')
set_param([sys,'/',['Integer vector  ',13,'to scalar',13,'converter']],...
		'Mask Entries','2\/',...
		'position',[650,50,710,90])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector',13,'converter']])
set_param([sys,'/',['Integer scalar',13,'to vector',13,'converter']],...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter',...
		'Mask Type','Scalar integer  to vector converter')
set_param([sys,'/',['Integer scalar',13,'to vector',13,'converter']],...
		'Mask Dialogue','Positive decimal interger to binary converter.|Output vector length:|Output element base:',...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector',13,'converter']],...
		'Mask Help','This block converts scaler positive decimal integer input to an arbitrary base integer  vector output with specified vector length and output element base. The first element of the output vector is the lowest binary bit. For example, for a length two binary output, y(1)=0, y(2)=1 means the input is 1; y(0)=1, y(2)=0 means the input is 2.')
set_param([sys,'/',['Integer scalar',13,'to vector',13,'converter']],...
		'Mask Entries','5\/2\/',...
		'position',[150,46,210,84])


%     Subsystem  ['Binary-vector',13,'BCH decode'].

new_system([sys,'/',['Binary-vector',13,'BCH decode']])
set_param([sys,'/',['Binary-vector',13,'BCH decode']],'Location',[157,499,740,659])

add_block('built-in/Outport',[sys,'/',['Binary-vector',13,'BCH decode/out_2']])
set_param([sys,'/',['Binary-vector',13,'BCH decode/out_2']],...
		'Port','2',...
		'position',[495,95,515,115])

add_block('built-in/Outport',[sys,'/',['Binary-vector',13,'BCH decode/out_1']])
set_param([sys,'/',['Binary-vector',13,'BCH decode/out_1']],...
		'position',[495,30,515,50])

add_block('built-in/Demux',[sys,'/',['Binary-vector',13,'BCH decode/Demux']])
set_param([sys,'/',['Binary-vector',13,'BCH decode/Demux']],...
		'outputs','[k, 1]',...
		'position',[395,40,435,75])

add_block('built-in/Inport',[sys,'/',['Binary-vector',13,'BCH decode/in_2']])
set_param([sys,'/',['Binary-vector',13,'BCH decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/',['Binary-vector',13,'BCH decode/in_1']])
set_param([sys,'/',['Binary-vector',13,'BCH decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Mux',[sys,'/',['Binary-vector',13,'BCH decode/Mux']])
set_param([sys,'/',['Binary-vector',13,'BCH decode/Mux']],...
		'inputs','[n, 1]',...
		'position',[80,41,115,74])

add_block('built-in/S-Function',[sys,'/',['Binary-vector',13,'BCH decode/S-function']])
set_param([sys,'/',['Binary-vector',13,'BCH decode/S-function']],...
		'function name','simbchdc',...
		'parameters','n, k, t,tp,dim',...
		'position',[170,20,235,40])

add_block('built-in/Switch',[sys,'/',['Binary-vector',13,'BCH decode/Switch']])
set_param([sys,'/',['Binary-vector',13,'BCH decode/Switch']],...
		'Threshold','0.5',...
		'position',[295,44,325,76])

add_block('built-in/Memory',[sys,'/',['Binary-vector',13,'BCH decode/Memory']])
set_param([sys,'/',['Binary-vector',13,'BCH decode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,k+1)',...
		'position',[295,95,335,125])
add_line([sys,'/',['Binary-vector',13,'BCH decode']],[440,65;455,65;455,105;490,105])
add_line([sys,'/',['Binary-vector',13,'BCH decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary-vector',13,'BCH decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary-vector',13,'BCH decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary-vector',13,'BCH decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary-vector',13,'BCH decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary-vector',13,'BCH decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary-vector',13,'BCH decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary-vector',13,'BCH decode']],[330,60;390,60])
add_line([sys,'/',['Binary-vector',13,'BCH decode']],[360,60;360,110;340,110])
set_param([sys,'/',['Binary-vector',13,'BCH decode']],...
		'Mask Display','BCH\ndecode',...
		'Mask Type','BCH decode')
set_param([sys,'/',['Binary-vector',13,'BCH decode']],...
		'Mask Dialogue','Code word length N, message length K, T error-correction BCH decode.|Code word length (N=2^M-1. M is a >2 integer):|Message length:|Error-correction capability (0 for unknown):')
set_param([sys,'/',['Binary-vector',13,'BCH decode']],...
		'Mask Translate','n=@1;k=@2;t=@3;if t<=0, [x1,x2,x3,x4,t]=bchpoly(n,k);end;dim=3;pow_dim=7;while pow_dim<n,dim=dim+1;pow_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);')
set_param([sys,'/',['Binary-vector',13,'BCH decode']],...
		'Mask Help','This block decodes N-ary binary code word from 1st inport into K-ary message sigusing at 1st ouport using BCH method. Use MATLAB command BCHPLOY to view the valid code word length N, message length K and error-correction capability T. A non-zero second inport signal triggers the block to do decode process. The block outputs the last processed results when second inport signal is zero. The second outport outputs the error detected in the process. A negative output indicates more error than the capability.')
set_param([sys,'/',['Binary-vector',13,'BCH decode']],...
		'Mask Entries','15\/5\/3\/')


%     Finished composite block ['Binary-vector',13,'BCH decode'].

set_param([sys,'/',['Binary-vector',13,'BCH decode']],...
		'position',[545,60,605,100])
add_line(sys,[90,65;145,65])
add_line(sys,[215,65;260,65])
add_line(sys,[340,65;365,65])
add_line(sys,[115,65;115,30;730,30;730,60;760,60])
add_line(sys,[395,70;430,70])
add_line(sys,[500,70;540,70])
add_line(sys,[610,70;645,70])
add_line(sys,[715,70;760,70])
add_line(sys,[805,75;840,75])
add_line(sys,[820,75;820,160;850,160])
add_line(sys,[610,90;630,90;630,125;740,125;740,80;760,80])
add_line(sys,[525,175;745,175;745,90;760,90])
add_line(sys,[430,135;500,135;500,90;540,90])
add_line(sys,[260,140;285,140;285,215;320,215])
add_line(sys,[190,225;320,225])
add_line(sys,[255,285;280,285;280,235;320,235])
add_line(sys,[365,225;375,225;375,170;350,170;350,75;365,75])
add_line(sys,[375,225;485,225;495,175])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
