function [ret,x0,str,ts,xts]=tcemmpsk(t,x,u,flag);
%TCEMMPSK	is the M-file description of the SIMULINK system named TCEMMPSK.
%	The block-diagram can be displayed by typing: TCEMMPSK.
%
%	SYS=TCEMMPSK(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TCEMMPSK to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TCEMMPSK with a FLAG of zero:
%	[SIZES]=TCEMMPSK([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[147,210,883,346])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;td=.2;M=8;Fc=100/2/pi;');


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate1'],[40,70;60,70])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[105,65;125,65])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','ceil(log10(M)/log10(2))\/20\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[605,58,685,102])


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(300,1,M)\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[25,68,100,112])


%     Subsystem  ['MPSK mod',13,'baseband'].

new_system([sys,'/',['MPSK mod',13,'baseband']])
set_param([sys,'/',['MPSK mod',13,'baseband']],'Location',[7,579,417,733])


%     Subsystem  ['MPSK mod',13,'baseband/PM',13,'baseband'].

new_system([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],'Location',[320,489,688,666])

add_block('built-in/Mux',[sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/Mux']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[250,51,285,84])

add_block('built-in/Outport',[sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/out_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/out_1']],...
		'position',[315,60,335,80])

add_block('built-in/Fcn',[sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/sin']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/sin']],...
		'Expr','sin(u)',...
		'position',[155,106,210,134])

add_block('built-in/Fcn',[sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/cos']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/cos']],...
		'Expr','cos(u)',...
		'position',[155,46,210,74])

add_block('built-in/Inport',[sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/in_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/in_1']],...
		'position',[35,50,55,70])
add_line([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],[215,60;245,60])
add_line([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],[290,70;310,70])
add_line([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],[215,120;230,120;230,75;245,75])
add_line([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],[60,60;150,60])
add_line([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],[130,60;130,120;150,120])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);PM',...
		'Mask Type','PM CE',...
		'Mask Dialogue','Output the complex envelope of a PM\nmodulated signal.|Initial phase (rad):')
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],...
		'Mask Translate','Ph=@1;pi2=2*pi;[x,y]=moduicon(3);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the phase modulated signal. The output of this block is a complex signal.',...
		'Mask Entries','Ph\/')


%     Finished composite block ['MPSK mod',13,'baseband/PM',13,'baseband'].

set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],...
		'ForeGround',4,...
		'position',[165,53,245,97])


%     Subsystem  ['MPSK mod',13,'baseband/MPSK map'].

new_system([sys,'/',['MPSK mod',13,'baseband/MPSK map']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],'Location',[71,474,419,648])

add_block('built-in/Inport',[sys,'/',['MPSK mod',13,'baseband/MPSK map/in_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map/in_1']],...
		'position',[60,35,80,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK mod',13,'baseband/MPSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[130,29,165,61])

add_block('built-in/Product',[sys,'/',['MPSK mod',13,'baseband/MPSK map/Product']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map/Product']],...
		'position',[235,76,260,109])

add_block('built-in/Outport',[sys,'/',['MPSK mod',13,'baseband/MPSK map/out_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map/out_1']],...
		'position',[310,85,330,105])

add_block('built-in/Constant',[sys,'/',['MPSK mod',13,'baseband/MPSK map/Multiple factor']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map/Multiple factor']],...
		'Value','Sft',...
		'position',[130,108,150,132])
add_line([sys,'/',['MPSK mod',13,'baseband/MPSK map']],[170,45;200,45;200,85;230,85])
add_line([sys,'/',['MPSK mod',13,'baseband/MPSK map']],[85,45;125,45])
add_line([sys,'/',['MPSK mod',13,'baseband/MPSK map']],[265,95;305,95])
add_line([sys,'/',['MPSK mod',13,'baseband/MPSK map']],[155,120;200,120;200,100;230,100])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'Mask Display','MPSK\nmap',...
		'Mask Type','MPSK map')
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'Mask Dialogue','Map input digital signal to analog phase shift.|M-ary number (input integer in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'Mask Translate','pi2=2*pi;Sft=pi2/@1;td=@2;')
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the PM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. You can view the MPSK constellation using the MODMAP function.')
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['MPSK mod',13,'baseband/MPSK map'].

set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'position',[55,53,135,97])

add_block('built-in/Outport',[sys,'/',['MPSK mod',13,'baseband/out_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/out_1']],...
		'position',[275,65,295,85])

add_block('built-in/Inport',[sys,'/',['MPSK mod',13,'baseband/in_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/in_1']],...
		'position',[10,65,30,85])
add_line([sys,'/',['MPSK mod',13,'baseband']],[140,75;160,75])
add_line([sys,'/',['MPSK mod',13,'baseband']],[250,75;270,75])
add_line([sys,'/',['MPSK mod',13,'baseband']],[35,75;50,75])
set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);MPSK',...
		'Mask Type','Baseband MPSK modulation')
set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of the\nM-ary phase shift keying modulation.|M-ary number (input integers in the range [0, M-1]):|Symbol interval and offset (sec):|Initial phase (rad):')
set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'Mask Translate','M=@1;td=@2;Ph=@3;[x,y]=moduicon(7);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of MPSK modulated signal. The inputs are integers in the range [0, M-1], where M is the M-ary number. When the symbol interval is a two-element vector, the second element is the offset (default 0). The block keeps a same input value in the symbol interval.')
set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'Mask Entries','M\/td\/0\/')


%     Finished composite block ['MPSK mod',13,'baseband'].

set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'hide name',0,...
		'position',[140,68,220,112])


%     Subsystem  ['Rayleigh fading',13,'channel'].

new_system([sys,'/',['Rayleigh fading',13,'channel']])
set_param([sys,'/',['Rayleigh fading',13,'channel']],'Location',[476,508,847,748])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading',13,'channel/out_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/out_1']],...
		'position',[290,125,310,145])

add_block('built-in/Mux',[sys,'/',['Rayleigh fading',13,'channel/Mux']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Mux']],...
		'inputs','2',...
		'position',[220,116,255,149])


%     Subsystem  ['Rayleigh fading',13,'channel/Inner',13,'Product1'].

new_system([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/Product']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/Sum']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/out_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/in_2']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/in_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],[40,100;60,70])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],[40,35;60,60])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],[95,65;120,65])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],[150,65;180,65])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Rayleigh fading',13,'channel/Inner',13,'Product1'].

set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],...
		'position',[150,154,170,176])

add_block('built-in/Constant',[sys,'/',['Rayleigh fading',13,'channel/Constant1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Constant1']],...
		'Value','[quad, in_p]',...
		'position',[30,155,105,185])


%     Subsystem  ['Rayleigh fading',13,'channel/Inner',13,'Product'].

new_system([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/in_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/in_2']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/out_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/Sum']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/Product']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],[150,65;180,65])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],[40,100;60,70])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Rayleigh fading',13,'channel/Inner',13,'Product'].

set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],...
		'position',[150,69,170,91])

add_block('built-in/Constant',[sys,'/',['Rayleigh fading',13,'channel/Constant']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Constant']],...
		'Value','[in_p, -quad]',...
		'position',[30,70,105,100])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel/in_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/in_1']],...
		'position',[30,20,50,40])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[260,135;285,135])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[175,165;190,165;190,140;215,140])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[175,80;190,80;190,125;215,125])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[55,30;120,30;120,75;145,75])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[120,75;120,160;145,160])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[110,170;145,170])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[110,85;145,85])
set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rayl F',...
		'Mask Type','Rayleigh fading channel, fixed parameter')
set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'Mask Dialogue','Rayleigh fading channel with fixed\nfading envelope and phase shift.|Rayleigh fading envelope:|Phase shift of the channel (rad):')
set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'Mask Translate','a=@1;b=@2;in_p=a*cos(b);quad=a*sin(b);[x,y]=chanicon;[v,w]=cmplxicn(0,50,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'Mask Help','This block applies the fading and phase shifting to the transmitting signal. In general, the fading envelope should be no larger than one. The input and the output of this block are both complex signals.')
set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'Mask Entries','.5\/pi/50\/')


%     Finished composite block ['Rayleigh fading',13,'channel'].

set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'hide name',0,...
		'position',[355,68,435,112])


%     Subsystem  ['MPSK demod',13,'baseband'].

new_system([sys,'/',['MPSK demod',13,'baseband']])
set_param([sys,'/',['MPSK demod',13,'baseband']],'Location',[4,554,405,737])


%     Subsystem  ['MPSK demod',13,'baseband/Min//max index2'].

new_system([sys,'/',['MPSK demod',13,'baseband/Min//max index2']])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],'Location',[192,461,623,564])

add_block('built-in/Inport',[sys,'/',['MPSK demod',13,'baseband/Min//max index2/in_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2/in_1']],...
		'position',[65,20,85,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK demod',13,'baseband/Min//max index2/Zero-Order',13,'Hold']])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Outport',[sys,'/',['MPSK demod',13,'baseband/Min//max index2/out_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2/out_1']],...
		'position',[335,20,355,40])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'baseband/Min//max index2/Maximum']])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2/Maximum']],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])
add_line([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],[90,30;160,30])
add_line([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],[325,30;330,30])
add_line([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],[205,30;235,30])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block ['MPSK demod',13,'baseband/Min//max index2'].

set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'ForeGround',4,...
		'position',[180,53,260,97])


%     Subsystem  ['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband'].

new_system([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],'Location',[102,505,735,711])

add_block('built-in/Constant',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Shift key']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Shift key']],...
		'Value','sft',...
		'position',[40,63,60,87])

add_block('built-in/Sum',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Sum1']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Sum1']],...
		'position',[165,75,190,115])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[420,19,480,61])

add_block('built-in/Product',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Product']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Product']],...
		'position',[355,21,380,54])

add_block('built-in/Demux',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Demux']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Demux']],...
		'ForeGround',2,...
		'outputs','2',...
		'position',[235,20,275,55])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Array cos']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Array cos']],...
		'ForeGround',3,...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[230,85,280,105])

add_block('built-in/Outport',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/out_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/out_1']],...
		'position',[585,105,605,125])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Array sin']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Array sin']],...
		'ForeGround',4,...
		'function name','arysin',...
		'parameters','''sin''',...
		'position',[230,130,280,150])

add_block('built-in/Product',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Product3']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Product3']],...
		'position',[355,116,380,149])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[420,114,480,156])

add_block('built-in/Inport',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/in_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/in_1']],...
		'position',[175,30,195,50])

add_block('built-in/Sum',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Sum3']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Sum3']],...
		'position',[535,105,555,125])

add_block('built-in/Constant',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Initial phase']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Initial phase']],...
		'Value','Ph',...
		'position',[100,93,120,117])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[200,40;230,40])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[280,45;310,45;310,125;350,125])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[285,140;350,140])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[385,135;415,135])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[385,40;415,40])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[485,40;510,40;510,110;530,110])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[485,135;510,135;510,120;530,120])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[560,115;580,115])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[285,95;320,95;320,45;350,45])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[280,30;350,30])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[195,95;225,95])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[205,95;205,140;225,140])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[125,105;160,105])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[65,75;95,75;95,85;160,85])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'Mask Display','plot(0,0,100,100,u,v);  MPSK corr',...
		'Mask Type','Baseband MPSK correlationA')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'Mask Dialogue','Compute Baseband MPSK correlation. Take\nMPSK CE modulated signal. Output a vector of correlation result.|M-ary number (integer in range [0, M-1]):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'Mask Translate','pi2=2*pi;N=@1;sft=[0:N-1]*pi2/N;td=@2;Ph=@3;ts=@4;[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'Mask Help','This block calculates the correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their phase shift the same as that of PM modulated signal of possible resulting digits. The output is an M length vector. The MPSK demodulation result is the index of the largest output, using the Min/max demap block. The input of this block is complex signal.')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'Mask Entries','M\/td\/Ph\/ts\/')


%     Finished composite block ['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband'].

set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'position',[60,53,140,97])

add_block('built-in/Inport',[sys,'/',['MPSK demod',13,'baseband/in_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/in_1']],...
		'position',[10,65,30,85])

add_block('built-in/Outport',[sys,'/',['MPSK demod',13,'baseband/out_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/out_1']],...
		'position',[295,65,315,85])
add_line([sys,'/',['MPSK demod',13,'baseband']],[145,75;175,75])
add_line([sys,'/',['MPSK demod',13,'baseband']],[35,75;55,75])
add_line([sys,'/',['MPSK demod',13,'baseband']],[265,75;290,75])
set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);MPSK',...
		'Mask Type','Baseband MPSK demodulation')
set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nMPSK modulated signal.|M-ary number (integer in range [0, M-1]):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'Mask Translate','M=@1;Ph=@3;td=@2;ts=@4;[x,y]=moduicon(8);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of a MPSK modulated signal using correlation method. The output signal are digits in the range [0, M-1], where M is the M-ary number. When the symbol interval is a two-element vector, the second element is the offset (default 0).')
set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'Mask Entries','M\/td\/0\/ts\/')


%     Finished composite block ['MPSK demod',13,'baseband'].

set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'hide name',0,...
		'position',[470,68,550,112])


%     Subsystem  ['Rician noise',13,'channel1'].

new_system([sys,'/',['Rician noise',13,'channel1']])
set_param([sys,'/',['Rician noise',13,'channel1']],'Location',[496,318,758,464])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'channel1/Sum']])
set_param([sys,'/',['Rician noise',13,'channel1/Sum']],...
		'position',[150,55,170,75])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'channel1/out_1']])
set_param([sys,'/',['Rician noise',13,'channel1/out_1']],...
		'position',[200,55,220,75])


%     Subsystem  ['Rician noise',13,'channel1/Gaussian',13,'noise'].

new_system([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],'Location',[358,505,706,710])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/',...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],...
		'Mask Entries','[m1 m2]\/[d d]\/s\/')


%     Finished composite block ['Rician noise',13,'channel1/Gaussian',13,'noise'].

set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Inport',[sys,'/',['Rician noise',13,'channel1/in_1']])
set_param([sys,'/',['Rician noise',13,'channel1/in_1']],...
		'position',[45,10,65,30])
add_line([sys,'/',['Rician noise',13,'channel1']],[90,70;145,70])
add_line([sys,'/',['Rician noise',13,'channel1']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['Rician noise',13,'channel1']],[175,65;195,65])
set_param([sys,'/',['Rician noise',13,'channel1']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rician N',...
		'Mask Type','Rician noise channel, fixed parameter')
set_param([sys,'/',['Rician noise',13,'channel1']],...
		'Mask Dialogue','Additive Rician noise channel for\nbaseband signal simulation. Input\nand output signals are complex.|In-phase m:|Quadrature m:|sigma:|Seed (1x2 vector):')
set_param([sys,'/',['Rician noise',13,'channel1']],...
		'Mask Translate','m1=@1;m2=@2;d=@3;s=@4;if length(s)<2,s=[s s+s];end;[x,y]=chanicon;[v,w]=cmplxicn(0,50,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rician noise',13,'channel1']],...
		'Mask Help','This block adds Rician noise to the input signal. The input and output of this block are complex signals. A Rician noise is composed with two independant Gaussian noise elements. The two Gaussian components have the same standard deviation, sigma. Their mean values are in-phase m and quadrature m respectively.')
set_param([sys,'/',['Rician noise',13,'channel1']],...
		'Mask Entries','.1\/.3\/.1\/[1234 4321]\/')


%     Finished composite block ['Rician noise',13,'channel1'].

set_param([sys,'/',['Rician noise',13,'channel1']],...
		'hide name',0,...
		'position',[245,68,325,112])
add_line(sys,[105,90;135,90])
add_line(sys,[115,90;115,25;580,25;580,70;600,70])
add_line(sys,[555,90;600,90])
add_line(sys,[225,90;240,90])
add_line(sys,[330,90;350,90])
add_line(sys,[440,90;465,90])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
