function [ret,x0,str,ts,xts]=tceps3c3(t,x,u,flag);
%TCEPS3C3	is the M-file description of the SIMULINK system named TCEPS3C3.
%	The block-diagram can be displayed by typing: TCEPS3C3.
%
%	SYS=TCEPS3C3(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TCEPS3C3 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TCEPS3C3 with a FLAG of zero:
%	[SIZES]=TCEPS3C3([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[364,61,936,337])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;td=.2;Fc=100/2/pi;M=16;');


%     Subsystem  'Error rate'.

new_system([sys,'/','Error rate'])
set_param([sys,'/','Error rate'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate/S-function'])
set_param([sys,'/','Error rate/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate/Mux'])
set_param([sys,'/','Error rate/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate/in_1'])
set_param([sys,'/','Error rate/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate/in_2'])
set_param([sys,'/','Error rate/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate'],[105,65;125,65])
add_line([sys,'/','Error rate'],[40,55;60,55])
add_line([sys,'/','Error rate'],[40,70;60,70])
set_param([sys,'/','Error rate'],...
		'Mask Display','Error Rate\nMeter',...
		'Mask Type','Symbol/Bit Error Counter.')
set_param([sys,'/','Error rate'],...
		'Mask Dialogue','Compare 2nd port input to scalar 1st port input. Compute the error rate.|Bit per symbol:|Number of digit on display:|Delay between input (1st port) and output (2nd port):|Sampling time (second):')
set_param([sys,'/','Error rate'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate'],...
		'Mask Help','The signal from the first port should be always be a scalar. The 2nd port input signal can be a vector with a same time delay to the input signal.',...
		'Mask Entries','4\/20\/td\/td\/')


%     Finished composite block 'Error rate'.

set_param([sys,'/','Error rate'],...
		'position',[450,78,525,122])


%     Subsystem  ['Arbitrary-map',13,'QASK demod'].

new_system([sys,'/',['Arbitrary-map',13,'QASK demod']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod']],'Location',[105,591,375,721])

add_block('built-in/Inport',[sys,'/',['Arbitrary-map',13,'QASK demod/in_1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/in_1']],...
		'position',[10,50,30,70])

add_block('built-in/Outport',[sys,'/',['Arbitrary-map',13,'QASK demod/out_1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/out_1']],...
		'position',[285,50,305,70])


%     Subsystem  ['Arbitrary-map',13,'QASK demod/QASK a-demap'].

new_system([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],'Location',[45,449,594,684])

add_block('built-in/Constant',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/imag_pt']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])

add_block('built-in/Constant',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/real_pt']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Outport',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/out_1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/S-Function',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Minimum1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Sum',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Sum2']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/Product',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Product1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Product',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Product']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Sum',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Sum6']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Sum',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Sum1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Zero-Order Hold',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Inport',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/imag']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Inport',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/real']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[480,95;490,95])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[395,95;410,95])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[160,130;225,130])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[160,45;225,45])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[70,130;115,130])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],[70,45;115,45])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],...
		'Mask Display','arbitrary\nQASK\ndemap',...
		'Mask Type','QASK arbitrary-demap')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],...
		'Mask Dialogue','QASK demapping for arbitrary defined\nmap. The arbitrary defined map is given in in-phase and quadreture component vector.|Vector of in-phase component:|Vector of quadreture component:|Symbol interval (second):')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],...
		'Mask Help','This block demaps input in-phase and quadreture QASK signal into digit. The vector length of the first two entries sould have the same length.')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],...
		'Mask Entries','y1\/y2\/td\/')


%     Finished composite block ['Arbitrary-map',13,'QASK demod/QASK a-demap'].

set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QASK a-demap']],...
		'position',[180,39,255,81])


%     Subsystem  ['Arbitrary-map',13,'QASK demod/QADM CE2'].

new_system([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],'Location',[283,122,827,462])

add_block('built-in/Inport',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/in_1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/in_1']],...
		'position',[55,115,75,135])

add_block('built-in/Constant',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Constant1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Sum',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Sum1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Outport',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/out_2']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Filter',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Filter1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Product',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Product1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Demux',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Demux']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Constant',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Constant']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Product',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Product2']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Product',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Product3']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Sum',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Sum']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Product']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Filter',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Filter']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Note',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Outport',[sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/out_1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[230,115;230,245;265,245])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[200,255;265,255])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[165,130;255,130])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[180,130;180,210;265,210])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[180,50;255,50])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[215,50;215,200;265,200])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[80,125;115,125])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[360,80;385,80])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[450,80;475,80])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[365,230;390,230])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],[455,230;480,230])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],...
		'Mask Display','QM\nDSB-SC\nADM',...
		'Mask Type','Quadrature Demultiplexed DSB-SC AM')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],...
		'Mask Dialogue','Quadrature Demultiplexed Double-Sideband Suppressed-Carrier Amplitude Demodulation:|Low-pass filter numerator:|Low-pass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(Ph);x2=sin(Ph);')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],...
		'Mask Help','The Quadratic Demultiplexed Double-Sideband Supressed-Carrier Amplitude Demodulation block demodulates the QM-DSB-SC-AM signal using quadratic duplex method. The filter to be speficed by the users is a lowpass filter which should pass the signal message and eliminate the carrier signal.')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['Arbitrary-map',13,'QASK demod/QADM CE2'].

set_param([sys,'/',['Arbitrary-map',13,'QASK demod/QADM CE2']],...
		'BackGround',3,...
		'position',[60,40,135,80])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod']],[35,60;55,60])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod']],[260,60;280,60])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod']],[140,50;175,50])
add_line([sys,'/',['Arbitrary-map',13,'QASK demod']],[140,70;175,70])
set_param([sys,'/',['Arbitrary-map',13,'QASK demod']],...
		'Mask Display','a-QASK\ndemod CE',...
		'Mask Type','QASK arbitrary-demod')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod']],...
		'Mask Dialogue','QASK demodulation for arbitrary defined map. The arbitrary defined map is given in in-phase and quadreture component vector.|Vector of in-phase component:|Vector of quadreture component:|Symbol interval (second):|Low-pass filter [num; den]:|Initial phase:|Sample time (second):')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;num=@4;Ph=@5;ts=@6;den=num(2,:);num=num(1,:);')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod']],...
		'Mask Help','This block demodulates input digit signal using QASK method. The vector length of the first two entries sould have the same length. This block use a default low-pass filter, which is [num,den]=butter(5,Fc*2*ts). Ungroup this block if you prefer to define your own filter.')
set_param([sys,'/',['Arbitrary-map',13,'QASK demod']],...
		'Mask Entries','real(exp(j*[0:M-1]/M*pi*2))\/imag(exp(j*[0:M-1]/M*pi*2))\/td\/[num;den]\/0\/ts\/')


%     Finished composite block ['Arbitrary-map',13,'QASK demod'].

set_param([sys,'/',['Arbitrary-map',13,'QASK demod']],...
		'position',[350,90,425,130])


%     Subsystem  ['Rayleigh channel',13,'with varian para'].

new_system([sys,'/',['Rayleigh channel',13,'with varian para']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para']],'Location',[266,502,924,748])

add_block('built-in/Inport',[sys,'/',['Rayleigh channel',13,'with varian para/in_2']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/in_2']],...
		'Port','2',...
		'position',[495,40,515,60])

add_block('built-in/Product',[sys,'/',['Rayleigh channel',13,'with varian para/Product4']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Product4']],...
		'position',[565,90,590,110])

add_block('built-in/Outport',[sys,'/',['Rayleigh channel',13,'with varian para/out_1']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/out_1']],...
		'position',[625,90,645,110])

add_block('built-in/Mux',[sys,'/',['Rayleigh channel',13,'with varian para/Mux']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Mux']],...
		'inputs','2',...
		'position',[495,96,530,129])

add_block('built-in/Product',[sys,'/',['Rayleigh channel',13,'with varian para/Product1']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Product1']],...
		'position',[295,90,320,110])

add_block('built-in/Sum',[sys,'/',['Rayleigh channel',13,'with varian para/Sum1']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Sum1']],...
		'position',[425,125,445,145])

add_block('built-in/Sum',[sys,'/',['Rayleigh channel',13,'with varian para/Sum']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Sum']],...
		'inputs','+-',...
		'position',[425,70,445,90])

add_block('built-in/Product',[sys,'/',['Rayleigh channel',13,'with varian para/Product3']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Product3']],...
		'position',[300,190,325,210])

add_block('built-in/Product',[sys,'/',['Rayleigh channel',13,'with varian para/Product2']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Product2']],...
		'position',[300,130,325,150])

add_block('built-in/Fcn',[sys,'/',['Rayleigh channel',13,'with varian para/Fcn1']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Fcn1']],...
		'position',[115,192,185,218])

add_block('built-in/Product',[sys,'/',['Rayleigh channel',13,'with varian para/Product']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Product']],...
		'position',[300,20,325,40])

add_block('built-in/Inport',[sys,'/',['Rayleigh channel',13,'with varian para/in_1']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/in_1']],...
		'position',[75,25,95,45])

add_block('built-in/Demux',[sys,'/',['Rayleigh channel',13,'with varian para/Demux']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Demux']],...
		'outputs','2',...
		'position',[140,15,180,50])

add_block('built-in/Fcn',[sys,'/',['Rayleigh channel',13,'with varian para/Fcn']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[110,132,180,158])

add_block('built-in/Inport',[sys,'/',['Rayleigh channel',13,'with varian para/in_3']])
set_param([sys,'/',['Rayleigh channel',13,'with varian para/in_3']],...
		'Port','3',...
		'position',[45,160,65,180])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[520,50;540,50;540,95;560,95])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[595,100;620,100])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[535,115;540,115;540,105;560,105])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[450,135;465,135;465,120;490,120])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[450,80;465,80;465,105;490,105])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[330,140;420,140])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[325,100;385,100;385,130;420,130])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[330,200;370,200;370,85;420,85])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[330,30;370,30;370,75;420,75])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[190,205;240,205;240,105;290,105])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[240,205;295,205])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[185,145;230,145;230,35;295,35])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[230,145;295,145])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[185,40;215,40;215,135;295,135])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[215,135;215,195;295,195])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[185,25;295,25])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[240,25;240,95;290,95])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[100,35;135,35])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[70,170;80,170;80,145;105,145])
add_line([sys,'/',['Rayleigh channel',13,'with varian para']],[80,170;80,205;110,205])
set_param([sys,'/',['Rayleigh channel',13,'with varian para']],...
		'Mask Display','Rayleigh\nfading CE\nchannel',...
		'Mask Type','Varian Rayleigh Fading Channel.')
set_param([sys,'/',['Rayleigh channel',13,'with varian para']],...
		'Mask Dialogue','Varian Rayleigh fading channel. The fading envelop and the phase are provided in the 2nd and 3rd input port.')
set_param([sys,'/',['Rayleigh channel',13,'with varian para']],...
		'Mask Help','Varian Rayleigh fading channel with the fading envelop and the phase of the channel provided in the 2nd and the 3rd input port. The 1st in-port and the output of this block are complex envelop of the transfer signal.')


%     Finished composite block ['Rayleigh channel',13,'with varian para'].

set_param([sys,'/',['Rayleigh channel',13,'with varian para']],...
		'position',[235,90,305,130])


%     Subsystem  ['Arbitrary-map',13,'QASK mod'].

new_system([sys,'/',['Arbitrary-map',13,'QASK mod']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod']],'Location',[26,513,291,653])

add_block('built-in/Inport',[sys,'/',['Arbitrary-map',13,'QASK mod/in_1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/in_1']],...
		'position',[5,70,20,90])

add_block('built-in/Outport',[sys,'/',['Arbitrary-map',13,'QASK mod/out_1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/out_1']],...
		'position',[270,70,290,90])


%     Subsystem  ['Arbitrary-map',13,'QASK mod/QASK a-map'].

new_system([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],'Location',[58,103,403,268])

add_block('built-in/Outport',[sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/Imag']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])

add_block('built-in/Outport',[sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/Real']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Look Up Table',[sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/imag part1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Look Up Table',[sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/real part']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Inport',[sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/in_1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],[215,110;270,110])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],[220,30;270,30])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],[120,30;175,30])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],[145,30;145,110;170,110])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],[50,30;75,30])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],...
		'Mask Display','arbitrary\nQASK\nmap',...
		'Mask Type','QASK arbitrary-map')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],...
		'Mask Dialogue','QASK mapping for arbitrary defined map. Assume input digit is K. 1st out_port\noutputs in-phase(K+1). 2nd out_port\noutputs quadreture(K+1).|Vector of in-phase component:|Vector of quadreture component:|Symbol interval (second):')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;ly=length(y1);x=[-10 1:ly-1;1:ly-1 10*ly]-.5;x=x(:);y1=y1(:)'';y1=[y1;y1];y1=y1(:);y2=y2(:)'';y2=[y2;y2];y2=y2(:);')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],...
		'Mask Help','This block maps input digit into in-phase and quadreture components of QASK. The vector length of the first two entries sould have the same length.')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],...
		'Mask Entries','y1\/y2\/td\/')


%     Finished composite block ['Arbitrary-map',13,'QASK mod/QASK a-map'].

set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QASK a-map']],...
		'position',[50,58,120,102])


%     Subsystem  ['Arbitrary-map',13,'QASK mod/QAM CE2'].

new_system([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],'Location',[125,397,758,690])

add_block('built-in/Note',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/R1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/R1']],...
		'position',[190,15,195,20])

add_block('built-in/Product',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Product']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Product',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Product1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Sum',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Sum']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Note',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/R_out']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Mux',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/RI2C']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/RI2C']],...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Inport',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/in_1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Outport',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/out_1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Constant',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Constant']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Constant',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Constant1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Note',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/I1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Inport',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/in_2']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/R2']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Note',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/I2']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Product',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Product3']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Product',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Product2']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Sum',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Sum1']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Note',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/I_out']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Note',[sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[550,140;580,140])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[250,100;250,245;305,245])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[280,175;280,200;305,200])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[270,155;270,235;305,235])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[120,40;295,40])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[238,40;238,190;305,190])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],[410,220;425,220;425,150;465,150])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],...
		'Mask Display','QM DSB\nAM',...
		'Mask Type','Quadrature Multiplexed DSB-SC AM')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],...
		'Mask Dialogue','Quadrature multiplexed double-sideband suppressed-carrier amplitude modulation:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],...
		'Mask Translate','Ph=@1;ts=@2;x1=cos(Ph);x2=sin(Ph);')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],...
		'Mask Help','The Quadratic Multiplexed Double-Sideband-Supressed-Carrier AM block causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. There are two input signal being modulated at the same time by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],...
		'Mask Entries','Ph\/ts\/')


%     Finished composite block ['Arbitrary-map',13,'QASK mod/QAM CE2'].

set_param([sys,'/',['Arbitrary-map',13,'QASK mod/QAM CE2']],...
		'BackGround',3,...
		'position',[160,60,240,100])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod']],[25,80;45,80])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod']],[245,80;265,80])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod']],[125,70;155,70])
add_line([sys,'/',['Arbitrary-map',13,'QASK mod']],[125,90;155,90])
set_param([sys,'/',['Arbitrary-map',13,'QASK mod']],...
		'Mask Display','a-map\nQASK ce',...
		'Mask Type','QASK arbitrary-map modulation')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod']],...
		'Mask Dialogue','Complex envelop of QASK modulation for arbitrary defined\nmap. Assume input digit is K. 1st out_port outputs in-phase(K+1). 2nd out_port\noutputs quadreture(K+1).|Vector of in-phase component:|Vector of quadreture component:|Symbol interval (second):|Initial phase (rad):|Sample time (second):')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;Ph=@4;ts=@5;')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod']],...
		'Mask Help','This block output the complex envelop of the modulation of input digit signal. The vector length of the first two entries sould have the same length.')
set_param([sys,'/',['Arbitrary-map',13,'QASK mod']],...
		'Mask Entries','real(exp(j*[0:M-1]/M*pi*2))\/imag(exp(j*[0:M-1]/M*pi*2))\/td\/0\/ts\/')


%     Finished composite block ['Arbitrary-map',13,'QASK mod'].

set_param([sys,'/',['Arbitrary-map',13,'QASK mod']],...
		'position',[120,74,185,116])


%     Subsystem  'Sampled read'.

new_system([sys,'/','Sampled read'])
set_param([sys,'/','Sampled read'],'Location',[355,528,737,675])


%     Subsystem  ['Sampled read/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/','Sampled read/out_1'])
set_param([sys,'/','Sampled read/out_1'],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/','Sampled read/Message source'])
set_param([sys,'/','Sampled read/Message source'],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;',...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])
add_line([sys,'/','Sampled read'],[260,75;290,75])
add_line([sys,'/','Sampled read'],[115,75;175,75])
set_param([sys,'/','Sampled read'],...
		'Mask Display','Sampled\nread\nvariable',...
		'Mask Type','Read from a variable at given sample time.')
set_param([sys,'/','Sampled read'],...
		'Mask Dialogue','Read from a workspace variable at a given interval:|Variable (column_number=block_output_length):|Output symbol interval:|Cyclic read (1) or amend zero (0):|Initial output:')
set_param([sys,'/','Sampled read'],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;')
set_param([sys,'/','Sampled read'],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable row, the block will cyclically output from the first row of the the variable or output zero based on the cyclic read entree.')
set_param([sys,'/','Sampled read'],...
		'Mask Entries','randint(300,1,M)\/td\/1\/0\/')


%     Finished composite block 'Sampled read'.

set_param([sys,'/','Sampled read'],...
		'BackGround',5,...
		'position',[10,73,85,117])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'outputs','2',...
		'position',[145,155,185,190])


%     Subsystem  ['Uniform',13,'noise'].

new_system([sys,'/',['Uniform',13,'noise']])
set_param([sys,'/',['Uniform',13,'noise']],'Location',[420,594,637,734])

add_block('built-in/Outport',[sys,'/',['Uniform',13,'noise/out_1']])
set_param([sys,'/',['Uniform',13,'noise/out_1']],...
		'position',[165,65,185,85])

add_block('built-in/S-Function',[sys,'/',['Uniform',13,'noise/Uniform',13,'noise']])
set_param([sys,'/',['Uniform',13,'noise/Uniform',13,'noise']],...
		'function name','surandom',...
		'parameters','seed,up,low',...
		'position',[65,55,135,95])
add_line([sys,'/',['Uniform',13,'noise']],[140,75;160,75])
set_param([sys,'/',['Uniform',13,'noise']],...
		'Mask Display','Uniform\nnoise',...
		'Mask Type','Uniform distribution noise.',...
		'Mask Dialogue','Uniform distribution noise.|Low bound of the output:|Upper bound of the output:|Seed:')
set_param([sys,'/',['Uniform',13,'noise']],...
		'Mask Translate','seed=@3;up=@2;low=@1;')
set_param([sys,'/',['Uniform',13,'noise']],...
		'Mask Help','The output of this block is uniformly distributed between the low and up boundaries. The output size is the same as the vector size for seed.')
set_param([sys,'/',['Uniform',13,'noise']],...
		'Mask Entries','[.8 0]\/[1.2 .26]\/randint(1,2,10000)\/')


%     Finished composite block ['Uniform',13,'noise'].

set_param([sys,'/',['Uniform',13,'noise']],...
		'position',[50,154,125,196])


%     Subsystem  ['Click here to plot',13,'constelation of this exmp'].

new_system([sys,'/',['Click here to plot',13,'constelation of this exmp']])
set_param([sys,'/',['Click here to plot',13,'constelation of this exmp']],'Location',[657,455,963,648])
set_param([sys,'/',['Click here to plot',13,'constelation of this exmp']],...
		'Mask Display','Constelation\nPlot',...
		'Mask Dialogue','eval(''x=[real(exp(j*[1:M]/M*pi*2))];y=[imag(exp(j*[1:M]/M*pi*2))];plot(x,y,''''r*'''');axis(''''equal'''');'')')


%     Finished composite block ['Click here to plot',13,'constelation of this exmp'].

set_param([sys,'/',['Click here to plot',13,'constelation of this exmp']],...
		'position',[345,170,445,210])
add_line(sys,[90,95;115,95])
add_line(sys,[100,95;100,50;415,50;415,90;445,90])
add_line(sys,[430,110;445,110])
add_line(sys,[190,95;230,95])
add_line(sys,[310,110;345,110])
add_line(sys,[130,175;140,175])
add_line(sys,[190,165;200,165;200,110;230,110])
add_line(sys,[190,180;205,180;205,125;230,125])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
