function [ret,x0,str,ts,xts]=tceps3cd(t,x,u,flag);
%TCEPS3CD	is the M-file description of the SIMULINK system named TCEPS3CD.
%	The block-diagram can be displayed by typing: TCEPS3CD.
%
%	SYS=TCEPS3CD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TCEPS3CD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TCEPS3CD with a FLAG of zero:
%	[SIZES]=TCEPS3CD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[353,76,1004,247])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;td=.2;Fc=100/2/pi;M=16;num=1;den=1;');


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(1000,1,M)\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[25,43,100,87])


%     Subsystem  ['Rayleigh fading channel',13,'w vary para CE'].

new_system([sys,'/',['Rayleigh fading channel',13,'w vary para CE']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],'Location',[266,502,924,748])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_2']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_2']],...
		'Port','2',...
		'position',[495,40,515,60])

add_block('built-in/Product',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product4']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product4']],...
		'position',[565,90,590,110])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/out_1']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/out_1']],...
		'position',[625,90,645,110])

add_block('built-in/Mux',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Mux']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Mux']],...
		'inputs','2',...
		'position',[495,96,530,129])

add_block('built-in/Product',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product1']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product1']],...
		'position',[295,90,320,110])

add_block('built-in/Sum',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Sum1']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Sum1']],...
		'position',[425,125,445,145])

add_block('built-in/Sum',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Sum']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Sum']],...
		'inputs','+-',...
		'position',[425,70,445,90])

add_block('built-in/Product',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product3']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product3']],...
		'position',[300,190,325,210])

add_block('built-in/Product',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product2']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product2']],...
		'position',[300,130,325,150])

add_block('built-in/Fcn',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Fcn1']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Fcn1']],...
		'position',[115,192,185,218])

add_block('built-in/Product',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Product']],...
		'position',[300,20,325,40])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_1']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_1']],...
		'position',[75,25,95,45])

add_block('built-in/Demux',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Demux']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Demux']],...
		'outputs','2',...
		'position',[140,15,180,50])

add_block('built-in/Fcn',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/Fcn']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[110,132,180,158])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_3']])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE/in_3']],...
		'Port','3',...
		'position',[45,160,65,180])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[520,50;540,50;540,95;560,95])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[595,100;620,100])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[535,115;540,115;540,105;560,105])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[450,135;465,135;465,120;490,120])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[450,80;465,80;465,105;490,105])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[330,140;420,140])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[325,100;385,100;385,130;420,130])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[330,200;370,200;370,85;420,85])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[330,30;370,30;370,75;420,75])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[190,205;240,205;240,105;290,105])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[240,205;295,205])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[185,145;230,145;230,35;295,35])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[230,145;295,145])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[185,40;215,40;215,135;295,135])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[215,135;215,195;295,195])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[185,25;295,25])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[240,25;240,95;290,95])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[100,35;135,35])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[70,170;80,170;80,145;105,145])
add_line([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],[80,170;80,205;110,205])
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rayl F',...
		'Mask Type','Rayleigh fading channel, vary parameter')
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],...
		'Mask Dialogue','The fading envelope and the phase shift of the channel changes with the 2nd and 3rd input port values.')
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],...
		'Mask Translate','[x,y]=chanicon;x=x*.9+10;[v,w]=cmplxicn(0,85,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,55,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],...
		'Mask Help','This block applies Rayleigh fading to the transmitting signals. The fading envelope and the phase of the channel are provided in the 2nd and the 3rd input port. The 1st input port and the output of this block are complex signals.')


%     Finished composite block ['Rayleigh fading channel',13,'w vary para CE'].

set_param([sys,'/',['Rayleigh fading channel',13,'w vary para CE']],...
		'hide name',0,...
		'position',[245,58,325,102])


%     Subsystem  ['ASK Mo//Dem',13,'demo1'].

new_system([sys,'/',['ASK Mo//Dem',13,'demo1']])
set_param([sys,'/',['ASK Mo//Dem',13,'demo1']],'Location',[175,552,335,697])
set_param([sys,'/',['ASK Mo//Dem',13,'demo1']],...
		'Mask Display','View\nconstellation')
set_param([sys,'/',['ASK Mo//Dem',13,'demo1']],...
		'Mask Dialogue','eval(''modmap(''''qask/arb'''',[real(exp(j*[1:floor(M/3)]/floor(M/3)*pi*2)) 2*real(exp(j*[1:M-floor(M/3)]/(M-floor(M/3))*pi*2))],[imag(exp(j*[1:floor(M/3)]/floor(M/3)*pi*2)) 2*imag(exp(j*[1:M-floor(M/3)]/(M-floor(M/3))*pi*2))])'')')


%     Finished composite block ['ASK Mo//Dem',13,'demo1'].

set_param([sys,'/',['ASK Mo//Dem',13,'demo1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[545,48,625,92])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate1'],[40,70;60,70])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[105,65;125,65])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','5\/20\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[450,48,530,92])


%     Subsystem  ['A-map QASK',13,'demod baseband'].

new_system([sys,'/',['A-map QASK',13,'demod baseband']])
set_param([sys,'/',['A-map QASK',13,'demod baseband']],'Location',[105,539,481,673])


%     Subsystem  ['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap'].

new_system([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],'Location',[45,449,594,684])

add_block('built-in/Zero-Order Hold',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/real']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/imag']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum6']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Product']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Product1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum2']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Minimum1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/out_1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/real_pt']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/imag_pt']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[70,45;115,45])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[70,130;115,130])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[160,45;225,45])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[160,130;225,130])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[395,95;410,95])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[480,95;490,95])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'Mask Entries','y1\/y2\/td\/')


%     Finished composite block ['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap'].

set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'position',[175,38,255,82])


%     Subsystem  ['A-map QASK',13,'demod baseband/QADM',13,'baseband3'].

new_system([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],'Location',[283,122,827,462])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/out_1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Filter',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product3']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product2']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Demux',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Demux']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Filter',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/out_2']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/in_1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/in_1']],...
		'position',[55,115,75,135])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[455,230;480,230])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[365,230;390,230])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[450,80;475,80])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[360,80;385,80])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[80,125;115,125])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[180,50;255,50])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[215,50;215,200;265,200])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[165,130;255,130])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[180,130;180,210;265,210])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[200,255;265,255])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[230,115;230,245;265,245])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['A-map QASK',13,'demod baseband/QADM',13,'baseband3'].

set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[70,38,150,82])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'demod baseband/in_1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/in_1']],...
		'position',[10,50,30,70])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'demod baseband/out_1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/out_1']],...
		'position',[285,50,305,70])
add_line([sys,'/',['A-map QASK',13,'demod baseband']],[35,60;65,60])
add_line([sys,'/',['A-map QASK',13,'demod baseband']],[260,60;280,60])
add_line([sys,'/',['A-map QASK',13,'demod baseband']],[155,50;170,50])
add_line([sys,'/',['A-map QASK',13,'demod baseband']],[155,70;170,70])
set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);A-QASK',...
		'Mask Type','Baseband A-QASK demodulation')
set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a QASK modulated signal. The arbitrary constellation is defined by in-phase and quadrature vectors.|Constellation in-phase component:|Constellation quadrature component:|Symbol interval and offset (sec):|Lowpass filter [num; den], a 2 row matrix:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;num=@4;Ph=@5;ts=@6;den=num(2,:);num=num(1,:);[x,y]=moduicon(6);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'Mask Help','This block demodulates the complex envelope of a QASK modulated signal with user-defined arbitrary constellation. The vector length of the in-phase and quadrature components vectors should have the same length. The outputs are integers in the range [0, M-1], where M is the vector length of in-phase or quadrature. When the symbol interval is a two-element vector, the second element is the offset (default 0).')
set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'Mask Entries','real(exp(j*[0:M-1]/M*pi*2))\/imag(exp(j*[0:M-1]/M*pi*2))\/[td, td-ts]\/[num;den]\/0\/ts\/')


%     Finished composite block ['A-map QASK',13,'demod baseband'].

set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'hide name',0,...
		'position',[350,58,430,102])


%     Subsystem  ['A-map QASK',13,'mod baseband'].

new_system([sys,'/',['A-map QASK',13,'mod baseband']])
set_param([sys,'/',['A-map QASK',13,'mod baseband']],'Location',[26,513,372,670])


%     Subsystem  ['A-map QASK',13,'mod baseband/QAM',13,'baseband2'].

new_system([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],'Location',[321,500,954,793])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I_out']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Sum1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product2']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product3']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I2']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R2']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/in_2']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Constant1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Constant']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/out_1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/in_1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Mux',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/RI2C']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/RI2C']],...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R_out']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Sum']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R1']],...
		'position',[190,15,195,20])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[410,220;425,220;425,150;465,150])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[120,40;295,40])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[238,40;238,190;305,190])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[270,155;270,235;305,235])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[280,175;280,200;305,200])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[250,100;250,245;305,245])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[550,140;580,140])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'Mask Entries','Ph\/')


%     Finished composite block ['A-map QASK',13,'mod baseband/QAM',13,'baseband2'].

set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[165,58,245,102])


%     Subsystem  ['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map'].

new_system([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],'Location',[58,103,403,268])

add_block('built-in/Zero-Order Hold',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/in_1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Look Up Table',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/real part']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Look Up Table',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/imag part1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Real']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Imag']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],[50,30;75,30])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],[120,30;175,30])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],[145,30;145,110;170,110])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],[220,30;270,30])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],[215,110;270,110])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'Mask Display','QASK\nA-map',...
		'Mask Type','QASK A-map')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'Mask Dialogue','QASK mapping for arbitrary defined\nmap. Assume input digit is K. 1st\noutport outputs in-phase(K+1). 2nd\noutport outputs quadrature(K+1).|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;ly=length(y1);x=[-10 1:ly-1;1:ly-1 10*ly]-.5;x=x(:);y1=y1(:)'';y1=[y1;y1];y1=y1(:);y2=y2(:)'';y2=[y2;y2];y2=y2(:);')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The in-phase and quadrature constellation vectors must have the same length. The input signal is in the range of [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'Mask Entries','y1\/y2\/td\/')


%     Finished composite block ['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map'].

set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'hide name',0,...
		'position',[50,58,130,102])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'mod baseband/in_1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/in_1']],...
		'position',[5,70,20,90])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'mod baseband/out_1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/out_1']],...
		'hide name',0,...
		'position',[270,70,290,90])
add_line([sys,'/',['A-map QASK',13,'mod baseband']],[135,90;160,90])
add_line([sys,'/',['A-map QASK',13,'mod baseband']],[135,70;160,70])
add_line([sys,'/',['A-map QASK',13,'mod baseband']],[25,80;45,80])
add_line([sys,'/',['A-map QASK',13,'mod baseband']],[250,80;265,80])
set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);A-QASK',...
		'Mask Type','Baseband A-QASK modulation')
set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'Mask Dialogue','Output the complex envelope of QASK\nmodulation. The arbitrary constellation\nis defined by in-phase and quadrature\nvectors.|Constellation in-phase component:|Constellation quadrature component:|Input symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;Ph=@4;ts=@5;[x,y]=moduicon(5);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'Mask Help','This block outputs the complex envelope of a QASK modulated signal with user-defined arbitrary constellation. The vector length of the in-phase and quadrature components vectors should be the same length. The inputs are integers in the range [0, M-1], where M is the vector length of in-phase or quadrature. When the symbol interval is a two-element vector, the second element is the offset (default 0).')
set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'Mask Entries','real(exp(j*[0:M-1]/M*pi*2))\/imag(exp(j*[0:M-1]/M*pi*2))\/td\/0\/ts\/')


%     Finished composite block ['A-map QASK',13,'mod baseband'].

set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'hide name',0,...
		'position',[135,43,215,87])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'hide name',0,...
		'outputs','2',...
		'position',[170,110,210,145])


%     Subsystem  ['Uniform noise',13,'generator'].

new_system([sys,'/',['Uniform noise',13,'generator']])
set_param([sys,'/',['Uniform noise',13,'generator']],'Location',[420,594,637,734])

add_block('built-in/Outport',[sys,'/',['Uniform noise',13,'generator/out_1']])
set_param([sys,'/',['Uniform noise',13,'generator/out_1']],...
		'position',[165,65,185,85])

add_block('built-in/S-Function',[sys,'/',['Uniform noise',13,'generator/Uniform',13,'noise']])
set_param([sys,'/',['Uniform noise',13,'generator/Uniform',13,'noise']],...
		'function name','surandom',...
		'parameters','seed,up,low',...
		'position',[65,55,135,95])
add_line([sys,'/',['Uniform noise',13,'generator']],[140,75;160,75])
set_param([sys,'/',['Uniform noise',13,'generator']],...
		'Mask Display','plot(0,0,100,100,x,y);Uniform',...
		'Mask Type','Uniform noise generator')
set_param([sys,'/',['Uniform noise',13,'generator']],...
		'Mask Dialogue','Generate uniformly distributed noise\nbetween the upper and lower bounds.|Noise lower bound:|Noise upper bound:|Seed:')
set_param([sys,'/',['Uniform noise',13,'generator']],...
		'Mask Translate','seed=@3;up=@2;low=@1;[x,y]=srcsicon(3);')
set_param([sys,'/',['Uniform noise',13,'generator']],...
		'Mask Help','This block generates a uniformly distributed noise between the given lower and upper bounds. The output size is the same as the vector length of the seed. The upper bound and lower bound can be scalar or vectors with their lengths the same as the length for the seed. The vector length of upper bound must be the same as length of lower bound.')
set_param([sys,'/',['Uniform noise',13,'generator']],...
		'Mask Entries','[0.7 -.2]\/[1.3 .2]\/[12345 54321]\/')


%     Finished composite block ['Uniform noise',13,'generator'].

set_param([sys,'/',['Uniform noise',13,'generator']],...
		'hide name',0,...
		'position',[55,108,135,152])
add_line(sys,[105,65;130,65])
add_line(sys,[120,65;120,35;435,35;445,60])
add_line(sys,[435,80;445,80])
add_line(sys,[330,80;345,80])
add_line(sys,[220,65;240,65])
add_line(sys,[215,120;220,120;220,80;240,80])
add_line(sys,[215,135;225,135;225,95;240,95])
add_line(sys,[140,130;165,130])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
