function [ret,x0,str,ts,xts]=tddmmask(t,x,u,flag);
%TDDMMASK	is the M-file description of the SIMULINK system named TDDMMASK.
%	The block-diagram can be displayed by typing: TDDMMASK.
%
%	SYS=TDDMMASK(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TDDMMASK to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TDDMMASK with a FLAG of zero:
%	[SIZES]=TDDMMASK([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[297,383,851,510])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;td=.1;M=8;Fc=100/2/pi;');


%     Subsystem  'MASK demod'.

new_system([sys,'/','MASK demod'])
set_param([sys,'/','MASK demod'],'Location',[482,504,899,622])


%     Subsystem  'MASK demod/MASK demap'.

new_system([sys,'/','MASK demod/MASK demap'])
set_param([sys,'/','MASK demod/MASK demap'],'Location',[187,342,628,482])

add_block('built-in/Inport',[sys,'/','MASK demod/MASK demap/in_1'])
set_param([sys,'/','MASK demod/MASK demap/in_1'],...
		'position',[30,35,50,55])

add_block('built-in/S-Function',[sys,'/','MASK demod/MASK demap/Minimum'])
set_param([sys,'/','MASK demod/MASK demap/Minimum'],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[315,45,370,65])

add_block('built-in/Outport',[sys,'/','MASK demod/MASK demap/out_1'])
set_param([sys,'/','MASK demod/MASK demap/out_1'],...
		'position',[400,45,420,65])

add_block('built-in/Abs',[sys,'/','MASK demod/MASK demap/Abs'])
set_param([sys,'/','MASK demod/MASK demap/Abs'],...
		'position',[235,42,270,68])

add_block('built-in/Sum',[sys,'/','MASK demod/MASK demap/Sum2'])
set_param([sys,'/','MASK demod/MASK demap/Sum2'],...
		'inputs','+-',...
		'position',[180,38,200,67])

add_block('built-in/Constant',[sys,'/','MASK demod/MASK demap/Shift key'])
set_param([sys,'/','MASK demod/MASK demap/Shift key'],...
		'Value','sft',...
		'position',[115,93,135,117])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK demod/MASK demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK demod/MASK demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[85,29,120,61])
add_line([sys,'/','MASK demod/MASK demap'],[205,55;230,55])
add_line([sys,'/','MASK demod/MASK demap'],[140,105;155,105;155,60;175,60])
add_line([sys,'/','MASK demod/MASK demap'],[375,55;395,55])
add_line([sys,'/','MASK demod/MASK demap'],[125,45;175,45])
add_line([sys,'/','MASK demod/MASK demap'],[275,55;310,55])
add_line([sys,'/','MASK demod/MASK demap'],[55,45;80,45])
set_param([sys,'/','MASK demod/MASK demap'],...
		'Mask Display','MASK\ndemap',...
		'Mask Type','MASK demap')
set_param([sys,'/','MASK demod/MASK demap'],...
		'Mask Dialogue','Reverse the MASK mapping process\nConvert [-1 1] analog signal to [0, M-1] symbols.|M-ary number (digit integers in ranger [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/','MASK demod/MASK demap'],...
		'Mask Translate','N=@1;Ac=1;sft=[0:N-1]*Ac*2/(N-1)-Ac;td=@2;')
set_param([sys,'/','MASK demod/MASK demap'],...
		'Mask Help','This block demaps a MASK mapped signal back to digit symbols. You can place this block after a amplitude demodulation block. The input of this block is an analog signal in the range [-1, 1]. The demodulation decides the closest integer fitting in [0,M-1] range. When the input symbol interval is a two-elements vector, the second element is offset. The default offset value is 0.')
set_param([sys,'/','MASK demod/MASK demap'],...
		'Mask Entries','M\/td\/')


%     Finished composite block 'MASK demod/MASK demap'.

set_param([sys,'/','MASK demod/MASK demap'],...
		'position',[215,18,295,62])


%     Subsystem  ['MASK demod/DSB-SC-ADM',13,'passband'].

new_system([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],'Location',[588,690,716,690])

add_block('built-in/Outport',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/In-phase',13,'output']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/In-phase',13,'output']],...
		'position',[695,50,715,70])

add_block('built-in/Filter',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Filter1']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Filter',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Filter']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Fcn',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/sin']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Note',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Inport',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/in_1']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Product',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Product']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Fcn',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/sin1']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Product2']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Sum',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Sum1']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Constant',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Carrier',13,'frequency1']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Gain',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Gain1']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Sum',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Sum']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Filter',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Filter2']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Product',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Product1']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Constant',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Carrier',13,'frequency']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])


%     Subsystem  ['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator'].

new_system([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])

add_block('built-in/Inport',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/module']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Unit Delay',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Outport',[sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[410,40;440,40])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator'].

set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[400,60;690,60])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[655,60;645,115])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[315,185;300,185;290,135])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[305,125;290,125])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[360,125;345,125])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[485,225;655,225;645,125])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[155,225;420,225])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[70,55;120,55])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[90,55;90,230;120,230])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[605,120;600,120])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[435,125;430,125])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[155,60;335,60])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[530,120;465,120])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[260,130;215,130])
add_line([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],[240,130;240,180;225,180])
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB ADM',...
		'Mask Type','Passband DSB-SC ADM')
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],...
		'Mask Dialogue','Demodulate a DSB-SC AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],...
		'Mask Help','This block demodulates a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],...
		'Mask Entries','Fc\/num\/den\/Ph\/ts\/')


%     Finished composite block ['MASK demod/DSB-SC-ADM',13,'passband'].

set_param([sys,'/',['MASK demod/DSB-SC-ADM',13,'passband']],...
		'ForeGround',4,...
		'position',[90,18,170,62])

add_block('built-in/Outport',[sys,'/','MASK demod/out_1'])
set_param([sys,'/','MASK demod/out_1'],...
		'position',[360,30,380,50])

add_block('built-in/Inport',[sys,'/','MASK demod/in_1'])
set_param([sys,'/','MASK demod/in_1'],...
		'position',[30,30,50,50])
add_line([sys,'/','MASK demod'],[55,40;85,40])
add_line([sys,'/','MASK demod'],[175,40;210,40])
add_line([sys,'/','MASK demod'],[300,40;355,40])
set_param([sys,'/','MASK demod'],...
		'Mask Display','plot(0,0,100,100,x,y);MASK',...
		'Mask Type','Passband MASK demodulation')
set_param([sys,'/','MASK demod'],...
		'Mask Dialogue','Demodulate a MASK modulated signal.|M-ary number (output integer in range [0, M-1]):|Symbol interval (sec):|Carrier Frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/','MASK demod'],...
		'Mask Translate','M=@1;td=@2;Fc=@3;Ph=@4;ts=@5;[num,den]=butter(5,Fc*2*ts);[x,y]=moduicon(6);')
set_param([sys,'/','MASK demod'],...
		'Mask Help','This block demodulates a MASK modulated signal. The output signals are digits in range [0, M-1]. When the symbol interval is a two element vector, the second element is the offset (default 0). A default lowpass filter is used in the demodulation, which is [num, den]=butter(5, Fc*2*ts). Ungroup this block to specify the numerator and denominator of the lowpass filter.')
set_param([sys,'/','MASK demod'],...
		'Mask Entries','M\/td\/100/2/pi\/0\/ts\/')


%     Finished composite block 'MASK demod'.

set_param([sys,'/','MASK demod'],...
		'hide name',0,...
		'position',[330,53,410,97])


%     Subsystem  ['AWGN',13,'channel'].

new_system([sys,'/',['AWGN',13,'channel']])
set_param([sys,'/',['AWGN',13,'channel']],'Location',[86,493,348,639])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'channel/in_1']])
set_param([sys,'/',['AWGN',13,'channel/in_1']],...
		'position',[45,10,65,30])


%     Subsystem  ['AWGN',13,'channel/Gaussian',13,'noise'].

new_system([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],'Location',[409,168,757,373])

add_block('built-in/White Noise',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[240,95;290,95])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['AWGN',13,'channel/Gaussian',13,'noise'].

set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/out_1']])
set_param([sys,'/',['AWGN',13,'channel/out_1']],...
		'position',[200,55,220,75])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Sum']],...
		'position',[150,55,170,75])
add_line([sys,'/',['AWGN',13,'channel']],[175,65;195,65])
add_line([sys,'/',['AWGN',13,'channel']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['AWGN',13,'channel']],[90,70;145,70])
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);AWGN',...
		'Mask Type','AWGN channel, fixed parameter')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Dialogue','Additive white Gaussian noise channel\nwith fixed mean and variance.|Mean value:|Variance (std^2):|Initial Seed:')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);[x,y]=chanicon;')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Help','This block adds white Gaussian noise to the input signal. The mean and the variance can be a scalar or vector with the same length as the input signal.')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Entries','0\/.000001\/57468\/')


%     Finished composite block ['AWGN',13,'channel'].

set_param([sys,'/',['AWGN',13,'channel']],...
		'hide name',0,...
		'position',[235,53,315,97])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate1'],[40,70;60,70])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[105,65;125,65])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','3\/20\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[440,43,520,87])


%     Subsystem  'MASK mod'.

new_system([sys,'/','MASK mod'])
set_param([sys,'/','MASK mod'],'Location',[652,470,1010,578])


%     Subsystem  ['MASK mod/DSB-SC AM',13,'passband'].

new_system([sys,'/',['MASK mod/DSB-SC AM',13,'passband']])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],'Location',[103,459,555,641])

add_block('built-in/Sum',[sys,'/',['MASK mod/DSB-SC AM',13,'passband/Sum2']])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband/Sum2']],...
		'position',[170,90,190,110])

add_block('built-in/Fcn',[sys,'/',['MASK mod/DSB-SC AM',13,'passband/Fcn']])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Constant',[sys,'/',['MASK mod/DSB-SC AM',13,'passband/Constant1']])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Inport',[sys,'/',['MASK mod/DSB-SC AM',13,'passband/in_1']])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Outport',[sys,'/',['MASK mod/DSB-SC AM',13,'passband/out_1']])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Product',[sys,'/',['MASK mod/DSB-SC AM',13,'passband/Product']])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Clock',[sys,'/',['MASK mod/DSB-SC AM',13,'passband/Clock']])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Gain',[sys,'/',['MASK mod/DSB-SC AM',13,'passband/Gain']])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK mod/DSB-SC AM',13,'passband/Zero-Order',13,'Hold',13,'timing control']])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband/Zero-Order',13,'Hold',13,'timing control']],...
		'Sample time','ts',...
		'position',[50,219,85,251])
add_line([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],[195,100;200,100])
add_line([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],[45,75;65,75])
add_line([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],[370,60;375,60])
add_line([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],[270,100;270,65;335,65])
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB AM',...
		'Mask Type','Passband DSB-SC AM')
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using\nDSB-SC AM method.|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],...
		'Mask Translate','Fc=@1;Fc=Fc*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],...
		'Mask Help','This block modulates the input signal using the double-sideband suppressed-carrier amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],...
		'Mask Entries','Fc\/Ph\/ts\/')


%     Finished composite block ['MASK mod/DSB-SC AM',13,'passband'].

set_param([sys,'/',['MASK mod/DSB-SC AM',13,'passband']],...
		'ForeGround',4,...
		'position',[195,13,275,57])


%     Subsystem  'MASK mod/MASK map1'.

new_system([sys,'/','MASK mod/MASK map1'])
set_param([sys,'/','MASK mod/MASK map1'],'Location',[520,162,902,335])

add_block('built-in/Constant',[sys,'/','MASK mod/MASK map1/Gain diff'])
set_param([sys,'/','MASK mod/MASK map1/Gain diff'],...
		'Value','Ac',...
		'position',[180,96,215,124])

add_block('built-in/Sum',[sys,'/','MASK mod/MASK map1/Sum1'])
set_param([sys,'/','MASK mod/MASK map1/Sum1'],...
		'inputs','+-',...
		'position',[250,63,270,87])

add_block('built-in/Gain',[sys,'/','MASK mod/MASK map1/Gain'])
set_param([sys,'/','MASK mod/MASK map1/Gain'],...
		'Gain','Kc',...
		'position',[180,25,220,55])

add_block('built-in/Inport',[sys,'/','MASK mod/MASK map1/in_1'])
set_param([sys,'/','MASK mod/MASK map1/in_1'],...
		'position',[40,30,60,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK mod/MASK map1/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK mod/MASK map1/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[100,24,135,56])

add_block('built-in/Outport',[sys,'/','MASK mod/MASK map1/out_1'])
set_param([sys,'/','MASK mod/MASK map1/out_1'],...
		'position',[315,65,335,85])
add_line([sys,'/','MASK mod/MASK map1'],[140,40;175,40])
add_line([sys,'/','MASK mod/MASK map1'],[65,40;95,40])
add_line([sys,'/','MASK mod/MASK map1'],[275,75;310,75])
add_line([sys,'/','MASK mod/MASK map1'],[220,110;230,110;230,80;245,80])
add_line([sys,'/','MASK mod/MASK map1'],[225,40;230,40;230,70;245,70])
set_param([sys,'/','MASK mod/MASK map1'],...
		'Mask Display','MASK\nmap',...
		'Mask Type','MASK map')
set_param([sys,'/','MASK mod/MASK map1'],...
		'Mask Dialogue','Map a digital symbol onto an analog\nsignal in the range [-1, 1] using M-ary\namplitude shift keying modulation mapping.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/','MASK mod/MASK map1'],...
		'Mask Translate','N=@1;Ac=1;Kc=Ac*2/(N-1);td=@2;')
set_param([sys,'/','MASK mod/MASK map1'],...
		'Mask Help','This block maps an input digit signal onto a signal in the range [-1, 1]. The coded signal can be modulated using analog\nmodulation blocks. Input digits are in the range [0, M-1], where M is the M-ary number. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/','MASK mod/MASK map1'],...
		'Mask Entries','M\/td\/')


%     Finished composite block 'MASK mod/MASK map1'.

set_param([sys,'/','MASK mod/MASK map1'],...
		'position',[80,13,160,57])

add_block('built-in/Inport',[sys,'/','MASK mod/in_1'])
set_param([sys,'/','MASK mod/in_1'],...
		'position',[30,25,50,45])

add_block('built-in/Outport',[sys,'/','MASK mod/out_1'])
set_param([sys,'/','MASK mod/out_1'],...
		'position',[300,25,320,45])
add_line([sys,'/','MASK mod'],[165,35;190,35])
add_line([sys,'/','MASK mod'],[55,35;75,35])
add_line([sys,'/','MASK mod'],[280,35;295,35])
set_param([sys,'/','MASK mod'],...
		'Mask Display','plot(0,0,100,100,x,y);MASK',...
		'Mask Type','Passband MASK modulation')
set_param([sys,'/','MASK mod'],...
		'Mask Dialogue','Modulate the input digital signal using M-ary amplitude shift keying method.|M-ary number (input integer in range [0, M-1]):|Input symbol interval (sec):|Carrier frequency (Hz):|Carrier initial phase (rad):|Sample time (sec):')
set_param([sys,'/','MASK mod'],...
		'Mask Translate','M=@1;td=@2;Fc=@3;Ph=@4;ts=@5;[x,y]=moduicon(5);')
set_param([sys,'/','MASK mod'],...
		'Mask Help','This block modulates a digital signal using MASK method. The inputs are integers in the range [0, M-1], where M is the M-ary number. When the symbol interval is a two-element vector, the second element is the offset (default 0). The block keeps the input value at the offset time point for the entire interval.')
set_param([sys,'/','MASK mod'],...
		'Mask Entries','M\/td\/100/2/pi\/0\/ts\/')


%     Finished composite block 'MASK mod'.

set_param([sys,'/','MASK mod'],...
		'hide name',0,...
		'position',[135,53,215,97])


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(300,1,M)\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[15,53,95,97])
add_line(sys,[100,75;130,75])
add_line(sys,[111,75;111,35;415,35;415,55;435,55])
add_line(sys,[415,75;435,75])
add_line(sys,[220,75;230,75])
add_line(sys,[320,75;325,75])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
