function [ret,x0,str,ts,xts]=tddmmfsk(t,x,u,flag);
%TDDMMFSK	is the M-file description of the SIMULINK system named TDDMMFSK.
%	The block-diagram can be displayed by typing: TDDMMFSK.
%
%	SYS=TDDMMFSK(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TDDMMFSK to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TDDMMFSK with a FLAG of zero:
%	[SIZES]=TDDMMFSK([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[300,229,1003,459])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;td=.2;M=8;Fc=100/2/pi;');


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','[0:M-1]''\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[45,63,120,107])


%     Subsystem  'MFSK mod'.

new_system([sys,'/','MFSK mod'])
set_param([sys,'/','MFSK mod'],'Location',[624,140,1004,330])


%     Subsystem  ['MFSK mod/FM',13,'passband'].

new_system([sys,'/',['MFSK mod/FM',13,'passband']])
set_param([sys,'/',['MFSK mod/FM',13,'passband']],'Location',[102,348,590,498])

add_block('built-in/Sum',[sys,'/',['MFSK mod/FM',13,'passband/Sum']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/Sum']],...
		'position',[130,42,150,78])

add_block('built-in/S-Function',[sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MFSK mod/FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[200,39,260,81])

add_block('built-in/Constant',[sys,'/',['MFSK mod/FM',13,'passband/Constant']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/Constant']],...
		'Value','Fc',...
		'position',[40,85,60,105])

add_block('built-in/Fcn',[sys,'/',['MFSK mod/FM',13,'passband/sin']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/sin']],...
		'Expr','cos(u[1]*pi2+Ph)',...
		'position',[290,45,430,75])

add_block('built-in/Outport',[sys,'/',['MFSK mod/FM',13,'passband/out_1']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/out_1']],...
		'position',[465,50,485,70])

add_block('built-in/Inport',[sys,'/',['MFSK mod/FM',13,'passband/in_1']])
set_param([sys,'/',['MFSK mod/FM',13,'passband/in_1']],...
		'position',[60,40,80,60])
add_line([sys,'/',['MFSK mod/FM',13,'passband']],[85,50;125,50])
add_line([sys,'/',['MFSK mod/FM',13,'passband']],[65,95;90,95;90,70;125,70])
add_line([sys,'/',['MFSK mod/FM',13,'passband']],[155,60;195,60])
add_line([sys,'/',['MFSK mod/FM',13,'passband']],[265,60;285,60])
add_line([sys,'/',['MFSK mod/FM',13,'passband']],[435,60;460,60])
set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);FM',...
		'Mask Type','Passband FM')
set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using FM method.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):|Symbol interval (sec; Use Inf for analog mod);')
set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2;pi2=2*pi;ts=@3;td=@4;if isinf(td),td=inf;end;[x,y]=moduicon(3);')
set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'Mask Help','This block modulates the input signal using frequency modulation method. The frequency of the output of the carrier signal depends on the amplitude of the input signal.')
set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'Mask Entries','Fc\/Ph\/ts\/td\/')


%     Finished composite block ['MFSK mod/FM',13,'passband'].

set_param([sys,'/',['MFSK mod/FM',13,'passband']],...
		'ForeGround',4,...
		'position',[190,48,270,92])


%     Subsystem  'MFSK mod/MFSK map'.

new_system([sys,'/','MFSK mod/MFSK map'])
set_param([sys,'/','MFSK mod/MFSK map'],'Location',[90,420,407,543])

add_block('built-in/Inport',[sys,'/','MFSK mod/MFSK map/in_1'])
set_param([sys,'/','MFSK mod/MFSK map/in_1'],...
		'position',[45,45,65,65])

add_block('built-in/Gain',[sys,'/','MFSK mod/MFSK map/Gain'])
set_param([sys,'/','MFSK mod/MFSK map/Gain'],...
		'Gain','Ton',...
		'position',[175,38,225,72])

add_block('built-in/Outport',[sys,'/','MFSK mod/MFSK map/out_1'])
set_param([sys,'/','MFSK mod/MFSK map/out_1'],...
		'position',[260,45,280,65])

add_block('built-in/Zero-Order Hold',[sys,'/',['MFSK mod/MFSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MFSK mod/MFSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[105,39,140,71])
add_line([sys,'/','MFSK mod/MFSK map'],[230,55;255,55])
add_line([sys,'/','MFSK mod/MFSK map'],[70,55;100,55])
add_line([sys,'/','MFSK mod/MFSK map'],[145,55;170,55])
set_param([sys,'/','MFSK mod/MFSK map'],...
		'Mask Display','MFSK\nmap',...
		'Mask Type','MFSK map')
set_param([sys,'/','MFSK mod/MFSK map'],...
		'Mask Dialogue','Map input digital signal to analog tone space for FM modulation. The tone space\nis the frequency distance between two \nconsective digit numbers.|Tone space (Hz):|Input symbol interval and offset (sec):')
set_param([sys,'/','MFSK mod/MFSK map'],...
		'Mask Translate','Ton=@1;td=@2;')
set_param([sys,'/','MFSK mod/MFSK map'],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the FM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. Tone space is the frequency separation between two consective digits for the input signal. After FM, the modulated signal has a frequency in the range of [Fc, Fc+B]. B is the bandwidth of the FSK, B=(M-1) * Tone_space.')
set_param([sys,'/','MFSK mod/MFSK map'],...
		'Mask Entries','Ton\/td\/')


%     Finished composite block 'MFSK mod/MFSK map'.

set_param([sys,'/','MFSK mod/MFSK map'],...
		'position',[75,48,155,92])

add_block('built-in/Inport',[sys,'/','MFSK mod/in_1'])
set_param([sys,'/','MFSK mod/in_1'],...
		'position',[15,60,35,80])

add_block('built-in/Outport',[sys,'/','MFSK mod/out_1'])
set_param([sys,'/','MFSK mod/out_1'],...
		'position',[290,60,310,80])
add_line([sys,'/','MFSK mod'],[160,70;185,70])
add_line([sys,'/','MFSK mod'],[275,70;285,70])
add_line([sys,'/','MFSK mod'],[40,70;70,70])
set_param([sys,'/','MFSK mod'],...
		'Mask Display','plot(0,0,100,100,x,y);MFSK',...
		'Mask Type','Passband FSK modulation')
set_param([sys,'/','MFSK mod'],...
		'Mask Dialogue','Modulate the input digital signal using M-ary frequency shift keying method.|Tone space(Hz):|Symbol interval (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample frequency (sec):')
set_param([sys,'/','MFSK mod'],...
		'Mask Translate','Ton=@1;td=@2;Fc=@3;Ph=@4;ts=@5;[x,y]=moduicon(7);')
set_param([sys,'/','MFSK mod'],...
		'Mask Help','This block modulates a digital signal using FSK method. The modulation resets the modulation phase to be the specified initial phase at the beginning of each digit. Tone space is the frequency distance between two consecutive digits after modulation. The output signal has its frequency in the range [Fc, Fc + Tone_space*Max_In_Value], where Fc is the carrier frequency.')
set_param([sys,'/','MFSK mod'],...
		'Mask Entries','M/td/5\/td\/100\/0\/ts\/')


%     Finished composite block 'MFSK mod'.

set_param([sys,'/','MFSK mod'],...
		'hide name',0,...
		'position',[170,63,250,107])


%     Subsystem  ['Coherent',13,'MFSK demod'].

new_system([sys,'/',['Coherent',13,'MFSK demod']])
set_param([sys,'/',['Coherent',13,'MFSK demod']],'Location',[521,150,957,294])


%     Subsystem  ['Coherent',13,'MFSK demod/Min//max index'].

new_system([sys,'/',['Coherent',13,'MFSK demod/Min//max index']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index']],'Location',[192,461,623,564])

add_block('built-in/S-Function',[sys,'/',['Coherent',13,'MFSK demod/Min//max index/Maximum']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index/Maximum']],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])

add_block('built-in/Outport',[sys,'/',['Coherent',13,'MFSK demod/Min//max index/out_1']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index/out_1']],...
		'position',[335,20,355,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Coherent',13,'MFSK demod/Min//max index/Zero-Order',13,'Hold']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Inport',[sys,'/',['Coherent',13,'MFSK demod/Min//max index/in_1']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index/in_1']],...
		'position',[65,20,85,40])
add_line([sys,'/',['Coherent',13,'MFSK demod/Min//max index']],[205,30;235,30])
add_line([sys,'/',['Coherent',13,'MFSK demod/Min//max index']],[325,30;330,30])
add_line([sys,'/',['Coherent',13,'MFSK demod/Min//max index']],[90,30;160,30])
set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index']],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index']],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index']],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index']],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index']],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block ['Coherent',13,'MFSK demod/Min//max index'].

set_param([sys,'/',['Coherent',13,'MFSK demod/Min//max index']],...
		'hide name',0,...
		'position',[225,28,305,72])


%     Subsystem  ['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband'].

new_system([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],'Location',[210,425,800,670])

add_block('built-in/Outport',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/out_1']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/out_1']],...
		'position',[560,55,580,75])

add_block('built-in/Inport',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/in_1']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/in_1']],...
		'position',[365,45,385,65])

add_block('built-in/S-Function',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Array sin']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Array sin']],...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[325,85,375,105])

add_block('built-in/Sum',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Sum1']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Sum1']],...
		'inputs','+++',...
		'position',[265,75,290,115])

add_block('built-in/Product',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Product']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Product']],...
		'position',[415,46,440,79])

add_block('built-in/S-Function',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int1']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[470,44,530,86])

add_block('built-in/S-Function',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int']],...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[140,39,200,81])

add_block('built-in/Constant',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Shift key']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Shift key']],...
		'Value','sft',...
		'position',[60,48,80,72])

add_block('built-in/Constant',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Initial phase']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Initial phase']],...
		'Value','Ph',...
		'position',[80,113,100,137])

add_block('built-in/Zero-Order Hold',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Zero-Order',13,'Hold']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[135,184,170,216])

add_block('built-in/Clock',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Clock']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Clock']],...
		'position',[35,160,55,180])

add_block('built-in/Sum',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Sum2']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Sum2']],...
		'inputs','+-',...
		'position',[205,160,230,195])

add_block('built-in/Gain',[sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Gain']])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband/Gain']],...
		'Gain','Fc',...
		'position',[70,155,110,185])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[535,65;555,65])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[390,55;410,55])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[445,65;465,65])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[295,95;320,95])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[380,95;400,95;410,70])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[85,60;135,60])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[205,60;225,60;225,80;260,80])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[105,125;230,125;230,95;260,95])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[60,170;65,170])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[235,180;250,180;260,110])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[115,170;200,170])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[115,170;130,200])
add_line([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],[175,200;180,200;180,185;200,185])
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],...
		'Mask Display','Coherent\nMFSK dm\ncorr',...
		'Mask Type','Passband coherent MFSK correlation')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],...
		'Mask Dialogue','Compute MFSK correlation. Take MFSK\nmodulated signal. Output a vector of\ncorrelation result.|M-ary number (input in range [0, M-1]):|Tone space (Hz):|Symbol interval and offset (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],...
		'Mask Translate','pi2=2*pi;N=@1;Fc=@4*pi2;Ph=@5;Ton=@2;sft=[0:N-1]*Ton*pi2;td=@3;ts=@6;')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],...
		'Mask Help','This block calculates the coherent correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their frequency the same as that of FM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MFSK demodulation result is the index of the largest output, using the Min/max demap block.')
set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],...
		'Mask Entries','M\/Ton\/td\/Fc\/Ph\/ts\/')


%     Finished composite block ['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband'].

set_param([sys,'/',['Coherent',13,'MFSK demod/Coh MFSK demod',13,'corr passband']],...
		'hide name',0,...
		'position',[100,28,180,72])

add_block('built-in/Outport',[sys,'/',['Coherent',13,'MFSK demod/out_1']])
set_param([sys,'/',['Coherent',13,'MFSK demod/out_1']],...
		'hide name',0,...
		'position',[360,40,380,60])

add_block('built-in/Inport',[sys,'/',['Coherent',13,'MFSK demod/in_1']])
set_param([sys,'/',['Coherent',13,'MFSK demod/in_1']],...
		'hide name',0,...
		'position',[30,40,50,60])
add_line([sys,'/',['Coherent',13,'MFSK demod']],[185,50;220,50])
add_line([sys,'/',['Coherent',13,'MFSK demod']],[55,50;95,50])
add_line([sys,'/',['Coherent',13,'MFSK demod']],[310,50;355,50])
set_param([sys,'/',['Coherent',13,'MFSK demod']],...
		'Mask Display','plot(0,0,100,100,x,y);Cohe MFSK',...
		'Mask Type','Passband MFSK demodulation')
set_param([sys,'/',['Coherent',13,'MFSK demod']],...
		'Mask Dialogue','Demodulate a MFSK modulated signal\nusing coherent demodulation method.|M-ary number (output digits in range [0, M-1]):|Tone space (Hz):|Symbol interval (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Coherent',13,'MFSK demod']],...
		'Mask Translate','M=@1;Fc=@4;Ph=@5;Ton=@2;td=@3;ts=@6;[x,y]=moduicon(8);')
set_param([sys,'/',['Coherent',13,'MFSK demod']],...
		'Mask Help','This block demodulates a MFSK modulated signal using coherent method. The coherent demodulation method is phase sensitive. The tone space is the frequency distance between two consecutive digit after the modulation. The inputs are integers in the range [0, M-1], where M is the M-ary number. When the symbol interval is a two-element vector, the second element is the offset (default 0).')
set_param([sys,'/',['Coherent',13,'MFSK demod']],...
		'Mask Entries','M\/M/td/5\/td\/100\/0\/ts\/')


%     Finished composite block ['Coherent',13,'MFSK demod'].

set_param([sys,'/',['Coherent',13,'MFSK demod']],...
		'hide name',0,...
		'position',[420,63,500,107])


%     Subsystem  ['AWGN',13,'channel'].

new_system([sys,'/',['AWGN',13,'channel']])
set_param([sys,'/',['AWGN',13,'channel']],'Location',[86,493,348,639])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Sum']],...
		'position',[150,55,170,75])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/out_1']])
set_param([sys,'/',['AWGN',13,'channel/out_1']],...
		'position',[200,55,220,75])


%     Subsystem  ['AWGN',13,'channel/Gaussian',13,'noise'].

new_system([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],'Location',[409,168,757,373])

add_block('built-in/State-Space',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['AWGN',13,'channel/Gaussian',13,'noise'].

set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'channel/in_1']])
set_param([sys,'/',['AWGN',13,'channel/in_1']],...
		'position',[45,10,65,30])
add_line([sys,'/',['AWGN',13,'channel']],[90,70;145,70])
add_line([sys,'/',['AWGN',13,'channel']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['AWGN',13,'channel']],[175,65;195,65])
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);AWGN',...
		'Mask Type','AWGN channel, fixed parameter')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Dialogue','Additive white Gaussian noise channel\nwith fixed mean and variance.|Mean value:|Variance (std^2):|Initial Seed:')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);[x,y]=chanicon;')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Help','This block adds white Gaussian noise to the input signal. The mean and the variance can be a scalar or vector with the same length as the input signal.')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Entries','0\/.001\/57468\/')


%     Finished composite block ['AWGN',13,'channel'].

set_param([sys,'/',['AWGN',13,'channel']],...
		'hide name',0,...
		'position',[275,63,355,107])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[545,72,580,123])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate1'],[40,70;60,70])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[105,65;125,65])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','3\/20\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[610,68,690,112])


%     Subsystem  ['Noncoherent',13,'MFSK demod'].

new_system([sys,'/',['Noncoherent',13,'MFSK demod']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod']],'Location',[547,283,1004,466])


%     Subsystem  ['Noncoherent',13,'MFSK demod/Min//max index1'].

new_system([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']],'Location',[192,461,623,564])

add_block('built-in/Inport',[sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1/in_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1/in_1']],...
		'position',[65,20,85,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Outport',[sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1/out_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1/out_1']],...
		'position',[335,20,355,40])

add_block('built-in/S-Function',[sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1/Maximum']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1/Maximum']],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']],[90,30;160,30])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']],[325,30;330,30])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']],[205,30;235,30])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block ['Noncoherent',13,'MFSK demod/Min//max index1'].

set_param([sys,'/',['Noncoherent',13,'MFSK demod/Min//max index1']],...
		'position',[230,68,310,112])


%     Subsystem  ['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband'].

new_system([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],'Location',[10,2228368,850,2228643])

add_block('built-in/Outport',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/out_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/out_1']],...
		'position',[825,85,845,105])

add_block('built-in/Inport',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/in_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/in_1']],...
		'position',[490,75,510,95])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Sum3']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Sum3']],...
		'position',[385,113,405,142])

add_block('built-in/Mux',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Mux']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Mux']],...
		'inputs','[N N]',...
		'position',[425,78,455,122])

add_block('built-in/S-Function',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Array sin']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Array sin']],...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[470,90,520,110])

add_block('built-in/Product',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Product']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Product']],...
		'position',[540,76,565,109])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Initial phase1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Initial phase1']],...
		'Value','Ph',...
		'position',[335,153,355,177])

add_block('built-in/Product',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Product1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Product1']],...
		'position',[675,76,700,109])

add_block('built-in/Demux',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Demux']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Demux']],...
		'outputs','[N N]',...
		'position',[720,75,760,110])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Sum4']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Sum4']],...
		'position',[785,78,805,107])

add_block('built-in/S-Function',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int1']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[580,74,640,116])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Sum2']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Sum2']],...
		'inputs','+-',...
		'position',[265,155,290,190])

add_block('built-in/Clock',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Clock']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Clock']],...
		'position',[95,155,115,175])

add_block('built-in/Gain',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Gain']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Gain']],...
		'Gain','Fc',...
		'position',[145,155,165,175])

add_block('built-in/Zero-Order Hold',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Zero-Order',13,'Hold']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[195,179,230,211])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Initial phase']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Initial phase']],...
		'Value','Ph',...
		'position',[140,108,160,132])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Shift key']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Shift key']],...
		'Value','sft',...
		'position',[120,43,140,67])

add_block('built-in/S-Function',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int']],...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[200,34,260,76])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Sum1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband/Sum1']],...
		'inputs','+++',...
		'position',[325,70,350,110])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[810,95;820,95])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[515,85;535,85])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[765,100;780,100])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[765,85;780,85])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[705,95;715,95])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[645,95;655,95;655,100;670,100])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[645,95;655,95;655,85;670,85])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[570,95;575,95])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[525,100;535,100])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[460,100;465,100])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[410,130;420,110])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[355,90;420,90])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[360,165;370,165;380,135])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[355,90;370,90;380,120])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[235,195;240,195;240,180;260,180])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[170,165;260,165])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[180,165;190,195])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[295,175;310,175;320,105])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[120,165;140,165])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[165,120;290,120;290,90;320,90])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[265,55;285,55;285,75;320,75])
add_line([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],[145,55;195,55])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],...
		'Mask Display','Noncohe\nMFSK dm\ncorr',...
		'Mask Type','Passband non-coherent MFSK correlation')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],...
		'Mask Dialogue','Compute MFSK correlation. Take MFSK\nmodulated signal. Output a vector of\ncorrelation result.|M-ary number (input in range [0, M-1]):|Tone space (Hz):|Symbol interval and offset (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],...
		'Mask Translate','pi2=2*pi;N=@1;Fc=@4*pi2;Ph=@5;Ton=@2;sft=[0:N-1]*Ton*pi2;td=@3;ts=@6;')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],...
		'Mask Help','This block calculates the noncoherent correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their frequency the same as that of FM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MFSK demodulation result is the index of the largest output, using the Min/max demap block.')
set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],...
		'Mask Entries','M\/Ton\/td\/Fc\/Ph\/ts\/')


%     Finished composite block ['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband'].

set_param([sys,'/',['Noncoherent',13,'MFSK demod/Non-coh MFSK dm',13,'corr passband']],...
		'position',[105,68,185,112])

add_block('built-in/Inport',[sys,'/',['Noncoherent',13,'MFSK demod/in_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/in_1']],...
		'position',[25,80,45,100])

add_block('built-in/Outport',[sys,'/',['Noncoherent',13,'MFSK demod/out_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demod/out_1']],...
		'position',[375,80,395,100])
add_line([sys,'/',['Noncoherent',13,'MFSK demod']],[190,90;225,90])
add_line([sys,'/',['Noncoherent',13,'MFSK demod']],[50,90;100,90])
add_line([sys,'/',['Noncoherent',13,'MFSK demod']],[315,90;370,90])
set_param([sys,'/',['Noncoherent',13,'MFSK demod']],...
		'Mask Display','plot(0,0,100,100,x,y);Nonc MFSK',...
		'Mask Type','Passband MPSK demodulation')
set_param([sys,'/',['Noncoherent',13,'MFSK demod']],...
		'Mask Dialogue','Demodulate a MFSK modulated signal using noncoherent method.|M-ary number (output digits in range [0, M-1]):|Tone space (Hz):|Symbol interval (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Noncoherent',13,'MFSK demod']],...
		'Mask Translate','M=@1;Fc=@4;Ph=@5;Ton=@2;td=@3;ts=@6;[x,y]=moduicon(8);')
set_param([sys,'/',['Noncoherent',13,'MFSK demod']],...
		'Mask Help','This block demodulates a MFSK modulated signal using noncoherent method. The tone space is the frequency distance between two consecutive after the modulation. The inputs are integers in the range [0, M-1], where M is the M-ary number. When the symbol interval is a two-element vector, the second element is the offset (default 0).')
set_param([sys,'/',['Noncoherent',13,'MFSK demod']],...
		'Mask Entries','M\/M/td/5\/td\/100\/0\/ts\/')


%     Finished composite block ['Noncoherent',13,'MFSK demod'].

set_param([sys,'/',['Noncoherent',13,'MFSK demod']],...
		'hide name',0,...
		'position',[425,138,505,182])
add_line(sys,[125,85;140,85;140,25;586,25;586,80;605,80])
add_line(sys,[585,100;605,100])
add_line(sys,[140,85;165,85])
add_line(sys,[505,85;540,85])
add_line(sys,[510,160;520,160;520,110;540,110])
add_line(sys,[255,85;270,85])
add_line(sys,[360,85;415,85])
add_line(sys,[385,85;385,160;420,160])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
