function [ret,x0,str,ts,xts]=tddmmpsk(t,x,u,flag);
%TDDMMPSK	is the M-file description of the SIMULINK system named TDDMMPSK.
%	The block-diagram can be displayed by typing: TDDMMPSK.
%
%	SYS=TDDMMPSK(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TDDMMPSK to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TDDMMPSK with a FLAG of zero:
%	[SIZES]=TDDMMPSK([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[56,112,672,269])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;td=.2;M=8;Fc=100/2/pi;');


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(300,1,M)\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[40,63,115,107])


%     Subsystem  'MPSK mod'.

new_system([sys,'/','MPSK mod'])
set_param([sys,'/','MPSK mod'],'Location',[623,420,941,555])


%     Subsystem  'MPSK mod/MPSK map'.

new_system([sys,'/','MPSK mod/MPSK map'])
set_param([sys,'/','MPSK mod/MPSK map'],'Location',[71,474,419,648])

add_block('built-in/Constant',[sys,'/','MPSK mod/MPSK map/Multiple factor'])
set_param([sys,'/','MPSK mod/MPSK map/Multiple factor'],...
		'Value','Sft',...
		'position',[130,108,150,132])

add_block('built-in/Outport',[sys,'/','MPSK mod/MPSK map/out_1'])
set_param([sys,'/','MPSK mod/MPSK map/out_1'],...
		'position',[310,85,330,105])

add_block('built-in/Product',[sys,'/','MPSK mod/MPSK map/Product'])
set_param([sys,'/','MPSK mod/MPSK map/Product'],...
		'position',[235,76,260,109])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK mod/MPSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MPSK mod/MPSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[130,29,165,61])

add_block('built-in/Inport',[sys,'/','MPSK mod/MPSK map/in_1'])
set_param([sys,'/','MPSK mod/MPSK map/in_1'],...
		'position',[60,35,80,55])
add_line([sys,'/','MPSK mod/MPSK map'],[155,120;200,120;200,100;230,100])
add_line([sys,'/','MPSK mod/MPSK map'],[265,95;305,95])
add_line([sys,'/','MPSK mod/MPSK map'],[85,45;125,45])
add_line([sys,'/','MPSK mod/MPSK map'],[170,45;200,45;200,85;230,85])
set_param([sys,'/','MPSK mod/MPSK map'],...
		'Mask Display','MPSK\nmap',...
		'Mask Type','MPSK map')
set_param([sys,'/','MPSK mod/MPSK map'],...
		'Mask Dialogue','Map input digital signal to analog phase shift.|M-ary number (input integer in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/','MPSK mod/MPSK map'],...
		'Mask Translate','pi2=2*pi;Sft=pi2/@1;td=@2;')
set_param([sys,'/','MPSK mod/MPSK map'],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the PM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. You can view the MPSK constellation using the MODMAP function.')
set_param([sys,'/','MPSK mod/MPSK map'],...
		'Mask Entries','M\/td\/')


%     Finished composite block 'MPSK mod/MPSK map'.

set_param([sys,'/','MPSK mod/MPSK map'],...
		'hide name',0,...
		'position',[60,53,140,97])


%     Subsystem  ['MPSK mod/PM',13,'passband'].

new_system([sys,'/',['MPSK mod/PM',13,'passband']])
set_param([sys,'/',['MPSK mod/PM',13,'passband']],'Location',[358,506,869,673])

add_block('built-in/Clock',[sys,'/',['MPSK mod/PM',13,'passband/Clock']])
set_param([sys,'/',['MPSK mod/PM',13,'passband/Clock']],...
		'position',[40,65,60,85])

add_block('built-in/Sum',[sys,'/',['MPSK mod/PM',13,'passband/Sum2']])
set_param([sys,'/',['MPSK mod/PM',13,'passband/Sum2']],...
		'inputs','+-',...
		'position',[220,55,245,90])

add_block('built-in/Outport',[sys,'/',['MPSK mod/PM',13,'passband/out_1']])
set_param([sys,'/',['MPSK mod/PM',13,'passband/out_1']],...
		'position',[445,65,465,85])

add_block('built-in/Inport',[sys,'/',['MPSK mod/PM',13,'passband/in_1']])
set_param([sys,'/',['MPSK mod/PM',13,'passband/in_1']],...
		'position',[150,10,170,30])

add_block('built-in/Fcn',[sys,'/',['MPSK mod/PM',13,'passband/Fcn']])
set_param([sys,'/',['MPSK mod/PM',13,'passband/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[325,60,400,90])

add_block('built-in/Sum',[sys,'/',['MPSK mod/PM',13,'passband/Sum1']])
set_param([sys,'/',['MPSK mod/PM',13,'passband/Sum1']],...
		'inputs','+++',...
		'position',[280,57,300,93])

add_block('built-in/Gain',[sys,'/',['MPSK mod/PM',13,'passband/Gain']])
set_param([sys,'/',['MPSK mod/PM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[80,60,120,90])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK mod/PM',13,'passband/Zero-Order',13,'Hold']])
set_param([sys,'/',['MPSK mod/PM',13,'passband/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[150,94,185,126])

add_block('built-in/Constant',[sys,'/',['MPSK mod/PM',13,'passband/Initial value']])
set_param([sys,'/',['MPSK mod/PM',13,'passband/Initial value']],...
		'Value','Ph',...
		'position',[220,120,240,140])
add_line([sys,'/',['MPSK mod/PM',13,'passband']],[405,75;440,75])
add_line([sys,'/',['MPSK mod/PM',13,'passband']],[245,130;255,130;255,85;275,85])
add_line([sys,'/',['MPSK mod/PM',13,'passband']],[305,75;320,75])
add_line([sys,'/',['MPSK mod/PM',13,'passband']],[175,20;255,20;255,65;275,65])
add_line([sys,'/',['MPSK mod/PM',13,'passband']],[65,75;75,75])
add_line([sys,'/',['MPSK mod/PM',13,'passband']],[250,75;275,75])
add_line([sys,'/',['MPSK mod/PM',13,'passband']],[125,75;165,75;165,65;215,65])
add_line([sys,'/',['MPSK mod/PM',13,'passband']],[190,110;195,110;195,80;215,80])
add_line([sys,'/',['MPSK mod/PM',13,'passband']],[125,75;130,75;130,110;145,110])
set_param([sys,'/',['MPSK mod/PM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);PM',...
		'Mask Type','Passband PM')
set_param([sys,'/',['MPSK mod/PM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using PM method.|Carrier frequency (Hz):|Initial phase (rad):|Symbol interval (sec, Use inf for analog case):')
set_param([sys,'/',['MPSK mod/PM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;td=@3;if isinf(td),td=inf;end;[x,y]=moduicon(3);')
set_param([sys,'/',['MPSK mod/PM',13,'passband']],...
		'Mask Help','The PM block causes the change of the carrier signal depending on the input signal voltage.',...
		'Mask Entries','Fc\/Ph\/td\/')


%     Finished composite block ['MPSK mod/PM',13,'passband'].

set_param([sys,'/',['MPSK mod/PM',13,'passband']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[165,53,245,97])

add_block('built-in/Outport',[sys,'/','MPSK mod/out_1'])
set_param([sys,'/','MPSK mod/out_1'],...
		'hide name',0,...
		'position',[275,65,295,85])

add_block('built-in/Inport',[sys,'/','MPSK mod/in_1'])
set_param([sys,'/','MPSK mod/in_1'],...
		'hide name',0,...
		'position',[10,65,30,85])
add_line([sys,'/','MPSK mod'],[145,75;160,75])
add_line([sys,'/','MPSK mod'],[250,75;270,75])
add_line([sys,'/','MPSK mod'],[35,75;55,75])
set_param([sys,'/','MPSK mod'],...
		'Mask Display','plot(0,0,100,100,x,y);MPSK',...
		'Mask Type','Passband MPSK modulation')
set_param([sys,'/','MPSK mod'],...
		'Mask Dialogue','Modulate the input signal using\nM-ary phase shift keying method.|M-ary number (input integer in range [0, M-1]):|Symbol interval (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample frequency (sec):')
set_param([sys,'/','MPSK mod'],...
		'Mask Translate','M=@1;td=@2;Fc=@3;Ph=@4;ts=@5;[x,y]=moduicon(7);')
set_param([sys,'/','MPSK mod'],...
		'Mask Help','This block modulates a digital signal with a given carrier frequency using MPSK method. The inputs are integers in the range [0, M-1], where M is the M-ary number. When the symbol interval is a two element vector, the second element is the offset (default 0). The block keeps the input value at the offset time point for the entire interval.')
set_param([sys,'/','MPSK mod'],...
		'Mask Entries','M\/td\/Fc\/0\/ts\/')


%     Finished composite block 'MPSK mod'.

set_param([sys,'/','MPSK mod'],...
		'hide name',0,...
		'position',[160,63,240,107])


%     Subsystem  'MPSK demod'.

new_system([sys,'/','MPSK demod'])
set_param([sys,'/','MPSK demod'],'Location',[642,398,976,562])


%     Subsystem  ['MPSK demod/MPSK demod',13,'corr passband'].

new_system([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],'Location',[269,223,837,414])

add_block('built-in/Gain',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Gain']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Gain']],...
		'Gain','Fc',...
		'position',[65,85,105,115])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Zero-Order',13,'Hold']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[125,119,160,151])

add_block('built-in/Clock',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Clock']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Clock']],...
		'position',[15,90,35,110])

add_block('built-in/Sum',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Sum2']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Sum2']],...
		'inputs','+-',...
		'position',[185,90,210,125])

add_block('built-in/Sum',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Sum1']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Sum1']],...
		'inputs','+++',...
		'position',[240,40,265,80])

add_block('built-in/Constant',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Initial phase']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Initial phase']],...
		'Value','Ph',...
		'position',[165,48,185,72])

add_block('built-in/S-Function',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Array sin']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Array sin']],...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[295,50,345,70])

add_block('built-in/Inport',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/in_1']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/in_1']],...
		'position',[305,100,325,120])

add_block('built-in/Product',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Product']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Product']],...
		'position',[385,51,410,84])

add_block('built-in/S-Function',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Scheduled',13,'reset-int1']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Scheduled',13,'reset-int1']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[440,49,500,91])

add_block('built-in/Outport',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/out_1']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/out_1']],...
		'position',[525,60,545,80])

add_block('built-in/Constant',[sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Shift key']])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband/Shift key']],...
		'Value','sft',...
		'position',[115,13,135,37])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[330,110;360,110;360,75;380,75])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[350,60;380,60])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[165,135;165,115;180,115])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[110,100;120,135])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[110,100;180,100])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[215,110;225,110;235,75])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[40,100;60,100])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[190,60;235,60])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[140,25;225,25;235,45])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[270,60;290,60])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[415,70;435,70])
add_line([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],[505,70;520,70])
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],...
		'Mask Display','MPSK\ndm corr',...
		'Mask Type','Passband coherent MPSK correlation')
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],...
		'Mask Dialogue','Compute MPSK correlation. Take MPSK\nmodulated signal. Output a vector of\ncorrelation result.|M-ary number (integer in range [0, M-1]):|Symbol interval and offset (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],...
		'Mask Translate','pi2=2*pi;N=@1;sft=[0:N-1]*pi2/N;td=@2;Fc=@3*pi2;Ph=@4;ts=@5;')
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],...
		'Mask Help','This block calculates the correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their phase shift the same as that of PM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MPSK demodulation result is the index of the largest output, using the Min/max demap block.')
set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],...
		'Mask Entries','M\/td\/Fc\/Ph\/ts\/')


%     Finished composite block ['MPSK demod/MPSK demod',13,'corr passband'].

set_param([sys,'/',['MPSK demod/MPSK demod',13,'corr passband']],...
		'position',[60,53,140,97])


%     Subsystem  'MPSK demod/Min//max index2'.

new_system([sys,'/','MPSK demod/Min//max index2'])
set_param([sys,'/','MPSK demod/Min//max index2'],'Location',[192,461,623,564])

add_block('built-in/S-Function',[sys,'/','MPSK demod/Min//max index2/Maximum'])
set_param([sys,'/','MPSK demod/Min//max index2/Maximum'],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])

add_block('built-in/Outport',[sys,'/','MPSK demod/Min//max index2/out_1'])
set_param([sys,'/','MPSK demod/Min//max index2/out_1'],...
		'position',[335,20,355,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK demod/Min//max index2/Zero-Order',13,'Hold']])
set_param([sys,'/',['MPSK demod/Min//max index2/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Inport',[sys,'/','MPSK demod/Min//max index2/in_1'])
set_param([sys,'/','MPSK demod/Min//max index2/in_1'],...
		'position',[65,20,85,40])
add_line([sys,'/','MPSK demod/Min//max index2'],[205,30;235,30])
add_line([sys,'/','MPSK demod/Min//max index2'],[325,30;330,30])
add_line([sys,'/','MPSK demod/Min//max index2'],[90,30;160,30])
set_param([sys,'/','MPSK demod/Min//max index2'],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/','MPSK demod/Min//max index2'],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/','MPSK demod/Min//max index2'],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/','MPSK demod/Min//max index2'],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/','MPSK demod/Min//max index2'],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block 'MPSK demod/Min//max index2'.

set_param([sys,'/','MPSK demod/Min//max index2'],...
		'position',[185,53,265,97])

add_block('built-in/Inport',[sys,'/','MPSK demod/in_1'])
set_param([sys,'/','MPSK demod/in_1'],...
		'position',[10,65,30,85])

add_block('built-in/Outport',[sys,'/','MPSK demod/out_1'])
set_param([sys,'/','MPSK demod/out_1'],...
		'position',[295,65,315,85])
add_line([sys,'/','MPSK demod'],[145,75;180,75])
add_line([sys,'/','MPSK demod'],[35,75;55,75])
add_line([sys,'/','MPSK demod'],[270,75;290,75])
set_param([sys,'/','MPSK demod'],...
		'Mask Display','plot(0,0,100,100,x,y);MPSK',...
		'Mask Type','Passband MPSK demodulation')
set_param([sys,'/','MPSK demod'],...
		'Mask Dialogue','Demodulate a MPSK modulated signal using correlation method.|M-ary number (output integer in range [0, M-1]):|Symbol interval (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/','MPSK demod'],...
		'Mask Translate','M=@1;Fc=@3;Ph=@4;td=@2;ts=@5;[x,y]=moduicon(8);')
set_param([sys,'/','MPSK demod'],...
		'Mask Help','This block demodulates a MPSK modulated signal using correlation method. The output signals are digits in range [0, M-1], where M is the M-ary number. When the symbol interval is a two-element vector, the second element is the offset (default 0).')
set_param([sys,'/','MPSK demod'],...
		'Mask Entries','M\/td\/Fc\/0\/ts\/')


%     Finished composite block 'MPSK demod'.

set_param([sys,'/','MPSK demod'],...
		'hide name',0,...
		'position',[365,63,445,107])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate1'],[105,65;125,65])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[40,70;60,70])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','ceil(log10(M)/log10(2))\/20\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[485,53,565,97])


%     Subsystem  ['AWGN',13,'channel'].

new_system([sys,'/',['AWGN',13,'channel']])
set_param([sys,'/',['AWGN',13,'channel']],'Location',[86,493,348,639])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'channel/in_1']])
set_param([sys,'/',['AWGN',13,'channel/in_1']],...
		'position',[45,10,65,30])


%     Subsystem  ['AWGN',13,'channel/Gaussian',13,'noise'].

new_system([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],'Location',[409,168,757,373])

add_block('built-in/White Noise',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[240,95;290,95])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['AWGN',13,'channel/Gaussian',13,'noise'].

set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/out_1']])
set_param([sys,'/',['AWGN',13,'channel/out_1']],...
		'position',[200,55,220,75])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Sum']],...
		'position',[150,55,170,75])
add_line([sys,'/',['AWGN',13,'channel']],[175,65;195,65])
add_line([sys,'/',['AWGN',13,'channel']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['AWGN',13,'channel']],[90,70;145,70])
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);AWGN',...
		'Mask Type','AWGN channel, fixed parameter')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Dialogue','Additive white Gaussian noise channel\nwith fixed mean and variance.|Mean value:|Variance (std^2):|Initial Seed:')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);[x,y]=chanicon;')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Help','This block adds white Gaussian noise to the input signal. The mean and the variance can be a scalar or vector with the same length as the input signal.')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Entries','0\/.01\/57468\/')


%     Finished composite block ['AWGN',13,'channel'].

set_param([sys,'/',['AWGN',13,'channel']],...
		'hide name',0,...
		'position',[265,63,345,107])
add_line(sys,[120,85;155,85])
add_line(sys,[450,85;480,85])
add_line(sys,[130,85;130,30;465,30;465,65;480,65])
add_line(sys,[245,85;260,85])
add_line(sys,[350,85;360,85])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
