function [ret,x0,str,ts,xts]=tddps2cd(t,x,u,flag);
%TDDPS2CD	is the M-file description of the SIMULINK system named TDDPS2CD.
%	The block-diagram can be displayed by typing: TDDPS2CD.
%
%	SYS=TDDPS2CD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TDDPS2CD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TDDPS2CD with a FLAG of zero:
%	[SIZES]=TDDPS2CD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[75,42,739,255])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;td=.2;Fc=100/2/pi;NIR=[6 12 18 24 30 38];AIR=[1 1.93 2.88 3.83 4.78 6.05];PIR=zeros(1,6);[num,den]=butter(4,100/pi*ts);M=sum(NIR);');


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(1000,1,sum(NIR))\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[45,43,120,87])


%     Subsystem  ['Circle-map',13,'QASK mod1'].

new_system([sys,'/',['Circle-map',13,'QASK mod1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1']],'Location',[4,416,269,541])


%     Subsystem  ['Circle-map',13,'QASK mod1/QAM',13,'passband1'].

new_system([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],'Location',[302,478,834,743])

add_block('built-in/Clock',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Clock']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Clock']],...
		'position',[80,85,100,105])

add_block('built-in/Gain',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Gain']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Gain']],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Inport',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/in_2']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/in_2']],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Inport',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/in_1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/in_1']],...
		'position',[160,30,180,50])

add_block('built-in/Outport',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/out_1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/out_1']],...
		'position',[490,90,510,110])

add_block('built-in/Sum',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Sum2']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Sum2']],...
		'position',[430,90,450,110])

add_block('built-in/Product',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Product1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Product1']],...
		'position',[355,112,380,143])

add_block('built-in/Product',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Product']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Product']],...
		'position',[355,47,380,78])

add_block('built-in/Note',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[250,305,255,310])

add_block('built-in/Fcn',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Fcn1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Fcn',[sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Fcn']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],[185,95;200,95;200,70;225,70])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],[200,95;200,120;225,120])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],[105,95;125,95])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],[385,130;400,130;400,105;425,105])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],[185,155;330,155;330,135;350,135])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],[330,120;350,120])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],[185,40;335,40;335,55;350,55])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],[330,70;350,70])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],[455,100;485,100])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],...
		'Mask Display','plot(0,0,100,100,x,y);QAM',...
		'Mask Type','Passband DSB-SC QAM')
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],...
		'Mask Dialogue','Modulate the in-phase signal from first input port and quadrature signal from\nthe second port using QAM.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],...
		'Mask Help','This block modulates the in-phase component inputted from the first port and the quadrature component inputted from the second port by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],...
		'Mask Entries','Fc\/Ph\/ts\/')


%     Finished composite block ['Circle-map',13,'QASK mod1/QAM',13,'passband1'].

set_param([sys,'/',['Circle-map',13,'QASK mod1/QAM',13,'passband1']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[160,53,240,97])


%     Subsystem  ['Circle-map',13,'QASK mod1/QASK',13,'circle-map'].

new_system([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],'Location',[58,103,403,268])

add_block('built-in/Zero-Order Hold',[sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])

add_block('built-in/Inport',[sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/in_1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Look Up Table',[sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/real part']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Look Up Table',[sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/imag part1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Outport',[sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/Real']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Outport',[sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/Imag']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],[50,30;75,30])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],[120,30;175,30])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],[145,30;145,110;170,110])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],[220,30;270,30])
add_line([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],[215,110;270,110])
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],...
		'Mask Display','QASK\nC-map',...
		'Mask Type','QASK C-map')
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],...
		'Mask Dialogue','QASK mapping with circle constellation. The constellation is defined in NIC, RIC and PIC.|Number of symbols in each circle NIC:|Radii in each circle RIC:|Phase shift in each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y1=[y1;y1];y1=y1(:);y2=imag(y1);y1=real(y1);x=[-sum(N) 1:sum(N)-1;1:sum(N)-1 10*sum(N)]-.5;x=x(:);')
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The circle constellation is defined in NIC, RIC, and PIC. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],...
		'Mask Entries','NIR\/AIR\/PIR\/td\/')


%     Finished composite block ['Circle-map',13,'QASK mod1/QASK',13,'circle-map'].

set_param([sys,'/',['Circle-map',13,'QASK mod1/QASK',13,'circle-map']],...
		'hide name',0,...
		'position',[50,53,130,97])

add_block('built-in/Inport',[sys,'/',['Circle-map',13,'QASK mod1/in_1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/in_1']],...
		'position',[5,65,20,85])

add_block('built-in/Outport',[sys,'/',['Circle-map',13,'QASK mod1/out_1']])
set_param([sys,'/',['Circle-map',13,'QASK mod1/out_1']],...
		'position',[270,65,290,85])
add_line([sys,'/',['Circle-map',13,'QASK mod1']],[135,65;155,65])
add_line([sys,'/',['Circle-map',13,'QASK mod1']],[25,75;45,75])
add_line([sys,'/',['Circle-map',13,'QASK mod1']],[245,75;265,75])
add_line([sys,'/',['Circle-map',13,'QASK mod1']],[135,85;155,85])
set_param([sys,'/',['Circle-map',13,'QASK mod1']],...
		'Mask Display','plot(0,0,100,100,x,y);C-QASK',...
		'Mask Type','Passband C-QASK modulation')
set_param([sys,'/',['Circle-map',13,'QASK mod1']],...
		'Mask Dialogue','Modulate the input digital signal using quadrature amplitude shift keying method with circle constellation.|Number of symbols on each circle NIC:|Radii for each circle RIC:|Phase shift on each circle PIC (rad):|Symbol interval (sec):|Carrier Frequency (Hz):|Sample time (sec):')
set_param([sys,'/',['Circle-map',13,'QASK mod1']],...
		'Mask Translate','NIR=@1;AIR=@2;PIR=@3;td=@4;Fc=@5;ts=@6;Ph=0;[x,y]=moduicon(5);')
set_param([sys,'/',['Circle-map',13,'QASK mod1']],...
		'Mask Help','This block modulates input digit using QASK modulation method with circle constellation. The vector lengths of NIC, RIC, and PIC should be the same. Use function DMOD to view the constellation of the signal distribution. The default initial phase is zero. To specify the phase information, ungroup this block to assign parameters.')
set_param([sys,'/',['Circle-map',13,'QASK mod1']],...
		'Mask Entries','NIR\/AIR\/PIR\/td\/Fc\/ts\/')


%     Finished composite block ['Circle-map',13,'QASK mod1'].

set_param([sys,'/',['Circle-map',13,'QASK mod1']],...
		'hide name',0,...
		'position',[170,43,250,87])


%     Subsystem  ['Circle-map',13,'QASK demod1'].

new_system([sys,'/',['Circle-map',13,'QASK demod1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1']],'Location',[514,549,825,674])


%     Subsystem  ['Circle-map',13,'QASK demod1/QASK',13,'circle-demap'].

new_system([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],'Location',[96,182,645,417])

add_block('built-in/Zero-Order Hold',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/real']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/imag']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Sum1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Sum6']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Product']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Product1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Sum2']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Minimum1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/out_1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/real_pt']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/imag_pt']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[70,45;115,45])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[70,130;115,130])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[160,45;225,45])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[160,130;225,130])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[395,95;410,95])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],[480,95;490,95])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],...
		'Mask Display','QASK\nC-demap',...
		'Mask Type','QASK C-demap')
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Number of symbols on each circle NIC::|Radii for each circle RIC:|Phase shift on each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y2=imag(y1);y1=real(y1);')
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using circle constellation. You can place this block after a QAM demodulation block. The circle constellation is defined in NIC, RIC, and PIC. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero. ')
set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],...
		'Mask Entries','NIR\/AIR\/PIR\/td\/')


%     Finished composite block ['Circle-map',13,'QASK demod1/QASK',13,'circle-demap'].

set_param([sys,'/',['Circle-map',13,'QASK demod1/QASK',13,'circle-demap']],...
		'hide name',0,...
		'position',[175,53,255,97])


%     Subsystem  ['Circle-map',13,'QASK demod1/QADM',13,'passband3'].

new_system([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],'Location',[194,478,738,741])

add_block('built-in/Clock',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Clock']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Clock']],...
		'position',[60,110,80,130])

add_block('built-in/Gain',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Gain']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Gain']],...
		'Gain','Fc',...
		'position',[110,101,160,139])

add_block('built-in/Filter',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Filter1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,166,445,204])

add_block('built-in/Filter',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Filter']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Gain',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Gain1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Gain1']],...
		'Gain','2',...
		'position',[270,118,295,142])

add_block('built-in/Inport',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/in_1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/in_1']],...
		'position',[230,120,250,140])

add_block('built-in/Note',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Fcn',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Fcn']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[205,55,300,85])

add_block('built-in/Fcn',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Fcn1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[200,175,300,205])

add_block('built-in/Product',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Product']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Product']],...
		'position',[330,62,355,93])

add_block('built-in/Product',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Product1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/Product1']],...
		'position',[330,167,355,198])

add_block('built-in/Outport',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/out_2']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/out_2']],...
		'Port','2',...
		'position',[480,175,500,195])

add_block('built-in/Outport',[sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/out_1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[300,130;305,130;305,175;325,175])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[255,130;265,130])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[165,120;185,120;185,70;200,70])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[185,120;195,190])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[305,70;325,70])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[305,190;325,190])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[360,80;385,80])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[450,80;475,80])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[360,185;385,185])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[450,185;475,185])
add_line([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],[85,120;105,120])
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],...
		'Mask Display','plot(0,0,100,100,x,y);QADM',...
		'Mask Type','Passband DSB-SC QADM')
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],...
		'Mask Dialogue','Demodulate a DSB-SC QAM modulated\nsignal into in-phase and quadrature\ncomponents.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],...
		'Mask Translate','Fc=@1*2*pi;num=@2;den=@3;Ph=@4;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],...
		'Mask Help','This block demodulates the QM-DSB-SC-AM modulated signal. The first output port outputs the in-phase component and the second port outputs the quadrature component. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],...
		'Mask Entries','Fc\/num\/den\/Ph\/ts\/')


%     Finished composite block ['Circle-map',13,'QASK demod1/QADM',13,'passband3'].

set_param([sys,'/',['Circle-map',13,'QASK demod1/QADM',13,'passband3']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[60,53,140,97])

add_block('built-in/Outport',[sys,'/',['Circle-map',13,'QASK demod1/out_1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/out_1']],...
		'hide name',0,...
		'position',[285,65,305,85])

add_block('built-in/Inport',[sys,'/',['Circle-map',13,'QASK demod1/in_1']])
set_param([sys,'/',['Circle-map',13,'QASK demod1/in_1']],...
		'hide name',0,...
		'position',[10,65,30,85])
add_line([sys,'/',['Circle-map',13,'QASK demod1']],[260,75;280,75])
add_line([sys,'/',['Circle-map',13,'QASK demod1']],[35,75;55,75])
add_line([sys,'/',['Circle-map',13,'QASK demod1']],[145,85;170,85])
add_line([sys,'/',['Circle-map',13,'QASK demod1']],[145,65;170,65])
set_param([sys,'/',['Circle-map',13,'QASK demod1']],...
		'Mask Display','plot(0,0,100,100,x,y);C-QASK',...
		'Mask Type','Passband QASK demodulation')
set_param([sys,'/',['Circle-map',13,'QASK demod1']],...
		'Mask Dialogue','Demodulate a QASK modulated signal\nwith circle constellation.|Number of symbols on each circle NIC:|Radii for each circle RIC:|Phase shift on each circle PIC (rad):|Symbol interval (sec):|Carrier frequency (Hz):|Sampling time (sec):')
set_param([sys,'/',['Circle-map',13,'QASK demod1']],...
		'Mask Translate','NIR=@1;AIR=@2;PIR=@3;td=@4;Fc=@5;ts=@6;[num,den]=butter(5,Fc*2*ts);Ph=0;[x,y]=moduicon(6);')
set_param([sys,'/',['Circle-map',13,'QASK demod1']],...
		'Mask Help','This block demodulates a QASK modulated signal with circle constellation. The vector lengths for NIC, RIC, and PIC should be the same. Use function DMOD to view the constellation of the signal distribution. This block uses [num,den]=butter(5,Fc*2*ts) as the default lowpass filter. The default initial phase is zero. To specify non-default parameters, ungroup this block to assign parameters.')
set_param([sys,'/',['Circle-map',13,'QASK demod1']],...
		'Mask Entries','NIR\/AIR\/PIR\/td\/Fc\/ts\/')


%     Finished composite block ['Circle-map',13,'QASK demod1'].

set_param([sys,'/',['Circle-map',13,'QASK demod1']],...
		'hide name',0,...
		'position',[395,58,475,102])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate1'],[40,70;60,70])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[105,65;125,65])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','ceil(log10(sum(NIR))/log10(2))\/20\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[520,48,600,92])


%     Subsystem  ['ASK Mo//Dem',13,'demo1'].

new_system([sys,'/',['ASK Mo//Dem',13,'demo1']])
set_param([sys,'/',['ASK Mo//Dem',13,'demo1']],'Location',[175,552,335,697])
set_param([sys,'/',['ASK Mo//Dem',13,'demo1']],...
		'Mask Display','View\nconstellation',...
		'Mask Dialogue','eval(''modmap(''''qask/cir'''',NIR,AIR,PIR)'')')


%     Finished composite block ['ASK Mo//Dem',13,'demo1'].

set_param([sys,'/',['ASK Mo//Dem',13,'demo1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[520,108,600,152])


%     Subsystem  ['AWGN',13,'w vary para'].

new_system([sys,'/',['AWGN',13,'w vary para']])
set_param([sys,'/',['AWGN',13,'w vary para']],'Location',[122,181,405,317])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'w vary para/in_3']])
set_param([sys,'/',['AWGN',13,'w vary para/in_3']],...
		'Port','3',...
		'position',[20,95,40,115])


%     Subsystem  ['AWGN',13,'w vary para/Gaussian',13,'noise'].

new_system([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],'Location',[482,386,830,557])

add_block('built-in/Product',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Product']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Product']],...
		'position',[240,80,265,100])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/out_1']],...
		'position',[300,80,320,100])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/in_2']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/in_2']],...
		'Port','2',...
		'position',[170,35,190,55])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/in_1']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/in_1']],...
		'position',[55,35,75,55])

add_block('built-in/White Noise',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[40,82,85,118])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])
add_line([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],[195,45;210,45;210,85;235,85])
add_line([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],[165,95;235,95])
add_line([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],[270,90;295,90])
add_line([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],[90,100;135,100])
add_line([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],[80,45;110,45;110,90;135,90])
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Initial Seed(s):',...
		'Mask Translate','s=@1;')
set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],...
		'Mask Help','The meanvalue is determined by value from the frist input. The standard deviation is determined by the second input. ',...
		'Mask Entries','s\/')


%     Finished composite block ['AWGN',13,'w vary para/Gaussian',13,'noise'].

set_param([sys,'/',['AWGN',13,'w vary para/Gaussian',13,'noise']],...
		'position',[75,50,150,90])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'w vary para/in_2']])
set_param([sys,'/',['AWGN',13,'w vary para/in_2']],...
		'Port','2',...
		'position',[10,50,30,70])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'w vary para/in_1']])
set_param([sys,'/',['AWGN',13,'w vary para/in_1']],...
		'position',[100,15,120,35])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'w vary para/out_1']])
set_param([sys,'/',['AWGN',13,'w vary para/out_1']],...
		'position',[245,55,265,75])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'w vary para/Sum']])
set_param([sys,'/',['AWGN',13,'w vary para/Sum']],...
		'position',[195,55,215,75])
add_line([sys,'/',['AWGN',13,'w vary para']],[45,105;55,105;55,80;70,80])
add_line([sys,'/',['AWGN',13,'w vary para']],[35,60;70,60])
add_line([sys,'/',['AWGN',13,'w vary para']],[155,70;190,70])
add_line([sys,'/',['AWGN',13,'w vary para']],[125,25;160,25;160,60;190,60])
add_line([sys,'/',['AWGN',13,'w vary para']],[220,65;240,65])
set_param([sys,'/',['AWGN',13,'w vary para']],...
		'Mask Display','plot(0,0,100,100,x,y);AWGN',...
		'Mask Type','AWGN channel, vary parameter')
set_param([sys,'/',['AWGN',13,'w vary para']],...
		'Mask Dialogue','AWGN channel with varying mean (2nd\nport) and standard deviation (3rd port) as input. Seed vector size is the block output size.|Initial seed:')
set_param([sys,'/',['AWGN',13,'w vary para']],...
		'Mask Translate','s=@1;[x,y]=chanicon;')
set_param([sys,'/',['AWGN',13,'w vary para']],...
		'Mask Help','This block adds white Gaussian noise to the input signal. When the mean value and/or the seed is a vector, a vector noise is added to the input vector signal. The mean value and the standard deviation are inputted from the second port and the third port respectively. The mean and std input can be scalars or vectors with the same length as the input signal.')
set_param([sys,'/',['AWGN',13,'w vary para']],...
		'Mask Entries','123456\/')


%     Finished composite block ['AWGN',13,'w vary para'].

set_param([sys,'/',['AWGN',13,'w vary para']],...
		'hide name',0,...
		'position',[290,58,365,102])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'hide name',0,...
		'Peak','0.010000',...
		'Peak Range','5.000000',...
		'Freq','1.000000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator']],...
		'position',[160,98,205,132])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator1']])
set_param([sys,'/',['Signal',13,'generator1']],...
		'hide name',0,...
		'Peak','0.400000',...
		'Peak Range','5.000000',...
		'Freq','0.200000',...
		'Freq Range','5.000000',...
		'Wave','Saw',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator1']],...
		'position',[160,138,205,172])

add_block('built-in/Saturation',[sys,'/','Saturation'])
set_param([sys,'/','Saturation'],...
		'Lower Limit','0',...
		'Upper Limit','20',...
		'position',[230,145,255,165])
add_line(sys,[125,65;165,65])
add_line(sys,[140,65;140,25;485,25;485,60;515,60])
add_line(sys,[480,80;515,80])
add_line(sys,[255,65;285,65])
add_line(sys,[370,80;390,80])
add_line(sys,[210,115;255,115;255,80;285,80])
add_line(sys,[210,155;225,155])
add_line(sys,[260,155;265,155;265,95;285,95])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
