function [ret,x0,str,ts,xts]=test_fm2(t,x,u,flag);
%TEST_FM2	is the M-file description of the SIMULINK system named TEST_FM2.
%	The block-diagram can be displayed by typing: TEST_FM2.
%
%	SYS=TEST_FM2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TEST_FM2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TEST_FM2 with a FLAG of zero:
%	[SIZES]=TEST_FM2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[465,332,989,549])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;[num,den]=butter(2,100/pi/2*ts);');

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'ForeGround',5,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','3.000000',...
		'Freq Range','6.000000',...
		'Wave','Saw',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator']],...
		'position',[30,43,75,77])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[385,35,420,85])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','4\/-1.5\/1.5\/''y-/g--/r-/m:/w-/r:/b+''\/ts\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'hide name',0,...
		'position',[450,41,480,79])


%     Subsystem  ['FM',13,'passband'].

new_system([sys,'/',['FM',13,'passband']])
set_param([sys,'/',['FM',13,'passband']],'Location',[451,587,939,737])

add_block('built-in/Sum',[sys,'/',['FM',13,'passband/Sum']])
set_param([sys,'/',['FM',13,'passband/Sum']],...
		'position',[130,42,150,78])

add_block('built-in/S-Function',[sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']])
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['FM',13,'passband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf/2\/',...
		'position',[200,39,260,81])

add_block('built-in/Constant',[sys,'/',['FM',13,'passband/Constant']])
set_param([sys,'/',['FM',13,'passband/Constant']],...
		'Value','Fc',...
		'position',[40,85,60,105])

add_block('built-in/Fcn',[sys,'/',['FM',13,'passband/sin']])
set_param([sys,'/',['FM',13,'passband/sin']],...
		'Expr','cos(u[1]*pi2+Ph)',...
		'position',[290,45,430,75])

add_block('built-in/Outport',[sys,'/',['FM',13,'passband/out_1']])
set_param([sys,'/',['FM',13,'passband/out_1']],...
		'position',[465,50,485,70])

add_block('built-in/Inport',[sys,'/',['FM',13,'passband/in_1']])
set_param([sys,'/',['FM',13,'passband/in_1']],...
		'position',[60,40,80,60])
add_line([sys,'/',['FM',13,'passband']],[85,50;125,50])
add_line([sys,'/',['FM',13,'passband']],[65,95;90,95;90,70;125,70])
add_line([sys,'/',['FM',13,'passband']],[155,60;195,60])
add_line([sys,'/',['FM',13,'passband']],[265,60;285,60])
add_line([sys,'/',['FM',13,'passband']],[435,60;460,60])
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);FM',...
		'Mask Type','Passband FM')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using FM method.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):|Symbol interval (sec; Use Inf for analog mod);')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2;pi2=2*pi;ts=@3;td=@4;if isinf(td),td=inf;end;[x,y]=moduicon(3);')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Help','This block modulates the input signal using frequency modulation method. The frequency of the output of the carrier signal depends on the amplitude of the input signal.')
set_param([sys,'/',['FM',13,'passband']],...
		'Mask Entries','100/2/pi\/pi/4\/ts\/Inf\/')


%     Finished composite block ['FM',13,'passband'].

set_param([sys,'/',['FM',13,'passband']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[135,38,215,82])


%     Subsystem  ['FDM',13,'passband'].

new_system([sys,'/',['FDM',13,'passband']])
set_param([sys,'/',['FDM',13,'passband']],'Location',[30,490,489,666])

add_block('built-in/Inport',[sys,'/',['FDM',13,'passband/in_1']])
set_param([sys,'/',['FDM',13,'passband/in_1']],...
		'position',[25,30,45,50])

add_block('built-in/Outport',[sys,'/',['FDM',13,'passband/out_1']])
set_param([sys,'/',['FDM',13,'passband/out_1']],...
		'position',[420,35,440,55])


%     Subsystem  ['FDM',13,'passband/Discrete-time',13,'VCO'].

new_system([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],'Location',[93,129,873,276])

add_block('built-in/Inport',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/in_1']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/in_1']],...
		'position',[35,20,55,40])

add_block('built-in/Unit Delay',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Unit Delay']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Unit Delay']],...
		'Sample time','ts',...
		'position',[300,25,350,45])

add_block('built-in/Sum',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum1']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum1']],...
		'position',[230,25,250,45])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[105,15,155,45])

add_block('built-in/Clock',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Clock']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Clock']],...
		'position',[180,80,200,100])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity2']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity2']],...
		'Gain','Fc',...
		'position',[255,75,300,105])

add_block('built-in/Sum',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sum']],...
		'inputs','+++',...
		'position',[465,27,485,63])

add_block('built-in/Constant',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Phase']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Phase']],...
		'Value','Ph',...
		'position',[400,100,420,120])

add_block('built-in/Fcn',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/sin']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/sin']],...
		'Expr','cos(u[1])',...
		'position',[510,32,585,58])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity3']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/Sensitivity3']],...
		'Gain','Ac',...
		'position',[605,30,655,60])

add_block('built-in/Outport',[sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/out_1']])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO/out_1']],...
		'position',[690,35,710,55])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[60,30;100,30])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[160,30;225,30])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[255,35;295,35])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[490,45;505,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[205,90;250,90])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[305,90;425,90;425,45;460,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[355,35;460,35])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[370,35;370,70;205,70;205,40;225,40])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[425,110;435,110;435,55;460,55])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[590,45;600,45])
add_line([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],[660,45;685,45])
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Display','Discrete\nVCO',...
		'Mask Type','VCO')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Dialogue','Voltage-Controlled Oscilator:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;ts=@5;Kc=Kc*pi2*ts(1);Fc=Fc*pi2;')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Help','The VCO block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Entries','1\/Fc\/1\/Ph\/ts\/')


%     Finished composite block ['FDM',13,'passband/Discrete-time',13,'VCO'].

set_param([sys,'/',['FDM',13,'passband/Discrete-time',13,'VCO']],...
		'orientation',2,...
		'position',[240,95,300,135])

add_block('built-in/Filter',[sys,'/',['FDM',13,'passband/Filter']])
set_param([sys,'/',['FDM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[275,26,330,64])

add_block('built-in/Product',[sys,'/',['FDM',13,'passband/Multiplier',13,'phase detector']])
set_param([sys,'/',['FDM',13,'passband/Multiplier',13,'phase detector']],...
		'position',[190,35,215,55])

add_block('built-in/Gain',[sys,'/',['FDM',13,'passband/Sensitivity']])
set_param([sys,'/',['FDM',13,'passband/Sensitivity']],...
		'Gain','2',...
		'position',[75,25,115,55])
add_line([sys,'/',['FDM',13,'passband']],[120,40;185,40])
add_line([sys,'/',['FDM',13,'passband']],[50,40;70,40])
add_line([sys,'/',['FDM',13,'passband']],[335,45;415,45])
add_line([sys,'/',['FDM',13,'passband']],[385,45;385,115;305,115])
add_line([sys,'/',['FDM',13,'passband']],[220,45;270,45])
add_line([sys,'/',['FDM',13,'passband']],[235,115;135,115;135,50;185,50])
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);FDM',...
		'Mask Type','Passabnd FDM')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Dialogue','Demodulate an FM modulated signal\nusing phase-locked loop.|VCO frequency (Hz):|VCO initial phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2+pi/2;num=@3;den=@4;ts=@5;[x,y]=moduicon(4);')
set_param([sys,'/',['FDM',13,'passband']],...
		'Mask Help','This block recovers a FM modulated signal using a phase-locked loop method. The phase detector used in this block is a multiplier.',...
		'Mask Entries','100/2/pi\/pi/4\/num\/den\/ts\/')


%     Finished composite block ['FDM',13,'passband'].

set_param([sys,'/',['FDM',13,'passband']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[250,38,330,82])


%     Subsystem  ['FM',13,'baseband2'].

new_system([sys,'/',['FM',13,'baseband2']])
set_param([sys,'/',['FM',13,'baseband2']],'Location',[55,571,668,718])

add_block('built-in/Constant',[sys,'/',['FM',13,'baseband2/Constant']])
set_param([sys,'/',['FM',13,'baseband2/Constant']],...
		'Value','Ph',...
		'position',[180,90,205,110])

add_block('built-in/Sum',[sys,'/',['FM',13,'baseband2/Sum']])
set_param([sys,'/',['FM',13,'baseband2/Sum']],...
		'position',[265,30,285,50])

add_block('built-in/Inport',[sys,'/',['FM',13,'baseband2/in_1']])
set_param([sys,'/',['FM',13,'baseband2/in_1']],...
		'position',[35,25,55,45])

add_block('built-in/Fcn',[sys,'/',['FM',13,'baseband2/cos']])
set_param([sys,'/',['FM',13,'baseband2/cos']],...
		'Expr','cos(u)',...
		'position',[330,26,385,54])

add_block('built-in/Fcn',[sys,'/',['FM',13,'baseband2/sin']])
set_param([sys,'/',['FM',13,'baseband2/sin']],...
		'Expr','sin(u)',...
		'position',[330,86,385,114])

add_block('built-in/Mux',[sys,'/',['FM',13,'baseband2/Mux']])
set_param([sys,'/',['FM',13,'baseband2/Mux']],...
		'inputs','2',...
		'position',[415,31,450,64])

add_block('built-in/Outport',[sys,'/',['FM',13,'baseband2/out_1']])
set_param([sys,'/',['FM',13,'baseband2/out_1']],...
		'position',[550,40,570,60])

add_block('built-in/S-Function',[sys,'/',['FM',13,'baseband2/Scheduled',13,'reset-int']])
set_param([sys,'/',['FM',13,'baseband2/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['FM',13,'baseband2/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['FM',13,'baseband2/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['FM',13,'baseband2/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['FM',13,'baseband2/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/pi2\/',...
		'position',[155,14,215,56])

add_block('built-in/Gain',[sys,'/',['FM',13,'baseband2/Sensitivity']])
set_param([sys,'/',['FM',13,'baseband2/Sensitivity']],...
		'Gain','pi2',...
		'position',[80,20,120,50])
add_line([sys,'/',['FM',13,'baseband2']],[290,40;325,40])
add_line([sys,'/',['FM',13,'baseband2']],[300,40;300,100;325,100])
add_line([sys,'/',['FM',13,'baseband2']],[210,100;250,100;260,45])
add_line([sys,'/',['FM',13,'baseband2']],[220,35;260,35])
add_line([sys,'/',['FM',13,'baseband2']],[390,40;410,40])
add_line([sys,'/',['FM',13,'baseband2']],[455,50;545,50])
add_line([sys,'/',['FM',13,'baseband2']],[390,100;395,100;395,55;410,55])
add_line([sys,'/',['FM',13,'baseband2']],[60,35;75,35])
add_line([sys,'/',['FM',13,'baseband2']],[125,35;150,35])
set_param([sys,'/',['FM',13,'baseband2']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);FM',...
		'Mask Type','FM CE')
set_param([sys,'/',['FM',13,'baseband2']],...
		'Mask Dialogue','Output the complex envelope of the FM signal.|Initial phase (rad):|Sample time (second):|Symbol interval (for digital mod, use Inf for analog mod):')
set_param([sys,'/',['FM',13,'baseband2']],...
		'Mask Translate','Kc=2*pi;Ph=@1;pi2=2*pi;ts=@2;td=@3;if isinf(td),td=inf;end;[x,y]=moduicon(3);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['FM',13,'baseband2']],...
		'Mask Help','This block outputs the complex envelope of the frequency modulated signal. The output is a complex signal. This block resets the phase at the very beginning of the symbol interval. For continuous-time simulation, the symbol interval can be set as infinity.')
set_param([sys,'/',['FM',13,'baseband2']],...
		'Mask Entries','0\/ts\/Inf\/')


%     Finished composite block ['FM',13,'baseband2'].

set_param([sys,'/',['FM',13,'baseband2']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[130,118,210,162])


%     Subsystem  ['FDM',13,'baseband2'].

new_system([sys,'/',['FDM',13,'baseband2']])
set_param([sys,'/',['FDM',13,'baseband2']],'Location',[240,174,805,409])


%     Subsystem  ['FDM',13,'baseband2/M//P 2 C'].

new_system([sys,'/',['FDM',13,'baseband2/M//P 2 C']])
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C']],'Location',[103,336,548,644])

add_block('built-in/Mux',[sys,'/',['FDM',13,'baseband2/M//P 2 C/Mux']])
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/Mux']],...
		'inputs','2',...
		'position',[225,111,270,149])

add_block('built-in/S-Function',[sys,'/',['FDM',13,'baseband2/M//P 2 C/Array',13,'function1']])
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/Array',13,'function1']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/Array',13,'function1']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10,sgn.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/Array',13,'function1']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sin''\/',...
		'position',[85,149,140,181])

add_block('built-in/S-Function',[sys,'/',['FDM',13,'baseband2/M//P 2 C/Array',13,'function']])
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/Array',13,'function']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/Array',13,'function']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10,sgn.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/Array',13,'function']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''cos''\/',...
		'position',[85,74,145,106])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband2/M//P 2 C/in_2']])
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/in_2']],...
		'Port','2',...
		'position',[15,155,35,175])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband2/M//P 2 C/in_1']])
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/in_1']],...
		'position',[235,50,255,70])

add_block('built-in/Product',[sys,'/',['FDM',13,'baseband2/M//P 2 C/Product']])
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/Product']],...
		'position',[320,107,345,138])

add_block('built-in/Outport',[sys,'/',['FDM',13,'baseband2/M//P 2 C/out_1']])
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C/out_1']],...
		'position',[380,115,400,135])
add_line([sys,'/',['FDM',13,'baseband2/M//P 2 C']],[150,90;170,90;170,120;220,120])
add_line([sys,'/',['FDM',13,'baseband2/M//P 2 C']],[145,165;170,165;170,140;220,140])
add_line([sys,'/',['FDM',13,'baseband2/M//P 2 C']],[40,165;80,165])
add_line([sys,'/',['FDM',13,'baseband2/M//P 2 C']],[55,165;55,90;80,90])
add_line([sys,'/',['FDM',13,'baseband2/M//P 2 C']],[275,130;315,130])
add_line([sys,'/',['FDM',13,'baseband2/M//P 2 C']],[350,125;375,125])
add_line([sys,'/',['FDM',13,'baseband2/M//P 2 C']],[260,60;280,60;280,115;315,115])
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C']],...
		'Mask Display','Mag/Phase\nto Cmplx',...
		'Mask Type','Mag/Phase to Complex number',...
		'Mask Dialogue','Convert Magnitude/Phase information to complex number.')
set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C']],...
		'Mask Help','This block conver Magnitude/Phase to complex number which is real/imag two part.')


%     Finished composite block ['FDM',13,'baseband2/M//P 2 C'].

set_param([sys,'/',['FDM',13,'baseband2/M//P 2 C']],...
		'orientation',2,...
		'position',[115,135,205,175])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband2/in_1']])
set_param([sys,'/',['FDM',13,'baseband2/in_1']],...
		'position',[45,25,65,45])

add_block('built-in/Sum',[sys,'/',['FDM',13,'baseband2/Sum']])
set_param([sys,'/',['FDM',13,'baseband2/Sum']],...
		'orientation',2,...
		'position',[245,155,265,175])

add_block('built-in/Constant',[sys,'/',['FDM',13,'baseband2/Constant']])
set_param([sys,'/',['FDM',13,'baseband2/Constant']],...
		'orientation',2,...
		'position',[290,85,320,105])


%     Subsystem  ['FDM',13,'baseband2/Multiply and',13,'take imag'].

new_system([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']])
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],'Location',[317,81,820,296])

add_block('built-in/Outport',[sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/I_out_']])
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/I_out_']],...
		'position',[450,105,470,125])

add_block('built-in/Sum',[sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Sum1']])
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Sum1']],...
		'position',[390,105,410,125])

add_block('built-in/Product',[sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Product2']])
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Product2']],...
		'position',[220,108,250,132])

add_block('built-in/Product',[sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Product3']])
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Product3']],...
		'position',[310,63,340,87])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Complex',13,'input 2']])
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Complex',13,'input 2']],...
		'Port','2',...
		'position',[30,150,50,170])

add_block('built-in/Demux',[sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Split1']])
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Split1']],...
		'position',[85,139,160,181])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Complex',13,'input 1']])
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Complex',13,'input 1']],...
		'position',[40,35,60,55])

add_block('built-in/Demux',[sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Split']])
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag/Split']],...
		'position',[90,24,165,66])
add_line([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],[415,115;445,115])
add_line([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],[65,45;85,45])
add_line([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],[55,160;80,160])
add_line([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],[170,35;248,35;248,70;305,70])
add_line([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],[165,170;290,170;290,80;305,80])
add_line([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],[170,55;185,55;185,115;215,115])
add_line([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],[165,150;180,150;180,125;215,125])
add_line([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],[345,75;360,75;360,110;385,110])
add_line([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],[255,120;385,120])


%     Finished composite block ['FDM',13,'baseband2/Multiply and',13,'take imag'].

set_param([sys,'/',['FDM',13,'baseband2/Multiply and',13,'take imag']],...
		'position',[125,24,200,66])

add_block('built-in/Filter',[sys,'/',['FDM',13,'baseband2/Filter']])
set_param([sys,'/',['FDM',13,'baseband2/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,26,310,64])

add_block('built-in/Constant',[sys,'/',['FDM',13,'baseband2/Constant1']])
set_param([sys,'/',['FDM',13,'baseband2/Constant1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[405,205,435,225])


%     Subsystem  ['FDM',13,'baseband2/Dis module',13,'integrator'].

new_system([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']])
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],'Location',[18,602,524,728])

add_block('built-in/Sum',[sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/module']])
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,350,61])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[75,16,135,54])

add_block('built-in/Unit Delay',[sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[370,35,420,55])

add_block('built-in/Outport',[sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator/out_1']],...
		'position',[460,35,480,55])
add_line([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],[220,40;230,45])
add_line([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],[40,35;70,35])
add_line([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],[355,45;365,45])
add_line([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],[425,45;435,45;435,95;175,95;175,45;190,45])
add_line([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],[425,45;455,45])
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],...
		'Mask Entries','pi2\/0\/ts\/')


%     Finished composite block ['FDM',13,'baseband2/Dis module',13,'integrator'].

set_param([sys,'/',['FDM',13,'baseband2/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[315,140,375,180])

add_block('built-in/Gain',[sys,'/',['FDM',13,'baseband2/Sensitivity']])
set_param([sys,'/',['FDM',13,'baseband2/Sensitivity']],...
		'orientation',1,...
		'Gain','-pi2',...
		'position',[390,90,430,120])

add_block('built-in/Outport',[sys,'/',['FDM',13,'baseband2/out_1']])
set_param([sys,'/',['FDM',13,'baseband2/out_1']],...
		'position',[445,10,465,30])
add_line([sys,'/',['FDM',13,'baseband2']],[400,215;295,215;295,170;270,170])
add_line([sys,'/',['FDM',13,'baseband2']],[410,125;410,160;380,160])
add_line([sys,'/',['FDM',13,'baseband2']],[70,35;120,35])
add_line([sys,'/',['FDM',13,'baseband2']],[285,95;255,95;255,145;210,145])
add_line([sys,'/',['FDM',13,'baseband2']],[240,165;210,165])
add_line([sys,'/',['FDM',13,'baseband2']],[310,160;270,160])
add_line([sys,'/',['FDM',13,'baseband2']],[110,155;85,155;85,55;120,55])
add_line([sys,'/',['FDM',13,'baseband2']],[205,45;250,45])
add_line([sys,'/',['FDM',13,'baseband2']],[315,45;325,45;325,20;440,20])
add_line([sys,'/',['FDM',13,'baseband2']],[315,45;410,45;410,85])
set_param([sys,'/',['FDM',13,'baseband2']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);FDM',...
		'Mask Type','FDM CE using PLL')
set_param([sys,'/',['FDM',13,'baseband2']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nFM signal.|VCO initial phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['FDM',13,'baseband2']],...
		'Mask Translate','Ph=@1;num=@2;den=@3;ts=@4;pi2=2*pi;[x,y]=moduicon(4);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['FDM',13,'baseband2']],...
		'Mask Help','This block demodulates the complex envelope of a frequency modulated signal. The filter to be specified by the users is a lowpass filter which passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['FDM',13,'baseband2']],...
		'Mask Entries','0\/num\/den\/ts\/')


%     Finished composite block ['FDM',13,'baseband2'].

set_param([sys,'/',['FDM',13,'baseband2']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[245,118,325,162])

add_block('built-in/Note',[sys,'/','Defaults in this simulation: ts=0.01; [num,den]=butter(2,Fc*2*ts);'])
set_param([sys,'/','Defaults in this simulation: ts=0.01; [num,den]=butter(2,Fc*2*ts);'],...
		'position',[230,185,235,190])
add_line(sys,[425,60;445,60])
add_line(sys,[80,60;100,60;100,20;360,20;360,45;380,45])
add_line(sys,[335,60;380,60])
add_line(sys,[220,60;245,60])
add_line(sys,[100,60;130,60])
add_line(sys,[215,140;240,140])
add_line(sys,[100,60;100,140;125,140])
add_line(sys,[330,140;350,140;350,75;380,75])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
