function [ret,x0,str,ts,xts]=test_pm2(t,x,u,flag);
%TEST_PM2	is the M-file description of the SIMULINK system named TEST_PM2.
%	The block-diagram can be displayed by typing: TEST_PM2.
%
%	SYS=TEST_PM2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TEST_PM2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TEST_PM2 with a FLAG of zero:
%	[SIZES]=TEST_PM2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[441,472,963,679])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;[num,den]=butter(2,100/pi/2*ts);');

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[385,35,420,85])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','4\/-1.5\/1.5\/''y-/g--/r-/m:/w-/r:/b+''\/ts\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'position',[450,41,480,79])


%     Subsystem  ['PDM',13,'passband'].

new_system([sys,'/',['PDM',13,'passband']])
set_param([sys,'/',['PDM',13,'passband']],'Location',[232,541,802,708])

add_block('built-in/Gain',[sys,'/',['PDM',13,'passband/Sensitivity1']])
set_param([sys,'/',['PDM',13,'passband/Sensitivity1']],...
		'Gain','2',...
		'position',[70,25,110,55])

add_block('built-in/Filter',[sys,'/',['PDM',13,'passband/Filter']])
set_param([sys,'/',['PDM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[235,26,290,64])

add_block('built-in/Product',[sys,'/',['PDM',13,'passband/Multiplier',13,'phase detector']])
set_param([sys,'/',['PDM',13,'passband/Multiplier',13,'phase detector']],...
		'position',[155,35,180,55])


%     Subsystem  ['PDM',13,'passband/Discrete-time',13,'VCO'].

new_system([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],'Location',[4,58,511,205])

add_block('built-in/Sum',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Sum']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Sum']],...
		'position',[155,30,175,50])


%     Subsystem  ['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator'].

new_system([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],'Location',[402,373,908,481])

add_block('built-in/Gain',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Sensitivity']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Sensitivity']],...
		'Gain','ts(1)',...
		'position',[80,16,135,54])

add_block('built-in/Unit Delay',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Inport',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/module']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator/out_1']],...
		'position',[430,30,450,50])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[400,40;425,40])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[40,35;75,35])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],[220,40;230,40])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'Mask Entries','pi*100\/0\/ts\/')


%     Finished composite block ['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator'].

set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Dis module',13,'integrator']],...
		'position',[200,21,260,59])

add_block('built-in/Gain',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Sensitivity']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Sensitivity']],...
		'Gain','Kc*pi2',...
		'position',[60,14,135,56])

add_block('built-in/Inport',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/in_1']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/sin']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/sin']],...
		'Expr','Ac*cos(u[1]+Ph)',...
		'position',[285,25,410,55])

add_block('built-in/Constant',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Carrier',13,'frequency']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/Carrier',13,'frequency']],...
		'Value','Fc*pi2',...
		'position',[60,85,115,105])

add_block('built-in/Outport',[sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/out_1']])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO/out_1']],...
		'position',[425,30,445,50])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[140,35;150,35])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[180,40;195,40])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[265,40;280,40])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[120,95;125,95;125,45;150,45])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[40,35;55,35])
add_line([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],[415,40;420,40])
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Display','Discrete\nVCO',...
		'Mask Type','VCO')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Dialogue','Voltage-Controlled Oscilator:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;ts=@5;')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Help','The VCO block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'Mask Entries','1\/Fc\/1\/Ph\/ts\/')


%     Finished composite block ['PDM',13,'passband/Discrete-time',13,'VCO'].

set_param([sys,'/',['PDM',13,'passband/Discrete-time',13,'VCO']],...
		'orientation',2,...
		'position',[145,90,205,130])

add_block('built-in/Gain',[sys,'/',['PDM',13,'passband/Sensitivity']])
set_param([sys,'/',['PDM',13,'passband/Sensitivity']],...
		'Gain','ts*2*pi',...
		'position',[355,30,395,60])

add_block('built-in/Sum',[sys,'/',['PDM',13,'passband/Sum']])
set_param([sys,'/',['PDM',13,'passband/Sum']],...
		'position',[435,40,455,60])

add_block('built-in/Unit Delay',[sys,'/',['PDM',13,'passband/Unit Delay1']])
set_param([sys,'/',['PDM',13,'passband/Unit Delay1']],...
		'orientation',2,...
		'Sample time','ts',...
		'position',[435,90,485,110])

add_block('built-in/Outport',[sys,'/',['PDM',13,'passband/out_1']])
set_param([sys,'/',['PDM',13,'passband/out_1']],...
		'position',[545,40,565,60])

add_block('built-in/Inport',[sys,'/',['PDM',13,'passband/in_1']])
set_param([sys,'/',['PDM',13,'passband/in_1']],...
		'position',[20,30,40,50])
add_line([sys,'/',['PDM',13,'passband']],[115,40;150,40])
add_line([sys,'/',['PDM',13,'passband']],[45,40;65,40])
add_line([sys,'/',['PDM',13,'passband']],[295,45;325,45;325,110;210,110])
add_line([sys,'/',['PDM',13,'passband']],[325,45;350,45])
add_line([sys,'/',['PDM',13,'passband']],[460,50;500,50;490,100])
add_line([sys,'/',['PDM',13,'passband']],[500,50;540,50])
add_line([sys,'/',['PDM',13,'passband']],[430,100;410,100;410,55;430,55])
add_line([sys,'/',['PDM',13,'passband']],[400,45;430,45])
add_line([sys,'/',['PDM',13,'passband']],[140,110;110,110;110,50;150,50])
add_line([sys,'/',['PDM',13,'passband']],[185,45;230,45])
set_param([sys,'/',['PDM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);PDM',...
		'Mask Type','Passband PDM')
set_param([sys,'/',['PDM',13,'passband']],...
		'Mask Dialogue','Demodulate a PM modulated signal\nusing phase locked loop.|VCO frequency (Hz):|VCO Phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['PDM',13,'passband']],...
		'Mask Translate','Fc=@1;Ph=@2+pi/2;num=@3;den=@4;ts=@5;[x,y]=moduicon(4);')
set_param([sys,'/',['PDM',13,'passband']],...
		'Mask Help','This block recovers a PM modulated signal. This block uses a multiplier phase detector in PLL. This block uses a discrete-time lowpass filter which passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['PDM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/[4.57 9.14 4.57]*.01\/[1 -1.3108 .4936]\/.01\/')


%     Finished composite block ['PDM',13,'passband'].

set_param([sys,'/',['PDM',13,'passband']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[240,38,320,82])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'ForeGround',5,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','7.100000',...
		'Freq Range','14.000000',...
		'Wave','Sin',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator']],...
		'position',[35,43,80,77])


%     Subsystem  ['PM',13,'passband'].

new_system([sys,'/',['PM',13,'passband']])
set_param([sys,'/',['PM',13,'passband']],'Location',[358,506,869,673])

add_block('built-in/Clock',[sys,'/',['PM',13,'passband/Clock']])
set_param([sys,'/',['PM',13,'passband/Clock']],...
		'position',[40,65,60,85])

add_block('built-in/Sum',[sys,'/',['PM',13,'passband/Sum2']])
set_param([sys,'/',['PM',13,'passband/Sum2']],...
		'inputs','+-',...
		'position',[220,55,245,90])

add_block('built-in/Outport',[sys,'/',['PM',13,'passband/out_1']])
set_param([sys,'/',['PM',13,'passband/out_1']],...
		'position',[445,65,465,85])

add_block('built-in/Inport',[sys,'/',['PM',13,'passband/in_1']])
set_param([sys,'/',['PM',13,'passband/in_1']],...
		'position',[150,10,170,30])

add_block('built-in/Fcn',[sys,'/',['PM',13,'passband/Fcn']])
set_param([sys,'/',['PM',13,'passband/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[325,60,400,90])

add_block('built-in/Sum',[sys,'/',['PM',13,'passband/Sum1']])
set_param([sys,'/',['PM',13,'passband/Sum1']],...
		'inputs','+++',...
		'position',[280,57,300,93])

add_block('built-in/Gain',[sys,'/',['PM',13,'passband/Gain']])
set_param([sys,'/',['PM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[80,60,120,90])

add_block('built-in/Zero-Order Hold',[sys,'/',['PM',13,'passband/Zero-Order',13,'Hold']])
set_param([sys,'/',['PM',13,'passband/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[150,94,185,126])

add_block('built-in/Constant',[sys,'/',['PM',13,'passband/Initial value']])
set_param([sys,'/',['PM',13,'passband/Initial value']],...
		'Value','Ph',...
		'position',[220,120,240,140])
add_line([sys,'/',['PM',13,'passband']],[405,75;440,75])
add_line([sys,'/',['PM',13,'passband']],[245,130;255,130;255,85;275,85])
add_line([sys,'/',['PM',13,'passband']],[305,75;320,75])
add_line([sys,'/',['PM',13,'passband']],[175,20;255,20;255,65;275,65])
add_line([sys,'/',['PM',13,'passband']],[65,75;75,75])
add_line([sys,'/',['PM',13,'passband']],[250,75;275,75])
add_line([sys,'/',['PM',13,'passband']],[125,75;165,75;165,65;215,65])
add_line([sys,'/',['PM',13,'passband']],[190,110;195,110;195,80;215,80])
add_line([sys,'/',['PM',13,'passband']],[125,75;130,75;130,110;145,110])
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);PM',...
		'Mask Type','Passband PM')
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using PM method.|Carrier frequency (Hz):|Initial phase (rad):|Symbol interval (sec, Use inf for analog case):')
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;td=@3;if isinf(td),td=inf;end;[x,y]=moduicon(3);',...
		'Mask Help','The PM block causes the change of the carrier signal depending on the input signal voltage.')
set_param([sys,'/',['PM',13,'passband']],...
		'Mask Entries','100/2/pi\/0\/Inf\/')


%     Finished composite block ['PM',13,'passband'].

set_param([sys,'/',['PM',13,'passband']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[130,38,210,82])


%     Subsystem  ['PDM',13,'baseband'].

new_system([sys,'/',['PDM',13,'baseband']])
set_param([sys,'/',['PDM',13,'baseband']],'Location',[166,496,871,735])


%     Subsystem  ['PDM',13,'baseband/M//P 2 C'].

new_system([sys,'/',['PDM',13,'baseband/M//P 2 C']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C']],'Location',[87,375,532,683])

add_block('built-in/Mux',[sys,'/',['PDM',13,'baseband/M//P 2 C/Mux']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/Mux']],...
		'inputs','2',...
		'position',[225,111,270,149])

add_block('built-in/Product',[sys,'/',['PDM',13,'baseband/M//P 2 C/Product']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/Product']],...
		'position',[320,107,345,138])

add_block('built-in/Outport',[sys,'/',['PDM',13,'baseband/M//P 2 C/out_1']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/out_1']],...
		'position',[380,115,400,135])

add_block('built-in/Fcn',[sys,'/',['PDM',13,'baseband/M//P 2 C/sin']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/sin']],...
		'position',[75,127,150,153])

add_block('built-in/Fcn',[sys,'/',['PDM',13,'baseband/M//P 2 C/cos']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/cos']],...
		'Expr','cos(u[1])',...
		'position',[80,52,155,78])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/M//P 2 C/in_2']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/in_2']],...
		'Port','2',...
		'position',[15,130,35,150])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/M//P 2 C/in_1']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/in_1']],...
		'position',[215,70,235,90])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[160,65;170,65;170,120;220,120])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[155,140;220,140])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[275,130;315,130])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[350,125;375,125])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[240,80;280,80;280,115;315,115])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[40,140;70,140])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[50,140;50,65;75,65])


%     Finished composite block ['PDM',13,'baseband/M//P 2 C'].

set_param([sys,'/',['PDM',13,'baseband/M//P 2 C']],...
		'orientation',2,...
		'position',[115,135,205,175])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/in_1']])
set_param([sys,'/',['PDM',13,'baseband/in_1']],...
		'position',[45,25,65,45])

add_block('built-in/Sum',[sys,'/',['PDM',13,'baseband/Sum']])
set_param([sys,'/',['PDM',13,'baseband/Sum']],...
		'orientation',2,...
		'position',[245,155,265,175])

add_block('built-in/Constant',[sys,'/',['PDM',13,'baseband/Constant']])
set_param([sys,'/',['PDM',13,'baseband/Constant']],...
		'orientation',2,...
		'position',[290,85,320,105])


%     Subsystem  ['PDM',13,'baseband/Multiply &',13,'take imag'].

new_system([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],'Location',[317,81,820,296])

add_block('built-in/Outport',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/I_out_']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/I_out_']],...
		'position',[450,105,470,125])

add_block('built-in/Sum',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Sum1']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Sum1']],...
		'position',[390,105,410,125])

add_block('built-in/Product',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Product2']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Product2']],...
		'position',[220,108,250,132])

add_block('built-in/Product',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Product3']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Product3']],...
		'position',[310,63,340,87])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Complex',13,'input 2']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Complex',13,'input 2']],...
		'Port','2',...
		'position',[30,150,50,170])

add_block('built-in/Demux',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split1']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split1']],...
		'position',[85,139,160,181])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Complex',13,'input 1']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Complex',13,'input 1']],...
		'position',[40,35,60,55])

add_block('built-in/Demux',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split']],...
		'position',[90,24,165,66])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[415,115;445,115])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[65,45;85,45])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[55,160;80,160])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[170,35;248,35;248,70;305,70])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[165,170;290,170;290,80;305,80])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[170,55;185,55;185,115;215,115])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[165,150;180,150;180,125;215,125])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[345,75;360,75;360,110;385,110])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[255,120;385,120])


%     Finished composite block ['PDM',13,'baseband/Multiply &',13,'take imag'].

set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],...
		'position',[125,24,200,66])

add_block('built-in/Filter',[sys,'/',['PDM',13,'baseband/Filter']])
set_param([sys,'/',['PDM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,26,310,64])

add_block('built-in/Constant',[sys,'/',['PDM',13,'baseband/Constant1']])
set_param([sys,'/',['PDM',13,'baseband/Constant1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[340,190,370,210])

add_block('built-in/Gain',[sys,'/',['PDM',13,'baseband/Sensitivity']])
set_param([sys,'/',['PDM',13,'baseband/Sensitivity']],...
		'Gain','-2*pi',...
		'position',[355,30,395,60])


%     Subsystem  ['PDM',13,'baseband/Dis module',13,'integrator1'].

new_system([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],'Location',[48,515,661,644])

add_block('built-in/Outport',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/out_1']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/out_1']],...
		'position',[425,30,445,50])

add_block('built-in/Unit Delay',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Unit Delay']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/in_1']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/module']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Sum']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Gain',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Gain1']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Gain1']],...
		'Gain','ts(1)',...
		'position',[100,20,130,50])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[400,40;420,40])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[330,40;340,40])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[135,35;190,35])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[40,35;95,35])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[220,40;230,40])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],...
		'Mask Entries','100\/0\/ts\/')


%     Finished composite block ['PDM',13,'baseband/Dis module',13,'integrator1'].

set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],...
		'orientation',1,...
		'position',[390,95,450,135])

add_block('built-in/Gain',[sys,'/',['PDM',13,'baseband/Gain1']])
set_param([sys,'/',['PDM',13,'baseband/Gain1']],...
		'Gain','-ts(1)',...
		'position',[465,30,495,60])

add_block('built-in/Sum',[sys,'/',['PDM',13,'baseband/Sum1']])
set_param([sys,'/',['PDM',13,'baseband/Sum1']],...
		'position',[565,40,585,60])

add_block('built-in/Unit Delay',[sys,'/',['PDM',13,'baseband/Unit Delay']])
set_param([sys,'/',['PDM',13,'baseband/Unit Delay']],...
		'orientation',2,...
		'Sample time','ts',...
		'position',[555,80,605,100])

add_block('built-in/Outport',[sys,'/',['PDM',13,'baseband/out_1']])
set_param([sys,'/',['PDM',13,'baseband/out_1']],...
		'position',[660,40,680,60])
add_line([sys,'/',['PDM',13,'baseband']],[420,140;420,160;270,160])
add_line([sys,'/',['PDM',13,'baseband']],[335,200;295,200;295,170;270,170])
add_line([sys,'/',['PDM',13,'baseband']],[70,35;120,35])
add_line([sys,'/',['PDM',13,'baseband']],[285,95;255,95;255,145;210,145])
add_line([sys,'/',['PDM',13,'baseband']],[240,165;210,165])
add_line([sys,'/',['PDM',13,'baseband']],[110,155;85,155;85,55;120,55])
add_line([sys,'/',['PDM',13,'baseband']],[205,45;250,45])
add_line([sys,'/',['PDM',13,'baseband']],[315,45;350,45])
add_line([sys,'/',['PDM',13,'baseband']],[500,45;560,45])
add_line([sys,'/',['PDM',13,'baseband']],[550,90;540,90;540,55;560,55])
add_line([sys,'/',['PDM',13,'baseband']],[590,50;630,50;630,90;610,90])
add_line([sys,'/',['PDM',13,'baseband']],[630,50;655,50])
add_line([sys,'/',['PDM',13,'baseband']],[400,45;460,45])
add_line([sys,'/',['PDM',13,'baseband']],[420,45;420,90])
set_param([sys,'/',['PDM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);PDM',...
		'Mask Type','PLL PDM CE')
set_param([sys,'/',['PDM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nPM modulated signal.|VCO initial phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['PDM',13,'baseband']],...
		'Mask Translate','Ph=@1;num=@2;den=@3;ts=@4;pi2=2*pi;[x,y]=moduicon(4);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['PDM',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a PM modulated signal. This block uses a phase-locked loop with a multiplier phase detector.',...
		'Mask Entries','0\/num\/den\/ts\/')


%     Finished composite block ['PDM',13,'baseband'].

set_param([sys,'/',['PDM',13,'baseband']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[240,98,320,142])


%     Subsystem  ['PM',13,'baseband'].

new_system([sys,'/',['PM',13,'baseband']])
set_param([sys,'/',['PM',13,'baseband']],'Location',[320,489,688,666])

add_block('built-in/Mux',[sys,'/',['PM',13,'baseband/Mux']])
set_param([sys,'/',['PM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[250,51,285,84])

add_block('built-in/Outport',[sys,'/',['PM',13,'baseband/out_1']])
set_param([sys,'/',['PM',13,'baseband/out_1']],...
		'position',[315,60,335,80])

add_block('built-in/Fcn',[sys,'/',['PM',13,'baseband/sin']])
set_param([sys,'/',['PM',13,'baseband/sin']],...
		'Expr','sin(u)',...
		'position',[155,106,210,134])

add_block('built-in/Fcn',[sys,'/',['PM',13,'baseband/cos']])
set_param([sys,'/',['PM',13,'baseband/cos']],...
		'Expr','cos(u)',...
		'position',[155,46,210,74])

add_block('built-in/Inport',[sys,'/',['PM',13,'baseband/in_1']])
set_param([sys,'/',['PM',13,'baseband/in_1']],...
		'position',[35,50,55,70])
add_line([sys,'/',['PM',13,'baseband']],[215,60;245,60])
add_line([sys,'/',['PM',13,'baseband']],[290,70;310,70])
add_line([sys,'/',['PM',13,'baseband']],[215,120;230,120;230,75;245,75])
add_line([sys,'/',['PM',13,'baseband']],[60,60;150,60])
add_line([sys,'/',['PM',13,'baseband']],[130,60;130,120;150,120])
set_param([sys,'/',['PM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);PM',...
		'Mask Type','PM CE',...
		'Mask Dialogue','Output the complex envelope of a PM\nmodulated signal.|Initial phase (rad):')
set_param([sys,'/',['PM',13,'baseband']],...
		'Mask Translate','Ph=@1;pi2=2*pi;[x,y]=moduicon(3);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['PM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the phase modulated signal. The output of this block is a complex signal.',...
		'Mask Entries','0\/')


%     Finished composite block ['PM',13,'baseband'].

set_param([sys,'/',['PM',13,'baseband']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[130,98,210,142])

add_block('built-in/Note',[sys,'/','Defaults in this simulation: ts=0.01; [num,den]=butter(2,Fc*2*ts);'])
set_param([sys,'/','Defaults in this simulation: ts=0.01; [num,den]=butter(2,Fc*2*ts);'],...
		'position',[230,160,235,165])
add_line(sys,[325,120;350,120;350,75;380,75])
add_line(sys,[425,60;445,60])
add_line(sys,[85,60;100,60;100,20;360,20;360,45;380,45])
add_line(sys,[325,60;380,60])
add_line(sys,[100,60;125,60])
add_line(sys,[100,60;100,120;125,120])
add_line(sys,[215,120;235,120])
add_line(sys,[215,60;235,60])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
