function [ret,x0,str,ts,xts]=testamc2(t,x,u,flag);
%TESTAMC2	is the M-file description of the SIMULINK system named TESTAMC2.
%	The block-diagram can be displayed by typing: TESTAMC2.
%
%	SYS=TESTAMC2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TESTAMC2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TESTAMC2 with a FLAG of zero:
%	[SIZES]=TESTAMC2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[376,354,883,596])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;[num,den]=butter(2,100/pi/2*ts);');

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[385,55,420,105])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','4\/-1.5\/1.5\/''y-/g--/r-/m:/w-/r:/b+''\/ts\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'hide name',0,...
		'position',[450,61,480,99])


%     Subsystem  ['ADM with carrier',13,'passband'].

new_system([sys,'/',['ADM with carrier',13,'passband']])
set_param([sys,'/',['ADM with carrier',13,'passband']],'Location',[67,574,402,724])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'passband/in_1']])
set_param([sys,'/',['ADM with carrier',13,'passband/in_1']],...
		'position',[40,25,60,45])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'passband/Sum']])
set_param([sys,'/',['ADM with carrier',13,'passband/Sum']],...
		'inputs','+-',...
		'position',[240,30,260,50])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'passband/out_1']])
set_param([sys,'/',['ADM with carrier',13,'passband/out_1']],...
		'position',[290,30,310,50])

add_block('built-in/Constant',[sys,'/',['ADM with carrier',13,'passband/Constant']])
set_param([sys,'/',['ADM with carrier',13,'passband/Constant']],...
		'Value','Offset',...
		'position',[90,95,130,115])


%     Subsystem  ['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas'].

new_system([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],'Location',[79,73,846,354])


%     Subsystem  ['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator'].

new_system([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])

add_block('built-in/Unit Delay',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/module']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[410,40;440,40])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],[140,35;190,35])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator'].

set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])

add_block('built-in/Constant',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter2']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Sum']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Gain',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Gain1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Constant',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Sum1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product2']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/sin1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/in_1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/sin']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter1']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/In-phase',13,'output']])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas/In-phase',13,'output']],...
		'position',[695,50,715,70])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[260,130;215,130])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[240,130;240,180;225,180])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[530,120;465,120])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[155,60;335,60])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[435,125;430,125])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[605,120;600,120])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[70,55;120,55])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[90,55;90,230;120,230])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[155,225;420,225])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[485,225;655,225;645,125])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[360,125;345,125])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[305,125;290,125])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[315,185;300,185;290,135])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[400,60;690,60])
add_line([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],[655,60;645,115])
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Display','Costas PL\nDSB ADM',...
		'Mask Type','DSB-SC ADM')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Dialogue','Double-sideband suppressed-carrier amplitude demodulation:|Carrier frequency:|Low-pass filter numerator (dis):|Low-pass filter denominator (dis):|Initial phase:|Sample time (sec):')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;pih=pi/2;ts=@5;')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Help','The DSB SC ADM demodulates a DSB-SC-AM signal using Costas Phase-Locked Loop method. The result of this ADM is phase sensitive. This block requires user to specify a lowpass filter which could filter the carrier freency and keep the message signal. Please refer Signal Processing Toolbox for design of the filters. ')
set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Entries','Fc\/num\/den\/Ph\/ts\/')


%     Finished composite block ['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas'].

set_param([sys,'/',['ADM with carrier',13,'passband/DSB-SC-ADM',13,'by-Costas']],...
		'ForeGround',3,...
		'position',[100,15,180,55])
add_line([sys,'/',['ADM with carrier',13,'passband']],[65,35;95,35])
add_line([sys,'/',['ADM with carrier',13,'passband']],[185,35;235,35])
add_line([sys,'/',['ADM with carrier',13,'passband']],[265,40;285,40])
add_line([sys,'/',['ADM with carrier',13,'passband']],[135,105;220,105;220,45;235,45])
set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);ADM w TC',...
		'Mask Type','Passband ADM with carrier')
set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'Mask Dialogue','Demodulate an AM with carrier modulated signal.|Offset factor:|Carrier frequency (Hz):|Initial Phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'Mask Translate','Offset=@1;Fc=@2;Ph=@3;num=@4;den=@5;ts=@6;[x,y]=moduicon(2);')
set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'Mask Help','This block demodulates a DSB-AM with carrier modulated signal. In order to recover the original signal, the offset parameter should be the same as the parameter in the modulation. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'Mask Entries','1\/100/2/pi\/pi/3\/num\/den\/ts\/')


%     Finished composite block ['ADM with carrier',13,'passband'].

set_param([sys,'/',['ADM with carrier',13,'passband']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[250,58,330,102])


%     Subsystem  ['AM with carrier',13,'passband'].

new_system([sys,'/',['AM with carrier',13,'passband']])
set_param([sys,'/',['AM with carrier',13,'passband']],'Location',[68,468,570,611])

add_block('built-in/Note',[sys,'/',['AM with carrier',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp76']])
set_param([sys,'/',['AM with carrier',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp76']],...
		'position',[180,155,185,160])

add_block('built-in/Outport',[sys,'/',['AM with carrier',13,'passband/out_1']])
set_param([sys,'/',['AM with carrier',13,'passband/out_1']],...
		'position',[395,35,415,55])

add_block('built-in/Sum',[sys,'/',['AM with carrier',13,'passband/Sum']])
set_param([sys,'/',['AM with carrier',13,'passband/Sum']],...
		'position',[160,35,180,55])

add_block('built-in/Inport',[sys,'/',['AM with carrier',13,'passband/in_1']])
set_param([sys,'/',['AM with carrier',13,'passband/in_1']],...
		'position',[50,30,70,50])

add_block('built-in/Constant',[sys,'/',['AM with carrier',13,'passband/Constant']])
set_param([sys,'/',['AM with carrier',13,'passband/Constant']],...
		'Value','Offset',...
		'position',[60,75,110,95])


%     Subsystem  ['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt'].

new_system([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],'Location',[51,135,503,309])

add_block('built-in/Sum',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Sum2']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Sum2']],...
		'position',[170,90,190,110])

add_block('built-in/Fcn',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Fcn']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Constant',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Constant1']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Inport',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/in_1']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Outport',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/out_1']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Product',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Product']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Clock',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Clock']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Gain',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Gain']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Filter',[sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/zero-hold',13,'for timing-control']])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt/zero-hold',13,'for timing-control']],...
		'Numerator','1',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[55,196,110,234])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[195,100;200,100])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[45,75;65,75])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[370,60;375,60])
add_line([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],[270,100;270,65;335,65])
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'Mask Display','DSB-SC\nAM',...
		'Mask Type','DSB-SC AM')
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'Mask Dialogue','Double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'Mask Translate','Ac=@1;Fc=@2;Fc=Fc*2*pi;Ph=@3;ts=@4;')
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'Mask Help','The DSB-SC AM causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'Mask Entries','1\/Fc\/Ph\/ts\/')


%     Finished composite block ['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt'].

set_param([sys,'/',['AM with carrier',13,'passband/DSB-SC AM',13,'discr-flt']],...
		'ForeGround',3,...
		'position',[265,28,340,62])
add_line([sys,'/',['AM with carrier',13,'passband']],[75,40;155,40])
add_line([sys,'/',['AM with carrier',13,'passband']],[185,45;260,45])
add_line([sys,'/',['AM with carrier',13,'passband']],[345,45;390,45])
add_line([sys,'/',['AM with carrier',13,'passband']],[115,85;130,85;130,50;155,50])
set_param([sys,'/',['AM with carrier',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);AM w TC',...
		'Mask Type','Passband AM with carrier')
set_param([sys,'/',['AM with carrier',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using\namplitude modulation with transmission\ncarrier method.|Input signal offset:|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec)')
set_param([sys,'/',['AM with carrier',13,'passband']],...
		'Mask Translate','Offset=@1;Fc=@2;Ph=@3;ts=@4;[x,y]=moduicon(1);')
set_param([sys,'/',['AM with carrier',13,'passband']],...
		'Mask Help','This block shifts the amplitude of the input signal before the modulation. AM with carrier is a simple technique but not an energy-efficient one.')
set_param([sys,'/',['AM with carrier',13,'passband']],...
		'Mask Entries','1\/100/2/pi\/pi/3\/ts\/')


%     Finished composite block ['AM with carrier',13,'passband'].

set_param([sys,'/',['AM with carrier',13,'passband']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[130,58,210,102])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'ForeGround',5,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','3.000000',...
		'Freq Range','6.000000',...
		'Wave','Saw',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator']],...
		'position',[25,63,70,97])


%     Subsystem  ['AM with carrier',13,'baseband'].

new_system([sys,'/',['AM with carrier',13,'baseband']])
set_param([sys,'/',['AM with carrier',13,'baseband']],'Location',[239,534,593,656])

add_block('built-in/Inport',[sys,'/',['AM with carrier',13,'baseband/in_1']])
set_param([sys,'/',['AM with carrier',13,'baseband/in_1']],...
		'position',[50,30,70,50])

add_block('built-in/Note',[sys,'/',['AM with carrier',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp76']])
set_param([sys,'/',['AM with carrier',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp76']],...
		'position',[180,155,185,160])

add_block('built-in/Sum',[sys,'/',['AM with carrier',13,'baseband/Sum']])
set_param([sys,'/',['AM with carrier',13,'baseband/Sum']],...
		'position',[125,35,145,55])

add_block('built-in/Outport',[sys,'/',['AM with carrier',13,'baseband/out_1']])
set_param([sys,'/',['AM with carrier',13,'baseband/out_1']],...
		'position',[280,35,300,55])

add_block('built-in/Constant',[sys,'/',['AM with carrier',13,'baseband/Constant']])
set_param([sys,'/',['AM with carrier',13,'baseband/Constant']],...
		'Value','Offset',...
		'position',[35,80,85,100])


%     Subsystem  ['AM with carrier',13,'baseband/DSB AM CE'].

new_system([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],'Location',[212,430,575,573])

add_block('built-in/Outport',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/out_1']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/out_1']],...
		'position',[320,50,340,70])

add_block('built-in/Product',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Product']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Product']],...
		'position',[255,42,280,73])

add_block('built-in/Inport',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/in_1']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/in_1']],...
		'position',[115,15,135,35])

add_block('built-in/Mux',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Mux']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Mux']],...
		'inputs','2',...
		'position',[170,66,205,99])

add_block('built-in/Constant',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Constant1']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Constant1']],...
		'Value','x2',...
		'position',[90,90,110,110])

add_block('built-in/Constant',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Constant']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Constant']],...
		'Value','x1',...
		'position',[40,65,60,85])
add_line([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],[65,75;165,75])
add_line([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],[115,100;130,100;130,90;165,90])
add_line([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],[140,25;185,25;185,50;250,50])
add_line([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],[285,60;315,60])
add_line([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],[210,85;230,85;230,65;250,65])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],...
		'Mask Display','DSB AM\ncmplx env',...
		'Mask Type','DSB-SC AM complex envelop')
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],...
		'Mask Dialogue','Double-sideband suppressed-carrier amplitude modulation complex envelop.|Initial Phase (rad):',...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);pi2=2*pi;')
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],...
		'Mask Help','The Double-Sideband-Supressed-Carrier Amplitude Modulation causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. This block outputs the complex envelop of the modulation, which is a complex number.')
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],...
		'Mask Entries','Ph\/')


%     Finished composite block ['AM with carrier',13,'baseband/DSB AM CE'].

set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],...
		'position',[180,25,255,65])
add_line([sys,'/',['AM with carrier',13,'baseband']],[90,90;100,90;100,50;120,50])
add_line([sys,'/',['AM with carrier',13,'baseband']],[260,45;275,45])
add_line([sys,'/',['AM with carrier',13,'baseband']],[75,40;120,40])
add_line([sys,'/',['AM with carrier',13,'baseband']],[150,45;175,45])
set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);AM w TC',...
		'Mask Type','AM CE with TC')
set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'Mask Dialogue','Output complex envelope of an AM with\ntransport carrier modulated signal.|Input signal offset:|Initial phase (rad):')
set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'Mask Translate','Offset=@1;Ph=@2;[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'Mask Help','This block causes the amplitude of the sinusoid carrier to depend on the message signal. An offset is added to the input signal before modulation. The output of this block is a complex signal. This modulation technique is not efficient.')
set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['AM with carrier',13,'baseband'].

set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[130,118,210,162])


%     Subsystem  ['ADM with carrier',13,'baseband'].

new_system([sys,'/',['ADM with carrier',13,'baseband']])
set_param([sys,'/',['ADM with carrier',13,'baseband']],'Location',[468,490,803,640])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/out_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/out_1']],...
		'position',[290,30,310,50])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'baseband/Sum']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[240,30,260,50])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/in_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/in_1']],...
		'position',[40,25,60,45])

add_block('built-in/Constant',[sys,'/',['ADM with carrier',13,'baseband/Constant']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Constant']],...
		'Value','Offset',...
		'position',[150,100,190,120])


%     Subsystem  ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE'].

new_system([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],'Location',[103,111,653,332])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[260,156,315,194])


%     Subsystem  ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO'].

new_system([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],'Location',[114,165,727,312])


%     Subsystem  ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator'].

new_system([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/module']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Unit Delay',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[410,40;440,40])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Entries','pi2\/0\/ts\/')


%     Finished composite block ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator'].

set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'position',[155,16,215,54])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/out_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/out_1']],...
		'position',[490,35,510,55])

add_block('built-in/Gain',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Sensitivity1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Sensitivity1']],...
		'Gain','Ac',...
		'position',[420,31,460,59])

add_block('built-in/Mux',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Mux']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Mux']],...
		'inputs','2',...
		'position',[355,26,390,59])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/sin']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/sin']],...
		'Expr','sin(u)',...
		'position',[270,81,325,109])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/cos']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/cos']],...
		'Expr','cos(u)',...
		'position',[270,21,325,49])

add_block('built-in/Gain',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Sensitivity']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[80,21,120,49])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/in_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/in_1']],...
		'position',[35,25,55,45])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[330,95;335,95;335,50;350,50])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[395,45;415,45])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[330,35;350,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[465,45;485,45])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[220,35;265,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[240,35;240,95;265,95])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[125,35;150,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[60,35;75,35])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'Mask Display','FM\ncmplx env',...
		'Mask Type','FM with cmplx env out')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'Mask Dialogue','Frequency modulation with complex envelop output:|Amplitude constant:|Modulation sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'Mask Translate','Ac=@1;Kc=@2*2*pi;Ph=@3;pi2=2*pi;ts=@4;')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'Mask Help','The FM block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'Mask Entries','1\/1\/0\/ts\/')


%     Finished composite block ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO'].

set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'orientation',2,...
		'position',[205,80,285,120])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/in_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/in_1']],...
		'orientation',2,...
		'position',[165,70,185,90])


%     Subsystem  ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

new_system([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],'Location',[297,318,980,694])

add_block('built-in/Gain',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']],...
		'Gain','-1',...
		'position',[190,210,230,240])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']],...
		'position',[170,225,175,230])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']],...
		'position',[495,110,515,130])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']],...
		'Port','2',...
		'position',[485,280,505,300])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']],...
		'position',[198,108,203,113])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']],...
		'position',[195,65,200,70])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']],...
		'position',[190,185,195,190])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']],...
		'position',[305,83,335,107])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']],...
		'position',[305,143,335,167])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']],...
		'inputs','+-',...
		'position',[380,110,400,130])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']],...
		'position',[305,253,335,277])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']],...
		'position',[305,298,335,322])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']],...
		'position',[380,280,400,300])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']],...
		'position',[450,95,455,100])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']],...
		'position',[450,286,455,291])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']],...
		'position',[55,0,60,5])

add_block('built-in/Demux',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'position',[85,79,160,121])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']],...
		'position',[35,90,55,110])

add_block('built-in/Demux',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'position',[80,194,155,236])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']],...
		'Port','2',...
		'position',[25,205,45,225])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[235,225;260,225;260,160;300,160])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[260,225;260,270;300,270])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,225;185,225])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,120;490,120])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,290;480,290])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[60,100;80,100])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[50,215;75,215])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,95;350,95;350,115;375,115])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,155;350,155;350,125;375,125])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,90;300,90])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[243,90;243,260;300,260])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,205;275,205;275,100;300,100])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[275,205;275,305;300,305])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,110;250,110;250,150;300,150])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[255,150;255,315;300,315])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,265;350,265;350,285;375,285])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,310;350,310;350,295;375,295])


%     Finished composite block ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],...
		'orientation',2,...
		'position',[50,70,125,110])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[270,6,325,44])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter2']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[310,80,370,120])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Product1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Product1']],...
		'orientation',2,...
		'position',[400,90,435,110])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/out_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/out_1']],...
		'position',[495,15,515,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[200,100;130,100])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[305,100;290,100])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[395,100;375,100])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[320,175;455,175;455,105;440,105])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[45,100;25,100;25,175;255,175])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[45,80;30,80;30,25;265,25])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[160,80;130,80])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[330,25;490,25])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[455,25;455,95;440,95])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'Mask Display','Costas PL\nDSB ADM',...
		'Mask Type','DSB-SC ADM')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'Mask Dialogue','Double-sideband suppressed-carrier amplitude demodulation:|Low-pass filter numerator:|Low-pass filter denominator:|Initial phase:|Sample time:')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;pi2=pi*2;ts=@4;')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'Mask Help','The DSB SC ADM demodulates a DSB-SC-AM signal using Costas Phase-Locked Loop method. The result of this ADM is phase sensitive. This block requires user to specify a lowpass filter which could filter the carrier freency and keep the message signal. Please refer Signal Processing Toolbox for design of the filters. ')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE'].

set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'ForeGround',2,...
		'position',[100,15,175,55])
add_line([sys,'/',['ADM with carrier',13,'baseband']],[265,40;285,40])
add_line([sys,'/',['ADM with carrier',13,'baseband']],[180,35;235,35])
add_line([sys,'/',['ADM with carrier',13,'baseband']],[65,35;95,35])
add_line([sys,'/',['ADM with carrier',13,'baseband']],[195,110;210,110;215,45;235,45])
set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);ADM w TC',...
		'Mask Type','ADM with TC CE')
set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of an\nAM with TC modulated signal.|Output signal offset:|Lowpass filter numerator:|Lowpass filter denominator:|Initial Phase (rad):|Sample time (ts):')
set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'Mask Translate','Offset=@1;num=@2;den=@3;Ph=@4;ts=@5;[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of an AM with transport carrier modulated signal. This block requires you to specify a lowpass filter, which eliminates the carrier frequency and keeps the message signal. This block takes a complex signal.')
set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'Mask Entries','1\/num\/den\/0\/ts\/')


%     Finished composite block ['ADM with carrier',13,'baseband'].

set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[250,118,330,162])

add_block('built-in/Note',[sys,'/','Defaults in this simulation: ts=0.01; [num,den]=butter(2,Fc*2*ts);'])
set_param([sys,'/','Defaults in this simulation: ts=0.01; [num,den]=butter(2,Fc*2*ts);'],...
		'position',[225,190,230,195])
add_line(sys,[75,80;125,80])
add_line(sys,[100,80;100,140;125,140])
add_line(sys,[335,140;350,140;350,95;380,95])
add_line(sys,[215,80;245,80])
add_line(sys,[425,80;445,80])
add_line(sys,[100,80;100,25;360,25;360,65;380,65])
add_line(sys,[335,80;380,80])
add_line(sys,[215,140;245,140])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
