function [ret,x0,str,ts,xts]=testing(t,x,u,flag);
%TESTING	is the M-file description of the SIMULINK system named TESTING.
%	TESTING has a the following characteristics:
%		0 continuous states
%		3 discrete states
%		3 outputs
%		2 inputs
%		has direct feedthrough
%		1 sample times
%
%	The block-diagram can be displayed by typing: TESTING.
%
%	SYS=TESTING(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TESTING to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TESTING with a FLAG of zero:
%	[SIZES]=TESTING([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[88,191,729,440])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Inport',[sys,'/','Inport'])
set_param([sys,'/','Inport'],...
		'position',[25,15,45,35])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay2'])
set_param([sys,'/','Unit Delay2'],...
		'orientation',2,...
		'hide name',0,...
		'position',[180,215,230,235])

add_block('built-in/Logical Operator',[sys,'/',['Logical',13,'Operator3']])
set_param([sys,'/',['Logical',13,'Operator3']],...
		'orientation',2,...
		'ForeGround',4,...
		'hide name',0,...
		'Operator','AND',...
		'position',[180,165,230,200])

add_block('built-in/Logical Operator',[sys,'/',['Logical',13,'Operator4']])
set_param([sys,'/',['Logical',13,'Operator4']],...
		'orientation',2,...
		'ForeGround',4,...
		'hide name',0,...
		'Operator','AND',...
		'position',[385,165,435,200])

add_block('built-in/Logical Operator',[sys,'/',['Logical',13,'Operator2']])
set_param([sys,'/',['Logical',13,'Operator2']],...
		'ForeGround',4,...
		'hide name',0,...
		'Operator','XOR',...
		'position',[390,115,435,150])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay'])
set_param([sys,'/','Unit Delay'],...
		'hide name',0,...
		'position',[480,127,530,143])

add_block('built-in/Outport',[sys,'/','Outport2'])
set_param([sys,'/','Outport2'],...
		'Port','3',...
		'position',[585,125,605,145])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay1'])
set_param([sys,'/','Unit Delay1'],...
		'hide name',0,...
		'position',[175,122,225,138])

add_block('built-in/Logical Operator',[sys,'/',['Logical',13,'Operator']])
set_param([sys,'/',['Logical',13,'Operator']],...
		'ForeGround',4,...
		'hide name',0,...
		'Operator','XOR',...
		'Number of Input Ports','4',...
		'position',[110,100,145,155])

add_block('built-in/Logical Operator',[sys,'/',['Logical',13,'Operator1']])
set_param([sys,'/',['Logical',13,'Operator1']],...
		'ForeGround',4,...
		'hide name',0,...
		'Operator','XOR',...
		'position',[270,105,315,140])

add_block('built-in/Inport',[sys,'/','Inport1'])
set_param([sys,'/','Inport1'],...
		'ForeGround',3,...
		'Port','2',...
		'position',[25,60,45,80])

add_block('built-in/Outport',[sys,'/','Outport1'])
set_param([sys,'/','Outport1'],...
		'Port','2',...
		'position',[590,60,610,80])

add_block('built-in/Outport',[sys,'/','Outport'])
set_param([sys,'/','Outport'],...
		'position',[585,15,605,35])
add_line(sys,[50,70;585,70])
add_line(sys,[50,25;580,25])
add_line(sys,[75,25;75,105;105,105])
add_line(sys,[50,70;60,70;60,120;105,120])
add_line(sys,[440,135;475,135])
add_line(sys,[535,135;580,135])
add_line(sys,[175,225;45,225;45,135;105,135])
add_line(sys,[150,130;170,130])
add_line(sys,[230,130;265,130])
add_line(sys,[240,25;240,115;265,115])
add_line(sys,[320,125;385,125])
add_line(sys,[175,185;85,185;85,150;105,150])
add_line(sys,[330,125;330,175;235,175])
add_line(sys,[380,185;365,185;365,140;385,140])
add_line(sys,[460,70;460,175;440,175])
add_line(sys,[550,135;550,225;235,225])
add_line(sys,[550,190;440,190])
add_line(sys,[295,225;295,190;235,190])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
