function [ret,x0,str,ts,xts]=testssba(t,x,u,flag);
%TESTSSBA	is the M-file description of the SIMULINK system named TESTSSBA.
%	The block-diagram can be displayed by typing: TESTSSBA.
%
%	SYS=TESTSSBA(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TESTSSBA to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TESTSSBA with a FLAG of zero:
%	[SIZES]=TESTSSBA([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[370,341,860,670])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '4')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[350,7,385,63])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','4\/-1.5\/1.5\/''y-/g--/r-/m:/w-/r:/b+''\/ts\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'hide name',0,...
		'position',[435,16,465,54])


%     Subsystem  'USB-AM'.

new_system([sys,'/','USB-AM'])
set_param([sys,'/','USB-AM'],'Location',[76,558,518,713])

add_block('built-in/Gain',[sys,'/','USB-AM/Gain'])
set_param([sys,'/','USB-AM/Gain'],...
		'Gain','k',...
		'position',[185,72,215,98])

add_block('built-in/Filter',[sys,'/','USB-AM/Filter'])
set_param([sys,'/','USB-AM/Filter'],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[95,66,150,104])

add_block('built-in/Inport',[sys,'/','USB-AM/in_1'])
set_param([sys,'/','USB-AM/in_1'],...
		'position',[30,20,50,40])

add_block('built-in/Note',[sys,'/','USB-AM/Ref: Hambley: An Intro to Comm. Systems. pp82'])
set_param([sys,'/','USB-AM/Ref: Hambley: An Intro to Comm. Systems. pp82'],...
		'position',[355,290,360,295])

add_block('built-in/Outport',[sys,'/','USB-AM/out_1'])
set_param([sys,'/','USB-AM/out_1'],...
		'position',[400,55,420,75])


%     Subsystem  'USB-AM/QAM discr-filt'.

new_system([sys,'/','USB-AM/QAM discr-filt'])
set_param([sys,'/','USB-AM/QAM discr-filt'],'Location',[302,478,834,743])

add_block('built-in/Fcn',[sys,'/','USB-AM/QAM discr-filt/Fcn'])
set_param([sys,'/','USB-AM/QAM discr-filt/Fcn'],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])

add_block('built-in/Fcn',[sys,'/','USB-AM/QAM discr-filt/Fcn1'])
set_param([sys,'/','USB-AM/QAM discr-filt/Fcn1'],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Note',[sys,'/','USB-AM/QAM discr-filt/Ref: Hambley: An Intro to Comm. Systems. pp72'])
set_param([sys,'/','USB-AM/QAM discr-filt/Ref: Hambley: An Intro to Comm. Systems. pp72'],...
		'position',[250,305,255,310])

add_block('built-in/Product',[sys,'/','USB-AM/QAM discr-filt/Product'])
set_param([sys,'/','USB-AM/QAM discr-filt/Product'],...
		'position',[355,47,380,78])

add_block('built-in/Product',[sys,'/','USB-AM/QAM discr-filt/Product1'])
set_param([sys,'/','USB-AM/QAM discr-filt/Product1'],...
		'position',[355,112,380,143])

add_block('built-in/Sum',[sys,'/','USB-AM/QAM discr-filt/Sum2'])
set_param([sys,'/','USB-AM/QAM discr-filt/Sum2'],...
		'position',[430,90,450,110])

add_block('built-in/Outport',[sys,'/','USB-AM/QAM discr-filt/out_1'])
set_param([sys,'/','USB-AM/QAM discr-filt/out_1'],...
		'position',[490,90,510,110])

add_block('built-in/Inport',[sys,'/','USB-AM/QAM discr-filt/in_1'])
set_param([sys,'/','USB-AM/QAM discr-filt/in_1'],...
		'position',[160,30,180,50])

add_block('built-in/Inport',[sys,'/','USB-AM/QAM discr-filt/in_2'])
set_param([sys,'/','USB-AM/QAM discr-filt/in_2'],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Gain',[sys,'/','USB-AM/QAM discr-filt/Gain'])
set_param([sys,'/','USB-AM/QAM discr-filt/Gain'],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Clock',[sys,'/','USB-AM/QAM discr-filt/Clock'])
set_param([sys,'/','USB-AM/QAM discr-filt/Clock'],...
		'position',[80,85,100,105])
add_line([sys,'/','USB-AM/QAM discr-filt'],[455,100;485,100])
add_line([sys,'/','USB-AM/QAM discr-filt'],[330,70;350,70])
add_line([sys,'/','USB-AM/QAM discr-filt'],[185,40;335,40;335,55;350,55])
add_line([sys,'/','USB-AM/QAM discr-filt'],[330,120;350,120])
add_line([sys,'/','USB-AM/QAM discr-filt'],[185,155;330,155;330,135;350,135])
add_line([sys,'/','USB-AM/QAM discr-filt'],[385,65;400,65;400,95;425,95])
add_line([sys,'/','USB-AM/QAM discr-filt'],[385,130;400,130;400,105;425,105])
add_line([sys,'/','USB-AM/QAM discr-filt'],[105,95;125,95])
add_line([sys,'/','USB-AM/QAM discr-filt'],[185,95;200,95;200,70;225,70])
add_line([sys,'/','USB-AM/QAM discr-filt'],[200,95;200,120;225,120])
set_param([sys,'/','USB-AM/QAM discr-filt'],...
		'Mask Display','QM DSB\nAM',...
		'Mask Type','Quadrature Multiplexed DSB-SC AM')
set_param([sys,'/','USB-AM/QAM discr-filt'],...
		'Mask Dialogue','Quadrature multiplexed double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency (Hz):|Initial phase (rad):|Sample time:')
set_param([sys,'/','USB-AM/QAM discr-filt'],...
		'Mask Translate','Am=@1;Fc=@2*2*pi;Ph=@3;ts=@4;')
set_param([sys,'/','USB-AM/QAM discr-filt'],...
		'Mask Help','The Quadratic Multiplexed Double-Sideband-Supressed-Carrier AM block causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. There are two input signal being modulated at the same time by using two orthogonal sinusoidal carriers.')
set_param([sys,'/','USB-AM/QAM discr-filt'],...
		'Mask Entries','1\/Fc\/Ph\/ts\/')


%     Finished composite block 'USB-AM/QAM discr-filt'.

set_param([sys,'/','USB-AM/QAM discr-filt'],...
		'ForeGround',3,...
		'position',[280,45,360,85])
add_line([sys,'/','USB-AM'],[220,85;240,85;240,75;275,75])
add_line([sys,'/','USB-AM'],[155,85;180,85])
add_line([sys,'/','USB-AM'],[55,30;65,30;65,85;90,85])
add_line([sys,'/','USB-AM'],[55,30;255,30;255,55;275,55])
add_line([sys,'/','USB-AM'],[365,65;395,65])
set_param([sys,'/','USB-AM'],...
		'Mask Display','plot(0,0,100,100,x,y);SSB AM',...
		'Mask Type','Passband SSB-AM')
set_param([sys,'/','USB-AM'],...
		'Mask Dialogue','Modulate the input signal using \nsingle-sideband amplitude modulation\nmethod with Hilbert transform filter.|Carrier frequency (Hz):|Initial Phase (rad):|Bandwidth of the input signal (Hz):|Time delay for Hilbert transform filter (sec):|Sample time (sec):|"upper" sideband or "lower" sideband:')
set_param([sys,'/','USB-AM'],...
		'Mask Translate','Fc=@1;Ph=@2;ban=@3;dly=@4;ts=@5;sd=@6;if ban>1/ts, ban=1/ts-ts;end;[num,den]=hilbiir(ts,dly,ban);pi2=2*pi;pih=pi/2;k=-1;if sd(1)==''l'',k=1;end;[x,y]=moduicon(1);')
set_param([sys,'/','USB-AM'],...
		'Mask Help','This block modulates the input signal using the SSB-AM method. The block uses Hilbert transfer filter. Hilbert transform filter is a non-causal filter. A positive time delay is requested in the implementation. You can specify the modulation to be an USB or LSB modulation.')
set_param([sys,'/','USB-AM'],...
		'Mask Entries','100/2/pi\/pi/2\/1/ts/10\/ts*10\/ts\/''upper''\/')


%     Finished composite block 'USB-AM'.

set_param([sys,'/','USB-AM'],...
		'ForeGround',3,...
		'position',[110,38,190,82])


%     Subsystem  ['SSB-ADM',13,'passband1'].

new_system([sys,'/',['SSB-ADM',13,'passband1']])
set_param([sys,'/',['SSB-ADM',13,'passband1']],'Location',[234,472,778,662])

add_block('built-in/Filter',[sys,'/',['SSB-ADM',13,'passband1/Filter']])
set_param([sys,'/',['SSB-ADM',13,'passband1/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Note',[sys,'/',['SSB-ADM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['SSB-ADM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Fcn',[sys,'/',['SSB-ADM',13,'passband1/Fcn']])
set_param([sys,'/',['SSB-ADM',13,'passband1/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[205,55,300,85])

add_block('built-in/Product',[sys,'/',['SSB-ADM',13,'passband1/Product']])
set_param([sys,'/',['SSB-ADM',13,'passband1/Product']],...
		'position',[330,62,355,93])

add_block('built-in/Outport',[sys,'/',['SSB-ADM',13,'passband1/out_1']])
set_param([sys,'/',['SSB-ADM',13,'passband1/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Clock',[sys,'/',['SSB-ADM',13,'passband1/Clock']])
set_param([sys,'/',['SSB-ADM',13,'passband1/Clock']],...
		'position',[60,60,80,80])

add_block('built-in/Gain',[sys,'/',['SSB-ADM',13,'passband1/Gain']])
set_param([sys,'/',['SSB-ADM',13,'passband1/Gain']],...
		'Gain','Fc',...
		'position',[110,51,160,89])

add_block('built-in/Inport',[sys,'/',['SSB-ADM',13,'passband1/in_1']])
set_param([sys,'/',['SSB-ADM',13,'passband1/in_1']],...
		'position',[210,110,230,130])

add_block('built-in/Gain',[sys,'/',['SSB-ADM',13,'passband1/Gain1']])
set_param([sys,'/',['SSB-ADM',13,'passband1/Gain1']],...
		'Gain','2',...
		'position',[250,108,275,132])
add_line([sys,'/',['SSB-ADM',13,'passband1']],[165,70;200,70])
add_line([sys,'/',['SSB-ADM',13,'passband1']],[280,120;305,120;305,85;325,85])
add_line([sys,'/',['SSB-ADM',13,'passband1']],[235,120;245,120])
add_line([sys,'/',['SSB-ADM',13,'passband1']],[305,70;325,70])
add_line([sys,'/',['SSB-ADM',13,'passband1']],[360,80;385,80])
add_line([sys,'/',['SSB-ADM',13,'passband1']],[450,80;475,80])
add_line([sys,'/',['SSB-ADM',13,'passband1']],[85,70;105,70])
set_param([sys,'/',['SSB-ADM',13,'passband1']],...
		'Mask Display','plot(0,0,100,100,x,y);SSB ADM',...
		'Mask Type','Passband SSB ADM')
set_param([sys,'/',['SSB-ADM',13,'passband1']],...
		'Mask Dialogue','Demodulate a SSB-AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['SSB-ADM',13,'passband1']],...
		'Mask Translate','Fc=@1*2*pi;num=@2;den=@3;Ph=@4;ts=@5;Pg=Ph+pi/2;[x,y]=moduicon(2);')
set_param([sys,'/',['SSB-ADM',13,'passband1']],...
		'Mask Help','This block demodulates the SSB-SC-AM modulated signal. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. You can specify the modulation to be a USB or LSB modulation.')
set_param([sys,'/',['SSB-ADM',13,'passband1']],...
		'Mask Entries','100/2/pi\/num\/den\/pi/2\/ts\/')


%     Finished composite block ['SSB-ADM',13,'passband1'].

set_param([sys,'/',['SSB-ADM',13,'passband1']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[225,38,305,82])

add_block('built-in/Note',[sys,'/',['Note: the FFT scope block requires DSP Blockset. Remove the FFT',13,'block before the simulation if you don''t have the DSP Blockset.     ']])
set_param([sys,'/',['Note: the FFT scope block requires DSP Blockset. Remove the FFT',13,'block before the simulation if you don''t have the DSP Blockset.     ']],...
		'position',[240,260,245,265])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'ForeGround',5,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','3.000000',...
		'Freq Range','5.000000',...
		'Wave','Saw',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator']],...
		'position',[15,43,60,77])


%     Subsystem  ['USB-AM',13,'spectrum'].

new_system([sys,'/',['USB-AM',13,'spectrum']])
set_param([sys,'/',['USB-AM',13,'spectrum']],'Location',[276,440,798,541])


%     Subsystem  ['USB-AM',13,'spectrum/Buffer'].

new_system([sys,'/',['USB-AM',13,'spectrum/Buffer']])
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer']],'Location',[486,410,806,564])

add_block('built-in/Zero-Order Hold',[sys,'/',['USB-AM',13,'spectrum/Buffer/Zero-Order',13,'Hold']])
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer/Zero-Order',13,'Hold']],...
		'Sample time','sampleTime(1,:)',...
		'position',[60,39,95,71])

add_block('built-in/S-Function',[sys,'/',['USB-AM',13,'spectrum/Buffer/Buffer']])
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer/Buffer']],...
		'function name','sbuffer',...
		'parameters','bufSize,bufOverlap,sampleTime',...
		'position',[120,34,195,76])

add_block('built-in/Inport',[sys,'/',['USB-AM',13,'spectrum/Buffer/in_1']])
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer/in_1']],...
		'position',[10,45,30,65])

add_block('built-in/Outport',[sys,'/',['USB-AM',13,'spectrum/Buffer/Outport']])
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer/Outport']],...
		'position',[285,45,305,65])

add_block('built-in/S-Function',[sys,'/',['USB-AM',13,'spectrum/Buffer/ZOH']])
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer/ZOH']],...
		'function name','szoh',...
		'parameters','sampleTime(2,:)',...
		'position',[220,43,260,67])
add_line([sys,'/',['USB-AM',13,'spectrum/Buffer']],[200,55;215,55])
add_line([sys,'/',['USB-AM',13,'spectrum/Buffer']],[265,55;280,55])
add_line([sys,'/',['USB-AM',13,'spectrum/Buffer']],[35,55;55,55])
add_line([sys,'/',['USB-AM',13,'spectrum/Buffer']],[100,55;115,55])
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer']],...
		'Mask Display','plot(0,0,100,100,[12 28 28 32 28 28],[92 92 94 92 90 92],[32 36 36 40 36 36],[92 92 94 92 90 92],[24 24 28],[92 92 92],[40 44 44 48 44 44],[92 92 94 92 90 92],[52 48 52 52 56 52 52],[92 92 92 94 92 90 92],[56 64 64 57 64 71],[92 92 69 76 69 76],[48 80 80 48 48],[64 64 12 12 64],[56 72],[56 56],[56 72],[48 48],[56 72],[40 40],[56 72],[32 32],[56 72],[24 24])')
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer']],...
		'Mask Type','Buffer',...
		'Mask Dialogue','Buffer input data.|Buffer size:|Buffer overlap:|Sample time:')
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer']],...
		'Mask Translate','bufSize=@1;bufOverlap=@2;sampleTime=dspbufst( @3, @1-@2, @1 - 1);')
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer']],...
		'Mask Help','Accumulates samples (at a sampling interval of Sample time) of the real scalar input into a buffer of length Buffer size. Outputs the content of the buffer in a real vector. Updates the buffer every (Buffer size - Buffer overlap) samples, outputting a frame of the input which overlaps the previous frame by Buffer overlap samples.  Buffer overlap may be zero or negative.')
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer']],...
		'Mask Entries','bufsize\/olap\/ts\/')


%     Finished composite block ['USB-AM',13,'spectrum/Buffer'].

set_param([sys,'/',['USB-AM',13,'spectrum/Buffer']],...
		'position',[75,24,115,56])


%     Subsystem  ['USB-AM',13,'spectrum/FFT',13,'R -> C'].

new_system([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']])
set_param([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']],'Location',[561,290,960,446])

add_block('built-in/Inport',[sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C/in_1']])
set_param([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C/in_1']],...
		'position',[40,75,60,95])

add_block('built-in/Mux',[sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C/Mux']])
set_param([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C/Mux']],...
		'inputs','2',...
		'position',[155,76,185,109])

add_block('built-in/S-Function',[sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C/FFT(u)']])
set_param([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C/FFT(u)']],...
		'function name','srfft',...
		'parameters','sample_time',...
		'position',[225,82,280,108])

add_block('built-in/Outport',[sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C/out_1']])
set_param([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C/out_1']],...
		'position',[310,85,330,105])
add_line([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']],[285,95;305,95])
add_line([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']],[65,85;100,85;100,100;150,100])
add_line([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']],[100,85;150,85])
add_line([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']],[190,95;220,95])
set_param([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']],...
		'Mask Display','plot(0,0,100,100,x,y);  FFT ',...
		'Mask Type','FFT',...
		'Mask Dialogue','Compute FFT of real vector.|Sample time (use -1 to inherit sample time):')
set_param([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']],...
		'Mask Translate','sample_time=@1; [x,y]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']],...
		'Mask Help','Computes the discrete Fourier transform of the real input vector. Sampling and FFT computation occur at each Sample time. The length of the input vector must be a power of two. The output is complex.')
set_param([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']],...
		'Mask Entries','-1\/')


%     Finished composite block ['USB-AM',13,'spectrum/FFT',13,'R -> C'].

set_param([sys,'/',['USB-AM',13,'spectrum/FFT',13,'R -> C']],...
		'position',[235,24,275,56])

add_block('built-in/S-Function',[sys,'/',['USB-AM',13,'spectrum/Buffer Scope']])
set_param([sys,'/',['USB-AM',13,'spectrum/Buffer Scope']],...
		'function name','sbufscop',...
		'parameters','1/ts,1,figpos,nan,rads',...
		'Mask Display','',...
		'position',[410,25,475,55])

add_block('built-in/Inport',[sys,'/',['USB-AM',13,'spectrum/u']])
set_param([sys,'/',['USB-AM',13,'spectrum/u']],...
		'position',[5,30,25,50])

add_block('built-in/S-Function',[sys,'/',['USB-AM',13,'spectrum/Zero Pad']])
set_param([sys,'/',['USB-AM',13,'spectrum/Zero Pad']],...
		'function name','szeropad',...
		'parameters','N')
set_param([sys,'/',['USB-AM',13,'spectrum/Zero Pad']],...
		'Mask Display','plot(0,0,100,100,[51 44 44 51],[92 92 8 8],[73 80 80 73],[92 92 8 8],[56 68],[80 80],[56 68],[72 72],[56 68],[64 64],[56 68],[56 56],[56 68],[48 48],[56 68],[40 40],[64 60 56 55 56 60 64 68 69 68 64],[32 32 28 22 16 12 12 16 22 28 32],[24 24 40 36 40 36],[52 24 24 28 24 20])')
set_param([sys,'/',['USB-AM',13,'spectrum/Zero Pad']],...
		'Mask Type','Zero Pad',...
		'Mask Dialogue','Pad vector with zeros to specified length.|Vector length:',...
		'Mask Translate','N=@1;')
set_param([sys,'/',['USB-AM',13,'spectrum/Zero Pad']],...
		'Mask Help','Increases the length of its input vector to length "Vector length" by appending zeros to the vector. If the Vector length is smaller than the input vector length, the Zero Pad block discards elements at the end of the input vector.')
set_param([sys,'/',['USB-AM',13,'spectrum/Zero Pad']],...
		'Mask Entries','2.^nextpow2(fftlength)\/',...
		'position',[155,24,195,56])


%     Subsystem  ['USB-AM',13,'spectrum/Magnitude'].

new_system([sys,'/',['USB-AM',13,'spectrum/Magnitude']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude']],'Location',[30,216,487,404])

add_block('built-in/Note',[sys,'/',['USB-AM',13,'spectrum/Magnitude/I']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/I']],...
		'position',[240,105,245,110])

add_block('built-in/S-Function',[sys,'/',['USB-AM',13,'spectrum/Magnitude/Sqrt']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Sqrt']],...
		'function name','selmath1',...
		'parameters','''sqrt''',...
		'Mask Display','plot(x*.9+5,y*.9+5,0,0,100,100,[87,65,62,58,54],[50,50,15,30,30])',...
		'Mask Type','Square Root')
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Sqrt']],...
		'Mask Dialogue','Square root of vector elements.',...
		'Mask Translate','[x,y]=fplot(''10*sqrt(x)'',[0 100],''-'',1e-2);')
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Sqrt']],...
		'Mask Help','Computes the square root of the input vector:\ny=sqrt(u)\nThe output is undefined if the input is negative.',...
		'position',[345,78,375,102])


%     Subsystem  ['USB-AM',13,'spectrum/Magnitude/Square'].

new_system([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square']],'Location',[98,193,374,369])

add_block('built-in/Product',[sys,'/',['USB-AM',13,'spectrum/Magnitude/Square/Product']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square/Product']],...
		'position',[150,73,180,97])

add_block('built-in/Outport',[sys,'/',['USB-AM',13,'spectrum/Magnitude/Square/out_1']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square/out_1']],...
		'position',[210,75,230,95])

add_block('built-in/Inport',[sys,'/',['USB-AM',13,'spectrum/Magnitude/Square/in_1']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square/in_1']],...
		'position',[65,70,85,90])
add_line([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square']],[185,85;205,85])
add_line([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square']],[90,80;145,80])
add_line([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square']],[100,80;100,90;145,90])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square']],...
		'Mask Display','plot(x,y); ',...
		'Mask Type','Square',...
		'Mask Dialogue','Square of vector elements.',...
		'Mask Translate','[x,y]=fplot(''x.^2'',[-2 2],''-'',1e-2);')
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square']],...
		'Mask Help','Computes the square of the input vector:\ny=u.^2')


%     Finished composite block ['USB-AM',13,'spectrum/Magnitude/Square'].

set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Square']],...
		'position',[85,78,115,102])

add_block('built-in/Demux',[sys,'/',['USB-AM',13,'spectrum/Magnitude/Split']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Split']],...
		'outputs','2',...
		'Mask Display','plot(0,0,100,100,x,y,x1,y1)',...
		'Mask Type','Complex to Real/Imag',...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Split']],...
		'Mask Translate','o=get_param(gcb,''orientation''); [x,y]=cmplxicn(0,50,o); [x1,y1]=joinicon(o+2); ')
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Split']],...
		'Mask Help','The Decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Split']],...
		'position',[160,78,190,102])

add_block('built-in/Sum',[sys,'/',['USB-AM',13,'spectrum/Magnitude/R^2+I^2']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/R^2+I^2']],...
		'position',[275,64,300,111])

add_block('built-in/Outport',[sys,'/',['USB-AM',13,'spectrum/Magnitude/Magnitude']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/Magnitude']],...
		'position',[410,80,430,100])

add_block('built-in/Inport',[sys,'/',['USB-AM',13,'spectrum/Magnitude/in_1']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/in_1']],...
		'position',[15,80,35,100])

add_block('built-in/Note',[sys,'/',['USB-AM',13,'spectrum/Magnitude/R']])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude/R']],...
		'position',[245,55,250,60])
add_line([sys,'/',['USB-AM',13,'spectrum/Magnitude']],[40,90;80,90])
add_line([sys,'/',['USB-AM',13,'spectrum/Magnitude']],[380,90;405,90])
add_line([sys,'/',['USB-AM',13,'spectrum/Magnitude']],[120,90;155,90])
add_line([sys,'/',['USB-AM',13,'spectrum/Magnitude']],[195,85;225,85;225,75;270,75])
add_line([sys,'/',['USB-AM',13,'spectrum/Magnitude']],[195,95;225,95;225,100;270,100])
add_line([sys,'/',['USB-AM',13,'spectrum/Magnitude']],[305,90;340,90])
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude']],...
		'Mask Display','plot(0,0,100,100,[30,30],[10,90],[90,12],[30,30],[73,80,30],[51,70,30],[64,80],[70,70],[76,83,64],[51,73,73],[78,33,30,77],[65,30,34,70],x,y)')
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude']],...
		'Mask Type','Magnitude',...
		'Mask Dialogue','Magnitude of complex vector.',...
		'Mask Translate','[x,y]=cmplxicn(0,50,get_param(gcb,''orientation'')); ')
set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude']],...
		'Mask Help','Computes the magnitude of the complex input vector:\ny=sqrt(u*conj(u))\nThe output is a real vector.')


%     Finished composite block ['USB-AM',13,'spectrum/Magnitude'].

set_param([sys,'/',['USB-AM',13,'spectrum/Magnitude']],...
		'position',[330,28,360,52])
add_line([sys,'/',['USB-AM',13,'spectrum']],[200,40;230,40])
add_line([sys,'/',['USB-AM',13,'spectrum']],[280,40;325,40])
add_line([sys,'/',['USB-AM',13,'spectrum']],[30,40;70,40])
add_line([sys,'/',['USB-AM',13,'spectrum']],[120,40;150,40])
add_line([sys,'/',['USB-AM',13,'spectrum']],[365,40;405,40])
set_param([sys,'/',['USB-AM',13,'spectrum']],...
		'Mask Display','plot(0,0,100,100,[8 8 92 92 8],[92 40 40 92 92],[16 16 84],[88 48 48],[24 24],[76 48],[32 32 32],[65 48 48],[40 40],[79 48],[48 48],[60 48],[56 56],[58 48],[64 64],[64 48],[72 72 72],[56 49 48],[80 80 80 80],[49 49 48 48],[38 32 32 36 32 32],[33 33 27 27 27 20],[51 44 44 48 44 44 44],[33 33 27 27 27 27 20],[64 60 56 60 60],[33 33 33 33 20])')
set_param([sys,'/',['USB-AM',13,'spectrum']],...
		'Mask Type','FFT Scope')
set_param([sys,'/',['USB-AM',13,'spectrum']],...
		'Mask Dialogue','FFT scope for real input.|Buffer size:|Buffer overlap:|Sample time:|FFT length (must be a power of two):|Units (0 - Hz, 1 - Rads/sec):|Figure position (in pixels):')
set_param([sys,'/',['USB-AM',13,'spectrum']],...
		'Mask Translate','bufsize=@1;olap=@2;ts=@3;fftlength=@4;rads=@5;figpos=@6;')
set_param([sys,'/',['USB-AM',13,'spectrum']],...
		'Mask Help','Successively accumulates Buffer size (real, scalar) signal values at a sampling rate of Sample time, overlapping successive buffers by Buffer overlap samples. Takes the FFT of length "FFT length" of each buffer and displays its magnitude in a figure.')
set_param([sys,'/',['USB-AM',13,'spectrum']],...
		'Mask Entries','128\/0\/ts\/256\/0\/get(0,''DefaultFigurePosition'')\/')


%     Finished composite block ['USB-AM',13,'spectrum'].

set_param([sys,'/',['USB-AM',13,'spectrum']],...
		'hide name',0,...
		'position',[395,63,430,107])


%     Subsystem  ['SSB-AM',13,'baseband'].

new_system([sys,'/',['SSB-AM',13,'baseband']])
set_param([sys,'/',['SSB-AM',13,'baseband']],'Location',[65,60,522,206])

add_block('built-in/Gain',[sys,'/',['SSB-AM',13,'baseband/Gain']])
set_param([sys,'/',['SSB-AM',13,'baseband/Gain']],...
		'Gain','k',...
		'position',[190,75,210,95])

add_block('built-in/Filter',[sys,'/',['SSB-AM',13,'baseband/Filter']])
set_param([sys,'/',['SSB-AM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[90,66,145,104])

add_block('built-in/Outport',[sys,'/',['SSB-AM',13,'baseband/out_1']])
set_param([sys,'/',['SSB-AM',13,'baseband/out_1']],...
		'position',[395,30,415,50])


%     Subsystem  ['SSB-AM',13,'baseband/QAM CE'].

new_system([sys,'/',['SSB-AM',13,'baseband/QAM CE']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],'Location',[125,397,758,690])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/R1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/R1']],...
		'position',[190,15,195,20])

add_block('built-in/Product',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Product']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Product',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Product1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Sum',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Sum']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/R_out']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Mux',[sys,'/',['SSB-AM',13,'baseband/QAM CE/RI2C']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex',...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Inport',[sys,'/',['SSB-AM',13,'baseband/QAM CE/in_1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Outport',[sys,'/',['SSB-AM',13,'baseband/QAM CE/out_1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Constant',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Constant']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Constant',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Constant1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/I1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Inport',[sys,'/',['SSB-AM',13,'baseband/QAM CE/in_2']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/R2']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/I2']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Product',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Product3']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Product',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Product2']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Sum',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Sum1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/I_out']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[550,140;580,140])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[250,100;250,245;305,245])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[280,175;280,200;305,200])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[270,155;270,235;305,235])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[120,40;295,40])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[238,40;238,190;305,190])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[410,220;425,220;425,150;465,150])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'Mask Display','QM DSB\nAM',...
		'Mask Type','Quadrature Multiplexed DSB-SC AM')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'Mask Dialogue','Quadrature multiplexed double-sideband suppressed-carrier amplitude modulation:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'Mask Translate','Ph=@1;ts=@2;x1=cos(Ph);x2=sin(Ph);')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'Mask Help','The Quadratic Multiplexed Double-Sideband-Supressed-Carrier AM block causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. There are two input signal being modulated at the same time by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'Mask Entries','Ph\/ts\/')


%     Finished composite block ['SSB-AM',13,'baseband/QAM CE'].

set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'position',[280,20,360,60])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp82']])
set_param([sys,'/',['SSB-AM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp82']],...
		'position',[355,290,360,295])

add_block('built-in/Inport',[sys,'/',['SSB-AM',13,'baseband/in_1']])
set_param([sys,'/',['SSB-AM',13,'baseband/in_1']],...
		'position',[30,20,50,40])
add_line([sys,'/',['SSB-AM',13,'baseband']],[215,85;240,85;240,50;275,50])
add_line([sys,'/',['SSB-AM',13,'baseband']],[150,85;185,85])
add_line([sys,'/',['SSB-AM',13,'baseband']],[55,30;65,30;65,85;85,85])
add_line([sys,'/',['SSB-AM',13,'baseband']],[65,30;275,30])
add_line([sys,'/',['SSB-AM',13,'baseband']],[365,40;390,40])
set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);SSB AM',...
		'Mask Type','SSB-AM CE using Hilbert transform filter.')
set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'Mask Dialogue','Output complex envelope of a SSB AM\nmodulated signal.|Initial Phase (rad):|Bandwidth of the input signal (Hz):|Time delay for Hilbert transform filter (sec):|Sample time (sec):|"upper" sideband or "lower" sideband:')
set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'Mask Translate','Ph=@1;ban=@2;dly=@3;ts=@4;sd=@5;k=-1;if sd(1)==''l'',k=1;end;if ban>1/ts, ban=1/ts-ts;end;[num,den]=hilbiir(ts,dly,ban);pi2=2*pi;pih=pi/2;[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of a SSB AM modulated signal. This block uses the Hilbert transfer filter. Because the Hilbert transform filter is a non-causal filter, you must use a positive time delay in the implementation. The input signal bandwidth is needed in designing the Hilbert transform filter. You can specify the modulation to be an USB or LSB modulation.')
set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'Mask Entries','pi/4\/1/ts/10\/ts*10\/ts\/''upper''\/')


%     Finished composite block ['SSB-AM',13,'baseband'].

set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[105,193,185,237])


%     Subsystem  ['SSB-ADM',13,'baseband'].

new_system([sys,'/',['SSB-ADM',13,'baseband']])
set_param([sys,'/',['SSB-ADM',13,'baseband']],'Location',[283,122,827,380])

add_block('built-in/Outport',[sys,'/',['SSB-ADM',13,'baseband/out_1']])
set_param([sys,'/',['SSB-ADM',13,'baseband/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Note',[sys,'/',['SSB-ADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Filter',[sys,'/',['SSB-ADM',13,'baseband/Filter']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Product',[sys,'/',['SSB-ADM',13,'baseband/Product']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Sum',[sys,'/',['SSB-ADM',13,'baseband/Sum']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Constant',[sys,'/',['SSB-ADM',13,'baseband/Constant']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Demux',[sys,'/',['SSB-ADM',13,'baseband/Demux']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Demux']],...
		'outputs','2',...
		'position',[105,105,160,140])

add_block('built-in/Product',[sys,'/',['SSB-ADM',13,'baseband/Product1']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Inport',[sys,'/',['SSB-ADM',13,'baseband/in_1']])
set_param([sys,'/',['SSB-ADM',13,'baseband/in_1']],...
		'position',[55,115,75,135])

add_block('built-in/Constant',[sys,'/',['SSB-ADM',13,'baseband/Constant1']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[150,175,170,195])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[450,80;475,80])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[360,80;385,80])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[80,125;100,125])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[180,50;255,50])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[165,130;255,130])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[175,185;210,185;210,140;255,140])
set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);SSB ADM',...
		'Mask Type','SSB-SC ADM CE')
set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nSSB AM modulated signal.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a SSB-SC-AM modulated signal. This block requires you to specify a lowpass filter which eliminates the carrier frequency and keeps the message signal. This block takes a complex signal.')
set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'Mask Entries','num\/den\/pi/4\/ts\/')


%     Finished composite block ['SSB-ADM',13,'baseband'].

set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[225,193,305,237])


%     Subsystem  'LSB-AM'.

new_system([sys,'/','LSB-AM'])
set_param([sys,'/','LSB-AM'],'Location',[76,558,518,713])


%     Subsystem  'LSB-AM/QAM discr-filt'.

new_system([sys,'/','LSB-AM/QAM discr-filt'])
set_param([sys,'/','LSB-AM/QAM discr-filt'],'Location',[302,478,834,743])

add_block('built-in/Clock',[sys,'/','LSB-AM/QAM discr-filt/Clock'])
set_param([sys,'/','LSB-AM/QAM discr-filt/Clock'],...
		'position',[80,85,100,105])

add_block('built-in/Gain',[sys,'/','LSB-AM/QAM discr-filt/Gain'])
set_param([sys,'/','LSB-AM/QAM discr-filt/Gain'],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Inport',[sys,'/','LSB-AM/QAM discr-filt/in_2'])
set_param([sys,'/','LSB-AM/QAM discr-filt/in_2'],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Inport',[sys,'/','LSB-AM/QAM discr-filt/in_1'])
set_param([sys,'/','LSB-AM/QAM discr-filt/in_1'],...
		'position',[160,30,180,50])

add_block('built-in/Outport',[sys,'/','LSB-AM/QAM discr-filt/out_1'])
set_param([sys,'/','LSB-AM/QAM discr-filt/out_1'],...
		'position',[490,90,510,110])

add_block('built-in/Sum',[sys,'/','LSB-AM/QAM discr-filt/Sum2'])
set_param([sys,'/','LSB-AM/QAM discr-filt/Sum2'],...
		'position',[430,90,450,110])

add_block('built-in/Product',[sys,'/','LSB-AM/QAM discr-filt/Product1'])
set_param([sys,'/','LSB-AM/QAM discr-filt/Product1'],...
		'position',[355,112,380,143])

add_block('built-in/Product',[sys,'/','LSB-AM/QAM discr-filt/Product'])
set_param([sys,'/','LSB-AM/QAM discr-filt/Product'],...
		'position',[355,47,380,78])

add_block('built-in/Note',[sys,'/','LSB-AM/QAM discr-filt/Ref: Hambley: An Intro to Comm. Systems. pp72'])
set_param([sys,'/','LSB-AM/QAM discr-filt/Ref: Hambley: An Intro to Comm. Systems. pp72'],...
		'position',[250,305,255,310])

add_block('built-in/Fcn',[sys,'/','LSB-AM/QAM discr-filt/Fcn1'])
set_param([sys,'/','LSB-AM/QAM discr-filt/Fcn1'],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Fcn',[sys,'/','LSB-AM/QAM discr-filt/Fcn'])
set_param([sys,'/','LSB-AM/QAM discr-filt/Fcn'],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])
add_line([sys,'/','LSB-AM/QAM discr-filt'],[185,95;200,95;200,70;225,70])
add_line([sys,'/','LSB-AM/QAM discr-filt'],[200,95;200,120;225,120])
add_line([sys,'/','LSB-AM/QAM discr-filt'],[105,95;125,95])
add_line([sys,'/','LSB-AM/QAM discr-filt'],[385,130;400,130;400,105;425,105])
add_line([sys,'/','LSB-AM/QAM discr-filt'],[385,65;400,65;400,95;425,95])
add_line([sys,'/','LSB-AM/QAM discr-filt'],[185,155;330,155;330,135;350,135])
add_line([sys,'/','LSB-AM/QAM discr-filt'],[330,120;350,120])
add_line([sys,'/','LSB-AM/QAM discr-filt'],[185,40;335,40;335,55;350,55])
add_line([sys,'/','LSB-AM/QAM discr-filt'],[330,70;350,70])
add_line([sys,'/','LSB-AM/QAM discr-filt'],[455,100;485,100])
set_param([sys,'/','LSB-AM/QAM discr-filt'],...
		'Mask Display','QM DSB\nAM',...
		'Mask Type','Quadrature Multiplexed DSB-SC AM')
set_param([sys,'/','LSB-AM/QAM discr-filt'],...
		'Mask Dialogue','Quadrature multiplexed double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency (Hz):|Initial phase (rad):|Sample time:')
set_param([sys,'/','LSB-AM/QAM discr-filt'],...
		'Mask Translate','Am=@1;Fc=@2*2*pi;Ph=@3;ts=@4;')
set_param([sys,'/','LSB-AM/QAM discr-filt'],...
		'Mask Help','The Quadratic Multiplexed Double-Sideband-Supressed-Carrier AM block causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. There are two input signal being modulated at the same time by using two orthogonal sinusoidal carriers.')
set_param([sys,'/','LSB-AM/QAM discr-filt'],...
		'Mask Entries','1\/Fc\/Ph\/ts\/')


%     Finished composite block 'LSB-AM/QAM discr-filt'.

set_param([sys,'/','LSB-AM/QAM discr-filt'],...
		'ForeGround',3,...
		'position',[280,45,360,85])

add_block('built-in/Outport',[sys,'/','LSB-AM/out_1'])
set_param([sys,'/','LSB-AM/out_1'],...
		'position',[400,55,420,75])

add_block('built-in/Note',[sys,'/','LSB-AM/Ref: Hambley: An Intro to Comm. Systems. pp82'])
set_param([sys,'/','LSB-AM/Ref: Hambley: An Intro to Comm. Systems. pp82'],...
		'position',[355,290,360,295])

add_block('built-in/Inport',[sys,'/','LSB-AM/in_1'])
set_param([sys,'/','LSB-AM/in_1'],...
		'position',[30,20,50,40])

add_block('built-in/Filter',[sys,'/','LSB-AM/Filter'])
set_param([sys,'/','LSB-AM/Filter'],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[95,66,150,104])

add_block('built-in/Gain',[sys,'/','LSB-AM/Gain'])
set_param([sys,'/','LSB-AM/Gain'],...
		'Gain','k',...
		'position',[185,72,215,98])
add_line([sys,'/','LSB-AM'],[365,65;395,65])
add_line([sys,'/','LSB-AM'],[55,30;255,30;255,55;275,55])
add_line([sys,'/','LSB-AM'],[55,30;65,30;65,85;90,85])
add_line([sys,'/','LSB-AM'],[155,85;180,85])
add_line([sys,'/','LSB-AM'],[220,85;240,85;240,75;275,75])
set_param([sys,'/','LSB-AM'],...
		'Mask Display','plot(0,0,100,100,x,y);SSB AM',...
		'Mask Type','Passband SSB-AM')
set_param([sys,'/','LSB-AM'],...
		'Mask Dialogue','Modulate the input signal using \nsingle-sideband amplitude modulation\nmethod with Hilbert transform filter.|Carrier frequency (Hz):|Initial Phase (rad):|Bandwidth of the input signal (Hz):|Time delay for Hilbert transform filter (sec):|Sample time (sec):|"upper" sideband or "lower" sideband:')
set_param([sys,'/','LSB-AM'],...
		'Mask Translate','Fc=@1;Ph=@2;ban=@3;dly=@4;ts=@5;sd=@6;if ban>1/ts, ban=1/ts-ts;end;[num,den]=hilbiir(ts,dly,ban);pi2=2*pi;pih=pi/2;k=-1;if sd(1)==''l'',k=1;end;[x,y]=moduicon(1);')
set_param([sys,'/','LSB-AM'],...
		'Mask Help','This block modulates the input signal using the SSB-AM method. The block uses Hilbert transfer filter. Hilbert transform filter is a non-causal filter. A positive time delay is requested in the implementation. You can specify the modulation to be an USB or LSB modulation.')
set_param([sys,'/','LSB-AM'],...
		'Mask Entries','100/2/pi\/pi/2\/1/ts/10\/ts*10\/ts\/''lower''\/')


%     Finished composite block 'LSB-AM'.

set_param([sys,'/','LSB-AM'],...
		'ForeGround',4,...
		'position',[110,118,190,162])


%     Subsystem  'LSB-AM spectrum'.

new_system([sys,'/','LSB-AM spectrum'])
set_param([sys,'/','LSB-AM spectrum'],'Location',[276,440,798,541])


%     Subsystem  'LSB-AM spectrum/Magnitude'.

new_system([sys,'/','LSB-AM spectrum/Magnitude'])
set_param([sys,'/','LSB-AM spectrum/Magnitude'],'Location',[30,216,487,404])

add_block('built-in/Note',[sys,'/','LSB-AM spectrum/Magnitude/R'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/R'],...
		'position',[245,55,250,60])

add_block('built-in/Inport',[sys,'/','LSB-AM spectrum/Magnitude/in_1'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/in_1'],...
		'position',[15,80,35,100])

add_block('built-in/Outport',[sys,'/','LSB-AM spectrum/Magnitude/Magnitude'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/Magnitude'],...
		'position',[410,80,430,100])

add_block('built-in/Sum',[sys,'/','LSB-AM spectrum/Magnitude/R^2+I^2'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/R^2+I^2'],...
		'position',[275,64,300,111])

add_block('built-in/Demux',[sys,'/','LSB-AM spectrum/Magnitude/Split'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/Split'],...
		'outputs','2',...
		'Mask Display','plot(0,0,100,100,x,y,x1,y1)',...
		'Mask Type','Complex to Real/Imag',...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/','LSB-AM spectrum/Magnitude/Split'],...
		'Mask Translate','o=get_param(gcb,''orientation''); [x,y]=cmplxicn(0,50,o); [x1,y1]=joinicon(o+2); ')
set_param([sys,'/','LSB-AM spectrum/Magnitude/Split'],...
		'Mask Help','The Decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/','LSB-AM spectrum/Magnitude/Split'],...
		'position',[160,78,190,102])


%     Subsystem  'LSB-AM spectrum/Magnitude/Square'.

new_system([sys,'/','LSB-AM spectrum/Magnitude/Square'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/Square'],'Location',[98,193,374,369])

add_block('built-in/Inport',[sys,'/','LSB-AM spectrum/Magnitude/Square/in_1'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/Square/in_1'],...
		'position',[65,70,85,90])

add_block('built-in/Outport',[sys,'/','LSB-AM spectrum/Magnitude/Square/out_1'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/Square/out_1'],...
		'position',[210,75,230,95])

add_block('built-in/Product',[sys,'/','LSB-AM spectrum/Magnitude/Square/Product'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/Square/Product'],...
		'position',[150,73,180,97])
add_line([sys,'/','LSB-AM spectrum/Magnitude/Square'],[90,80;145,80])
add_line([sys,'/','LSB-AM spectrum/Magnitude/Square'],[100,80;100,90;145,90])
add_line([sys,'/','LSB-AM spectrum/Magnitude/Square'],[185,85;205,85])
set_param([sys,'/','LSB-AM spectrum/Magnitude/Square'],...
		'Mask Display','plot(x,y); ',...
		'Mask Type','Square',...
		'Mask Dialogue','Square of vector elements.',...
		'Mask Translate','[x,y]=fplot(''x.^2'',[-2 2],''-'',1e-2);')
set_param([sys,'/','LSB-AM spectrum/Magnitude/Square'],...
		'Mask Help','Computes the square of the input vector:\ny=u.^2')


%     Finished composite block 'LSB-AM spectrum/Magnitude/Square'.

set_param([sys,'/','LSB-AM spectrum/Magnitude/Square'],...
		'position',[85,78,115,102])

add_block('built-in/S-Function',[sys,'/','LSB-AM spectrum/Magnitude/Sqrt'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/Sqrt'],...
		'function name','selmath1',...
		'parameters','''sqrt''',...
		'Mask Display','plot(x*.9+5,y*.9+5,0,0,100,100,[87,65,62,58,54],[50,50,15,30,30])',...
		'Mask Type','Square Root')
set_param([sys,'/','LSB-AM spectrum/Magnitude/Sqrt'],...
		'Mask Dialogue','Square root of vector elements.',...
		'Mask Translate','[x,y]=fplot(''10*sqrt(x)'',[0 100],''-'',1e-2);')
set_param([sys,'/','LSB-AM spectrum/Magnitude/Sqrt'],...
		'Mask Help','Computes the square root of the input vector:\ny=sqrt(u)\nThe output is undefined if the input is negative.',...
		'position',[345,78,375,102])

add_block('built-in/Note',[sys,'/','LSB-AM spectrum/Magnitude/I'])
set_param([sys,'/','LSB-AM spectrum/Magnitude/I'],...
		'position',[240,105,245,110])
add_line([sys,'/','LSB-AM spectrum/Magnitude'],[305,90;340,90])
add_line([sys,'/','LSB-AM spectrum/Magnitude'],[195,95;225,95;225,100;270,100])
add_line([sys,'/','LSB-AM spectrum/Magnitude'],[195,85;225,85;225,75;270,75])
add_line([sys,'/','LSB-AM spectrum/Magnitude'],[120,90;155,90])
add_line([sys,'/','LSB-AM spectrum/Magnitude'],[380,90;405,90])
add_line([sys,'/','LSB-AM spectrum/Magnitude'],[40,90;80,90])
set_param([sys,'/','LSB-AM spectrum/Magnitude'],...
		'Mask Display','plot(0,0,100,100,[30,30],[10,90],[90,12],[30,30],[73,80,30],[51,70,30],[64,80],[70,70],[76,83,64],[51,73,73],[78,33,30,77],[65,30,34,70],x,y)',...
		'Mask Type','Magnitude')
set_param([sys,'/','LSB-AM spectrum/Magnitude'],...
		'Mask Dialogue','Magnitude of complex vector.',...
		'Mask Translate','[x,y]=cmplxicn(0,50,get_param(gcb,''orientation'')); ')
set_param([sys,'/','LSB-AM spectrum/Magnitude'],...
		'Mask Help','Computes the magnitude of the complex input vector:\ny=sqrt(u*conj(u))\nThe output is a real vector.')


%     Finished composite block 'LSB-AM spectrum/Magnitude'.

set_param([sys,'/','LSB-AM spectrum/Magnitude'],...
		'position',[330,28,360,52])

add_block('built-in/S-Function',[sys,'/','LSB-AM spectrum/Zero Pad'])
set_param([sys,'/','LSB-AM spectrum/Zero Pad'],...
		'function name','szeropad',...
		'parameters','N')
set_param([sys,'/','LSB-AM spectrum/Zero Pad'],...
		'Mask Display','plot(0,0,100,100,[51 44 44 51],[92 92 8 8],[73 80 80 73],[92 92 8 8],[56 68],[80 80],[56 68],[72 72],[56 68],[64 64],[56 68],[56 56],[56 68],[48 48],[56 68],[40 40],[64 60 56 55 56 60 64 68 69 68 64],[32 32 28 22 16 12 12 16 22 28 32],[24 24 40 36 40 36],[52 24 24 28 24 20])')
set_param([sys,'/','LSB-AM spectrum/Zero Pad'],...
		'Mask Type','Zero Pad',...
		'Mask Dialogue','Pad vector with zeros to specified length.|Vector length:',...
		'Mask Translate','N=@1;')
set_param([sys,'/','LSB-AM spectrum/Zero Pad'],...
		'Mask Help','Increases the length of its input vector to length "Vector length" by appending zeros to the vector. If the Vector length is smaller than the input vector length, the Zero Pad block discards elements at the end of the input vector.')
set_param([sys,'/','LSB-AM spectrum/Zero Pad'],...
		'Mask Entries','2.^nextpow2(fftlength)\/',...
		'position',[155,24,195,56])

add_block('built-in/Inport',[sys,'/','LSB-AM spectrum/u'])
set_param([sys,'/','LSB-AM spectrum/u'],...
		'position',[5,30,25,50])

add_block('built-in/S-Function',[sys,'/','LSB-AM spectrum/Buffer Scope'])
set_param([sys,'/','LSB-AM spectrum/Buffer Scope'],...
		'function name','sbufscop',...
		'parameters','1/ts,1,figpos,nan,rads',...
		'Mask Display','',...
		'position',[410,25,475,55])


%     Subsystem  ['LSB-AM spectrum/FFT',13,'R -> C'].

new_system([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']])
set_param([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']],'Location',[561,290,960,446])

add_block('built-in/Outport',[sys,'/',['LSB-AM spectrum/FFT',13,'R -> C/out_1']])
set_param([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C/out_1']],...
		'position',[310,85,330,105])

add_block('built-in/S-Function',[sys,'/',['LSB-AM spectrum/FFT',13,'R -> C/FFT(u)']])
set_param([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C/FFT(u)']],...
		'function name','srfft',...
		'parameters','sample_time',...
		'position',[225,82,280,108])

add_block('built-in/Mux',[sys,'/',['LSB-AM spectrum/FFT',13,'R -> C/Mux']])
set_param([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C/Mux']],...
		'inputs','2',...
		'position',[155,76,185,109])

add_block('built-in/Inport',[sys,'/',['LSB-AM spectrum/FFT',13,'R -> C/in_1']])
set_param([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C/in_1']],...
		'position',[40,75,60,95])
add_line([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']],[190,95;220,95])
add_line([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']],[65,85;100,85;100,100;150,100])
add_line([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']],[100,85;150,85])
add_line([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']],[285,95;305,95])
set_param([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']],...
		'Mask Display','plot(0,0,100,100,x,y);  FFT ',...
		'Mask Type','FFT',...
		'Mask Dialogue','Compute FFT of real vector.|Sample time (use -1 to inherit sample time):')
set_param([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']],...
		'Mask Translate','sample_time=@1; [x,y]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']],...
		'Mask Help','Computes the discrete Fourier transform of the real input vector. Sampling and FFT computation occur at each Sample time. The length of the input vector must be a power of two. The output is complex.')
set_param([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']],...
		'Mask Entries','-1\/')


%     Finished composite block ['LSB-AM spectrum/FFT',13,'R -> C'].

set_param([sys,'/',['LSB-AM spectrum/FFT',13,'R -> C']],...
		'position',[235,24,275,56])


%     Subsystem  'LSB-AM spectrum/Buffer'.

new_system([sys,'/','LSB-AM spectrum/Buffer'])
set_param([sys,'/','LSB-AM spectrum/Buffer'],'Location',[486,410,806,564])

add_block('built-in/S-Function',[sys,'/','LSB-AM spectrum/Buffer/ZOH'])
set_param([sys,'/','LSB-AM spectrum/Buffer/ZOH'],...
		'function name','szoh',...
		'parameters','sampleTime(2,:)',...
		'position',[220,43,260,67])

add_block('built-in/Outport',[sys,'/','LSB-AM spectrum/Buffer/Outport'])
set_param([sys,'/','LSB-AM spectrum/Buffer/Outport'],...
		'position',[285,45,305,65])

add_block('built-in/Inport',[sys,'/','LSB-AM spectrum/Buffer/in_1'])
set_param([sys,'/','LSB-AM spectrum/Buffer/in_1'],...
		'position',[10,45,30,65])

add_block('built-in/S-Function',[sys,'/','LSB-AM spectrum/Buffer/Buffer'])
set_param([sys,'/','LSB-AM spectrum/Buffer/Buffer'],...
		'function name','sbuffer',...
		'parameters','bufSize,bufOverlap,sampleTime',...
		'position',[120,34,195,76])

add_block('built-in/Zero-Order Hold',[sys,'/',['LSB-AM spectrum/Buffer/Zero-Order',13,'Hold']])
set_param([sys,'/',['LSB-AM spectrum/Buffer/Zero-Order',13,'Hold']],...
		'Sample time','sampleTime(1,:)',...
		'position',[60,39,95,71])
add_line([sys,'/','LSB-AM spectrum/Buffer'],[100,55;115,55])
add_line([sys,'/','LSB-AM spectrum/Buffer'],[35,55;55,55])
add_line([sys,'/','LSB-AM spectrum/Buffer'],[265,55;280,55])
add_line([sys,'/','LSB-AM spectrum/Buffer'],[200,55;215,55])
set_param([sys,'/','LSB-AM spectrum/Buffer'],...
		'Mask Display','plot(0,0,100,100,[12 28 28 32 28 28],[92 92 94 92 90 92],[32 36 36 40 36 36],[92 92 94 92 90 92],[24 24 28],[92 92 92],[40 44 44 48 44 44],[92 92 94 92 90 92],[52 48 52 52 56 52 52],[92 92 92 94 92 90 92],[56 64 64 57 64 71],[92 92 69 76 69 76],[48 80 80 48 48],[64 64 12 12 64],[56 72],[56 56],[56 72],[48 48],[56 72],[40 40],[56 72],[32 32],[56 72],[24 24])')
set_param([sys,'/','LSB-AM spectrum/Buffer'],...
		'Mask Type','Buffer',...
		'Mask Dialogue','Buffer input data.|Buffer size:|Buffer overlap:|Sample time:',...
		'Mask Translate','bufSize=@1;bufOverlap=@2;sampleTime=dspbufst( @3, @1-@2, @1 - 1);')
set_param([sys,'/','LSB-AM spectrum/Buffer'],...
		'Mask Help','Accumulates samples (at a sampling interval of Sample time) of the real scalar input into a buffer of length Buffer size. Outputs the content of the buffer in a real vector. Updates the buffer every (Buffer size - Buffer overlap) samples, outputting a frame of the input which overlaps the previous frame by Buffer overlap samples.  Buffer overlap may be zero or negative.')
set_param([sys,'/','LSB-AM spectrum/Buffer'],...
		'Mask Entries','bufsize\/olap\/ts\/')


%     Finished composite block 'LSB-AM spectrum/Buffer'.

set_param([sys,'/','LSB-AM spectrum/Buffer'],...
		'position',[75,24,115,56])
add_line([sys,'/','LSB-AM spectrum'],[365,40;405,40])
add_line([sys,'/','LSB-AM spectrum'],[120,40;150,40])
add_line([sys,'/','LSB-AM spectrum'],[30,40;70,40])
add_line([sys,'/','LSB-AM spectrum'],[280,40;325,40])
add_line([sys,'/','LSB-AM spectrum'],[200,40;230,40])
set_param([sys,'/','LSB-AM spectrum'],...
		'Mask Display','plot(0,0,100,100,[8 8 92 92 8],[92 40 40 92 92],[16 16 84],[88 48 48],[24 24],[76 48],[32 32 32],[65 48 48],[40 40],[79 48],[48 48],[60 48],[56 56],[58 48],[64 64],[64 48],[72 72 72],[56 49 48],[80 80 80 80],[49 49 48 48],[38 32 32 36 32 32],[33 33 27 27 27 20],[51 44 44 48 44 44 44],[33 33 27 27 27 27 20],[64 60 56 60 60],[33 33 33 33 20])')
set_param([sys,'/','LSB-AM spectrum'],...
		'Mask Type','FFT Scope')
set_param([sys,'/','LSB-AM spectrum'],...
		'Mask Dialogue','FFT scope for real input.|Buffer size:|Buffer overlap:|Sample time:|FFT length (must be a power of two):|Units (0 - Hz, 1 - Rads/sec):|Figure position (in pixels):')
set_param([sys,'/','LSB-AM spectrum'],...
		'Mask Translate','bufsize=@1;olap=@2;ts=@3;fftlength=@4;rads=@5;figpos=@6;')
set_param([sys,'/','LSB-AM spectrum'],...
		'Mask Help','Successively accumulates Buffer size (real, scalar) signal values at a sampling rate of Sample time, overlapping successive buffers by Buffer overlap samples. Takes the FFT of length "FFT length" of each buffer and displays its magnitude in a figure.')
set_param([sys,'/','LSB-AM spectrum'],...
		'Mask Entries','128\/0\/ts\/256\/0\/get(0,''DefaultFigurePosition'')\/')


%     Finished composite block 'LSB-AM spectrum'.

set_param([sys,'/','LSB-AM spectrum'],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[240,118,275,162])
add_line(sys,[390,35;430,35])
add_line(sys,[65,60;80,60;80,15;345,15])
add_line(sys,[195,60;220,60])
add_line(sys,[310,60;320,60;320,35;345,35])
add_line(sys,[310,215;325,215;325,55;345,55])
add_line(sys,[80,60;105,60])
add_line(sys,[80,60;80,215;100,215])
add_line(sys,[190,215;220,215])
add_line(sys,[205,60;205,85;390,85])
add_line(sys,[80,140;105,140])
add_line(sys,[195,140;235,140])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
