function [ret,x0,str,ts,xts]=tgrand(t,x,u,flag);
%TGRAND	is the M-file description of the SIMULINK system named TGRAND.
%	The block-diagram can be displayed by typing: TGRAND.
%
%	SYS=TGRAND(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TGRAND to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TGRAND with a FLAG of zero:
%	[SIZES]=TGRAND([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[102,355,512,499])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[270,29,305,91])


%     Subsystem  'Mean and std'.

new_system([sys,'/','Mean and std'])
set_param([sys,'/','Mean and std'],'Location',[16,148,871,412])

add_block('built-in/Inport',[sys,'/','Mean and std/Actual'])
set_param([sys,'/','Mean and std/Actual'],...
		'position',[25,35,45,55])

add_block('built-in/Digital Clock',[sys,'/','Mean and std/Digital Clock'])
set_param([sys,'/','Mean and std/Digital Clock'],...
		'Sample time','Ts',...
		'position',[45,80,80,110])

add_block('built-in/Fcn',[sys,'/','Mean and std/Fcn2'])
set_param([sys,'/','Mean and std/Fcn2'],...
		'Expr','u[1]/Ts +1',...
		'position',[105,83,165,107])

add_block('built-in/Unit Delay',[sys,'/','Mean and std/Unit Delay1'])
set_param([sys,'/','Mean and std/Unit Delay1'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[350,87,400,103])

add_block('built-in/Outport',[sys,'/','Mean and std/mean value'])
set_param([sys,'/','Mean and std/mean value'],...
		'position',[545,45,565,65])

add_block('built-in/Mux',[sys,'/','Mean and std/Mux1'])
set_param([sys,'/','Mean and std/Mux1'],...
		'inputs','3',...
		'position',[235,39,265,71])

add_block('built-in/Fcn',[sys,'/','Mean and std/Fcn3'])
set_param([sys,'/','Mean and std/Fcn3'],...
		'Expr','(u[3]*(u[2]-1) + u[1])/u[2]',...
		'position',[290,41,465,69])

add_block('built-in/Mux',[sys,'/','Mean and std/Mux'])
set_param([sys,'/','Mean and std/Mux'],...
		'inputs','3',...
		'position',[235,134,265,166])

add_block('built-in/Unit Delay',[sys,'/','Mean and std/Unit Delay'])
set_param([sys,'/','Mean and std/Unit Delay'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[345,192,395,208])

add_block('built-in/Fcn',[sys,'/','Mean and std/Fcn'])
set_param([sys,'/','Mean and std/Fcn'],...
		'Expr','(u[3]*(u[2]-1) + u[1]*u[1])/u[2]',...
		'position',[290,136,465,164])

add_block('built-in/Sum',[sys,'/','Mean and std/Sum'])
set_param([sys,'/','Mean and std/Sum'],...
		'inputs','-+',...
		'position',[645,135,665,155])

add_block('built-in/Outport',[sys,'/',['Mean and std/Mean',13,'Squared',13,'Error1']])
set_param([sys,'/',['Mean and std/Mean',13,'Squared',13,'Error1']],...
		'Port','2',...
		'position',[790,135,810,155])

add_block('built-in/Fcn',[sys,'/','Mean and std/Fcn1'])
set_param([sys,'/','Mean and std/Fcn1'],...
		'Expr','sqrt(u[1])',...
		'position',[690,132,755,158])

add_block('built-in/Mux',[sys,'/','Mean and std/Mux2'])
set_param([sys,'/','Mean and std/Mux2'],...
		'inputs','2',...
		'position',[515,101,545,134])

add_block('built-in/Fcn',[sys,'/','Mean and std/Fcn4'])
set_param([sys,'/','Mean and std/Fcn4'],...
		'Expr','u[1]*u[1]',...
		'position',[555,107,620,133])
add_line([sys,'/','Mean and std'],[85,95;100,95])
add_line([sys,'/','Mean and std'],[340,200;220,200;230,160])
add_line([sys,'/','Mean and std'],[270,150;285,150])
add_line([sys,'/','Mean and std'],[270,55;285,55])
add_line([sys,'/','Mean and std'],[760,145;785,145])
add_line([sys,'/','Mean and std'],[170,95;190,95;190,150;230,150])
add_line([sys,'/','Mean and std'],[190,95;190,55;230,55])
add_line([sys,'/','Mean and std'],[345,95;210,95;210,65;230,65])
add_line([sys,'/','Mean and std'],[50,45;230,45])
add_line([sys,'/','Mean and std'],[200,45;200,140;230,140])
add_line([sys,'/','Mean and std'],[670,145;685,145])
add_line([sys,'/','Mean and std'],[470,150;480,150;480,200;400,200])
add_line([sys,'/','Mean and std'],[480,150;640,150])
add_line([sys,'/','Mean and std'],[625,120;625,140;640,140])
add_line([sys,'/','Mean and std'],[470,55;540,55])
add_line([sys,'/','Mean and std'],[495,55;495,95;405,95])
add_line([sys,'/','Mean and std'],[495,95;495,110;510,110])
add_line([sys,'/','Mean and std'],[190,125;510,125])
add_line([sys,'/','Mean and std'],[550,120;550,120])
set_param([sys,'/','Mean and std'],...
		'Mask Display','Mean\n& std',...
		'Mask Type','Running mean and std',...
		'Mask Dialogue','Output the running mean to 1st outport\nand running standard deviation to 2nd outport.|Sample time (sec):')
set_param([sys,'/','Mean and std'],...
		'Mask Translate','Ts=@1;')
set_param([sys,'/','Mean and std'],...
		'Mask Help','This block updates the running mean and standard deviation (std) value at sampling time point. The mean and std are outputted into 1st and 2nd outports respectively.')
set_param([sys,'/','Mean and std'],...
		'Mask Entries','.1\/')


%     Finished composite block 'Mean and std'.

set_param([sys,'/','Mean and std'],...
		'hide name',0,...
		'position',[150,28,230,72])

add_block('built-in/Constant',[sys,'/','Expected value'])
set_param([sys,'/','Expected value'],...
		'Value','[0 1]',...
		'position',[175,85,215,105])


%     Subsystem  ['Mean and',13,'std'].

new_system([sys,'/',['Mean and',13,'std']])
set_param([sys,'/',['Mean and',13,'std']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Mean and',13,'std/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Mean and',13,'std/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Mean and',13,'std/x']])
set_param([sys,'/',['Mean and',13,'std/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Mean and',13,'std']],[90,65;125,65])
set_param([sys,'/',['Mean and',13,'std']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Mean and',13,'std']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type:|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/',['Mean and',13,'std']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/',['Mean and',13,'std']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Mean and',13,'std']],...
		'Mask Entries','20\/-.2\/1.2\/''y-/g--/y-./g:/m*/ro/b+''\/.1\/')


%     Finished composite block ['Mean and',13,'std'].

set_param([sys,'/',['Mean and',13,'std']],...
		'hide name',0,...
		'position',[340,41,370,79])


%     Subsystem  ['Gaussian noise',13,'generator1'].

new_system([sys,'/',['Gaussian noise',13,'generator1']])
set_param([sys,'/',['Gaussian noise',13,'generator1']],'Location',[371,386,719,591])

add_block('built-in/State-Space',[sys,'/',['Gaussian noise',13,'generator1/Matrix',13,'Gain']])
set_param([sys,'/',['Gaussian noise',13,'generator1/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Gaussian noise',13,'generator1/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Gaussian noise',13,'generator1/Matrix',13,'Gain']],...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['Gaussian noise',13,'generator1/out_1']])
set_param([sys,'/',['Gaussian noise',13,'generator1/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['Gaussian noise',13,'generator1/Sum']])
set_param([sys,'/',['Gaussian noise',13,'generator1/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['Gaussian noise',13,'generator1/Constant']])
set_param([sys,'/',['Gaussian noise',13,'generator1/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['Gaussian noise',13,'generator1/Random',13,'Number']])
set_param([sys,'/',['Gaussian noise',13,'generator1/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['Gaussian noise',13,'generator1']],[240,95;290,95])
add_line([sys,'/',['Gaussian noise',13,'generator1']],[165,95;205,95])
add_line([sys,'/',['Gaussian noise',13,'generator1']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Gaussian noise',13,'generator1']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['Gaussian noise',13,'generator1']],...
		'Mask Display','plot(0,0,100,100,x,y);Gaussian',...
		'Mask Type','Gaussian noise generator')
set_param([sys,'/',['Gaussian noise',13,'generator1']],...
		'Mask Dialogue','Generate Gaussian distributed noise with\ngiven mean and variance value.|Mean value:|Variance (vector or matrix):|Initial seed:')
set_param([sys,'/',['Gaussian noise',13,'generator1']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);[x,y]=srcsicon(3);')
set_param([sys,'/',['Gaussian noise',13,'generator1']],...
		'Mask Help','When the mean value and seed are vectors, the output of this block is a vector. The length of the vector is the same as the length of the mean value vector or the length of the seed. When the variance entry is a vector, the variance is a diagonal matrix.')
set_param([sys,'/',['Gaussian noise',13,'generator1']],...
		'Mask Entries','0\/1\/654321\/')


%     Finished composite block ['Gaussian noise',13,'generator1'].

set_param([sys,'/',['Gaussian noise',13,'generator1']],...
		'hide name',0,...
		'position',[25,28,105,72])
add_line(sys,[235,40;265,40])
add_line(sys,[235,60;265,60])
add_line(sys,[110,50;145,50])
add_line(sys,[310,60;335,60])
add_line(sys,[220,95;235,95;235,80;265,80])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
