function [ret,x0,str,ts,xts]=tmpam2cd(t,x,u,flag);
%TMPAM2CD	is the M-file description of the SIMULINK system named TMPAM2CD.
%	The block-diagram can be displayed by typing: TMPAM2CD.
%
%	SYS=TMPAM2CD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TMPAM2CD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TMPAM2CD with a FLAG of zero:
%	[SIZES]=TMPAM2CD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[50,366,716,553])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;[num,den]=butter(2,100/pi/2*ts);td=.1;M=8;');


%     Subsystem  ['Eye-diagram',13,'scatter plot'].

new_system([sys,'/',['Eye-diagram',13,'scatter plot']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],'Location',[165,242,460,428])

add_block('built-in/Inport',[sys,'/',['Eye-diagram',13,'scatter plot/in_1']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Eye-diagram',13,'scatter plot/in_2']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/in_2']],...
		'Port','2',...
		'position',[20,115,40,135])

add_block('built-in/Mux',[sys,'/',['Eye-diagram',13,'scatter plot/Mux']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/Mux']],...
		'inputs','2',...
		'position',[65,70,100,105])

add_block('built-in/S-Function',[sys,'/',['Eye-diagram',13,'scatter plot/Plot1']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/Plot1']],...
		'function name','eyediasi',...
		'parameters','time_range, boundary, kept_length, eye_line, scatter_line, two_d_line',...
		'position',[130,70,200,110])
add_line([sys,'/',['Eye-diagram',13,'scatter plot']],[40,65;45,65;45,80;60,80])
add_line([sys,'/',['Eye-diagram',13,'scatter plot']],[45,125;50,125;60,95])
add_line([sys,'/',['Eye-diagram',13,'scatter plot']],[105,90;125,90])
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);',...
		'Mask Type','Eye-diagram/scatter plot')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Dialogue','Produce eye-pattern diagram/scatter\nplot/x-y plot with the rising edge of the second input as the decision line.|Eye-pattern plot time frame:|Lower and upper bound of in-coming signal (1x2 vector):|Number of saved traces:|Line-type for eye-pattern diagram (0 for no such plot):|Line-type for scatter plot (0 for no such plot):|Line-type for x-y plot (0 for no such plot):')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Translate','time_range=@1;boundary=@2;kept_length=@3;eye_line=@4;scatter_line=@5;two_d_line=@6;[x,y]=srcsicon(10);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Help','This plot opens one, two, or three plots by assigning the line type parameters. The scatter plot point is selected by the rising edge of a trigger signal. A decision line is drawn at the rising edge of the trigger signal.')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Entries','td*2\/[-1.2 1.2]\/10\/''r-/g--/b-.''\/0\/0\/')


%     Finished composite block ['Eye-diagram',13,'scatter plot'].

set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'hide name',0,...
		'position',[570,98,650,142])


%     Subsystem  ['Pulses divide',13,'same sample time'].

new_system([sys,'/',['Pulses divide',13,'same sample time']])
set_param([sys,'/',['Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Entries','td\/1\/-ts\/')


%     Finished composite block ['Pulses divide',13,'same sample time'].

set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'hide name',0,...
		'position',[340,108,420,152])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate1'],[40,70;60,70])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[105,65;125,65])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','3\/20\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[570,43,650,87])


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(300,1,M)\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[10,53,90,97])


%     Subsystem  'MASK map'.

new_system([sys,'/','MASK map'])
set_param([sys,'/','MASK map'],'Location',[520,162,902,335])

add_block('built-in/Constant',[sys,'/','MASK map/Gain diff'])
set_param([sys,'/','MASK map/Gain diff'],...
		'Value','Ac',...
		'position',[180,96,215,124])

add_block('built-in/Sum',[sys,'/','MASK map/Sum1'])
set_param([sys,'/','MASK map/Sum1'],...
		'inputs','+-',...
		'position',[250,63,270,87])

add_block('built-in/Gain',[sys,'/','MASK map/Gain'])
set_param([sys,'/','MASK map/Gain'],...
		'Gain','Kc',...
		'position',[180,25,220,55])

add_block('built-in/Inport',[sys,'/','MASK map/in_1'])
set_param([sys,'/','MASK map/in_1'],...
		'position',[40,30,60,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK map/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[100,24,135,56])

add_block('built-in/Outport',[sys,'/','MASK map/out_1'])
set_param([sys,'/','MASK map/out_1'],...
		'position',[315,65,335,85])
add_line([sys,'/','MASK map'],[140,40;175,40])
add_line([sys,'/','MASK map'],[65,40;95,40])
add_line([sys,'/','MASK map'],[275,75;310,75])
add_line([sys,'/','MASK map'],[220,110;230,110;230,80;245,80])
add_line([sys,'/','MASK map'],[225,40;230,40;230,70;245,70])
set_param([sys,'/','MASK map'],...
		'Mask Display','MASK\nmap',...
		'Mask Type','MASK map')
set_param([sys,'/','MASK map'],...
		'Mask Dialogue','Map a digital symbol onto an analog\nsignal in the range [-1, 1] using M-ary\namplitude shift keying modulation mapping.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/','MASK map'],...
		'Mask Translate','N=@1;Ac=1;Kc=Ac*2/(N-1);td=@2;')
set_param([sys,'/','MASK map'],...
		'Mask Help','This block maps an input digit signal onto a signal in the range [-1, 1]. The coded signal can be modulated using analog\nmodulation blocks. Input digits are in the range [0, M-1], where M is the M-ary number. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/','MASK map'],...
		'Mask Entries','M\/td\/')


%     Finished composite block 'MASK map'.

set_param([sys,'/','MASK map'],...
		'hide name',0,...
		'position',[125,53,205,97])


%     Subsystem  'MASK demap'.

new_system([sys,'/','MASK demap'])
set_param([sys,'/','MASK demap'],'Location',[187,342,628,482])

add_block('built-in/Inport',[sys,'/','MASK demap/in_1'])
set_param([sys,'/','MASK demap/in_1'],...
		'position',[30,35,50,55])

add_block('built-in/S-Function',[sys,'/','MASK demap/Minimum'])
set_param([sys,'/','MASK demap/Minimum'],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[315,45,370,65])

add_block('built-in/Outport',[sys,'/','MASK demap/out_1'])
set_param([sys,'/','MASK demap/out_1'],...
		'position',[400,45,420,65])

add_block('built-in/Abs',[sys,'/','MASK demap/Abs'])
set_param([sys,'/','MASK demap/Abs'],...
		'position',[235,42,270,68])

add_block('built-in/Sum',[sys,'/','MASK demap/Sum2'])
set_param([sys,'/','MASK demap/Sum2'],...
		'inputs','+-',...
		'position',[180,38,200,67])

add_block('built-in/Constant',[sys,'/','MASK demap/Shift key'])
set_param([sys,'/','MASK demap/Shift key'],...
		'Value','sft',...
		'position',[115,93,135,117])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[85,29,120,61])
add_line([sys,'/','MASK demap'],[205,55;230,55])
add_line([sys,'/','MASK demap'],[140,105;155,105;155,60;175,60])
add_line([sys,'/','MASK demap'],[375,55;395,55])
add_line([sys,'/','MASK demap'],[125,45;175,45])
add_line([sys,'/','MASK demap'],[275,55;310,55])
add_line([sys,'/','MASK demap'],[55,45;80,45])
set_param([sys,'/','MASK demap'],...
		'Mask Display','MASK\ndemap',...
		'Mask Type','MASK demap')
set_param([sys,'/','MASK demap'],...
		'Mask Dialogue','Reverse the MASK mapping process\nConvert [-1 1] analog signal to [0, M-1] symbols.|M-ary number (digit integers in ranger [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/','MASK demap'],...
		'Mask Translate','N=@1;Ac=1;sft=[0:N-1]*Ac*2/(N-1)-Ac;td=@2;')
set_param([sys,'/','MASK demap'],...
		'Mask Help','This block demaps a MASK mapped signal back to digit symbols. You can place this block after a amplitude demodulation block. The input of this block is an analog signal in the range [-1, 1]. The demodulation decides the closest integer fitting in [0,M-1] range. When the input symbol interval is a two-elements vector, the second element is offset. The default offset value is 0.')
set_param([sys,'/','MASK demap'],...
		'Mask Entries','M\/[td, td-ts]\/')


%     Finished composite block 'MASK demap'.

set_param([sys,'/','MASK demap'],...
		'hide name',0,...
		'position',[455,53,535,97])


%     Subsystem  ['DSB AM',13,'baseband'].

new_system([sys,'/',['DSB AM',13,'baseband']])
set_param([sys,'/',['DSB AM',13,'baseband']],'Location',[212,430,575,573])

add_block('built-in/Constant',[sys,'/',['DSB AM',13,'baseband/Constant']])
set_param([sys,'/',['DSB AM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[40,65,60,85])

add_block('built-in/Constant',[sys,'/',['DSB AM',13,'baseband/Constant1']])
set_param([sys,'/',['DSB AM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[90,90,110,110])

add_block('built-in/Mux',[sys,'/',['DSB AM',13,'baseband/Mux']])
set_param([sys,'/',['DSB AM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[170,66,205,99])

add_block('built-in/Inport',[sys,'/',['DSB AM',13,'baseband/in_1']])
set_param([sys,'/',['DSB AM',13,'baseband/in_1']],...
		'position',[115,15,135,35])

add_block('built-in/Product',[sys,'/',['DSB AM',13,'baseband/Product']])
set_param([sys,'/',['DSB AM',13,'baseband/Product']],...
		'position',[255,42,280,73])

add_block('built-in/Outport',[sys,'/',['DSB AM',13,'baseband/out_1']])
set_param([sys,'/',['DSB AM',13,'baseband/out_1']],...
		'position',[320,50,340,70])
add_line([sys,'/',['DSB AM',13,'baseband']],[210,85;230,85;230,65;250,65])
add_line([sys,'/',['DSB AM',13,'baseband']],[285,60;315,60])
add_line([sys,'/',['DSB AM',13,'baseband']],[140,25;185,25;185,50;250,50])
add_line([sys,'/',['DSB AM',13,'baseband']],[115,100;130,100;130,90;165,90])
add_line([sys,'/',['DSB AM',13,'baseband']],[65,75;165,75])
set_param([sys,'/',['DSB AM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);DSB AM',...
		'Mask Type','DSB-SC AM CE',...
		'Mask Dialogue','Output the complex envelope of a\nDSB-SC AM modulated signal.|Initial Phase (rad):')
set_param([sys,'/',['DSB AM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);pi2=2*pi;[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['DSB AM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the double-sideband suppressed-carrier amplitude modulated signal. The output is a complex signal.',...
		'Mask Entries','pi/2\/')


%     Finished composite block ['DSB AM',13,'baseband'].

set_param([sys,'/',['DSB AM',13,'baseband']],...
		'hide name',0,...
		'position',[230,53,310,97])


%     Subsystem  ['DSB-ADM',13,'baseband'].

new_system([sys,'/',['DSB-ADM',13,'baseband']])
set_param([sys,'/',['DSB-ADM',13,'baseband']],'Location',[172,360,722,581])

add_block('built-in/Filter',[sys,'/',['DSB-ADM',13,'baseband/Filter2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[310,100,370,140])


%     Subsystem  ['DSB-ADM',13,'baseband/FM CE//VCO'].

new_system([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],'Location',[493,551,1106,698])

add_block('built-in/Constant',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Constant']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Constant']],...
		'Value','Ph',...
		'position',[160,100,180,120])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sum']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sum']],...
		'position',[220,30,240,50])


%     Subsystem  ['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator'].

new_system([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/module']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Unit Delay',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[410,40;440,40])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Entries','pi2\/0\/ts\/')


%     Finished composite block ['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator'].

set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'position',[135,16,195,54])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/out_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/out_1']],...
		'position',[490,35,510,55])

add_block('built-in/Gain',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity1']],...
		'Gain','Ac',...
		'position',[420,31,460,59])

add_block('built-in/Mux',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Mux']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Mux']],...
		'inputs','2',...
		'position',[355,26,390,59])

add_block('built-in/Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/sin']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/sin']],...
		'Expr','sin(u)',...
		'position',[270,81,325,109])

add_block('built-in/Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/cos']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/cos']],...
		'Expr','cos(u)',...
		'position',[270,21,325,49])

add_block('built-in/Gain',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[80,21,120,49])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/in_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/in_1']],...
		'position',[35,25,55,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[245,40;250,40;250,95;265,95])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[185,110;200,110;200,45;215,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[245,40;245,35;265,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[200,35;215,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[330,95;335,95;335,50;350,50])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[395,45;415,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[330,35;350,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[465,45;485,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[125,35;130,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[60,35;75,35])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Display','FM\ncmplx env',...
		'Mask Type','FM with cmplx env out')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Dialogue','Frequency modulation with complex envelop output:|Amplitude constant:|Modulation sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Translate','Ac=@1;Kc=@2*2*pi;Ph=@3;pi2=2*pi;ts=@4;')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Help','The FM block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Entries','1\/1\/Ph\/ts\/')


%     Finished composite block ['DSB-ADM',13,'baseband/FM CE//VCO'].

set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'orientation',2,...
		'position',[215,100,295,140])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/in_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/in_1']],...
		'orientation',2,...
		'position',[185,90,205,110])

add_block('built-in/Filter',[sys,'/',['DSB-ADM',13,'baseband/Filter1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[250,176,305,214])


%     Subsystem  ['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

new_system([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],'Location',[297,318,980,694])

add_block('built-in/Gain',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']],...
		'Gain','-1',...
		'position',[190,210,230,240])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']],...
		'position',[170,225,175,230])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']],...
		'position',[495,110,515,130])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']],...
		'Port','2',...
		'position',[485,280,505,300])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']],...
		'position',[198,108,203,113])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']],...
		'position',[195,65,200,70])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']],...
		'position',[190,185,195,190])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']],...
		'position',[305,83,335,107])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']],...
		'position',[305,143,335,167])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']],...
		'inputs','+-',...
		'position',[380,110,400,130])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']],...
		'position',[305,253,335,277])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']],...
		'position',[305,298,335,322])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']],...
		'position',[380,280,400,300])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']],...
		'position',[450,95,455,100])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']],...
		'position',[450,286,455,291])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']],...
		'position',[55,0,60,5])

add_block('built-in/Demux',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'position',[85,79,160,121])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']],...
		'position',[35,90,55,110])

add_block('built-in/Demux',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'position',[80,194,155,236])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']],...
		'Port','2',...
		'position',[25,205,45,225])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[235,225;260,225;260,160;300,160])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[260,225;260,270;300,270])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,225;185,225])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,120;490,120])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,290;480,290])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[60,100;80,100])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[50,215;75,215])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,95;350,95;350,115;375,115])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,155;350,155;350,125;375,125])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,90;300,90])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[243,90;243,260;300,260])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,205;275,205;275,100;300,100])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[275,205;275,305;300,305])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,110;250,110;250,150;300,150])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[255,150;255,315;300,315])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,265;350,265;350,285;375,285])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,310;350,310;350,295;375,295])


%     Finished composite block ['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],...
		'orientation',2,...
		'position',[40,90,115,130])

add_block('built-in/Filter',[sys,'/',['DSB-ADM',13,'baseband/Filter']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[260,26,315,64])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Product1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Product1']],...
		'orientation',2,...
		'position',[390,110,425,130])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/out_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/out_1']],...
		'position',[485,35,505,55])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[210,120;120,120])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[305,120;300,120])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[385,120;375,120])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[310,195;445,195;445,125;430,125])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[35,120;15,120;15,195;245,195])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[35,100;20,100;20,45;255,45])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[180,100;120,100])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[320,45;480,45])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[445,45;445,115;430,115])
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);DSB ADM',...
		'Mask Type','DSB-SC ADM CE')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nDSB-SC AM modulated signal.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;pi2=pi*2;ts=@4;[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block requires you to specify a lowpass filter that eliminates the carrier frequency and keeps the message signal. This block takes a complex signal.')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Entries','num\/den\/pi/2\/ts\/')


%     Finished composite block ['DSB-ADM',13,'baseband'].

set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'hide name',0,...
		'position',[335,53,415,97])
add_line(sys,[95,75;120,75])
add_line(sys,[105,75;105,30;550,30;550,55;565,55])
add_line(sys,[425,130;565,130])
add_line(sys,[420,75;450,75])
add_line(sys,[435,75;435,110;565,110])
add_line(sys,[210,75;225,75])
add_line(sys,[540,75;565,75])
add_line(sys,[315,75;330,75])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
