function [ret,x0,str,ts,xts]=tmpfs2cd(t,x,u,flag);
%TMPFS2CD	is the M-file description of the SIMULINK system named TMPFS2CD.
%	The block-diagram can be displayed by typing: TMPFS2CD.
%
%	SYS=TMPFS2CD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TMPFS2CD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TMPFS2CD with a FLAG of zero:
%	[SIZES]=TMPFS2CD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[29,84,821,393])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;td=.2;M=8;Fc=100/2/pi;');


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','[0:M-1]''\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[20,63,95,107])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate1'],[40,70;60,70])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[105,65;125,65])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','3\/20\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[700,68,780,112])


%     Subsystem  'M-FSK modulation'.

new_system([sys,'/','M-FSK modulation'])
set_param([sys,'/','M-FSK modulation'],'Location',[657,455,963,648])
set_param([sys,'/','M-FSK modulation'],...
		'Mask Display','.',...
		'Mask Dialogue',' ')


%     Finished composite block 'M-FSK modulation'.

set_param([sys,'/','M-FSK modulation'],...
		'ForeGround',3,...
		'position',[125,50,320,121])


%     Subsystem  'MFSK map'.

new_system([sys,'/','MFSK map'])
set_param([sys,'/','MFSK map'],'Location',[90,420,407,543])

add_block('built-in/Inport',[sys,'/','MFSK map/in_1'])
set_param([sys,'/','MFSK map/in_1'],...
		'position',[45,45,65,65])

add_block('built-in/Gain',[sys,'/','MFSK map/Gain'])
set_param([sys,'/','MFSK map/Gain'],...
		'Gain','Ton',...
		'position',[175,38,225,72])

add_block('built-in/Outport',[sys,'/','MFSK map/out_1'])
set_param([sys,'/','MFSK map/out_1'],...
		'position',[260,45,280,65])

add_block('built-in/Zero-Order Hold',[sys,'/',['MFSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MFSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[105,39,140,71])
add_line([sys,'/','MFSK map'],[230,55;255,55])
add_line([sys,'/','MFSK map'],[70,55;100,55])
add_line([sys,'/','MFSK map'],[145,55;170,55])
set_param([sys,'/','MFSK map'],...
		'Mask Display','MFSK\nmap',...
		'Mask Type','MFSK map')
set_param([sys,'/','MFSK map'],...
		'Mask Dialogue','Map input digital signal to analog tone space for FM modulation. The tone space\nis the frequency distance between two \nconsective digit numbers.|Tone space (Hz):|Input symbol interval and offset (sec):')
set_param([sys,'/','MFSK map'],...
		'Mask Translate','Ton=@1;td=@2;')
set_param([sys,'/','MFSK map'],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the FM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. Tone space is the frequency separation between two consective digits for the input signal. After FM, the modulated signal has a frequency in the range of [Fc, Fc+B]. B is the bandwidth of the FSK, B=(M-1) * Tone_space.')
set_param([sys,'/','MFSK map'],...
		'Mask Entries','M/td/5\/td\/')


%     Finished composite block 'MFSK map'.

set_param([sys,'/','MFSK map'],...
		'hide name',0,...
		'position',[135,63,215,107])


%     Subsystem  'M-FSK coherent demodulation'.

new_system([sys,'/','M-FSK coherent demodulation'])
set_param([sys,'/','M-FSK coherent demodulation'],'Location',[657,455,963,648])
set_param([sys,'/','M-FSK coherent demodulation'],...
		'Mask Display','.',...
		'Mask Dialogue',' ')


%     Finished composite block 'M-FSK coherent demodulation'.

set_param([sys,'/','M-FSK coherent demodulation'],...
		'ForeGround',3,...
		'position',[355,55,580,126])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[625,72,660,123])


%     Subsystem  'Min//max index'.

new_system([sys,'/','Min//max index'])
set_param([sys,'/','Min//max index'],'Location',[192,461,623,564])

add_block('built-in/S-Function',[sys,'/','Min//max index/Maximum'])
set_param([sys,'/','Min//max index/Maximum'],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])

add_block('built-in/Outport',[sys,'/','Min//max index/out_1'])
set_param([sys,'/','Min//max index/out_1'],...
		'position',[335,20,355,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Min//max index/Zero-Order',13,'Hold']])
set_param([sys,'/',['Min//max index/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Inport',[sys,'/','Min//max index/in_1'])
set_param([sys,'/','Min//max index/in_1'],...
		'position',[65,20,85,40])
add_line([sys,'/','Min//max index'],[205,30;235,30])
add_line([sys,'/','Min//max index'],[325,30;330,30])
add_line([sys,'/','Min//max index'],[90,30;160,30])
set_param([sys,'/','Min//max index'],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/','Min//max index'],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/','Min//max index'],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/','Min//max index'],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/','Min//max index'],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block 'Min//max index'.

set_param([sys,'/','Min//max index'],...
		'hide name',0,...
		'position',[495,63,575,107])


%     Subsystem  'M-FSK noncoherent demodulation'.

new_system([sys,'/','M-FSK noncoherent demodulation'])
set_param([sys,'/','M-FSK noncoherent demodulation'],'Location',[657,455,963,648])
set_param([sys,'/','M-FSK noncoherent demodulation'],...
		'Mask Display','.',...
		'Mask Dialogue',' ')


%     Finished composite block 'M-FSK noncoherent demodulation'.

set_param([sys,'/','M-FSK noncoherent demodulation'],...
		'ForeGround',3,...
		'position',[360,175,585,246])


%     Subsystem  'Min//max index1'.

new_system([sys,'/','Min//max index1'])
set_param([sys,'/','Min//max index1'],'Location',[192,461,623,564])

add_block('built-in/Inport',[sys,'/','Min//max index1/in_1'])
set_param([sys,'/','Min//max index1/in_1'],...
		'position',[65,20,85,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Min//max index1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Min//max index1/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Outport',[sys,'/','Min//max index1/out_1'])
set_param([sys,'/','Min//max index1/out_1'],...
		'position',[335,20,355,40])

add_block('built-in/S-Function',[sys,'/','Min//max index1/Maximum'])
set_param([sys,'/','Min//max index1/Maximum'],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])
add_line([sys,'/','Min//max index1'],[90,30;160,30])
add_line([sys,'/','Min//max index1'],[325,30;330,30])
add_line([sys,'/','Min//max index1'],[205,30;235,30])
set_param([sys,'/','Min//max index1'],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/','Min//max index1'],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/','Min//max index1'],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/','Min//max index1'],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/','Min//max index1'],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block 'Min//max index1'.

set_param([sys,'/','Min//max index1'],...
		'hide name',0,...
		'position',[495,188,575,232])


%     Subsystem  ['FM',13,'baseband'].

new_system([sys,'/',['FM',13,'baseband']])
set_param([sys,'/',['FM',13,'baseband']],'Location',[55,571,668,718])

add_block('built-in/S-Function',[sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']])
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/pi2\/',...
		'position',[155,14,215,56])

add_block('built-in/Gain',[sys,'/',['FM',13,'baseband/Sensitivity']])
set_param([sys,'/',['FM',13,'baseband/Sensitivity']],...
		'Gain','pi2',...
		'position',[80,25,120,55])

add_block('built-in/Outport',[sys,'/',['FM',13,'baseband/out_1']])
set_param([sys,'/',['FM',13,'baseband/out_1']],...
		'position',[550,40,570,60])

add_block('built-in/Mux',[sys,'/',['FM',13,'baseband/Mux']])
set_param([sys,'/',['FM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[415,31,450,64])

add_block('built-in/Fcn',[sys,'/',['FM',13,'baseband/sin']])
set_param([sys,'/',['FM',13,'baseband/sin']],...
		'Expr','sin(u)',...
		'position',[330,86,385,114])

add_block('built-in/Fcn',[sys,'/',['FM',13,'baseband/cos']])
set_param([sys,'/',['FM',13,'baseband/cos']],...
		'Expr','cos(u)',...
		'position',[330,26,385,54])

add_block('built-in/Inport',[sys,'/',['FM',13,'baseband/in_1']])
set_param([sys,'/',['FM',13,'baseband/in_1']],...
		'position',[35,25,55,45])

add_block('built-in/Sum',[sys,'/',['FM',13,'baseband/Sum']])
set_param([sys,'/',['FM',13,'baseband/Sum']],...
		'position',[265,30,285,50])

add_block('built-in/Constant',[sys,'/',['FM',13,'baseband/Constant']])
set_param([sys,'/',['FM',13,'baseband/Constant']],...
		'Value','Ph',...
		'position',[180,90,205,110])
add_line([sys,'/',['FM',13,'baseband']],[125,40;150,35])
add_line([sys,'/',['FM',13,'baseband']],[60,35;60,40;75,40])
add_line([sys,'/',['FM',13,'baseband']],[390,100;395,100;395,55;410,55])
add_line([sys,'/',['FM',13,'baseband']],[455,50;545,50])
add_line([sys,'/',['FM',13,'baseband']],[390,40;410,40])
add_line([sys,'/',['FM',13,'baseband']],[220,35;260,35])
add_line([sys,'/',['FM',13,'baseband']],[210,100;250,100;260,45])
add_line([sys,'/',['FM',13,'baseband']],[290,40;325,40])
add_line([sys,'/',['FM',13,'baseband']],[300,40;300,100;325,100])
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);FM',...
		'Mask Type','FM CE')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of the FM signal.|Initial phase (rad):|Sample time (second):|Symbol interval (for digital mod, use Inf for analog mod):')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Translate','Kc=2*pi;Ph=@1;pi2=2*pi;ts=@2;td=@3;if isinf(td),td=inf;end;[x,y]=moduicon(3);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the frequency modulated signal. The output is a complex signal. This block resets the phase at the very beginning of the symbol interval. For continuous-time simulation, the symbol interval can be set as infinity.')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Entries','0\/ts\/td\/')


%     Finished composite block ['FM',13,'baseband'].

set_param([sys,'/',['FM',13,'baseband']],...
		'hide name',0,...
		'position',[230,63,310,107])


%     Subsystem  ['Coh MFSK demod',13,'corr baseband'].

new_system([sys,'/',['Coh MFSK demod',13,'corr baseband']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],'Location',[124,519,842,743])

add_block('built-in/Constant',[sys,'/',['Coh MFSK demod',13,'corr baseband/Shift key']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Shift key']],...
		'Value','sft',...
		'position',[60,48,80,72])

add_block('built-in/Sum',[sys,'/',['Coh MFSK demod',13,'corr baseband/Sum1']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Sum1']],...
		'position',[265,77,290,108])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK demod',13,'corr baseband/Array sin']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Array sin']],...
		'ForeGround',3,...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[325,85,375,105])

add_block('built-in/Constant',[sys,'/',['Coh MFSK demod',13,'corr baseband/Initial phase']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Initial phase']],...
		'Value','Ph',...
		'position',[105,113,125,137])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[125,39,185,81])

add_block('built-in/Inport',[sys,'/',['Coh MFSK demod',13,'corr baseband/in_1']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/in_1']],...
		'position',[260,30,280,50])

add_block('built-in/Demux',[sys,'/',['Coh MFSK demod',13,'corr baseband/Demux']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Demux']],...
		'ForeGround',2,...
		'outputs','2',...
		'position',[330,20,370,55])

add_block('built-in/Product',[sys,'/',['Coh MFSK demod',13,'corr baseband/Product']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Product']],...
		'position',[450,21,475,54])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK demod',13,'corr baseband/Array sin1']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Array sin1']],...
		'ForeGround',4,...
		'function name','arysin',...
		'parameters','''sin''',...
		'position',[330,145,380,165])

add_block('built-in/Product',[sys,'/',['Coh MFSK demod',13,'corr baseband/Product3']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Product3']],...
		'position',[455,131,480,164])

add_block('built-in/Outport',[sys,'/',['Coh MFSK demod',13,'corr baseband/out_1']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/out_1']],...
		'position',[685,105,705,125])

add_block('built-in/Sum',[sys,'/',['Coh MFSK demod',13,'corr baseband/Sum3']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Sum3']],...
		'position',[640,105,660,125])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Entries','N\/td\/ts\/''backward''\/',...
		'position',[505,18,580,62])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Entries','N\/td\/ts\/''backward''\/',...
		'position',[510,128,585,172])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[130,125;230,125;230,100;260,100])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[190,60;225,60;225,85;260,85])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[85,60;120,60])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[295,95;320,95])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[305,95;305,155;325,155])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[285,40;325,40])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[375,30;445,30])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[380,95;415,95;415,45;445,45])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[665,115;680,115])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[590,150;605,150;605,120;635,120])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[585,40;605,40;605,110;635,110])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[480,40;500,40])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[485,150;505,150])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[385,155;450,155])
add_line([sys,'/',['Coh MFSK demod',13,'corr baseband']],[375,45;405,45;405,140;450,140])
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'Mask Display','plot(0,0,100,100,u,v);   Co MFSK',...
		'Mask Type','Baseband coherent MFSK correlation')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'Mask Dialogue','Compute baseband MFSK correlation. Take\nMFSK CE modulated signal. Output a vector\nof correlation result.|M-ary number (input in range [0, M-1]):|Tone space (Hz):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'Mask Translate','pi2=2*pi;N=@1;Ph=@4;Ton=@2;sft=[0:N-1]*Ton*pi2;td=@3;ts=@5;[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'Mask Help','This block calculates the coherent correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their frequency the same as that of FM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MFSK demodulation result is the index of the largest output. The computation is phase sensitive. The input of this block is complex signal.')
set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'Mask Entries','M\/M/td/5\/td\/0\/ts\/')


%     Finished composite block ['Coh MFSK demod',13,'corr baseband'].

set_param([sys,'/',['Coh MFSK demod',13,'corr baseband']],...
		'hide name',0,...
		'position',[370,63,450,107])


%     Subsystem  ['Non-coh MFSK dm',13,'corr baseband'].

new_system([sys,'/',['Non-coh MFSK dm',13,'corr baseband']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],'Location',[69,218,990,452])

add_block('built-in/Constant',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Shift key']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Shift key']],...
		'Value','sft',...
		'position',[40,43,60,67])

add_block('built-in/S-Function',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[105,34,165,76])

add_block('built-in/Sum',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum1']],...
		'position',[210,72,235,103])

add_block('built-in/Sum',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum3']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum3']],...
		'position',[285,108,305,137])

add_block('built-in/Constant',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Initial phase']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Initial phase']],...
		'Value','Ph',...
		'position',[85,118,105,142])

add_block('built-in/Mux',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Mux']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Mux']],...
		'inputs','2',...
		'position',[325,78,355,122])

add_block('built-in/S-Function',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Array sin']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Array sin']],...
		'ForeGround',3,...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[390,90,440,110])

add_block('built-in/S-Function',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Array sin1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Array sin1']],...
		'ForeGround',4,...
		'function name','arysin',...
		'parameters','''sin''',...
		'position',[395,150,445,170])

add_block('built-in/Sum',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum4']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Sum4']],...
		'inputs','++++',...
		'position',[785,87,805,133])

add_block('built-in/Product',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product2']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product2']],...
		'position',[645,141,670,174])

add_block('built-in/Product',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product3']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product3']],...
		'position',[480,136,505,169])

add_block('built-in/Inport',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/in_1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/in_1']],...
		'position',[345,40,365,60])

add_block('built-in/Demux',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux1']],...
		'ForeGround',2,...
		'outputs','2',...
		'position',[395,30,435,65])

add_block('built-in/Product',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product1']],...
		'position',[645,36,670,69])

add_block('built-in/Product',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Product']],...
		'position',[490,31,515,64])

add_block('built-in/Outport',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/out_1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/out_1']],...
		'position',[830,100,850,120])

add_block('built-in/Demux',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux2']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux2']],...
		'outputs','2',...
		'position',[695,140,735,175])

add_block('built-in/Demux',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Demux']],...
		'outputs','2',...
		'position',[685,35,725,70])

add_block('built-in/S-Function',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Entries','N*2\/td\/ts\/''backward''\/',...
		'position',[530,28,605,72])

add_block('built-in/S-Function',[sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Entries','N*2\/td\/ts\/''backward''\/',...
		'position',[525,133,600,177])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[310,125;320,110])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[520,50;525,50])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[610,50;615,45;640,45])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[610,50;615,60;640,60])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[675,55;680,55])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[730,45;760,45;760,95;780,95])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[730,60;755,60;755,105;780,105])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[810,110;825,110])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[65,55;100,55])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[170,55;185,55;185,80;205,80])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[240,90;320,90])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[260,90;260,115;280,115])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[110,130;185,130;185,95;205,95])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[185,130;280,130])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[360,100;385,100])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[370,100;370,160;390,160])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[370,50;390,50])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[675,160;690,160])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[605,155;615,155;615,165;640,165])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[605,155;615,155;615,150;640,150])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[510,155;520,155])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[740,150;755,150;755,115;780,115])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[740,165;760,165;760,125;780,125])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[450,160;475,160])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[440,55;450,55;450,145;475,145])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[440,40;485,40])
add_line([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],[445,100;460,100;460,55;485,55])
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Display','plot(0,0,100,100,u,v);  NC MFSK',...
		'Mask Type','Baseband non-coherent MFSK correlation')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Dialogue','Compute baseband MFSK correlation. Take\nMFSK CE modulated signal. Output a vector\nof correlation result.|M-ary number (input in range [0, M-1]):|Tone space (Hz):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Translate','pi2=2*pi;N=@1;Ph=@4;Ton=@2;sft=[0:N-1]*Ton*pi2;td=@3;ts=@5;[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Help','This block calculates the noncoherent correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their frequency the same as that of FM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MFSK demodulation result is the index of the largest output, using the Min/max demap block. The input of this block is complex signal.')
set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Entries','M\/M/td/5\/td\/0\/ts\/')


%     Finished composite block ['Non-coh MFSK dm',13,'corr baseband'].

set_param([sys,'/',['Non-coh MFSK dm',13,'corr baseband']],...
		'hide name',0,...
		'position',[370,188,450,232])


%     Subsystem  'Graph1'.

new_system([sys,'/','Graph1'])
set_param([sys,'/','Graph1'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Graph1/x'])
set_param([sys,'/','Graph1/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Graph1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph1/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Graph1'],[90,65;125,65])
set_param([sys,'/','Graph1'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph1'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph1'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph1'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph1'],...
		'Mask Entries','5*td\/-.1\/.15\/''r-/y--/b-./g-/c--/w-./m:/r:/y--/b--/g--/c--/w--/m--/r:/y:/b:/g:''\/ts\/')


%     Finished composite block 'Graph1'.

set_param([sys,'/','Graph1'],...
		'position',[635,136,665,174])


%     Subsystem  'Graph2'.

new_system([sys,'/','Graph2'])
set_param([sys,'/','Graph2'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph2/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph2/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph2/x'])
set_param([sys,'/','Graph2/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph2'],[90,65;125,65])
set_param([sys,'/','Graph2'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph2'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph2'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph2'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph2'],...
		'Mask Entries','5*td\/-.001\/.03\/''r-/y--/b-./g-/c--/w-./m:/r:/y--/b--/g--/c--/w--/m--/r:/y:/b:/g:''\/ts\/')


%     Finished composite block 'Graph2'.

set_param([sys,'/','Graph2'],...
		'position',[645,251,675,289])
add_line(sys,[455,210;490,210])
add_line(sys,[475,210;475,270;640,270])
add_line(sys,[455,85;490,85])
add_line(sys,[475,85;475,155;630,155])
add_line(sys,[315,85;365,85])
add_line(sys,[345,85;345,210;365,210])
add_line(sys,[580,210;595,210;595,110;620,110])
add_line(sys,[220,85;225,85])
add_line(sys,[100,85;100,30;675,30;675,80;695,80])
add_line(sys,[580,85;620,85])
add_line(sys,[100,85;130,85])
add_line(sys,[665,100;695,100])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
