function [ret,x0,str,ts,xts]=tstam(t,x,u,flag);
%TSTAM   is the M-file description of the SIMULINK system named TSTAM.
%  The block-diagram can be displayed by typing: TSTAM.
%
%  SYS=TSTAM(T,X,U,FLAG) returns depending on FLAG certain
%        system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes TSTAM to return state derivatives, FLAG=2
%        discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling TSTAM with a FLAG of zero:
%     [SIZES]=TSTAM([],[],[],0),  returns a vector, SIZES, which
%     contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs
%              SIZES(5) number of roots (currently unsupported)
%               SIZES(6) direct feedthrough flag
%               SIZES(7) number of sample times
%
%       For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[36,79,816,331])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.005')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['DSB-SC',13,'AM'].

new_system([sys,'/',['DSB-SC',13,'AM']])
set_param([sys,'/',['DSB-SC',13,'AM']],'Location',[112,331,527,488])

add_block('built-in/Constant',[sys,'/',['DSB-SC',13,'AM/Constant']])
set_param([sys,'/',['DSB-SC',13,'AM/Constant']],...
          'Value','Fc',...
                'position',[30,75,50,95])


%     Subsystem  ['DSB-SC',13,'AM/Module',13,'Integrator'].

new_system([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Outport',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/out_1']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/out_1']],...
            'position',[370,30,390,50])

add_block('built-in/Sum',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Sum']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Sum']],...
               'position',[195,30,215,50])

add_block('built-in/Constant',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/one']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/one']],...
          'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Reset Integrator',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Reset',13,'integrator']],...
                'position',[110,19,150,51])

add_block('built-in/Fcn',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/module']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/module']],...
         'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Memory',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Memory']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Memory']],...
              'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Inport',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/in_1']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/in_1']],...
         'position',[35,15,55,35])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[340,40;340,90;265,90])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[205,90;180,90;190,45])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],...
         'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator',...
             'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],...
                'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],...
          'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],...
          'Mask Entries','1\/0\/')


%     Finished composite block ['DSB-SC',13,'AM/Module',13,'Integrator'].

set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],...
              'position',[75,64,140,106])

add_block('built-in/Fcn',[sys,'/',['DSB-SC',13,'AM/Fcn']])
set_param([sys,'/',['DSB-SC',13,'AM/Fcn']],...
             'Expr','sin(u[1]*pi2+Ph)',...
           'position',[160,71,280,99])

add_block('built-in/Outport',[sys,'/',['DSB-SC',13,'AM/out_1']])
set_param([sys,'/',['DSB-SC',13,'AM/out_1']],...
             'position',[380,50,400,70])

add_block('built-in/Inport',[sys,'/',['DSB-SC',13,'AM/in_1']])
set_param([sys,'/',['DSB-SC',13,'AM/in_1']],...
                'position',[230,15,250,35])

add_block('built-in/Product',[sys,'/',['DSB-SC',13,'AM/Product']])
set_param([sys,'/',['DSB-SC',13,'AM/Product']],...
         'position',[340,42,365,73])
add_line([sys,'/',['DSB-SC',13,'AM']],[255,25;310,25;310,50;335,50])
add_line([sys,'/',['DSB-SC',13,'AM']],[370,60;375,60])
add_line([sys,'/',['DSB-SC',13,'AM']],[55,85;70,85])
add_line([sys,'/',['DSB-SC',13,'AM']],[145,85;155,85])
add_line([sys,'/',['DSB-SC',13,'AM']],[285,85;305,85;305,65;335,65])
set_param([sys,'/',['DSB-SC',13,'AM']],...
           'Mask Display','DSB-SC\nAM',...
         'Mask Type','DSB-SC AM')
set_param([sys,'/',['DSB-SC',13,'AM']],...
              'Mask Dialogue','Double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency (Hz):|Initial Phase (rad):',...
             'Mask Translate','Ac=@1;Fc=@2;Ph=@3;pi2=2*pi;')
set_param([sys,'/',['DSB-SC',13,'AM']],...
               'Mask Help','The Double-Sideband-Supressed-Carrier Amplitude Modulation causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation.')
set_param([sys,'/',['DSB-SC',13,'AM']],...
            'Mask Entries','1\/100\/0\/')


%     Finished composite block ['DSB-SC',13,'AM'].

set_param([sys,'/',['DSB-SC',13,'AM']],...
               'position',[255,22,315,58])

add_block('built-in/Sine Wave',[sys,'/','Sine wave'])
set_param([sys,'/','Sine wave'],...
             'ForeGround',2,...
              'frequency','30',...
            'position',[145,30,165,50])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
             'orientation',2,...
             'inputs','5',...
                'position',[140,70,180,100])


%     Subsystem  ['AM with',13,'Carrier1'].

new_system([sys,'/',['AM with',13,'Carrier1']])
set_param([sys,'/',['AM with',13,'Carrier1']],'Location',[184,550,815,693])

add_block('built-in/Note',[sys,'/',['AM with',13,'Carrier1/Ref: Hambley: An Intro to Comm. Systems. pp76']])
set_param([sys,'/',['AM with',13,'Carrier1/Ref: Hambley: An Intro to Comm. Systems. pp76']],...
            'position',[180,155,185,160])


%     Subsystem  ['AM with',13,'Carrier1/Module',13,'Integrator'].

new_system([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']])
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/in_1']])
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/in_1']],...
                'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/Memory']])
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/Memory']],...
          'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/module']])
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/module']],...
          'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/Reset',13,'integrator']],...
                'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/one']])
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/one']],...
            'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/Sum']])
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/Sum']],...
           'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/out_1']])
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator/out_1']],...
         'position',[370,30,390,50])
add_line([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator',...
             'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],...
         'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],...
           'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],...
           'Mask Entries','1\/0\/')


%     Finished composite block ['AM with',13,'Carrier1/Module',13,'Integrator'].

set_param([sys,'/',['AM with',13,'Carrier1/Module',13,'Integrator']],...
                'position',[90,59,155,101])

add_block('built-in/Constant',[sys,'/',['AM with',13,'Carrier1/Constant']])
set_param([sys,'/',['AM with',13,'Carrier1/Constant']],...
                'Value','Fc',...
                'position',[40,70,60,90])

add_block('built-in/Fcn',[sys,'/',['AM with',13,'Carrier1/Fcn']])
set_param([sys,'/',['AM with',13,'Carrier1/Fcn']],...
         'Expr','sin(u[1]*pi2+Ph)',...
           'position',[190,66,310,94])

add_block('built-in/Outport',[sys,'/',['AM with',13,'Carrier1/out_1']])
set_param([sys,'/',['AM with',13,'Carrier1/out_1']],...
               'position',[535,30,555,50])

add_block('built-in/Sum',[sys,'/',['AM with',13,'Carrier1/Sum']])
set_param([sys,'/',['AM with',13,'Carrier1/Sum']],...
               'position',[440,30,460,50])

add_block('built-in/Inport',[sys,'/',['AM with',13,'Carrier1/in_1']])
set_param([sys,'/',['AM with',13,'Carrier1/in_1']],...
          'position',[300,15,320,35])

add_block('built-in/Product',[sys,'/',['AM with',13,'Carrier1/Product']])
set_param([sys,'/',['AM with',13,'Carrier1/Product']],...
           'position',[360,20,385,40])
add_line([sys,'/',['AM with',13,'Carrier1']],[465,40;530,40])
add_line([sys,'/',['AM with',13,'Carrier1']],[325,25;355,25])
add_line([sys,'/',['AM with',13,'Carrier1']],[390,30;405,30;405,35;435,35])
add_line([sys,'/',['AM with',13,'Carrier1']],[160,80;185,80])
add_line([sys,'/',['AM with',13,'Carrier1']],[65,80;85,80])
add_line([sys,'/',['AM with',13,'Carrier1']],[315,80;330,80;330,35;355,35])
add_line([sys,'/',['AM with',13,'Carrier1']],[330,80;425,80;435,45])
set_param([sys,'/',['AM with',13,'Carrier1']],...
                'Mask Display','AM with\nCarrier',...
           'Mask Type','AM with Carrier',...
               'Mask Dialogue','Amplitude modulation with carrier:|Amplitude scale factor:|Carrier frequency:|Initial phase:')
set_param([sys,'/',['AM with',13,'Carrier1']],...
                'Mask Translate','Ac=@1;Fc=@2;Ph=@3;pi2=2*pi;')
set_param([sys,'/',['AM with',13,'Carrier1']],...
                'Mask Help','AM with Carrier. This block causes the amplitude of the sinusoid carrier to depend on the message signal plus the carrier signal. The modulated signal has added onto the carrier signal.')
set_param([sys,'/',['AM with',13,'Carrier1']],...
               'Mask Entries','1\/100\/0\/')


%     Finished composite block ['AM with',13,'Carrier1'].

set_param([sys,'/',['AM with',13,'Carrier1']],...
         'position',[265,122,325,158])


%     Subsystem  ['ADM by',13,'Envelop detector'].

new_system([sys,'/',['ADM by',13,'Envelop detector']])
set_param([sys,'/',['ADM by',13,'Envelop detector']],'Location',[576,377,911,527])

add_block('built-in/Outport',[sys,'/',['ADM by',13,'Envelop detector/out_1']])
set_param([sys,'/',['ADM by',13,'Envelop detector/out_1']],...
             'position',[290,30,310,50])

add_block('built-in/Sum',[sys,'/',['ADM by',13,'Envelop detector/Sum']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Sum']],...
         'inputs','+-',...
               'position',[240,30,260,50])

add_block('built-in/Inport',[sys,'/',['ADM by',13,'Envelop detector/in_1']])
set_param([sys,'/',['ADM by',13,'Envelop detector/in_1']],...
            'position',[40,25,60,45])


%     Subsystem  ['ADM by',13,'Envelop detector/Envelop',13,'Detector'].

new_system([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],'Location',[86,374,774,617])

add_block('built-in/Gain',[sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Gain1']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Gain1']],...
               'Gain','g',...
          'position',[585,100,605,120])

add_block('built-in/Outport',[sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/out_1']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/out_1']],...
           'position',[625,100,645,120])

add_block('built-in/Gain',[sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Gain']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Gain']],...
                'Gain','g',...
          'position',[65,100,85,120])

add_block('built-in/Inport',[sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/in_1']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/in_1']],...
                'position',[15,100,35,120])

add_block('built-in/Switch',[sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Switch']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Switch']],...
            'Threshold','eps',...
           'position',[505,94,530,126])

add_block('built-in/Memory',[sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Memory']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Memory']],...
           'position',[140,35,180,65])

add_block('built-in/Memory',[sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Memory2']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Memory2']],...
          'orientation',2,...
             'position',[495,155,535,185])

add_block('built-in/Relational Operator',[sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Relational',13,'Operator1']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Relational',13,'Operator1']],...
               'Operator','>',...
              'position',[385,98,415,122])

add_block('built-in/Memory',[sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Memory1']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Memory1']],...
         'position',[300,125,340,155])

add_block('built-in/Relational Operator',[sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Relational',13,'Operator']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector/Relational',13,'Operator']],...
         'position',[225,93,255,117])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[610,110;620,110])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[535,110;560,110;560,170;540,170])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[560,110;580,110])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[90,110;105,110;105,50;135,50])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[105,110;220,110])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[40,110;60,110])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[490,170;480,170;480,120;500,120])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[420,110;500,110])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[260,105;270,105;270,140;295,140])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[270,105;380,105])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[345,140;355,140;355,115;380,115])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[185,50;195,50;195,100;220,100])
add_line([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],[195,50;490,50;500,100])
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],...
           'Mask Display','Envelop\nDetector',...
          'Mask Type','Envelop Detector',...
              'Mask Dialogue','Envelop Detector:|Boundary Side (''upper'' or ''lower''):')
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],...
              'Mask Translate','x=@1;if length(x)<2, error(''Error in Envelop Detector''); end; x=x(1:2); g=1; if x==''lo'', g=-1; end;')
set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],...
               'Mask Help','Envelop Detector detects the envelop of a signal.',...
             'Mask Entries','''upper''\/')


%     Finished composite block ['ADM by',13,'Envelop detector/Envelop',13,'Detector'].

set_param([sys,'/',['ADM by',13,'Envelop detector/Envelop',13,'Detector']],...
               'position',[110,16,175,54])

add_block('built-in/Constant',[sys,'/',['ADM by',13,'Envelop detector/Constant']])
set_param([sys,'/',['ADM by',13,'Envelop detector/Constant']],...
          'Value','Ac',...
                'position',[165,95,185,115])
add_line([sys,'/',['ADM by',13,'Envelop detector']],[265,40;285,40])
add_line([sys,'/',['ADM by',13,'Envelop detector']],[180,35;235,35])
add_line([sys,'/',['ADM by',13,'Envelop detector']],[65,35;105,35])
add_line([sys,'/',['ADM by',13,'Envelop detector']],[190,105;210,105;210,45;235,45])
set_param([sys,'/',['ADM by',13,'Envelop detector']],...
             'Mask Display','ADM by\nenvelop',...
            'Mask Type','AM with Carrier',...
               'Mask Dialogue','Amplitude modulation with carrier:|Carrier amplitude:',...
             'Mask Translate','Ac=@1;')
set_param([sys,'/',['ADM by',13,'Envelop detector']],...
              'Mask Help','Amplitude Demodulation by Envelop. This block demodulates the Signal modulated using AM with Carrier method.',...
               'Mask Entries','1\/')


%     Finished composite block ['ADM by',13,'Envelop detector'].

set_param([sys,'/',['ADM by',13,'Envelop detector']],...
           'orientation',2,...
             'ForeGround',6,...
              'position',[385,155,445,195])


%     Subsystem  ['Auto-Scale',13,'Graph1'].

new_system([sys,'/',['Auto-Scale',13,'Graph1']])
set_param([sys,'/',['Auto-Scale',13,'Graph1']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph1/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph1/x']],...
               'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph1/S-function',13,'M-file which plots',13,'lines',13,'']],...
                'function name','sfunyst',...
           'parameters','ax, color, npts, dt',...
          'position',[130,55,180,75])
add_line([sys,'/',['Auto-Scale',13,'Graph1']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
              'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
              'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
         'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):|Sample time:')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
         'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=@6;')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
               'Mask Help','Uses MATLAB''s graph window.\nUse only one block per system.\nLine type must be in quotes.\nSee the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
          'Mask Entries','.5\/-1.5\/1.5\/200\/''r-/y--/b-./g:/m-/ro/b+''\/0\/')


%     Finished composite block ['Auto-Scale',13,'Graph1'].

set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
               'orientation',2,...
             'position',[50,65,80,105])


%     Subsystem  ['DSB-SC-ADM',13,'by-pilot-carrier'].

new_system([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],'Location',[91,464,741,629])

add_block('built-in/Note',[sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Ref: Hambley: An Intro to Comm. Systems. pp67']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Ref: Hambley: An Intro to Comm. Systems. pp67']],...
                'position',[615,300,620,305])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/in_1']],...
          'position',[25,15,45,35])

add_block('built-in/Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/BandPassFilter',13,'pass Fc']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/BandPassFilter',13,'pass Fc']],...
          'Numerator','nb',...
            'Denominator','db',...
          'position',[95,68,145,102])

add_block('built-in/Look Up Table',[sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Coulombic',13,'Friction']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Coulombic',13,'Friction']],...
               'Input_Values','[-1,0,0,1]',...
         'Output_Values','[-gain-ini -ini ini gain+ini]')
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Coulombic',13,'Friction']],...
            'Mask Display','plot([-1 0 0 1],[-gain-ini, -ini, ini, gain+ini],[-1 1],[0 0],[0 0],[-x,x])',...
                'Mask Type','Coulombic Friction')
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Coulombic',13,'Friction']],...
           'Mask Dialogue','Coulombic Friction\ny = sign(x) * (Gain * abs(x) + Offset)|Offset discontinuity at zero:|Gain:')
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Coulombic',13,'Friction']],...
           'Mask Translate','ini=@1;gain=@2;x=max(ini,gain+ini);')
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Coulombic',13,'Friction']],...
             'Mask Help','This block has a discontinuity\nat zero and a linear gain afterward.\ny= sign(x)*(Gain*abs(x)+Offset)',...
         'Mask Entries','Ac\/0\/')
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Coulombic',13,'Friction']],...
           'position',[205,72,235,98])

add_block('built-in/Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Wave',13,'Shape',13,'low pass Fc']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Wave',13,'Shape',13,'low pass Fc']],...
              'Numerator','nw',...
            'Denominator','dw',...
          'position',[280,68,330,102])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Product']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Product']],...
            'position',[405,20,430,40])

add_block('built-in/Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/LowPassFilter',13,'low pass << Fc']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/LowPassFilter',13,'low pass << Fc']],...
            'Numerator','nl',...
            'Denominator','dl',...
          'position',[470,14,530,46])

add_block('built-in/Gain',[sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Gain']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/Gain']],...
              'Gain','G',...
          'position',[560,14,585,46])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/out_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier/out_1']],...
         'position',[605,20,625,40])
add_line([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],[50,25;400,25])
add_line([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],[60,25;60,85;90,85])
add_line([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],[435,30;465,30])
add_line([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],[535,30;555,30])
add_line([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],[590,30;600,30])
add_line([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],[150,85;200,85])
add_line([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],[240,85;275,85])
add_line([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],[335,85;360,85;360,35;400,35])
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],...
                'Mask Display','Pilot carrier\nDSB ADM',...
             'Mask Type','Pilot carrier DSB ADM')
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],...
                'Mask Dialogue','Double-sideband suppressed-carrier amplitude demodulation using pilot carrier method:|Carrier Amplitude:|Carrier frequency:|Order of filters:|Gain at the output:')
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],...
             'Mask Translate','Ac=@1;Fc=@2;[nb,db,nw,dw,nl,dl]=dsbadmpc(Fc,@3);G=@4;')
set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],...
           'Mask Help','The Double-Sideband-Supressed-Carrier Amplitude Demodulation demodulates a DSB-SC-AM signal using pilot carrier method.',...
            'Mask Entries','1\/100\/2\/2\/')


%     Finished composite block ['DSB-SC-ADM',13,'by-pilot-carrier'].

set_param([sys,'/',['DSB-SC-ADM',13,'by-pilot-carrier']],...
                'orientation',2,...
             'ForeGround',3,...
              'position',[625,61,690,99])


%     Subsystem  ['DSB-SC-ADM',13,'by-squaring'].

new_system([sys,'/',['DSB-SC-ADM',13,'by-squaring']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring']],'Location',[78,137,928,358])

add_block('built-in/Memory',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Memory']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Memory']],...
            'orientation',2,...
             'position',[465,125,505,155])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'by-squaring/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/in_1']],...
            'position',[25,15,45,35])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'by-squaring/square']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/square']],...
           'position',[80,55,105,75])

add_block('built-in/Relational Operator',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Relational',13,'Operator']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Relational',13,'Operator']],...
          'position',[235,58,265,82])

add_block('built-in/Relational Operator',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Relational',13,'Operator1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Relational',13,'Operator1']],...
               'Operator','>',...
              'position',[355,63,385,87])

add_block('built-in/Combinatorial Logic',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Flip-Flop']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Flip-Flop']],...
               'Truth Table','[-1;1;1;-1]*Ac',...
              'position',[475,69,515,101])

add_block('built-in/Mux',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Mux']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Mux']],...
          'inputs','2',...
                'position',[420,66,450,99])

add_block('built-in/Relational Operator',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Relational',13,'Operator2']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Relational',13,'Operator2']],...
               'orientation',2,...
             'Operator','>',...
              'position',[415,134,445,161])

add_block('built-in/Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'by-squaring/BandPassFilter',13,'pass 2Fc']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/BandPassFilter',13,'pass 2Fc']],...
              'Numerator','nb',...
            'Denominator','db',...
          'position',[135,48,185,82])

add_block('built-in/Memory',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Memory1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Memory1']],...
                'position',[295,95,335,125])

add_block('built-in/Note',[sys,'/',['DSB-SC-ADM',13,'by-squaring/The seven blocks in the above plays the role of "dividing by two"']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/The seven blocks in the above plays the role of "dividing by two"']],...
             'position',[385,185,390,190])

add_block('built-in/Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Wave',13,'Shape',13,'low pass Fc']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Wave',13,'Shape',13,'low pass Fc']],...
              'Numerator','nw',...
            'Denominator','dw',...
          'position',[560,68,610,102])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Product']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Product']],...
              'position',[650,20,675,40])

add_block('built-in/Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'by-squaring/LowPassFilter',13,'low pass << Fc']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/LowPassFilter',13,'low pass << Fc']],...
              'Numerator','nl',...
            'Denominator','dl',...
          'position',[690,14,750,46])

add_block('built-in/Gain',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Gain']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Gain']],...
                'Gain','G',...
          'position',[770,14,795,46])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'by-squaring/out_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/out_1']],...
           'position',[815,20,835,40])

add_block('built-in/Note',[sys,'/',['DSB-SC-ADM',13,'by-squaring/Ref: Hambley: An Intro to Comm. Systems. pp67']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring/Ref: Hambley: An Intro to Comm. Systems. pp67']],...
              'position',[615,300,620,305])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[800,30;810,30])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[755,30;765,30])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[520,85;510,140])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[270,70;350,70])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[280,70;290,110])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[615,85;630,85;630,35;645,35])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[520,85;555,85])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[410,150;405,150;415,90])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[460,140;450,140])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[390,75;415,75])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[340,110;350,80])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[455,85;470,85])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[680,30;685,30])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[190,65;230,65])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[110,65;130,65])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[50,25;645,25])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[60,25;60,60;75,60])
add_line([sys,'/',['DSB-SC-ADM',13,'by-squaring']],[60,60;60,70;75,70])
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring']],...
           'Mask Display','Squaring\nDSB ADM',...
          'Mask Type','Squaring DSB ADM')
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring']],...
          'Mask Dialogue','Double-sideband suppressed-carrier amplitude demodulation using squaring method:|Carrier Amplitude:|Carrier frequency:|Order of filters:|Gain at the output')
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring']],...
                'Mask Translate','Ac=@1;[nb,db,nw,dw,nl,dl]=dsbadmft(@2,@3);G=@4;')
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring']],...
              'Mask Help','The Double-Sideband-Supressed-Carrier Amplitude Demodulation demodulates a DSB-SC-AM signal using squaring method. Limit: the result of this block has 50% chance reverse the positive and nagative value.')
set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring']],...
             'Mask Entries','1\/100\/2\/-3\/')


%     Finished composite block ['DSB-SC-ADM',13,'by-squaring'].

set_param([sys,'/',['DSB-SC-ADM',13,'by-squaring']],...
         'orientation',2,...
             'ForeGround',5,...
              'position',[410,61,475,99])

add_block('built-in/Note',[sys,'/','The curve color in the graphical scope matches the color of the blocks in the block diagram'])
set_param([sys,'/','The curve color in the graphical scope matches the color of the blocks in the block diagram'],...
              'position',[350,225,355,230])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[162,381,644,544])

add_block('built-in/Note',[sys,'/','Subsystem/This block diagram tests amplitude modulators and demodulators.'])
set_param([sys,'/','Subsystem/This block diagram tests amplitude modulators and demodulators.'],...
             'position',[205,15,210,20])

add_block('built-in/Note',[sys,'/','Subsystem/The red signal is the inputed signal to be modulated.'])
set_param([sys,'/','Subsystem/The red signal is the inputed signal to be modulated.'],...
              'ForeGround',2,...
              'position',[165,35,170,40])

add_block('built-in/Note',[sys,'/','Subsystem/The yellow signal is the squaring demodulationr for DSB-SC AM'])
set_param([sys,'/','Subsystem/The yellow signal is the squaring demodulationr for DSB-SC AM'],...
              'ForeGround',5,...
              'BackGround',6,...
              'position',[200,60,205,65])

add_block('built-in/Note',[sys,'/','Subsystem/The blue signal is the costas phase-locked demodulation for DSB ADM'])
set_param([sys,'/','Subsystem/The blue signal is the costas phase-locked demodulation for DSB ADM'],...
          'ForeGround',4,...
              'position',[220,85,225,90])

add_block('built-in/Note',[sys,'/','Subsystem/The green signal is the pilot carrier demodulation for DSB-ADM'])
set_param([sys,'/','Subsystem/The green signal is the pilot carrier demodulation for DSB-ADM'],...
            'ForeGround',3,...
              'position',[195,105,200,110])

add_block('built-in/Note',[sys,'/','Subsystem/The magenta signal is the envelop detector for ADM'])
set_param([sys,'/','Subsystem/The magenta signal is the envelop detector for ADM'],...
          'ForeGround',6,...
              'position',[165,130,170,135])
set_param([sys,'/','Subsystem'],...
                'Mask Display','?')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
               'hide name',0,...
               'Drop Shadow',4,...
             'position',[685,165,715,201])


%     Subsystem  ['DSB-SC-ADM',13,'by-Costas'].

new_system([sys,'/',['DSB-SC-ADM',13,'by-Costas']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas']],'Location',[164,182,967,463])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Product2']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Product2']],...
              'position',[125,215,150,235])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'by-Costas/sin1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/sin1']],...
           'orientation',2,...
             'Expr','sin(u[1]+pih)',...
              'position',[120,160,220,190])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Product']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Product']],...
         'position',[125,50,150,70])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'by-Costas/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/in_1']],...
          'position',[45,45,65,65])

add_block('built-in/Note',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
            'position',[260,350,265,355])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']],...
          'orientation',2,...
             'Value','Fc',...
                'position',[580,175,600,195])

add_block('built-in/Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter']],...
            'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[345,39,395,81])

add_block('built-in/Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter2']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter2']],...
            'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[430,204,480,246])

add_block('built-in/Gain',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Gain']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Gain']],...
          'Gain','G',...
          'position',[710,45,735,75])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'by-Costas/out_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/out_1']],...
               'position',[765,50,785,70])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'by-Costas/sin']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/sin']],...
               'orientation',2,...
             'position',[125,118,210,142])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Sum1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Sum1']],...
           'orientation',2,...
             'position',[275,120,295,140])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency1']],...
                'orientation',2,...
             'Value','Ph',...
                'position',[340,175,360,195])

add_block('built-in/Gain',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Gain1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Gain1']],...
                'orientation',2,...
             'Gain','pi2',...
                'position',[330,110,360,140])


%     Subsystem  ['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator'].

new_system([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],'Location',[529,321,954,458])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/in_1']],...
            'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Memory']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Memory']],...
          'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/module']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/module']],...
          'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Reset',13,'integrator']],...
                'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/one']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/one']],...
            'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Sum']],...
           'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/out_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/out_1']],...
         'position',[370,30,390,50])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator',...
             'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
             'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
               'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
               'Mask Entries','1\/0\/')


%     Finished composite block ['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator'].

set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
                'orientation',2,...
             'position',[390,110,450,140])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Sum']],...
             'orientation',2,...
             'position',[475,115,495,135])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Product1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Product1']],...
               'orientation',2,...
             'position',[605,110,635,130])

add_block('built-in/Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter1']])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter1']],...
          'orientation',2,...
             'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[535,100,585,140])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[400,60;705,60])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[740,60;760,60])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[70,55;120,55])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[155,60;340,60])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[575,185;525,185;525,130;500,130])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[470,125;455,125])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[600,120;590,120])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[530,120;500,120])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[115,175;105,175;105,220;120,220])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[90,55;90,230;120,230])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[155,225;425,225])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[485,225;655,225;655,125;640,125])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[385,125;365,125])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[325,125;300,125])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[335,185;315,185;315,135;300,135])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[270,130;215,130])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[255,130;255,175;225,175])
add_line([sys,'/',['DSB-SC-ADM',13,'by-Costas']],[655,60;655,115;640,115])
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas']],...
            'Mask Display','Costas PL\nDSB ADM',...
         'Mask Type','DSB-SC ADM')
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas']],...
          'Mask Dialogue','Double-sideband suppressed-carrier amplitude demodulation:|Carrier frequency:|Filter numerator:|Filter denominator:|Output gain:|Initial phase:')
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas']],...
         'Mask Translate','Fc=@1;Fn=@2;Fd=@3;G=@4;Ph=@5;pi2=pi*2;pih=pi/2;')
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas']],...
                'Mask Help','The Double-Sideband Supressed-Carrier Amplitude Modulation demodulates a DSB-SC-AM signal using Costas Phase-Locked Loop method.')
set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas']],...
         'Mask Entries','100\/[3.0002,0,40002]\/[1,67.46,2270.9,40002]\/2\/0\/')


%     Finished composite block ['DSB-SC-ADM',13,'by-Costas'].

set_param([sys,'/',['DSB-SC-ADM',13,'by-Costas']],...
               'orientation',2,...
             'ForeGround',4,...
              'position',[520,67,585,103])
add_line(sys,[170,40;250,40])
add_line(sys,[220,40;220,140;260,140])
add_line(sys,[135,85;85,85])
add_line(sys,[320,40;490,40;480,80])
add_line(sys,[490,40;600,40;590,85])
add_line(sys,[600,40;705,40;695,80])
add_line(sys,[330,140;470,140;470,175;450,175])
add_line(sys,[405,80;185,80])
add_line(sys,[220,75;185,75])
add_line(sys,[515,85;500,85;500,130;355,130;355,85;185,85])
add_line(sys,[380,175;215,175;215,95;185,95])
add_line(sys,[620,80;610,80;610,135;345,135;345,90;185,90])

drawnow

% Return any arguments.
if (nargin | nargout)
  % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
else
 drawnow % Flash up the model and execute load callback
end
