function [ret,x0,str,ts,xts]=tstam2ce(t,x,u,flag);
%TSTAM2CE	is the M-file description of the SIMULINK system named TSTAM2CE.
%	The block-diagram can be displayed by typing: TSTAM2CE.
%
%	SYS=TSTAM2CE(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTAM2CE to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTAM2CE with a FLAG of zero:
%	[SIZES]=TSTAM2CE([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[113,384,689,544])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;[num,den]=butter(2,100/pi/2*ts);td=.1;M=8;');


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(300,1,M)\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[20,63,100,107])


%     Subsystem  ['MASK mod',13,'baseband'].

new_system([sys,'/',['MASK mod',13,'baseband']])
set_param([sys,'/',['MASK mod',13,'baseband']],'Location',[7,381,369,492])


%     Subsystem  ['MASK mod',13,'baseband/DSB AM',13,'baseband'].

new_system([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],'Location',[212,430,575,573])

add_block('built-in/Outport',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/out_1']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/out_1']],...
		'position',[320,50,340,70])

add_block('built-in/Product',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Product']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Product']],...
		'position',[255,42,280,73])

add_block('built-in/Inport',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/in_1']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/in_1']],...
		'position',[115,15,135,35])

add_block('built-in/Mux',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Mux']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[170,66,205,99])

add_block('built-in/Constant',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Constant1']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[90,90,110,110])

add_block('built-in/Constant',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Constant']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[40,65,60,85])
add_line([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],[65,75;165,75])
add_line([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],[115,100;130,100;130,90;165,90])
add_line([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],[140,25;185,25;185,50;250,50])
add_line([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],[285,60;315,60])
add_line([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],[210,85;230,85;230,65;250,65])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);DSB AM',...
		'Mask Type','DSB-SC AM CE')
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of a\nDSB-SC AM modulated signal.|Initial Phase (rad):')
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);pi2=2*pi;[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the double-sideband suppressed-carrier amplitude modulated signal. The output is a complex signal.')
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'Mask Entries','Ph\/')


%     Finished composite block ['MASK mod',13,'baseband/DSB AM',13,'baseband'].

set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'ForeGround',4,...
		'position',[180,33,260,77])


%     Subsystem  ['MASK mod',13,'baseband/MASK map'].

new_system([sys,'/',['MASK mod',13,'baseband/MASK map']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],'Location',[520,162,902,335])

add_block('built-in/Outport',[sys,'/',['MASK mod',13,'baseband/MASK map/out_1']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/out_1']],...
		'position',[315,65,335,85])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK mod',13,'baseband/MASK map/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[100,24,135,56])

add_block('built-in/Inport',[sys,'/',['MASK mod',13,'baseband/MASK map/in_1']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/in_1']],...
		'position',[40,30,60,50])

add_block('built-in/Gain',[sys,'/',['MASK mod',13,'baseband/MASK map/Gain']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/Gain']],...
		'Gain','Kc',...
		'position',[180,25,220,55])

add_block('built-in/Sum',[sys,'/',['MASK mod',13,'baseband/MASK map/Sum1']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/Sum1']],...
		'inputs','+-',...
		'position',[250,63,270,87])

add_block('built-in/Constant',[sys,'/',['MASK mod',13,'baseband/MASK map/Gain diff']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/Gain diff']],...
		'Value','Ac',...
		'position',[180,96,215,124])
add_line([sys,'/',['MASK mod',13,'baseband/MASK map']],[225,40;230,40;230,70;245,70])
add_line([sys,'/',['MASK mod',13,'baseband/MASK map']],[220,110;230,110;230,80;245,80])
add_line([sys,'/',['MASK mod',13,'baseband/MASK map']],[275,75;310,75])
add_line([sys,'/',['MASK mod',13,'baseband/MASK map']],[65,40;95,40])
add_line([sys,'/',['MASK mod',13,'baseband/MASK map']],[140,40;175,40])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'Mask Display','MASK\nmap',...
		'Mask Type','MASK map')
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'Mask Dialogue','Map a digital symbol onto an analog\nsignal in the range [-1, 1] using M-ary\namplitude shift keying modulation mapping.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'Mask Translate','N=@1;Ac=1;Kc=Ac*2/(N-1);td=@2;')
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'Mask Help','This block maps an input digit signal onto a signal in the range [-1, 1]. The coded signal can be modulated using analog\nmodulation blocks. Input digits are in the range [0, M-1], where M is the M-ary number. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'Mask Entries','n\/td\/')


%     Finished composite block ['MASK mod',13,'baseband/MASK map'].

set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'position',[75,33,155,77])

add_block('built-in/Outport',[sys,'/',['MASK mod',13,'baseband/out_1']])
set_param([sys,'/',['MASK mod',13,'baseband/out_1']],...
		'position',[300,45,320,65])

add_block('built-in/Inport',[sys,'/',['MASK mod',13,'baseband/in_1']])
set_param([sys,'/',['MASK mod',13,'baseband/in_1']],...
		'position',[25,45,45,65])
add_line([sys,'/',['MASK mod',13,'baseband']],[265,55;295,55])
add_line([sys,'/',['MASK mod',13,'baseband']],[160,55;175,55])
add_line([sys,'/',['MASK mod',13,'baseband']],[50,55;70,55])
set_param([sys,'/',['MASK mod',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);MASK',...
		'Mask Type','Baseband MASK modulation')
set_param([sys,'/',['MASK mod',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of the\namplitude shift keying modulated signal.|M-ary number (input integers in the range [0, M-1]):|Input symbol interval and offset (sec):|Initial phase (rad):')
set_param([sys,'/',['MASK mod',13,'baseband']],...
		'Mask Translate','n=@1;td=@2;Ph=@3;[x,y]=moduicon(5);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MASK mod',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of MASK modulated signal. The inputs are integers in the range [0, M-1], where M is the M-ary number. The maximum amplitude of the output is 1. When the symbol interval is a two-element vector, the second element is the offset (default 0). The block takes the input value at the sampling time point.')
set_param([sys,'/',['MASK mod',13,'baseband']],...
		'Mask Entries','M\/td\/0\/')


%     Finished composite block ['MASK mod',13,'baseband'].

set_param([sys,'/',['MASK mod',13,'baseband']],...
		'hide name',0,...
		'position',[145,63,225,107])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate1'],[105,65;125,65])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[40,70;60,70])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','ceil(log10(M)/log10(2))\/20\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[485,53,565,97])


%     Subsystem  ['MASK demod',13,'baseband'].

new_system([sys,'/',['MASK demod',13,'baseband']])
set_param([sys,'/',['MASK demod',13,'baseband']],'Location',[82,326,492,462])


%     Subsystem  ['MASK demod',13,'baseband/DSB-ADM',13,'baseband'].

new_system([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],'Location',[172,360,722,581])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/out_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/out_1']],...
		'position',[485,35,505,55])

add_block('built-in/Product',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Product1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Product1']],...
		'orientation',2,...
		'position',[390,110,425,130])

add_block('built-in/Filter',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[260,26,315,64])


%     Subsystem  ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

new_system([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],'Location',[297,318,980,694])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']],...
		'Port','2',...
		'position',[25,205,45,225])

add_block('built-in/Demux',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'position',[80,194,155,236])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']],...
		'position',[35,90,55,110])

add_block('built-in/Demux',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'position',[85,79,160,121])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']],...
		'position',[55,0,60,5])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']],...
		'position',[450,286,455,291])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']],...
		'position',[450,95,455,100])

add_block('built-in/Sum',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']],...
		'position',[380,280,400,300])

add_block('built-in/Product',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']],...
		'position',[305,298,335,322])

add_block('built-in/Product',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']],...
		'position',[305,253,335,277])

add_block('built-in/Sum',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']],...
		'inputs','+-',...
		'position',[380,110,400,130])

add_block('built-in/Product',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']],...
		'position',[305,143,335,167])

add_block('built-in/Product',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']],...
		'position',[305,83,335,107])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']],...
		'position',[190,185,195,190])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']],...
		'position',[195,65,200,70])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']],...
		'position',[198,108,203,113])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']],...
		'Port','2',...
		'position',[485,280,505,300])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']],...
		'position',[495,110,515,130])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']],...
		'position',[170,225,175,230])

add_block('built-in/Gain',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']],...
		'Gain','-1',...
		'position',[190,210,230,240])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,310;350,310;350,295;375,295])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,265;350,265;350,285;375,285])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,110;250,110;250,150;300,150])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[255,150;255,315;300,315])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,205;275,205;275,100;300,100])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[275,205;275,305;300,305])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,90;300,90])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[243,90;243,260;300,260])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,155;350,155;350,125;375,125])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,95;350,95;350,115;375,115])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[50,215;75,215])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[60,100;80,100])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,290;480,290])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,120;490,120])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,225;185,225])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[235,225;260,225;260,160;300,160])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[260,225;260,270;300,270])


%     Finished composite block ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],...
		'orientation',2,...
		'position',[40,90,115,130])

add_block('built-in/Filter',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[250,176,305,214])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/in_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/in_1']],...
		'orientation',2,...
		'position',[185,90,205,110])


%     Subsystem  ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO'].

new_system([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],'Location',[493,551,1106,698])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/in_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/in_1']],...
		'position',[35,25,55,45])

add_block('built-in/Gain',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[80,21,120,49])

add_block('built-in/Fcn',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/cos']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/cos']],...
		'Expr','cos(u)',...
		'position',[270,21,325,49])

add_block('built-in/Fcn',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/sin']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/sin']],...
		'Expr','sin(u)',...
		'position',[270,81,325,109])

add_block('built-in/Mux',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Mux']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Mux']],...
		'inputs','2',...
		'position',[355,26,390,59])

add_block('built-in/Gain',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity1']],...
		'Gain','Ac',...
		'position',[420,31,460,59])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/out_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/out_1']],...
		'position',[490,35,510,55])


%     Subsystem  ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator'].

new_system([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])

add_block('built-in/Unit Delay',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Sum',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/module']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[410,40;440,40])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[140,35;190,35])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Entries','pi2\/0\/ts\/')


%     Finished composite block ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator'].

set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'position',[135,16,195,54])

add_block('built-in/Sum',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sum']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sum']],...
		'position',[220,30,240,50])

add_block('built-in/Constant',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Constant']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Constant']],...
		'Value','Ph',...
		'position',[160,100,180,120])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[60,35;75,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[125,35;130,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[465,45;485,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[330,35;350,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[395,45;415,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[330,95;335,95;335,50;350,50])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[200,35;215,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[245,40;245,35;265,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[185,110;200,110;200,45;215,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[245,40;250,40;250,95;265,95])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Display','FM\ncmplx env',...
		'Mask Type','FM with cmplx env out')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Dialogue','Frequency modulation with complex envelop output:|Amplitude constant:|Modulation sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Translate','Ac=@1;Kc=@2*2*pi;Ph=@3;pi2=2*pi;ts=@4;')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Help','The FM block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Entries','1\/1\/Ph\/ts\/')


%     Finished composite block ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO'].

set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'orientation',2,...
		'position',[215,100,295,140])

add_block('built-in/Filter',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter2']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[310,100,370,140])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[320,45;480,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[445,45;445,115;430,115])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[180,100;120,100])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[35,100;20,100;20,45;255,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[35,120;15,120;15,195;245,195])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[310,195;445,195;445,125;430,125])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[385,120;375,120])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[305,120;300,120])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[210,120;120,120])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);DSB ADM',...
		'Mask Type','DSB-SC ADM CE')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nDSB-SC AM modulated signal.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;pi2=pi*2;ts=@4;[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block requires you to specify a lowpass filter that eliminates the carrier frequency and keeps the message signal. This block takes a complex signal.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['MASK demod',13,'baseband/DSB-ADM',13,'baseband'].

set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'ForeGround',4,...
		'position',[90,23,170,67])


%     Subsystem  ['MASK demod',13,'baseband/MASK demap'].

new_system([sys,'/',['MASK demod',13,'baseband/MASK demap']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],'Location',[187,342,628,482])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK demod',13,'baseband/MASK demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[85,29,120,61])

add_block('built-in/Constant',[sys,'/',['MASK demod',13,'baseband/MASK demap/Shift key']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/Shift key']],...
		'Value','sft',...
		'position',[115,93,135,117])

add_block('built-in/Sum',[sys,'/',['MASK demod',13,'baseband/MASK demap/Sum2']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/Sum2']],...
		'inputs','+-',...
		'position',[180,38,200,67])

add_block('built-in/Abs',[sys,'/',['MASK demod',13,'baseband/MASK demap/Abs']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/Abs']],...
		'position',[235,42,270,68])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/MASK demap/out_1']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/out_1']],...
		'position',[400,45,420,65])

add_block('built-in/S-Function',[sys,'/',['MASK demod',13,'baseband/MASK demap/Minimum']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/Minimum']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[315,45,370,65])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/MASK demap/in_1']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[55,45;80,45])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[275,55;310,55])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[125,45;175,45])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[375,55;395,55])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[140,105;155,105;155,60;175,60])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[205,55;230,55])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'Mask Display','MASK\ndemap',...
		'Mask Type','MASK demap')
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'Mask Dialogue','Reverse the MASK mapping process\nConvert [-1 1] analog signal to [0, M-1] symbols.|M-ary number (digit integers in ranger [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'Mask Translate','N=@1;Ac=1;sft=[0:N-1]*Ac*2/(N-1)-Ac;td=@2;')
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'Mask Help','This block demaps a MASK mapped signal back to digit symbols. You can place this block after a amplitude demodulation block. The input of this block is an analog signal in the range [-1, 1]. The demodulation decides the closest integer fitting in [0,M-1] range. When the input symbol interval is a two-elements vector, the second element is offset. The default offset value is 0.')
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'Mask Entries','N\/td\/')


%     Finished composite block ['MASK demod',13,'baseband/MASK demap'].

set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'position',[215,23,295,67])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/out_1']])
set_param([sys,'/',['MASK demod',13,'baseband/out_1']],...
		'position',[330,35,350,55])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/in_1']])
set_param([sys,'/',['MASK demod',13,'baseband/in_1']],...
		'position',[15,35,35,55])
add_line([sys,'/',['MASK demod',13,'baseband']],[175,45;210,45])
add_line([sys,'/',['MASK demod',13,'baseband']],[300,45;325,45])
add_line([sys,'/',['MASK demod',13,'baseband']],[40,45;85,45])
set_param([sys,'/',['MASK demod',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);MASK',...
		'Mask Type','Baseband MASK demodulation')
set_param([sys,'/',['MASK demod',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nMASK modulated signal.|M-ary number (output integer in range [0, M-1]):|Output symbol interval and offset (sec):|Initial phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Filter sample time (sec):')
set_param([sys,'/',['MASK demod',13,'baseband']],...
		'Mask Translate','N=@1;td=@2;Ph=@3;num=@4;den=@5;ts=@6;[x,y]=moduicon(6);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MASK demod',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a MASK modulated signal. The output signal are digits in the range [0, M-1]. When the output symbol interval is a two-element vector, the second element is the offset (default 0). A lowpass filter is required in the demodulation. You can set both numerator and denominator to one for not using the lowpass filter.')
set_param([sys,'/',['MASK demod',13,'baseband']],...
		'Mask Entries','M\/[td, td-ts]\/0\/num\/den\/ts\/')


%     Finished composite block ['MASK demod',13,'baseband'].

set_param([sys,'/',['MASK demod',13,'baseband']],...
		'hide name',0,...
		'position',[350,63,430,107])


%     Subsystem  ['Rayleigh noise',13,'channel CE'].

new_system([sys,'/',['Rayleigh noise',13,'channel CE']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],'Location',[496,318,758,464])

add_block('built-in/Inport',[sys,'/',['Rayleigh noise',13,'channel CE/in_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/in_1']],...
		'position',[45,10,65,30])


%     Subsystem  ['Rayleigh noise',13,'channel CE/Gaussian',13,'noise'].

new_system([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],'Location',[371,386,719,591])

add_block('built-in/White Noise',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[240,95;290,95])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['Rayleigh noise',13,'channel CE/Gaussian',13,'noise'].

set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise',13,'channel CE/out_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/out_1']],...
		'position',[200,55,220,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise',13,'channel CE/Sum']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Sum']],...
		'position',[150,55,170,75])
add_line([sys,'/',['Rayleigh noise',13,'channel CE']],[175,65;195,65])
add_line([sys,'/',['Rayleigh noise',13,'channel CE']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['Rayleigh noise',13,'channel CE']],[90,70;145,70])
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rayl N',...
		'Mask Type','Rayleigh noise channel, fixed parameter')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Dialogue','Additive Rayleigh noise channel for\nbaseband signal simulation. Input\nand output signals are complex.|sigma:|Seeds (1x2 vector):')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Translate','m=0;d=@1;d=d^2;s=@2;if length(s)<2,s=[s s+s];end;[x,y]=chanicon;[v,w]=cmplxicn(0,50,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Help','This block adds Rayleigh noise to the transmitting signal. The input and output of this block are complex data. The Rayleigh noise is composed with two independant zero mean Gaussian noise. These two Gaussian components have the same standard deviation sigma.')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Entries','.1\/[12345 54321]\/')


%     Finished composite block ['Rayleigh noise',13,'channel CE'].

set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'hide name',0,...
		'position',[250,63,330,107])
add_line(sys,[105,85;140,85])
add_line(sys,[435,85;480,85])
add_line(sys,[120,85;120,40;440,40;440,65;480,65])
add_line(sys,[230,85;245,85])
add_line(sys,[335,85;345,85])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
