function [ret,x0,str,ts,xts]=tstap2cd(t,x,u,flag);
%TSTAP2CD	is the M-file description of the SIMULINK system named TSTAP2CD.
%	The block-diagram can be displayed by typing: TSTAP2CD.
%
%	SYS=TSTAP2CD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTAP2CD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTAP2CD with a FLAG of zero:
%	[SIZES]=TSTAP2CD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[64,60,751,248])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;td=.2;M=8;Fc=100/2/pi;');


%     Subsystem  'MPSK modu'.

new_system([sys,'/','MPSK modu'])
set_param([sys,'/','MPSK modu'],'Location',[52,104,441,278])

add_block('built-in/Inport',[sys,'/','MPSK modu/in_1'])
set_param([sys,'/','MPSK modu/in_1'],...
		'position',[60,35,80,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK modu/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MPSK modu/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[130,29,165,61])

add_block('built-in/Product',[sys,'/','MPSK modu/Product'])
set_param([sys,'/','MPSK modu/Product'],...
		'position',[235,76,260,109])

add_block('built-in/Outport',[sys,'/','MPSK modu/out_1'])
set_param([sys,'/','MPSK modu/out_1'],...
		'position',[310,85,330,105])

add_block('built-in/Constant',[sys,'/','MPSK modu/Multiple factor'])
set_param([sys,'/','MPSK modu/Multiple factor'],...
		'Value','Sft',...
		'position',[130,108,150,132])
add_line([sys,'/','MPSK modu'],[170,45;200,45;200,85;230,85])
add_line([sys,'/','MPSK modu'],[85,45;125,45])
add_line([sys,'/','MPSK modu'],[265,95;305,95])
add_line([sys,'/','MPSK modu'],[155,120;200,120;200,100;230,100])
set_param([sys,'/','MPSK modu'],...
		'Mask Display','MPSK\ncode',...
		'Mask Type','MPSK code')
set_param([sys,'/','MPSK modu'],...
		'Mask Dialogue','Code for M-ary phase shift keying modulation.|M-ary number (input integer in range [0, M-1]):|Symbol interval (second):',...
		'Mask Translate','pi2=2*pi;Sft=pi2/@1; td=@2;')
set_param([sys,'/','MPSK modu'],...
		'Mask Help','This block code the digital signal into phase shifting signal for M-ary phase shift keying modulation. The constellation of the PSK con be seen using the MATLAB command apkconst(M).')
set_param([sys,'/','MPSK modu'],...
		'Mask Entries','M\/td\/')


%     Finished composite block 'MPSK modu'.

set_param([sys,'/','MPSK modu'],...
		'position',[125,92,195,128])


%     Subsystem  ['Phase',13,'Modulation'].

new_system([sys,'/',['Phase',13,'Modulation']])
set_param([sys,'/',['Phase',13,'Modulation']],'Location',[269,388,780,574])

add_block('built-in/Clock',[sys,'/',['Phase',13,'Modulation/Clock']])
set_param([sys,'/',['Phase',13,'Modulation/Clock']],...
		'position',[45,70,65,90])

add_block('built-in/Sum',[sys,'/',['Phase',13,'Modulation/Sum2']])
set_param([sys,'/',['Phase',13,'Modulation/Sum2']],...
		'inputs','+-',...
		'position',[225,60,250,95])

add_block('built-in/Outport',[sys,'/',['Phase',13,'Modulation/out_1']])
set_param([sys,'/',['Phase',13,'Modulation/out_1']],...
		'position',[450,70,470,90])

add_block('built-in/Inport',[sys,'/',['Phase',13,'Modulation/in_1']])
set_param([sys,'/',['Phase',13,'Modulation/in_1']],...
		'position',[155,15,175,35])

add_block('built-in/Fcn',[sys,'/',['Phase',13,'Modulation/Fcn']])
set_param([sys,'/',['Phase',13,'Modulation/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[330,65,405,95])

add_block('built-in/Sum',[sys,'/',['Phase',13,'Modulation/Sum1']])
set_param([sys,'/',['Phase',13,'Modulation/Sum1']],...
		'inputs','+++',...
		'position',[285,62,305,98])

add_block('built-in/Gain',[sys,'/',['Phase',13,'Modulation/Gain']])
set_param([sys,'/',['Phase',13,'Modulation/Gain']],...
		'Gain','Fc',...
		'position',[85,65,125,95])

add_block('built-in/Zero-Order Hold',[sys,'/',['Phase',13,'Modulation/Zero-Order',13,'Hold']])
set_param([sys,'/',['Phase',13,'Modulation/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[155,99,190,131])

add_block('built-in/Constant',[sys,'/',['Phase',13,'Modulation/Initial value']])
set_param([sys,'/',['Phase',13,'Modulation/Initial value']],...
		'Value','Ph',...
		'position',[225,125,245,145])

add_block('built-in/Zero-Order Hold',[sys,'/',['Phase',13,'Modulation/Zero-Order Hold',13,'timing control']])
set_param([sys,'/',['Phase',13,'Modulation/Zero-Order Hold',13,'timing control']],...
		'Sample time','ts',...
		'position',[150,229,185,261])
add_line([sys,'/',['Phase',13,'Modulation']],[410,80;445,80])
add_line([sys,'/',['Phase',13,'Modulation']],[250,135;260,135;260,90;280,90])
add_line([sys,'/',['Phase',13,'Modulation']],[310,80;325,80])
add_line([sys,'/',['Phase',13,'Modulation']],[180,25;260,25;260,70;280,70])
add_line([sys,'/',['Phase',13,'Modulation']],[70,80;80,80])
add_line([sys,'/',['Phase',13,'Modulation']],[255,80;280,80])
add_line([sys,'/',['Phase',13,'Modulation']],[130,80;170,80;170,70;220,70])
add_line([sys,'/',['Phase',13,'Modulation']],[195,115;200,115;200,85;220,85])
add_line([sys,'/',['Phase',13,'Modulation']],[130,80;135,80;135,115;150,115])
set_param([sys,'/',['Phase',13,'Modulation']],...
		'Mask Display','PM',...
		'Mask Type','PM')
set_param([sys,'/',['Phase',13,'Modulation']],...
		'Mask Dialogue','Phase modulation:|Carier frequency (Hz):|Initial phase (rad):|Sample time (second):|Symbol interval (Inf for analog modulation): ')
set_param([sys,'/',['Phase',13,'Modulation']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;ts=@3;td=@4;',...
		'Mask Help','The PM block cause the phase of the sinusoidal carrier to depend on the input signal voltage.')
set_param([sys,'/',['Phase',13,'Modulation']],...
		'Mask Entries','Fc\/0\/ts\/td\/')


%     Finished composite block ['Phase',13,'Modulation'].

set_param([sys,'/',['Phase',13,'Modulation']],...
		'ForeGround',3,...
		'position',[220,93,295,127])


%     Subsystem  ['K-step',13,'delay'].

new_system([sys,'/',['K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay']],'Location',[4,432,349,702])

add_block('built-in/Inport',[sys,'/',['K-step',13,'delay/in_1']])
set_param([sys,'/',['K-step',13,'delay/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['K-step',13,'delay/out_1']])
set_param([sys,'/',['K-step',13,'delay/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Filter',[sys,'/',['K-step',13,'delay/K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Switch',[sys,'/',['K-step',13,'delay/Switch']])
set_param([sys,'/',['K-step',13,'delay/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant']])
set_param([sys,'/',['K-step',13,'delay/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Clock',[sys,'/',['K-step',13,'delay/Clock']])
set_param([sys,'/',['K-step',13,'delay/Clock']],...
		'position',[75,145,95,165])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant1']])
set_param([sys,'/',['K-step',13,'delay/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Relational Operator',[sys,'/',['K-step',13,'delay/Relational',13,'Operator']])
set_param([sys,'/',['K-step',13,'delay/Relational',13,'Operator']],...
		'position',[150,168,180,192])
add_line([sys,'/',['K-step',13,'delay']],[300,130;320,130])
add_line([sys,'/',['K-step',13,'delay']],[45,90;55,90])
add_line([sys,'/',['K-step',13,'delay']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['K-step',13,'delay']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['K-step',13,'delay']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['K-step',13,'delay']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['K-step',13,'delay']],[185,180;220,180;220,130;265,130])
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay',...
		'Mask Dialogue','Output is K steps delay of the input signal.|Delay steps (integer):|Sample time (sec):|Inital condition:')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;',...
		'Mask Help','This block equivalent to K unit delay.',...
		'Mask Entries','1\/td\/NaN\/')


%     Finished composite block ['K-step',13,'delay'].

set_param([sys,'/',['K-step',13,'delay']],...
		'BackGround',5,...
		'position',[285,30,345,60])


%     Subsystem  ['MPSK demod',13,'correlation'].

new_system([sys,'/',['MPSK demod',13,'correlation']])
set_param([sys,'/',['MPSK demod',13,'correlation']],'Location',[269,223,837,414])

add_block('built-in/Constant',[sys,'/',['MPSK demod',13,'correlation/Shift key']])
set_param([sys,'/',['MPSK demod',13,'correlation/Shift key']],...
		'Value','sft',...
		'position',[115,13,135,37])

add_block('built-in/Outport',[sys,'/',['MPSK demod',13,'correlation/out_1']])
set_param([sys,'/',['MPSK demod',13,'correlation/out_1']],...
		'position',[525,60,545,80])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'correlation/Scheduled',13,'reset-int1']])
set_param([sys,'/',['MPSK demod',13,'correlation/Scheduled',13,'reset-int1']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MPSK demod',13,'correlation/Scheduled',13,'reset-int1']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MPSK demod',13,'correlation/Scheduled',13,'reset-int1']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MPSK demod',13,'correlation/Scheduled',13,'reset-int1']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MPSK demod',13,'correlation/Scheduled',13,'reset-int1']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[440,49,500,91])

add_block('built-in/Product',[sys,'/',['MPSK demod',13,'correlation/Product']])
set_param([sys,'/',['MPSK demod',13,'correlation/Product']],...
		'position',[385,51,410,84])

add_block('built-in/Inport',[sys,'/',['MPSK demod',13,'correlation/in_1']])
set_param([sys,'/',['MPSK demod',13,'correlation/in_1']],...
		'position',[305,100,325,120])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'correlation/Array sin']])
set_param([sys,'/',['MPSK demod',13,'correlation/Array sin']],...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[295,50,345,70])

add_block('built-in/Constant',[sys,'/',['MPSK demod',13,'correlation/Initial phase']])
set_param([sys,'/',['MPSK demod',13,'correlation/Initial phase']],...
		'Value','Ph',...
		'position',[165,48,185,72])

add_block('built-in/Sum',[sys,'/',['MPSK demod',13,'correlation/Sum1']])
set_param([sys,'/',['MPSK demod',13,'correlation/Sum1']],...
		'inputs','+++',...
		'position',[240,40,265,80])

add_block('built-in/Sum',[sys,'/',['MPSK demod',13,'correlation/Sum2']])
set_param([sys,'/',['MPSK demod',13,'correlation/Sum2']],...
		'inputs','+-',...
		'position',[185,90,210,125])

add_block('built-in/Clock',[sys,'/',['MPSK demod',13,'correlation/Clock']])
set_param([sys,'/',['MPSK demod',13,'correlation/Clock']],...
		'position',[15,90,35,110])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK demod',13,'correlation/Zero-Order',13,'Hold']])
set_param([sys,'/',['MPSK demod',13,'correlation/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[125,119,160,151])

add_block('built-in/Gain',[sys,'/',['MPSK demod',13,'correlation/Gain']])
set_param([sys,'/',['MPSK demod',13,'correlation/Gain']],...
		'Gain','Fc',...
		'position',[65,85,105,115])
add_line([sys,'/',['MPSK demod',13,'correlation']],[505,70;520,70])
add_line([sys,'/',['MPSK demod',13,'correlation']],[415,70;435,70])
add_line([sys,'/',['MPSK demod',13,'correlation']],[270,60;290,60])
add_line([sys,'/',['MPSK demod',13,'correlation']],[140,25;225,25;235,45])
add_line([sys,'/',['MPSK demod',13,'correlation']],[190,60;235,60])
add_line([sys,'/',['MPSK demod',13,'correlation']],[40,100;60,100])
add_line([sys,'/',['MPSK demod',13,'correlation']],[215,110;225,110;235,75])
add_line([sys,'/',['MPSK demod',13,'correlation']],[110,100;180,100])
add_line([sys,'/',['MPSK demod',13,'correlation']],[110,100;120,135])
add_line([sys,'/',['MPSK demod',13,'correlation']],[165,135;165,115;180,115])
add_line([sys,'/',['MPSK demod',13,'correlation']],[350,60;380,60])
add_line([sys,'/',['MPSK demod',13,'correlation']],[330,110;360,110;360,75;380,75])
set_param([sys,'/',['MPSK demod',13,'correlation']],...
		'Mask Display','MPSK\ndm corr',...
		'Mask Type','MPSK Demodulation')
set_param([sys,'/',['MPSK demod',13,'correlation']],...
		'Mask Dialogue','Correlation calculation for M-ary phase shift keying demodulation.|M-ary number (integer in range [0, M-1]):|Symbol interval (second):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (second):')
set_param([sys,'/',['MPSK demod',13,'correlation']],...
		'Mask Translate','pi2=2*pi;N=@1;sft=[0:N-1]*pi2/N; td=@2;Fc=@3*pi2;Ph=@4;ts=@5;')
set_param([sys,'/',['MPSK demod',13,'correlation']],...
		'Mask Help','This block calculates the correlation value for MPSK demodulation. The initial phase should match those in the modulation.',...
		'Mask Entries','M\/td\/Fc\/0\/ts\/')


%     Finished composite block ['MPSK demod',13,'correlation'].

set_param([sys,'/',['MPSK demod',13,'correlation']],...
		'position',[345,90,420,130])


%     Subsystem  'Min//Max Index'.

new_system([sys,'/','Min//Max Index'])
set_param([sys,'/','Min//Max Index'],'Location',[36,467,390,564])

add_block('built-in/Inport',[sys,'/','Min//Max Index/in_1'])
set_param([sys,'/','Min//Max Index/in_1'],...
		'position',[65,20,85,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Min//Max Index/Zero-Order',13,'Hold']])
set_param([sys,'/',['Min//Max Index/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[125,14,160,46])

add_block('built-in/S-Function',[sys,'/','Min//Max Index/Maximum'])
set_param([sys,'/','Min//Max Index/Maximum'],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[195,20,275,40])

add_block('built-in/Outport',[sys,'/','Min//Max Index/out_1'])
set_param([sys,'/','Min//Max Index/out_1'],...
		'position',[305,20,325,40])
add_line([sys,'/','Min//Max Index'],[165,30;190,30])
add_line([sys,'/','Min//Max Index'],[280,30;300,30])
add_line([sys,'/','Min//Max Index'],[90,30;120,30])
set_param([sys,'/','Min//Max Index'],...
		'Mask Display','Min/Max\ndecode',...
		'Mask Type','Maximum/Minimum Index.')
set_param([sys,'/','Min//Max Index'],...
		'Mask Dialogue','Choose the maximum or minimum index of inputing element. The output are [0, N-1], where N is input vector length.|Symbol interval (second):|''max'' or ''min'':')
set_param([sys,'/','Min//Max Index'],...
		'Mask Translate','td=@1;mima=@2;',...
		'Mask Help','This block outputs the index of the maximum/minmum element in the input vector.',...
		'Mask Entries','td\/''max''\/')


%     Finished composite block 'Min//Max Index'.

set_param([sys,'/','Min//Max Index'],...
		'position',[455,90,530,130])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[575,62,610,113])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','20*td\/-1\/M\/''y-/g--/r-/m:/w-/r:/b-''\/td\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'position',[640,71,670,109])


%     Subsystem  'Sampled read'.

new_system([sys,'/','Sampled read'])
set_param([sys,'/','Sampled read'],'Location',[355,528,737,675])


%     Subsystem  ['Sampled read/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/','Sampled read/out_1'])
set_param([sys,'/','Sampled read/out_1'],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/','Sampled read/Message source'])
set_param([sys,'/','Sampled read/Message source'],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;',...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])
add_line([sys,'/','Sampled read'],[260,75;290,75])
add_line([sys,'/','Sampled read'],[115,75;175,75])
set_param([sys,'/','Sampled read'],...
		'Mask Display','Sampled\nread\nvariable',...
		'Mask Type','Read from a variable at given sample time.')
set_param([sys,'/','Sampled read'],...
		'Mask Dialogue','Read from a workspace variable at a given interval:|Variable (column_number=block_output_length):|Output symbol interval:|Cyclic read (1) or amend zero (0):|Initial output:')
set_param([sys,'/','Sampled read'],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;')
set_param([sys,'/','Sampled read'],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable row, the block will cyclically output from the first row of the the variable or output zero based on the cyclic read entree.')
set_param([sys,'/','Sampled read'],...
		'Mask Entries','rem([0:100]'',M)\/td\/1\/2\/')


%     Finished composite block 'Sampled read'.

set_param([sys,'/','Sampled read'],...
		'BackGround',5,...
		'position',[25,88,100,132])
add_line(sys,[615,90;635,90])
add_line(sys,[105,110;120,110])
add_line(sys,[110,110;110,45;280,45])
add_line(sys,[350,45;550,45;550,75;570,75])
add_line(sys,[200,110;215,110])
add_line(sys,[300,110;340,110])
add_line(sys,[535,110;555,110;555,100;570,100])
add_line(sys,[425,110;450,110])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
