function [ret,x0,str,ts,xts]=tstapk(t,x,u,flag);
%TSTAPK is the M-file description of the SIMULINK system named TSTAPK.
% The block-diagram can be displayed by typing: TSTAPK.
%
% SYS=TSTAPK(T,X,U,FLAG) returns depending on FLAG certain
%       system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes TSTAPK to return state derivatives, FLAG=2
%       discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling TSTAPK with a FLAG of zero:
%    [SIZES]=TSTAPK([],[],[],0),  returns a vector, SIZES, which
%    contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs
%              SIZES(5) number of roots (currently unsupported)
%               SIZES(6) direct feedthrough flag
%               SIZES(7) number of sample times
%
%       For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[63,60,857,523])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.003')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','N=128;T=.1;Fc=100;NIL=[6 12 18 24 30 38];AIL=[1 1.93 2.88 3.83 4.78 6.05];PIL=zeros(1,6);');


%     Subsystem  ['ASK//PSK',13,'modulation'].

new_system([sys,'/',['ASK//PSK',13,'modulation']])
set_param([sys,'/',['ASK//PSK',13,'modulation']],'Location',[59,72,945,387])

add_block('built-in/Inport',[sys,'/',['ASK//PSK',13,'modulation/in_2']])
set_param([sys,'/',['ASK//PSK',13,'modulation/in_2']],...
             'Port','2',...
          'position',[20,120,40,140])

add_block('built-in/Inport',[sys,'/',['ASK//PSK',13,'modulation/in_1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/in_1']],...
            'position',[65,20,85,40])

add_block('built-in/Memory',[sys,'/',['ASK//PSK',13,'modulation/Memory1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Memory1']],...
                'orientation',2,...
             'position',[185,75,225,105])

add_block('built-in/Switch',[sys,'/',['ASK//PSK',13,'modulation/Switch']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Switch']],...
               'Threshold','eps',...
           'position',[190,24,220,56])


%     Subsystem  ['ASK//PSK',13,'modulation/Rising edge',13,'detector'].

new_system([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']],...
               'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/in_1']],...
                'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Memory1']],...
            'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/one1']],...
             'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
         'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/out_1']],...
            'position',[340,25,360,45])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],...
          'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],...
              'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['ASK//PSK',13,'modulation/Rising edge',13,'detector'].

set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],...
            'ForeGround',4,...
              'position',[75,108,135,152])

add_block('built-in/Look Up Table',[sys,'/',['ASK//PSK',13,'modulation/index match']])
set_param([sys,'/',['ASK//PSK',13,'modulation/index match']],...
              'Input_Values','z',...
          'Output_Values','y',...
         'position',[285,27,320,53])

add_block('built-in/Look Up Table',[sys,'/',['ASK//PSK',13,'modulation/amplitude',13,'match']])
set_param([sys,'/',['ASK//PSK',13,'modulation/amplitude',13,'match']],...
             'Input_Values','x',...
          'Output_Values','A',...
         'position',[380,27,415,53])

add_block('built-in/Reset Integrator',[sys,'/',['ASK//PSK',13,'modulation/Reset',13,'integrator']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Reset',13,'integrator']],...
                'position',[320,264,360,296])

add_block('built-in/Constant',[sys,'/',['ASK//PSK',13,'modulation/freq']])
set_param([sys,'/',['ASK//PSK',13,'modulation/freq']],...
                'Value','Fc',...
                'position',[225,236,250,264])

add_block('built-in/Switch',[sys,'/',['ASK//PSK',13,'modulation/Switch1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Switch1']],...
            'Threshold','eps',...
           'position',[410,214,440,246])

add_block('built-in/Sum',[sys,'/',['ASK//PSK',13,'modulation/Sum']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Sum']],...
               'inputs','-+',...
               'position',[455,185,475,205])

add_block('built-in/Look Up Table',[sys,'/',['ASK//PSK',13,'modulation/base number',13,'match']])
set_param([sys,'/',['ASK//PSK',13,'modulation/base number',13,'match']],...
               'Input_Values','x',...
          'Output_Values','s',...
         'position',[380,147,415,173])

add_block('built-in/Sum',[sys,'/',['ASK//PSK',13,'modulation/Sum1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Sum1']],...
             'inputs','+++',...
              'position',[610,72,630,108])

add_block('built-in/Fcn',[sys,'/',['ASK//PSK',13,'modulation/Oscilation']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Oscilation']],...
          'position',[650,75,725,105])

add_block('built-in/Product',[sys,'/',['ASK//PSK',13,'modulation/Product']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Product']],...
            'position',[755,75,780,95])

add_block('built-in/Outport',[sys,'/',['ASK//PSK',13,'modulation/out_1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/out_1']],...
         'position',[800,75,820,95])

add_block('built-in/Look Up Table',[sys,'/',['ASK//PSK',13,'modulation/initial phase',13,'match']])
set_param([sys,'/',['ASK//PSK',13,'modulation/initial phase',13,'match']],...
             'Input_Values','x',...
          'Output_Values','P',...
         'position',[445,67,480,93])

add_block('built-in/Look Up Table',[sys,'/',['ASK//PSK',13,'modulation/dividing base']])
set_param([sys,'/',['ASK//PSK',13,'modulation/dividing base']],...
           'Input_Values','x',...
          'Output_Values','2*pi ./ N',...
         'position',[445,122,480,148])

add_block('built-in/Product',[sys,'/',['ASK//PSK',13,'modulation/Product1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Product1']],...
         'position',[520,180,545,200])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[225,40;250,40;250,90;230,90])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[140,130;155,130;155,40;185,40])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[180,90;165,90;165,50;185,50])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[45,130;70,130])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[90,30;185,30])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[250,40;280,40])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[325,40;375,40])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[360,40;360,80;440,80])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[360,80;360,160;375,160])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[420,160;435,160;435,190;450,190])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[250,90;250,200;450,200])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[480,195;515,195])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[635,90;645,90])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[730,90;750,90])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[785,85;795,85])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[420,40;735,40;735,80;750,80])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[485,80;605,80])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[550,190;575,190;575,90;605,90])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[255,250;280,250;280,270;315,270])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[155,130;155,280;315,280])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[365,280;380,280;380,240;405,240])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[155,230;405,230])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[445,230;585,230;585,100;605,100])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[485,135;495,135;495,185;515,185])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[360,135;440,135])
set_param([sys,'/',['ASK//PSK',13,'modulation']],...
           'Mask Display','APK',...
                'Mask Type','APK')
set_param([sys,'/',['ASK//PSK',13,'modulation']],...
          'Mask Dialogue','ASK/PSK with concentric circles:|Vector of number of symboles on each circle:|Distance to the originall point for each circle:|Phase shift on each circle:|Carrier frequency:|Trigger signal threshold:')
set_param([sys,'/',['ASK//PSK',13,'modulation']],...
          'Mask Translate','N=@1;A=@2;P=@3;Fc=@4*2*pi;thld=@5;M=length(N);for i=1:M,s(i)=sum(N(1:i));end;z=[s(:)'';s(:)''];z=z(:);z=[-.5;z(1:2*M-1)-.5];x=[1:M];y=[x;x];y=y(:);s=[0,s(1:M-1)];')
set_param([sys,'/',['ASK//PSK',13,'modulation']],...
              'Mask Help','This block modulates the first port inputted message by ASK/PSK modulation method. The message should be coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The vector size of the 1st, 2nd, and 3rd entry of this block should be the same. The summation of the first entry is M, the M-ary number of the modulation.')
set_param([sys,'/',['ASK//PSK',13,'modulation']],...
           'Mask Entries','NIL\/AIL\/PIL\/Fc\/.2\/')


%     Finished composite block ['ASK//PSK',13,'modulation'].

set_param([sys,'/',['ASK//PSK',13,'modulation']],...
               'position',[185,108,245,152])

add_block('built-in/Sum',[sys,'/','Sum5'])
set_param([sys,'/','Sum5'],...
           'position',[295,125,315,145])


%     Subsystem  ['APK amp+phase',13,'demodulation'].

new_system([sys,'/',['APK amp+phase',13,'demodulation']])
set_param([sys,'/',['APK amp+phase',13,'demodulation']],'Location',[73,245,769,433])

add_block('built-in/Inport',[sys,'/',['APK amp+phase',13,'demodulation/in_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/in_1']],...
          'position',[35,65,55,85])

add_block('built-in/Product',[sys,'/',['APK amp+phase',13,'demodulation/Product1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Product1']],...
               'position',[250,80,275,100])

add_block('built-in/Product',[sys,'/',['APK amp+phase',13,'demodulation/Product']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Product']],...
              'position',[250,45,275,65])


%     Subsystem  ['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM'].

new_system([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],'Location',[353,42,897,305])

add_block('built-in/Gain',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Gain1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Gain1']],...
             'Gain','2',...
          'position',[270,118,295,142])

add_block('built-in/Inport',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/in_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/in_1']],...
              'position',[230,120,250,140])

add_block('built-in/Note',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
              'position',[285,280,290,285])

add_block('built-in/Constant',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Constant']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Constant']],...
            'Value','Fc',...
                'position',[35,115,55,135])


%     Subsystem  ['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator'].

new_system([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/in_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/in_1']],...
         'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Memory']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Memory']],...
                'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/module']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/module']],...
                'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Reset',13,'integrator']],...
              'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/one']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/one']],...
          'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Sum']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Sum']],...
         'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/out_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/out_1']],...
               'position',[370,30,390,50])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
           'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
            'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'Mask Entries','1\/0\/')


%     Finished composite block ['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator'].

set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'position',[80,109,140,141])

add_block('built-in/Gain',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Gain']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Gain']],...
         'Gain','pi2',...
                'position',[165,109,200,141])

add_block('built-in/Fcn',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Fcn']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Fcn']],...
           'Expr','sin(u[1]+Ph)',...
               'position',[225,56,300,84])

add_block('built-in/Fcn',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Fcn1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Fcn1']],...
           'Expr','sin(u[1]+Pg)',...
               'position',[220,176,295,204])

add_block('built-in/Product',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Product']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Product']],...
               'position',[330,62,355,93])

add_block('built-in/Product',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Product1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Product1']],...
               'position',[330,167,355,198])

add_block('built-in/Transfer Fcn',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter']],...
          'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[395,59,445,101])

add_block('built-in/Transfer Fcn',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter1']],...
         'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[395,164,445,206])

add_block('built-in/Outport',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/out_2']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/out_2']],...
           'Port','2',...
          'position',[480,175,500,195])

add_block('built-in/Outport',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/out_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/out_1']],...
           'position',[480,70,500,90])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[300,130;305,130;305,175;325,175])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[255,130;265,130])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[60,125;75,125])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[145,125;160,125])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[205,125;205,70;220,70])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[205,125;215,190])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[305,70;325,70])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[300,190;325,190])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[360,80;390,80])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[450,80;475,80])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[360,185;390,185])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[450,185;475,185])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
               'Mask Display','QM\nDSB-SC\nADM',...
            'Mask Type','Quadrature Demultiplexed DSB-SC AM')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
         'Mask Dialogue','Quadrature Demultiplexed Double-Sideband Suppressed-Carrier Amplitude Demodulation:|Carrier amplitude:|Carrier frequency:|Initial phase:|Filter numerator:|Filter denominator:')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
         'Mask Translate','Ac=@1;Fc=@2;Ph=@3;Fn=@4;Fd=@5;pi2=2*pi;Pg=Ph+pi/2;')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
            'Mask Help','The Quadratic Demultiplexed Double-Sideband Supressed-Carrier Amplitude Demodulation block demodulates the QM-DSB-SC-AM signal using quadratic duplex method.')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
           'Mask Entries','Am\/Fc\/0\/num\/den\/')


%     Finished composite block ['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM'].

set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
             'ForeGround',5,...
              'position',[125,49,200,96])

add_block('built-in/Sum',[sys,'/',['APK amp+phase',13,'demodulation/Sum']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Sum']],...
           'position',[340,65,360,85])

add_block('built-in/Fcn',[sys,'/',['APK amp+phase',13,'demodulation/sin']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/sin']],...
           'Expr','sqrt(u[1])',...
         'position',[385,64,450,86])

add_block('built-in/Mux',[sys,'/',['APK amp+phase',13,'demodulation/Mux']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Mux']],...
           'inputs','3',...
                'position',[490,58,525,92])

add_block('built-in/S-Function',[sys,'/',['APK amp+phase',13,'demodulation/S-function']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/S-function']],...
              'ForeGround',2,...
              'function name','apskdemo',...
          'parameters','L, Fc, N, P, A',...
               'position',[550,65,625,85])

add_block('built-in/Outport',[sys,'/',['APK amp+phase',13,'demodulation/out_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/out_1']],...
           'position',[655,65,675,85])


%     Subsystem  ['APK amp+phase',13,'demodulation/Rising edge',13,'detector'].

new_system([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/out_1']],...
              'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
           'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
          'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/one1']],...
                'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Memory1']],...
            'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/in_1']],...
         'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']],...
               'position',[135,18,165,42])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],...
           'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],...
               'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['APK amp+phase',13,'demodulation/Rising edge',13,'detector'].

set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],...
              'ForeGround',4,...
              'position',[320,108,380,152])

add_block('built-in/Inport',[sys,'/',['APK amp+phase',13,'demodulation/in_2']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/in_2']],...
            'Port','2',...
          'position',[220,120,240,140])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[245,130;315,130])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[530,75;545,75])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[60,75;120,75])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[385,130;460,130;460,85;485,85])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[630,75;650,75])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[365,75;380,75])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[85,75;85,25;470,25;470,65;485,65])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[455,75;485,75])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[205,60;215,60;215,50;245,50])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[205,60;245,60])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[280,55;300,55;300,70;335,70])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[205,85;245,85])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[205,85;215,85;215,95;245,95])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[280,90;300,90;300,80;335,80])
set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
          'Mask Display','APK\na-p demo',...
              'Mask Type','APK demodulation')
set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
              'Mask Dialogue','ASK/PSK with concentric circles:|Vector of number of symboles on each circle:|Distance to the originall point for each circle:|Phase shift on each circle:|Carrier frequency:|Trigger signal threshold:')
set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
           'Mask Translate','N=@1;A=@2;P=@3;Fc=@4;thld=@5;L=length(N); [num,den]=cheby1(2,.1,Fc*pi/5,''s'');Am=max(A);')
set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
                'Mask Help','This block demodulates an ASK/PSK modulated signal in the 1st in-port. The demodulated message are 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The parameter entry should exactly match the ASK/PSK modulation block.')
set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
           'Mask Entries','NIL\/AIL\/PIL\/Fc\/.2\/')


%     Finished composite block ['APK amp+phase',13,'demodulation'].

set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
         'ForeGround',2,...
              'position',[375,123,435,167])


%     Subsystem  'Hold and delay'.

new_system([sys,'/','Hold and delay'])
set_param([sys,'/','Hold and delay'],'Location',[380,124,840,274])

add_block('built-in/Memory',[sys,'/','Hold and delay/Memory1'])
set_param([sys,'/','Hold and delay/Memory1'],...
          'position',[220,30,260,60])

add_block('built-in/Outport',[sys,'/','Hold and delay/out_1'])
set_param([sys,'/','Hold and delay/out_1'],...
         'position',[390,45,410,65])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer1'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],'Location',[229,493,559,628])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_1']],...
              'position',[40,25,60,45])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_2']],...
              'Port','2',...
          'position',[15,60,35,80])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/out_1']],...
           'position',[290,35,310,55])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator']],...
               'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/in_1']],...
                'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Memory1']],...
            'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/one1']],...
             'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator2']],...
         'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/out_1']],...
            'position',[340,25,360,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
          'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
              'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
              'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
              'Mask Entries','thld\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
            'position',[80,48,140,92])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Memory']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Memory']],...
         'orientation',2,...
             'position',[200,80,240,110])

add_block('built-in/Switch',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Switch']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Switch']],...
               'ForeGround',5,...
              'Threshold','eps',...
           'position',[210,29,240,61])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[245,45;260,45;260,95;245,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[145,70;155,70;155,45;205,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[195,95;185,95;185,55;205,55])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[65,35;205,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[245,45;285,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[40,70;75,70])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
          'Mask Display','Hold\nBuffer',...
               'Mask Type','Hold Buffer',...
           'Mask Dialogue','Clock triggered hold buffer:|Threshold for clock signal:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
                'Mask Help','The first input port is for signal. The second input port is for clocks pulse. The rising edge of the clock signal locks the signal from the first port and outputs the value until next clock pulse rising edge.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
            'Mask Entries','.2\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer1'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
          'position',[295,33,355,77])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],'Location',[229,493,559,639])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Memory']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Memory']],...
               'orientation',2,...
             'position',[200,85,240,115])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_2']],...
             'Port','2',...
          'position',[35,70,55,90])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/out_1']],...
                'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator1']],...
           'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator2']],...
          'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/one1']],...
                'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Memory1']],...
            'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/in_1']],...
         'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator']],...
               'position',[135,18,165,42])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
           'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
               'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
               'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
               'Mask Entries','thld\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
              'position',[80,58,140,102])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_1']],...
              'position',[35,25,55,45])

add_block('built-in/Switch',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Switch']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Switch']],...
            'Threshold','eps',...
           'position',[210,29,240,61])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/out_1']],...
           'position',[290,35,310,55])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[60,80;75,80])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[245,45;285,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[60,35;205,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[195,100;185,100;185,55;205,55])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[145,80;155,80;155,45;205,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[245,45;260,45;260,100;245,100])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
             'Mask Display','Hold\nBuffer',...
               'Mask Type','Hold Buffer',...
           'Mask Dialogue','Clock triggered hold buffer:|Threshold for clock signal:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
          'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
         'Mask Help','The first input port is for signal. The second input port is for clocks pulse. The rising edge of the clock signal locks the signal from the first port and outputs the value until next clock pulse rising edge.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
             'Mask Entries','.2\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
            'position',[130,23,190,67])

add_block('built-in/Inport',[sys,'/','Hold and delay/in_1'])
set_param([sys,'/','Hold and delay/in_1'],...
            'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/','Hold and delay/in_2'])
set_param([sys,'/','Hold and delay/in_2'],...
              'Port','2',...
          'position',[45,45,65,65])
add_line([sys,'/','Hold and delay'],[70,55;125,55])
add_line([sys,'/','Hold and delay'],[85,55;85,105;270,105;270,65;290,65])
add_line([sys,'/','Hold and delay'],[360,55;385,55])
add_line([sys,'/','Hold and delay'],[40,35;125,35])
add_line([sys,'/','Hold and delay'],[195,45;215,45])
add_line([sys,'/','Hold and delay'],[265,45;290,45])


%     Finished composite block 'Hold and delay'.

set_param([sys,'/','Hold and delay'],...
            'ForeGround',5,...
              'position',[285,44,340,86])


%     Subsystem  ['Random-number',13,'generator'].

new_system([sys,'/',['Random-number',13,'generator']])
set_param([sys,'/',['Random-number',13,'generator']],'Location',[115,400,471,569])

add_block('built-in/White Noise',[sys,'/',['Random-number',13,'generator/Random',13,'Number']])
set_param([sys,'/',['Random-number',13,'generator/Random',13,'Number']],...
         'Seed','seed',...
               'position',[40,27,85,63])

add_block('built-in/Relational Operator',[sys,'/',['Random-number',13,'generator/Relational',13,'Operator']])
set_param([sys,'/',['Random-number',13,'generator/Relational',13,'Operator']],...
         'position',[155,38,185,62])

add_block('built-in/Outport',[sys,'/',['Random-number',13,'generator/out_1']])
set_param([sys,'/',['Random-number',13,'generator/out_1']],...
         'position',[310,40,330,60])

add_block('built-in/State-Space',[sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']])
set_param([sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']],...
               'A','[]',...
            'B','[]',...
            'C','[]',...
            'D','K',...
             'Mask Display','K',...
          'Mask Type','Matrix Gain',...
           'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']],...
           'Mask Translate','K = @1;',...
          'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
            'Mask Entries','ones(1,N-1)\/')
set_param([sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']],...
                'position',[230,35,275,65])

add_block('built-in/Constant',[sys,'/',['Random-number',13,'generator/Constant']])
set_param([sys,'/',['Random-number',13,'generator/Constant']],...
          'Value','x',...
         'position',[65,105,95,125])
add_line([sys,'/',['Random-number',13,'generator']],[280,50;305,50])
add_line([sys,'/',['Random-number',13,'generator']],[190,50;225,50])
add_line([sys,'/',['Random-number',13,'generator']],[100,115;115,115;115,55;150,55])
add_line([sys,'/',['Random-number',13,'generator']],[90,45;150,45])
set_param([sys,'/',['Random-number',13,'generator']],...
              'Mask Display','Random\nNumber',...
             'Mask Type','Random number generator',...
               'Mask Dialogue','Random number generator:|M-ary number:|Seed:')
set_param([sys,'/',['Random-number',13,'generator']],...
              'Mask Translate','N=@1;x=[(2-N)/N:2/N:(N-2)/N];seed=@2;')
set_param([sys,'/',['Random-number',13,'generator']],...
               'Mask Help','This block generate integer number 0 to M-1, where M is a integer. The probability of the apperance for each number is not guaranteed to be the same.')
set_param([sys,'/',['Random-number',13,'generator']],...
            'Mask Entries','N\/4432\/')


%     Finished composite block ['Random-number',13,'generator'].

set_param([sys,'/',['Random-number',13,'generator']],...
             'BackGround',5,...
              'position',[45,35,105,75])


%     Subsystem  ['Clock',13,'pulse'].

new_system([sys,'/',['Clock',13,'pulse']])
set_param([sys,'/',['Clock',13,'pulse']],'Location',[272,165,909,406])

add_block('built-in/Unit Delay',[sys,'/',['Clock',13,'pulse/Unit Delay1']])
set_param([sys,'/',['Clock',13,'pulse/Unit Delay1']],...
             'orientation',2,...
             'Sample time','[Ts/2,st2]',...
          'x0','ini',...
          'position',[140,165,190,185])

add_block('built-in/Unit Delay',[sys,'/',['Clock',13,'pulse/Unit Delay']])
set_param([sys,'/',['Clock',13,'pulse/Unit Delay']],...
          'orientation',2,...
             'Sample time','[Ts/2,st1]',...
          'position',[145,75,195,95])

add_block('built-in/Gain',[sys,'/',['Clock',13,'pulse/Gain1']])
set_param([sys,'/',['Clock',13,'pulse/Gain1']],...
            'Gain','g',...
          'position',[235,122,255,138])

add_block('built-in/Constant',[sys,'/',['Clock',13,'pulse/Constant']])
set_param([sys,'/',['Clock',13,'pulse/Constant']],...
                'position',[25,30,45,50])

add_block('built-in/Saturation',[sys,'/',['Clock',13,'pulse/Saturation']])
set_param([sys,'/',['Clock',13,'pulse/Saturation']],...
              'Lower Limit','0',...
           'Upper Limit','1',...
           'position',[365,40,390,60])

add_block('built-in/Sum',[sys,'/',['Clock',13,'pulse/Sum2']])
set_param([sys,'/',['Clock',13,'pulse/Sum2']],...
               'hide name',0,...
               'inputs','+-',...
               'position',[300,40,320,60])

add_block('built-in/Sum',[sys,'/',['Clock',13,'pulse/Sum']])
set_param([sys,'/',['Clock',13,'pulse/Sum']],...
         'hide name',0,...
               'inputs','+-',...
               'position',[135,35,155,55])

add_block('built-in/Sum',[sys,'/',['Clock',13,'pulse/Sum1']])
set_param([sys,'/',['Clock',13,'pulse/Sum1']],...
               'hide name',0,...
               'inputs','+-',...
               'position',[130,120,150,140])

add_block('built-in/Relational Operator',[sys,'/',['Clock',13,'pulse/Relational',13,'operator']])
set_param([sys,'/',['Clock',13,'pulse/Relational',13,'operator']],...
             'hide name',0,...
               'position',[370,102,400,133])

add_block('built-in/Gain',[sys,'/',['Clock',13,'pulse/Gain']])
set_param([sys,'/',['Clock',13,'pulse/Gain']],...
            'hide name',0,...
               'Gain','ht',...
         'position',[540,102,565,128])

add_block('built-in/Product',[sys,'/',['Clock',13,'pulse/Product']])
set_param([sys,'/',['Clock',13,'pulse/Product']],...
           'hide name',0,...
               'position',[470,105,495,125])

add_block('built-in/Clock',[sys,'/',['Clock',13,'pulse/Clock1']])
set_param([sys,'/',['Clock',13,'pulse/Clock1']],...
               'hide name',0,...
               'position',[295,100,315,120])

add_block('built-in/Constant',[sys,'/',['Clock',13,'pulse/Constant1']])
set_param([sys,'/',['Clock',13,'pulse/Constant1']],...
              'Value','stt',...
               'position',[295,149,320,171])

add_block('built-in/Outport',[sys,'/',['Clock',13,'pulse/out_1']])
set_param([sys,'/',['Clock',13,'pulse/out_1']],...
               'hide name',0,...
               'position',[590,105,610,125])
add_line([sys,'/',['Clock',13,'pulse']],[260,130;275,130;275,55;295,55])
add_line([sys,'/',['Clock',13,'pulse']],[155,130;230,130])
add_line([sys,'/',['Clock',13,'pulse']],[325,50;360,50])
add_line([sys,'/',['Clock',13,'pulse']],[160,45;295,45])
add_line([sys,'/',['Clock',13,'pulse']],[50,40;70,40;70,125;125,125])
add_line([sys,'/',['Clock',13,'pulse']],[135,175;100,175;100,135;125,135])
add_line([sys,'/',['Clock',13,'pulse']],[155,130;210,130;210,175;195,175])
add_line([sys,'/',['Clock',13,'pulse']],[50,40;130,40])
add_line([sys,'/',['Clock',13,'pulse']],[160,45;230,45;230,85;200,85])
add_line([sys,'/',['Clock',13,'pulse']],[140,85;105,85;105,50;130,50])
add_line([sys,'/',['Clock',13,'pulse']],[320,110;365,110])
add_line([sys,'/',['Clock',13,'pulse']],[405,120;465,120])
add_line([sys,'/',['Clock',13,'pulse']],[500,115;535,115])
add_line([sys,'/',['Clock',13,'pulse']],[570,115;585,115])
add_line([sys,'/',['Clock',13,'pulse']],[325,160;345,160;345,125;365,125])
add_line([sys,'/',['Clock',13,'pulse']],[395,50;430,50;430,110;465,110])
set_param([sys,'/',['Clock',13,'pulse']],...
               'Mask Display','plot(0,0,100,100,[90,75,75,60,60,35,35,20,20,10],[20,20,80,80,20,20,80,80,20,20])',...
          'Mask Type','Pulse Generator')
set_param([sys,'/',['Clock',13,'pulse']],...
              'Mask Dialogue','Pulse Generator.|Pulse period (secs):|Pulse width:|Pulse height:|Pulse start time:')
set_param([sys,'/',['Clock',13,'pulse']],...
               'Mask Translate','Ts=@1; du=@2; ht=@3; stt=@4; g=1; ini=ones(length(@3),1); if (Ts<2*du), g=-1; du=du-Ts/2; ini=zeros(length(@3),1); end; st1=rem(stt,Ts); st2=rem(stt+du,Ts);')
set_param([sys,'/',['Clock',13,'pulse']],...
            'Mask Help','Pulse generator which ensures pulse\ntransitions are hit. Provides a vector of pulses when the height is entered as a vector.\nUnmask to see how it works.')
set_param([sys,'/',['Clock',13,'pulse']],...
           'Mask Entries','T\/.05\/1\/0\/')


%     Finished composite block ['Clock',13,'pulse'].

set_param([sys,'/',['Clock',13,'pulse']],...
                'BackGround',4,...
              'position',[50,262,85,298])


%     Subsystem  ['APK correlation',13,'demodulation1'].

new_system([sys,'/',['APK correlation',13,'demodulation1']])
set_param([sys,'/',['APK correlation',13,'demodulation1']],'Location',[2,46,536,174])

add_block('built-in/Mux',[sys,'/',['APK correlation',13,'demodulation1/Mux']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Mux']],...
            'inputs','2',...
                'position',[250,25,285,60])

add_block('built-in/Outport',[sys,'/',['APK correlation',13,'demodulation1/out_1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/out_1']],...
             'position',[430,35,450,55])

add_block('built-in/S-Function',[sys,'/',['APK correlation',13,'demodulation1/S-function']])
set_param([sys,'/',['APK correlation',13,'demodulation1/S-function']],...
                'ForeGround',2,...
              'function name','apskdem2',...
          'parameters','L, Fc, N, P, A',...
               'position',[325,35,400,55])

add_block('built-in/Inport',[sys,'/',['APK correlation',13,'demodulation1/in_1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/in_1']],...
                'position',[85,25,105,45])


%     Subsystem  ['APK correlation',13,'demodulation1/Rising edge',13,'detector'].

new_system([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator']],...
              'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/in_1']],...
            'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Memory1']],...
                'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/one1']],...
         'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator2']],...
             'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator1']],...
             'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/out_1']],...
                'position',[340,25,360,45])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],...
                'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],...
            'Mask Translate','thld=@1;')
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],...
            'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['APK correlation',13,'demodulation1/Rising edge',13,'detector'].

set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],...
                'ForeGround',4,...
              'position',[125,53,185,97])

add_block('built-in/Inport',[sys,'/',['APK correlation',13,'demodulation1/in_2']])
set_param([sys,'/',['APK correlation',13,'demodulation1/in_2']],...
                'Port','2',...
          'position',[25,65,45,85])
add_line([sys,'/',['APK correlation',13,'demodulation1']],[110,35;245,35])
add_line([sys,'/',['APK correlation',13,'demodulation1']],[405,45;425,45])
add_line([sys,'/',['APK correlation',13,'demodulation1']],[190,75;210,75;210,50;245,50])
add_line([sys,'/',['APK correlation',13,'demodulation1']],[290,45;320,45])
add_line([sys,'/',['APK correlation',13,'demodulation1']],[50,75;120,75])
set_param([sys,'/',['APK correlation',13,'demodulation1']],...
          'Mask Display','APK\ncorr demo',...
             'Mask Type','APK demodulation')
set_param([sys,'/',['APK correlation',13,'demodulation1']],...
           'Mask Dialogue','ASK/PSK with concentric circles:|Vector of number of symboles on each circle:|Distance to the originall point for each circle:|Phase shift on each circle:|Carrier frequency:|Trigger signal threshold:')
set_param([sys,'/',['APK correlation',13,'demodulation1']],...
                'Mask Translate','N=@1;A=@2;P=@3;Fc=@4;thld=@5;L=length(N); [num,den]=cheby1(2,.1,Fc*pi/5,''s'');Am=max(A);')
set_param([sys,'/',['APK correlation',13,'demodulation1']],...
             'Mask Help','This block demodulates an ASK/PSK modulated signal in the 1st in-port. The demodulated message are 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The parameter entry should exactly match the ASK/PSK modulation block.')
set_param([sys,'/',['APK correlation',13,'demodulation1']],...
                'Mask Entries','NIL\/AIL\/PIL\/Fc\/.2\/')


%     Finished composite block ['APK correlation',13,'demodulation1'].

set_param([sys,'/',['APK correlation',13,'demodulation1']],...
           'ForeGround',3,...
              'position',[375,198,435,242])


%     Subsystem  ['Transmitting',13,'error-counter1'].

new_system([sys,'/',['Transmitting',13,'error-counter1']])
set_param([sys,'/',['Transmitting',13,'error-counter1']],'Location',[67,468,602,636])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter1/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/in_1']],...
             'position',[40,15,60,35])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter1/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/out_1']],...
           'position',[475,55,495,75])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter1/in_4']])
set_param([sys,'/',['Transmitting',13,'error-counter1/in_4']],...
            'Port','4',...
          'position',[300,125,320,145])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter1/in_3']])
set_param([sys,'/',['Transmitting',13,'error-counter1/in_3']],...
          'Port','3',...
          'position',[260,100,280,120])


%     Subsystem  ['Transmitting',13,'error-counter1/Counter'].

new_system([sys,'/',['Transmitting',13,'error-counter1/Counter']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter']],'Location',[378,106,972,431])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter1/Counter/Constant']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Constant']],...
          'ForeGround',3,...
              'Value','thld',...
              'position',[105,100,135,120])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter1/Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Relational',13,'Operator1']],...
           'ForeGround',2,...
              'Operator','>',...
              'position',[225,53,255,77])

add_block('built-in/Sum',[sys,'/',['Transmitting',13,'error-counter1/Counter/Sum']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Sum']],...
         'ForeGround',3,...
              'position',[295,100,315,120])

add_block('built-in/Switch',[sys,'/',['Transmitting',13,'error-counter1/Counter/Switch2']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Switch2']],...
            'ForeGround',3,...
              'Threshold','eps',...
           'position',[345,149,370,181])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter1/Counter/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/in_1']],...
          'position',[15,50,35,70])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter1/Counter/in_2']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/in_2']],...
              'Port','2',...
          'position',[15,155,35,175])


%     Subsystem  ['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/out_1']],...
         'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
                'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/one1']],...
              'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/Memory1']],...
          'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/in_1']],...
               'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
             'position',[135,18,165,42])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],...
          'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],...
              'Mask Translate','thld=@1;')
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],...
              'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],...
              'Mask Entries','thld\/')


%     Finished composite block ['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector']],...
            'ForeGround',4,...
              'position',[80,148,140,182])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter1/Counter/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/out_1']],...
                'position',[550,145,570,165])

add_block('built-in/Switch',[sys,'/',['Transmitting',13,'error-counter1/Counter/Switch3']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Switch3']],...
            'ForeGround',3,...
              'Threshold','eps',...
           'position',[470,139,495,171])

add_block('built-in/Memory',[sys,'/',['Transmitting',13,'error-counter1/Counter/Memory3']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Memory3']],...
            'orientation',2,...
             'ForeGround',3,...
              'position',[400,205,440,235])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter1/Counter/in_3']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/in_3']],...
          'Port','3',...
          'position',[315,60,335,80])


%     Subsystem  ['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
          'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/in_1']],...
              'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/Memory1']],...
          'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/one1']],...
           'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
               'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
               'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1/out_1']],...
          'position',[340,25,360,45])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],[300,35;335,35])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],...
         'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],...
             'Mask Translate','thld=@1;')
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],...
             'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],...
             'Mask Entries','thld\/')


%     Finished composite block ['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Transmitting',13,'error-counter1/Counter/Rising edge',13,'detector1']],...
          'ForeGround',4,...
              'position',[375,53,435,87])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[440,70;450,70;450,155;465,155])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[395,220;275,220;275,175;340,175])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[275,175;275,115;290,115])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[145,165;340,165])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[260,65;275,65;275,105;290,105])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[140,110;190,110;190,70;220,70])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[320,110;330,110;340,155])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[40,60;220,60])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[40,165;75,165])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[340,70;370,70])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[375,165;465,165])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[500,155;545,155])
add_line([sys,'/',['Transmitting',13,'error-counter1/Counter']],[520,155;520,220;445,220])
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter']],...
            'Mask Display','Number\nCounter',...
            'Mask Type','Number Counter',...
                'Mask Dialogue','Number counter:|Threshold:',...
                'Mask Translate','thld=@1;')
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter']],...
                'Mask Help','If the signal at the first port is larger than the given threshold at the time of the clock raising edge, the counter increases one. The clock signl is provided at the second port. The raising edge of the third port clears the counter, which enforces the counter to be zero regardless the signal in port one and two.')
set_param([sys,'/',['Transmitting',13,'error-counter1/Counter']],...
         'Mask Entries','.2\/')


%     Finished composite block ['Transmitting',13,'error-counter1/Counter'].

set_param([sys,'/',['Transmitting',13,'error-counter1/Counter']],...
          'position',[365,43,425,87])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter1/Constant']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Constant']],...
          'Value','tol',...
               'position',[195,80,215,100])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter1/Relational',13,'Operator']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Relational',13,'Operator']],...
              'Operator','>',...
              'position',[270,38,300,62])

add_block('built-in/Abs',[sys,'/',['Transmitting',13,'error-counter1/Abs']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Abs']],...
         'position',[195,33,225,57])

add_block('built-in/Sum',[sys,'/',['Transmitting',13,'error-counter1/Sum']])
set_param([sys,'/',['Transmitting',13,'error-counter1/Sum']],...
         'inputs','+-',...
               'position',[140,35,160,55])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter1/in_2']])
set_param([sys,'/',['Transmitting',13,'error-counter1/in_2']],...
            'Port','2',...
          'position',[80,40,100,60])
add_line([sys,'/',['Transmitting',13,'error-counter1']],[65,25;110,25;110,40;135,40])
add_line([sys,'/',['Transmitting',13,'error-counter1']],[105,50;135,50])
add_line([sys,'/',['Transmitting',13,'error-counter1']],[165,45;190,45])
add_line([sys,'/',['Transmitting',13,'error-counter1']],[230,45;265,45])
add_line([sys,'/',['Transmitting',13,'error-counter1']],[220,90;235,90;235,55;265,55])
add_line([sys,'/',['Transmitting',13,'error-counter1']],[305,50;360,50])
add_line([sys,'/',['Transmitting',13,'error-counter1']],[285,110;315,110;315,65;360,65])
add_line([sys,'/',['Transmitting',13,'error-counter1']],[325,135;335,135;335,80;360,80])
add_line([sys,'/',['Transmitting',13,'error-counter1']],[430,65;470,65])
set_param([sys,'/',['Transmitting',13,'error-counter1']],...
               'Mask Display','Error\ncounter',...
             'Mask Type','Error Counter',...
         'Mask Dialogue','Transmission error counter:|Threshold:|Tolerance:',...
         'Mask Translate','thld=@1;tol=@2;')
set_param([sys,'/',['Transmitting',13,'error-counter1']],...
         'Mask Help','This block counts the errors digital transmitting. If the difference between the first two ports is larger than the threshold, the counter increases one at the clock raising edge. The clock signal is provided from port three. Port four is used to reset the count to be zero.')
set_param([sys,'/',['Transmitting',13,'error-counter1']],...
           'Mask Entries','0.2\/eps\/')


%     Finished composite block ['Transmitting',13,'error-counter1'].

set_param([sys,'/',['Transmitting',13,'error-counter1']],...
            'ForeGround',6,...
              'position',[515,204,575,246])


%     Subsystem  ['Transmitting',13,'error-counter'].

new_system([sys,'/',['Transmitting',13,'error-counter']])
set_param([sys,'/',['Transmitting',13,'error-counter']],'Location',[67,468,602,636])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/in_2']])
set_param([sys,'/',['Transmitting',13,'error-counter/in_2']],...
          'Port','2',...
          'position',[80,40,100,60])

add_block('built-in/Sum',[sys,'/',['Transmitting',13,'error-counter/Sum']])
set_param([sys,'/',['Transmitting',13,'error-counter/Sum']],...
            'inputs','+-',...
               'position',[140,35,160,55])

add_block('built-in/Abs',[sys,'/',['Transmitting',13,'error-counter/Abs']])
set_param([sys,'/',['Transmitting',13,'error-counter/Abs']],...
           'position',[195,33,225,57])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Relational',13,'Operator']])
set_param([sys,'/',['Transmitting',13,'error-counter/Relational',13,'Operator']],...
         'Operator','>',...
              'position',[270,38,300,62])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter/Constant']])
set_param([sys,'/',['Transmitting',13,'error-counter/Constant']],...
            'Value','tol',...
               'position',[195,80,215,100])


%     Subsystem  ['Transmitting',13,'error-counter/Counter'].

new_system([sys,'/',['Transmitting',13,'error-counter/Counter']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter']],'Location',[378,106,972,431])


%     Subsystem  ['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/out_1']],...
             'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
                'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/one1']],...
              'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Memory1']],...
          'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/in_1']],...
               'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
             'position',[135,18,165,42])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[300,35;335,35])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],...
          'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],...
              'Mask Translate','thld=@1;')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],...
              'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],...
              'Mask Entries','thld\/')


%     Finished composite block ['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],...
            'ForeGround',4,...
              'position',[375,53,435,87])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/Counter/in_3']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/in_3']],...
              'Port','3',...
          'position',[315,60,335,80])

add_block('built-in/Memory',[sys,'/',['Transmitting',13,'error-counter/Counter/Memory3']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Memory3']],...
                'orientation',2,...
             'ForeGround',3,...
              'position',[400,205,440,235])

add_block('built-in/Switch',[sys,'/',['Transmitting',13,'error-counter/Counter/Switch3']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Switch3']],...
              'ForeGround',3,...
              'Threshold','eps',...
           'position',[470,139,495,171])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter/Counter/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/out_1']],...
         'position',[550,145,570,165])


%     Subsystem  ['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
          'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/in_1']],...
          'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Memory1']],...
              'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/one1']],...
               'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
           'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
           'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/out_1']],...
              'position',[340,25,360,45])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],...
           'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],...
               'Mask Translate','thld=@1;')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],...
               'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],...
               'Mask Entries','thld\/')


%     Finished composite block ['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],...
              'ForeGround',4,...
              'position',[80,148,140,182])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/Counter/in_2']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/in_2']],...
             'Port','2',...
          'position',[15,155,35,175])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/Counter/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/in_1']],...
              'position',[15,50,35,70])

add_block('built-in/Switch',[sys,'/',['Transmitting',13,'error-counter/Counter/Switch2']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Switch2']],...
          'ForeGround',3,...
              'Threshold','eps',...
           'position',[345,149,370,181])

add_block('built-in/Sum',[sys,'/',['Transmitting',13,'error-counter/Counter/Sum']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Sum']],...
         'ForeGround',3,...
              'position',[295,100,315,120])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Relational',13,'Operator1']],...
             'ForeGround',2,...
              'Operator','>',...
              'position',[225,53,255,77])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter/Counter/Constant']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Constant']],...
            'ForeGround',3,...
              'Value','thld',...
              'position',[105,100,135,120])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[500,155;545,155])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[520,155;520,220;445,220])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[375,165;465,165])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[340,70;370,70])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[40,165;75,165])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[40,60;220,60])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[320,110;330,110;340,155])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[395,220;275,220;275,175;340,175])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[140,110;190,110;190,70;220,70])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[260,65;275,65;275,105;290,105])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[145,165;340,165])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[275,175;275,115;290,115])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[440,70;450,70;450,155;465,155])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter']],...
                'Mask Display','Number\nCounter',...
            'Mask Type','Number Counter',...
                'Mask Dialogue','Number counter:|Threshold:',...
                'Mask Translate','thld=@1;')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter']],...
         'Mask Help','If the signal at the first port is larger than the given threshold at the time of the clock raising edge, the counter increases one. The clock signl is provided at the second port. The raising edge of the third port clears the counter, which enforces the counter to be zero regardless the signal in port one and two.')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter']],...
          'Mask Entries','.2\/')


%     Finished composite block ['Transmitting',13,'error-counter/Counter'].

set_param([sys,'/',['Transmitting',13,'error-counter/Counter']],...
            'position',[365,43,425,87])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/in_3']])
set_param([sys,'/',['Transmitting',13,'error-counter/in_3']],...
              'Port','3',...
          'position',[260,100,280,120])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/in_4']])
set_param([sys,'/',['Transmitting',13,'error-counter/in_4']],...
            'Port','4',...
          'position',[300,125,320,145])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/out_1']],...
         'position',[475,55,495,75])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/in_1']],...
              'position',[40,15,60,35])
add_line([sys,'/',['Transmitting',13,'error-counter']],[430,65;470,65])
add_line([sys,'/',['Transmitting',13,'error-counter']],[325,135;335,135;335,80;360,80])
add_line([sys,'/',['Transmitting',13,'error-counter']],[285,110;315,110;315,65;360,65])
add_line([sys,'/',['Transmitting',13,'error-counter']],[305,50;360,50])
add_line([sys,'/',['Transmitting',13,'error-counter']],[220,90;235,90;235,55;265,55])
add_line([sys,'/',['Transmitting',13,'error-counter']],[230,45;265,45])
add_line([sys,'/',['Transmitting',13,'error-counter']],[165,45;190,45])
add_line([sys,'/',['Transmitting',13,'error-counter']],[105,50;135,50])
add_line([sys,'/',['Transmitting',13,'error-counter']],[65,25;110,25;110,40;135,40])
set_param([sys,'/',['Transmitting',13,'error-counter']],...
          'Mask Display','Error\ncounter',...
             'Mask Type','Error Counter',...
         'Mask Dialogue','Transmission error counter:|Threshold:|Tolerance:',...
         'Mask Translate','thld=@1;tol=@2;')
set_param([sys,'/',['Transmitting',13,'error-counter']],...
          'Mask Help','This block counts the errors digital transmitting. If the difference between the first two ports is larger than the threshold, the counter increases one at the clock raising edge. The clock signal is provided from port three. Port four is used to reset the count to be zero.')
set_param([sys,'/',['Transmitting',13,'error-counter']],...
            'Mask Entries','0.2\/eps\/')


%     Finished composite block ['Transmitting',13,'error-counter'].

set_param([sys,'/',['Transmitting',13,'error-counter']],...
              'ForeGround',7,...
              'position',[515,129,575,171])


%     Subsystem  'Additive Noise'.

new_system([sys,'/','Additive Noise'])
set_param([sys,'/','Additive Noise'],'Location',[54,341,339,470])

add_block('built-in/White Noise',[sys,'/','Additive Noise/White Noise'])
set_param([sys,'/','Additive Noise/White Noise'],...
              'Seed','seed',...
               'position',[25,40,45,60])

add_block('built-in/Zero-Order Hold',[sys,'/',['Additive Noise/Zero-Order',13,'Hold']])
set_param([sys,'/',['Additive Noise/Zero-Order',13,'Hold']],...
         'Sample time','Ts',...
          'position',[85,34,120,66])

add_block('built-in/Gain',[sys,'/','Additive Noise/Gain'])
set_param([sys,'/','Additive Noise/Gain'],...
               'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
             'position',[155,31,195,69])

add_block('built-in/Outport',[sys,'/','Additive Noise/Out_1'])
set_param([sys,'/','Additive Noise/Out_1'],...
         'position',[230,40,250,60])
add_line([sys,'/','Additive Noise'],[125,50;150,50])
add_line([sys,'/','Additive Noise'],[200,50;225,50])
add_line([sys,'/','Additive Noise'],[50,50;80,50])
set_param([sys,'/','Additive Noise'],...
           'Mask Display','plot(t(:),r2(:))',...
           'Mask Type','Continuous White Noise.')
set_param([sys,'/','Additive Noise'],...
          'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/','Additive Noise'],...
           'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/','Additive Noise'],...
                'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/','Additive Noise'],...
           'Mask Entries','.001\/0.005\/[23341]\/')


%     Finished composite block 'Additive Noise'.

set_param([sys,'/','Additive Noise'],...
                'BackGround',3,...
              'position',[135,292,180,328])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[85,525,838,667])

add_block('built-in/Note',[sys,'/','Subsystem1/Green signal is the result of error counting. It records all error occured in the transmitting.'])
set_param([sys,'/','Subsystem1/Green signal is the result of error counting. It records all error occured in the transmitting.'],...
         'ForeGround',3,...
              'position',[285,100,290,105])

add_block('built-in/Note',[sys,'/',['Subsystem1/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']])
set_param([sys,'/',['Subsystem1/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']],...
            'ForeGround',5)
set_param([sys,'/',['Subsystem1/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']],...
            'position',[330,45,335,50])

add_block('built-in/Note',[sys,'/','Subsystem1/Red signal is the M-ary Quadrature ASK//PSK modulated//demodulated result. It should match the yellow signal.'])
set_param([sys,'/','Subsystem1/Red signal is the M-ary Quadrature ASK//PSK modulated//demodulated result. It should match the yellow signal.'],...
              'ForeGround',2,...
              'position',[355,75,360,80])

add_block('built-in/Note',[sys,'/','Subsystem1/This test file is to test digital amplitude shift-keying//phase shift-keying modulation//demodulation blocks.'])
set_param([sys,'/','Subsystem1/This test file is to test digital amplitude shift-keying//phase shift-keying modulation//demodulation blocks.'],...
            'position',[325,25,330,30])
set_param([sys,'/','Subsystem1'],...
         'Mask Display','Plot\nsignal set',...
           'Mask Dialogue','eval(''sigsetpl(NIL, AIL, PIL);'');')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
          'hide name',0,...
               'Drop Shadow',4,...
             'position',[120,365,185,401])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[93,451,802,680])

add_block('built-in/Note',[sys,'/','Subsystem/This test file is to test digital amplitude shift-keying//phase shift-keying modulation//demodulation blocks.'])
set_param([sys,'/','Subsystem/This test file is to test digital amplitude shift-keying//phase shift-keying modulation//demodulation blocks.'],...
          'position',[325,25,330,30])

add_block('built-in/Note',[sys,'/',['Subsystem/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']])
set_param([sys,'/',['Subsystem/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']],...
                'ForeGround',5)
set_param([sys,'/',['Subsystem/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']],...
             'position',[330,45,335,50])

add_block('built-in/Note',[sys,'/','Subsystem/Red signal is the M-ary Quadrature ASK//PSK modulated//a-p demodulated result. It should match the yellow signal.'])
set_param([sys,'/','Subsystem/Red signal is the M-ary Quadrature ASK//PSK modulated//a-p demodulated result. It should match the yellow signal.'],...
                'ForeGround',2,...
              'position',[365,80,370,85])

add_block('built-in/Note',[sys,'/','Subsystem/Green signal is the M-ary Quadrature ASK//PSK modulated//corr demodulated result. It should match the yellow signal.'])
set_param([sys,'/','Subsystem/Green signal is the M-ary Quadrature ASK//PSK modulated//corr demodulated result. It should match the yellow signal.'],...
          'ForeGround',3,...
              'position',[370,100,375,105])

add_block('built-in/Note',[sys,'/','Subsystem/Cyan signal is the result of error counting. It records number of errors occured in the a-p demodulation.'])
set_param([sys,'/','Subsystem/Cyan signal is the result of error counting. It records number of errors occured in the a-p demodulation.'],...
            'ForeGround',7,...
              'position',[320,120,325,125])

add_block('built-in/Note',[sys,'/','Subsystem/Magenta signal is the result of error counting. It records number of errors occured in the corr demodulation.'])
set_param([sys,'/','Subsystem/Magenta signal is the result of error counting. It records number of errors occured in the corr demodulation.'],...
            'ForeGround',6,...
              'position',[335,140,340,145])

add_block('built-in/Note',[sys,'/',['Subsystem/The default signal set design example can be found in Thomas, C.M., M.Y.Weidner, S.H. Durrani, 1974, Digital',13,'Amplitude-Phase Keying with M-ary Alphabets, IEEE trans. COM-22:168-180 ']])
set_param([sys,'/',['Subsystem/The default signal set design example can be found in Thomas, C.M., M.Y.Weidner, S.H. Durrani, 1974, Digital',13,'Amplitude-Phase Keying with M-ary Alphabets, IEEE trans. COM-22:168-180 ']],...
              'position',[350,170,355,175])
set_param([sys,'/','Subsystem'],...
                'Mask Display','?')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
               'hide name',0,...
               'Drop Shadow',4,...
             'position',[45,365,75,401])

add_block('built-in/Note',[sys,'/',['The curve color in the graphical scope matches the color of the',13,'blocks in the block diagram                                                   ']])
set_param([sys,'/',['The curve color in the graphical scope matches the color of the',13,'blocks in the block diagram                                                   ']],...
          'position',[490,290,495,295])

add_block('built-in/Note',[sys,'/',['Change MATLAB workspace variable for different parameters:',13,'N -- M-ary number (default 128)   ',13,'T -- Clock sample time (default .1)  ',13,'Fc -- Carrier frequency (default 100)']])
set_param([sys,'/',['Change MATLAB workspace variable for different parameters:',13,'N -- M-ary number (default 128)   ',13,'T -- Clock sample time (default .1)  ',13,'Fc -- Carrier frequency (default 100)']],...
                'position',[485,320,490,325])

add_block('built-in/Note',[sys,'/',['NIL -- Number in each layer (default [6 12 18 24 30 38])                 ',13,'AIL -- Amplitude in each layer (default [1 1.93 2.88 3.82 4.78 6.05])',13,'PIL -- Phase in each layer (default [0 0 0 0 0 0])                            ']])
set_param([sys,'/',['NIL -- Number in each layer (default [6 12 18 24 30 38])                 ',13,'AIL -- Amplitude in each layer (default [1 1.93 2.88 3.82 4.78 6.05])',13,'PIL -- Phase in each layer (default [0 0 0 0 0 0])                            ']],...
              'position',[575,375,580,380])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
             'inputs','5',...
                'position',[630,61,665,109])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
               'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
          'function name','sfuny',...
             'parameters','ax, color,dt',...
         'position',[130,55,180,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
            'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
                'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
              'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Graph'],...
              'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Graph'],...
           'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
         'Mask Entries','.5\/-1.1\/N-.8\/''y-/r--/g-./c:/m:/g-./w-/r:''\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
                'position',[690,66,720,104])
add_line(sys,[110,55;280,55])
add_line(sys,[250,130;290,130])
add_line(sys,[320,135;370,135])
add_line(sys,[185,310;265,310;265,140;290,140])
add_line(sys,[90,280;350,280;350,155;370,155])
add_line(sys,[155,280;155,140;180,140])
add_line(sys,[155,140;155,75;280,75])
add_line(sys,[345,65;485,65;485,135;510,135])
add_line(sys,[440,145;510,145])
add_line(sys,[130,55;130,120;180,120])
add_line(sys,[330,135;330,210;370,210])
add_line(sys,[440,220;510,220])
add_line(sys,[485,135;485,210;510,210])
add_line(sys,[670,85;685,85])
add_line(sys,[350,280;495,280;495,155;510,155])
add_line(sys,[495,230;510,230])
add_line(sys,[350,230;370,230])
add_line(sys,[485,65;625,65])
add_line(sys,[450,145;450,75;625,75])
add_line(sys,[465,220;465,85;625,85])
add_line(sys,[580,150;595,150;595,95;625,95])
add_line(sys,[580,225;600,225;600,105;625,105])

drawnow

% Return any arguments.
if (nargin | nargout)
 % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
else
 drawnow % Flash up the model and execute load callback
end
