function [ret,x0,str,ts,xts]=tstbchsq(t,x,u,flag);
%TSTBCHSQ	is the M-file description of the SIMULINK system named TSTBCHSQ.
%	The block-diagram can be displayed by typing: TSTBCHSQ.
%
%	SYS=TSTBCHSQ(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTBCHSQ to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTBCHSQ with a FLAG of zero:
%	[SIZES]=TSTBCHSQ([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[34,207,747,496])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','N_bch_demo=15;K_bch_demo=5;T_bch_demo=3;GWN=.05;');

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[595,81,625,114])


%     Subsystem  ['Placed and',13,'detected errors'].

new_system([sys,'/',['Placed and',13,'detected errors']])
set_param([sys,'/',['Placed and',13,'detected errors']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Placed and',13,'detected errors/x']])
set_param([sys,'/',['Placed and',13,'detected errors/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Placed and',13,'detected errors/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Placed and',13,'detected errors/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Placed and',13,'detected errors']],[90,65;125,65])
set_param([sys,'/',['Placed and',13,'detected errors']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Placed and',13,'detected errors']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Placed and',13,'detected errors']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Placed and',13,'detected errors']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Placed and',13,'detected errors']],...
		'Mask Entries','5\/-1.1\/5\/''r-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Placed and',13,'detected errors'].

set_param([sys,'/',['Placed and',13,'detected errors']],...
		'position',[650,81,680,119])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate1'],[40,70;60,70])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[105,65;125,65])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','1\/20\/2\/1/K_bch_demo\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[530,23,610,67])


%     Subsystem  ['Binary sequence',13,'BCH decode'].

new_system([sys,'/',['Binary sequence',13,'BCH decode']])
set_param([sys,'/',['Binary sequence',13,'BCH decode']],'Location',[88,100,698,253])


%     Subsystem  ['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode'].

new_system([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],'Location',[157,499,740,659])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Memory']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,k+1)',...
		'position',[295,95,335,125])

add_block('built-in/Switch',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Switch']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Switch']],...
		'Threshold','0.5',...
		'position',[295,44,325,76])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/S-function']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/S-function']],...
		'function name','simbchdc',...
		'parameters','n, k, t,tp,dim',...
		'position',[170,20,235,40])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Mux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Mux']],...
		'inputs','[n, 1]',...
		'position',[80,41,115,74])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/in_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/Demux']],...
		'outputs','[k, 1]',...
		'position',[395,40,435,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/out_1']],...
		'position',[495,30,515,50])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode/out_2']],...
		'Port','2',...
		'position',[495,95,515,115])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[330,60;390,60])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[360,60;360,110;340,110])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],[440,65;455,65;455,105;490,105])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);BCH de',...
		'Mask Type','Vector I/O BCH decode')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'Mask Dialogue','Codeword length N, message length K, T\nerror-correction BCH decode. (N,K,T) must be a valid BCH code combination.|Codeword length (N=2^M-1. M is a >2 integer):|Message length K (check BCHPOLY for valid K):|Error-correction capability (0 for unknown):')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'Mask Translate','n=@1;k=@2;t=@3;if t<=0, [x1,x2,x3,x4,t]=bchpoly(n,k);end;dim=3;pow_dim=7;while pow_dim<n,dim=dim+1;pow_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using BCH code. The block refreshes its decoding output only if the enable signal at the second inport is high. The second outport outputs the error detected in the process. A negative output indicates more error than the capability.')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'Mask Entries','n\/k\/t\/')


%     Finished composite block ['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode'].

set_param([sys,'/',['Binary sequence',13,'BCH decode/Binary-vector',13,'BCH decode']],...
		'hide name',0,...
		'position',[275,26,345,64])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/out_2']],...
		'hide name',0,...
		'Port','2',...
		'position',[370,45,390,65])


%     Subsystem  ['Binary sequence',13,'BCH decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'BCH decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'BCH decode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'hide name',0,...
		'position',[445,28,505,72])


%     Subsystem  ['Binary sequence',13,'BCH decode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/in_1']],...
		'position',[10,55,30,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[65,80;75,80])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[35,65;75,65])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'BCH decode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'BCH decode/Register-shift']],...
		'BackGround',3,...
		'hide name',0,...
		'position',[185,25,240,65])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH decode/sequential',13,'code-word-in']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/sequential',13,'code-word-in']],...
		'hide name',0,...
		'position',[100,25,120,45])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/sequential',13,'message-out']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/sequential',13,'message-out']],...
		'hide name',0,...
		'position',[560,30,580,50])


%     Subsystem  ['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n, k]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'BCH decode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[25,81,85,119])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH decode/Demux']],...
		'hide name',0,...
		'outputs','2',...
		'position',[110,80,150,115])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[155,105;425,105;425,65;440,65])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[510,40;555,40])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[90,100;105,100])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[125,35;180,35])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[350,35;440,35])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[350,55;365,55])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[245,35;270,35])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[245,55;260,55;260,100;415,100;415,50;440,50])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[245,55;270,55])
add_line([sys,'/',['Binary sequence',13,'BCH decode']],[155,90;160,90;160,55;180,55])
set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'Mask Display','plot(0,0,100,100,x,y);BCH de',...
		'Mask Type','Sequence I/O BCH decode')
set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'Mask Dialogue','BCH decode with codeword length N,\nmessage length K, and error-correction capability T. (N,K,T) must be a valid BCH code combination.|Codeword length N (N=2^M-1. M is a >2 integer):|Message length K (check BCHPOLY for valid K):|Error-correction capability T (0 for unknown):|Output sample time T_out (sec):')
set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'Mask Translate','n=@1;k=@2;t=@3;samp=@4;[x,y]=codeicon(4);')
set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'Mask Help','This block decodes length N binary codeword into length K message using BCH code. The block uses sequential input/output format. The input sequence sample time is K*T_out/N. The block causes a K*T_out delay. The second outport outputs the number of errors detected in the process. A negative value indicates the block found more error in the codeword than T.')
set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'Mask Entries','N_bch_demo\/K_bch_demo\/T_bch_demo\/1/K_bch_demo\/')


%     Finished composite block ['Binary sequence',13,'BCH decode'].

set_param([sys,'/',['Binary sequence',13,'BCH decode']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[405,58,485,102])


%     Subsystem  'Counter'.

new_system([sys,'/','Counter'])
set_param([sys,'/','Counter'],'Location',[128,50,722,374])


%     Subsystem  ['Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[300,35;335,35])
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'ForeGround',4,...
		'position',[375,53,435,87])

add_block('built-in/Inport',[sys,'/','Counter/in_3'])
set_param([sys,'/','Counter/in_3'],...
		'Port','3',...
		'position',[315,60,335,80])

add_block('built-in/Memory',[sys,'/','Counter/Memory3'])
set_param([sys,'/','Counter/Memory3'],...
		'orientation',2,...
		'ForeGround',3,...
		'position',[400,205,440,235])

add_block('built-in/Switch',[sys,'/','Counter/Switch3'])
set_param([sys,'/','Counter/Switch3'],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[470,139,495,171])

add_block('built-in/Outport',[sys,'/','Counter/out_1'])
set_param([sys,'/','Counter/out_1'],...
		'position',[550,145,570,165])


%     Subsystem  ['Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'ForeGround',4,...
		'position',[80,148,140,182])

add_block('built-in/Inport',[sys,'/','Counter/in_2'])
set_param([sys,'/','Counter/in_2'],...
		'Port','2',...
		'position',[15,155,35,175])

add_block('built-in/Inport',[sys,'/','Counter/in_1'])
set_param([sys,'/','Counter/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Switch',[sys,'/','Counter/Switch2'])
set_param([sys,'/','Counter/Switch2'],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[345,149,370,181])

add_block('built-in/Sum',[sys,'/','Counter/Sum'])
set_param([sys,'/','Counter/Sum'],...
		'ForeGround',3,...
		'position',[295,100,315,120])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Relational',13,'Operator1']],...
		'ForeGround',2,...
		'Operator','>',...
		'position',[225,53,255,77])

add_block('built-in/Constant',[sys,'/','Counter/Constant'])
set_param([sys,'/','Counter/Constant'],...
		'ForeGround',3,...
		'Value','thld',...
		'position',[105,100,135,120])
add_line([sys,'/','Counter'],[500,155;545,155])
add_line([sys,'/','Counter'],[520,155;520,220;445,220])
add_line([sys,'/','Counter'],[375,165;465,165])
add_line([sys,'/','Counter'],[340,70;370,70])
add_line([sys,'/','Counter'],[40,165;75,165])
add_line([sys,'/','Counter'],[40,60;220,60])
add_line([sys,'/','Counter'],[320,110;330,110;340,155])
add_line([sys,'/','Counter'],[140,110;190,110;190,70;220,70])
add_line([sys,'/','Counter'],[260,65;275,65;275,105;290,105])
add_line([sys,'/','Counter'],[145,165;340,165])
add_line([sys,'/','Counter'],[395,220;275,220;275,175;340,175])
add_line([sys,'/','Counter'],[275,175;275,115;290,115])
add_line([sys,'/','Counter'],[440,70;450,70;450,155;465,155])
set_param([sys,'/','Counter'],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Counter',...
		'Mask Type','Resettable number counter')
set_param([sys,'/','Counter'],...
		'Mask Dialogue','If the 1st inport value is larger than the threshold, the counter increases one at the rising edge of the 2nd inport pulse.|Threshold:')
set_param([sys,'/','Counter'],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(0,20,get_param(gcb,''orientation''),2);')
set_param([sys,'/','Counter'],...
		'Mask Help','If the signal at the 1st inport is larger than or equal to the given threshold at the rising edge of the 2nd inport, the counter increases by one. The rising edge of the 3rd port resets the counter to zero.')
set_param([sys,'/','Counter'],...
		'Mask Entries','.6\/')


%     Finished composite block 'Counter'.

set_param([sys,'/','Counter'],...
		'hide name',0,...
		'position',[390,138,470,182])


%     Subsystem  ['K-step',13,'delay'].

new_system([sys,'/',['K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay']],'Location',[12,432,357,702])

add_block('built-in/Digital Clock',[sys,'/',['K-step',13,'delay/Digital Clock']])
set_param([sys,'/',['K-step',13,'delay/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])

add_block('built-in/Inport',[sys,'/',['K-step',13,'delay/in_1']])
set_param([sys,'/',['K-step',13,'delay/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['K-step',13,'delay/out_1']])
set_param([sys,'/',['K-step',13,'delay/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Filter',[sys,'/',['K-step',13,'delay/K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Switch',[sys,'/',['K-step',13,'delay/Switch']])
set_param([sys,'/',['K-step',13,'delay/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant']])
set_param([sys,'/',['K-step',13,'delay/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant1']])
set_param([sys,'/',['K-step',13,'delay/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Relational Operator',[sys,'/',['K-step',13,'delay/Relational',13,'Operator']])
set_param([sys,'/',['K-step',13,'delay/Relational',13,'Operator']],...
		'position',[150,168,180,192])
add_line([sys,'/',['K-step',13,'delay']],[300,130;320,130])
add_line([sys,'/',['K-step',13,'delay']],[45,90;55,90])
add_line([sys,'/',['K-step',13,'delay']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['K-step',13,'delay']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['K-step',13,'delay']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['K-step',13,'delay']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['K-step',13,'delay']],[185,180;220,180;220,130;265,130])
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay',...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.',...
		'Mask Entries','N_bch_demo\/1/N_bch_demo\/0\/')


%     Finished composite block ['K-step',13,'delay'].

set_param([sys,'/',['K-step',13,'delay']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[490,138,570,182])


%     Subsystem  ['Pulses divide',13,'same sample time'].

new_system([sys,'/',['Pulses divide',13,'same sample time']])
set_param([sys,'/',['Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Entries','1\/N_bch_demo\/.5/N_bch_demo\/')


%     Finished composite block ['Pulses divide',13,'same sample time'].

set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'hide name',0,...
		'position',[265,123,345,167])


%     Subsystem  ['Binary error',13,'channel'].

new_system([sys,'/',['Binary error',13,'channel']])
set_param([sys,'/',['Binary error',13,'channel']],'Location',[259,203,738,408])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/out_2']])
set_param([sys,'/',['Binary error',13,'channel/out_2']],...
		'Port','2',...
		'position',[275,125,295,145])

add_block('built-in/Saturation',[sys,'/',['Binary error',13,'channel/Saturation']])
set_param([sys,'/',['Binary error',13,'channel/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','1',...
		'position',[165,70,190,90])

add_block('built-in/S-Function',[sys,'/',['Binary error',13,'channel/Modulo',13,'operation']])
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulo operation:|Modulo base:')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[300,56,360,94])

add_block('built-in/Sum',[sys,'/',['Binary error',13,'channel/Sum']])
set_param([sys,'/',['Binary error',13,'channel/Sum']],...
		'position',[235,65,255,85])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/out_1']])
set_param([sys,'/',['Binary error',13,'channel/out_1']],...
		'position',[390,65,410,85])

add_block('built-in/Inport',[sys,'/',['Binary error',13,'channel/in_1']])
set_param([sys,'/',['Binary error',13,'channel/in_1']],...
		'position',[95,30,115,50])


%     Subsystem  ['Binary error',13,'channel/Poisson',13,'noise'].

new_system([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],'Location',[391,74,676,237])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/Poisson',13,'noise/out_1']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise/out_1']],...
		'position',[165,65,185,85])

add_block('built-in/S-Function',[sys,'/',['Binary error',13,'channel/Poisson',13,'noise/Poisson distribution',13,'number']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise/Poisson distribution',13,'number']],...
		'function name','srandpoi',...
		'parameters','seed,lambda',...
		'position',[65,55,135,95])
add_line([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],[140,75;160,75])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Display','Poison\nrand int',...
		'Mask Type','Poisson distribution noise.',...
		'Mask Dialogue','Poisson distribution number generator.|Lambda:|Seed:')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Translate','seed=@2;lambda=@1;')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Help','The output of this block is poisson distributed integers. The output size is the same as the vector size for seed. Please use function disttool to see the distribution of the outputof this block.')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Entries','P\/(randint(1, M)+100)*1000*max(P)\/')


%     Finished composite block ['Binary error',13,'channel/Poisson',13,'noise'].

set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'position',[20,94,95,136])
add_line([sys,'/',['Binary error',13,'channel']],[195,80;230,80])
add_line([sys,'/',['Binary error',13,'channel']],[210,80;210,135;270,135])
add_line([sys,'/',['Binary error',13,'channel']],[260,75;295,75])
add_line([sys,'/',['Binary error',13,'channel']],[100,115;140,115;140,80;160,80])
add_line([sys,'/',['Binary error',13,'channel']],[120,40;210,40;210,70;230,70])
add_line([sys,'/',['Binary error',13,'channel']],[365,75;385,75])
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);B-error',...
		'Mask Type','Add binary errors')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Dialogue','The error probability can be a scalar or a vector with the same length as the\ninput vector length.|Error probability:|Input vector length:')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Translate','M=@2;P=@1;if length(P)~=M,P=ones(1,M)*P(1);end;[x,y]=chanicon;')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Help','This block adds binary errors to transmitted binary signals. The error probability is given in the parameter setting. The first output port outputs the transmitting signal (after adding noise). The second port outputs the errors signal added to the transmitting signal.')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Entries','.03\/1\/')


%     Finished composite block ['Binary error',13,'channel'].

set_param([sys,'/',['Binary error',13,'channel']],...
		'hide name',0,...
		'position',[260,68,340,112])


%     Subsystem  ['Binary sequence',13,'BCH encode'].

new_system([sys,'/',['Binary sequence',13,'BCH encode']])
set_param([sys,'/',['Binary sequence',13,'BCH encode']],'Location',[248,302,892,459])


%     Subsystem  ['Binary sequence',13,'BCH encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'BCH encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'BCH encode/Register-shift']],...
		'BackGround',3,...
		'position',[230,26,285,59])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/in_1']],...
		'position',[55,25,75,45])


%     Subsystem  ['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode'].

new_system([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],'Location',[235,592,599,711])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode/out_1']],...
		'position',[290,35,310,55])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],[55,45;105,45])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],[140,45;175,45])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],[245,45;285,45])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'Mask Display','BCH\nencode',...
		'Mask Type','BCH encoding')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'Mask Dialogue','Code word N, message length K multi-error-correction BCH code.|Code length (N=2^M-1. M is a >2 integer):|Message length (check BCHPOLY for valid number):')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'Mask Translate','n=@1; k=@2; pg = bchpoly(n,k);[h,G]=cyclgen(n,pg); G=G'';')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'Mask Help','This block encodes the K-ary binary message signal into N-ary binary code word using BCH code. Use MATLAB command BCHPOLY to view the valid code-word length N and message length K combination.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'Mask Entries','n\/k\/')


%     Finished composite block ['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode'].

set_param([sys,'/',['Binary sequence',13,'BCH encode/Binary-vector',13,'BCH encode']],...
		'BackGround',5,...
		'position',[340,15,400,55])


%     Subsystem  ['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k, n]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'BCH encode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[45,81,105,119])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Demux']],...
		'outputs','2',...
		'position',[140,80,180,115])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/out_1']],...
		'position',[575,30,595,50])


%     Subsystem  ['Binary sequence',13,'BCH encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'Mask Entries','n\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'BCH encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'BCH encode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[445,28,505,62])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'BCH encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'BCH encode/out_2']],...
		'Port','2',...
		'position',[535,45,555,65])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[185,105;420,105;420,55;440,55])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[185,90;195,90;195,50;225,50])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[110,100;135,100])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[290,50;305,50;305,85;410,85;410,45;440,45])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[80,35;225,35])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[290,35;335,35])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[405,35;440,35])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[510,40;570,40])
add_line([sys,'/',['Binary sequence',13,'BCH encode']],[510,55;530,55])
set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);BCH en',...
		'Mask Type','Sequence I/O BCH encode')
set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'Mask Dialogue','BCH encode with codeword length N,\nand message length K. (N, K) must be a valid BCH code pair.|Codeword length N (N=2^M-1. M is a >2 integer):|Message length K (check BCHPOLY for valid K):|Input sample time T_in (sec):')
set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'Mask Translate','n=@1;k=@2;samp=@3;[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'Mask Help','This block encodes length K binary message into length N binary codeword using BCH code. The block uses sequence input/output format. The output sequential sample time is K*T_in/N. The block causes a K*T_in delay. The second outport outputs a pulse when Kth message signal is received. Use function BCHPOLY to view the valid N, K, and error-corr ection capability T combination.')
set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'Mask Entries','N_bch_demo\/K_bch_demo\/1/K_bch_demo\/')


%     Finished composite block ['Binary sequence',13,'BCH encode'].

set_param([sys,'/',['Binary sequence',13,'BCH encode']],...
		'hide name',0,...
		'position',[145,78,225,122])


%     Subsystem  ['Sampled read with',13,'synchronized pulse'].

new_system([sys,'/',['Sampled read with',13,'synchronized pulse']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],'Location',[355,527,737,674])

add_block('built-in/S-Function',[sys,'/',['Sampled read with',13,'synchronized pulse/Message source']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/out_2']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/out_2']],...
		'Port','2',...
		'position',[195,115,215,135])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/out_1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[115,75;175,75])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[135,75;135,125;190,125])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[260,75;290,75])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);[v,w]=trigicon(1,75,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reaches the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree. The second output is the synchronization pulse, which outputs a spike when the data is refreshed.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Entries','randint(100,1)\/1/K_bch_demo\/1\/0\/')


%     Finished composite block ['Sampled read with',13,'synchronized pulse'].

set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'hide name',0,...
		'position',[20,88,100,132])

add_block('built-in/Note',[sys,'/',['Double click "BCH code view table" block to view most frequently used code word length//message',13,'length//error-correction capability table.                                                                                    ']])
set_param([sys,'/',['Double click "BCH code view table" block to view most frequently used code word length//message',13,'length//error-correction capability table.                                                                                    ']],...
		'position',[340,230,345,235])


%     Subsystem  ['BCH code',13,'length table'].

new_system([sys,'/',['BCH code',13,'length table']])
set_param([sys,'/',['BCH code',13,'length table']],'Location',[-10,380,117,533])
set_param([sys,'/',['BCH code',13,'length table']],...
		'Mask Display','BCH code\nview table',...
		'Mask Dialogue','eval(''bchpoly'')')


%     Finished composite block ['BCH code',13,'length table'].

set_param([sys,'/',['BCH code',13,'length table']],...
		'BackGround',5,...
		'hide name',0,...
		'position',[120,153,200,197])

add_block('built-in/Note',[sys,'/',['This demo uses the MATLAB workspace variable to set the code world length N_bch_demo=15,',13,'message length K_bch_demo= 5, and error correction capability T_bch_demo=3.                      ']])
set_param([sys,'/',['This demo uses the MATLAB workspace variable to set the code world length N_bch_demo=15,',13,'message length K_bch_demo= 5, and error correction capability T_bch_demo=3.                      ']],...
		'position',[335,200,340,205])
add_line(sys,[105,100;140,100])
add_line(sys,[230,90;255,90])
add_line(sys,[345,80;400,80])
add_line(sys,[490,70;505,70;505,55;525,55])
add_line(sys,[115,100;115,35;525,35])
add_line(sys,[345,100;370,100;370,145;385,145])
add_line(sys,[230,110;240,110;240,175;385,175])
add_line(sys,[490,90;590,90])
add_line(sys,[630,100;645,100])
add_line(sys,[475,160;485,160])
add_line(sys,[575,160;580,160;590,105])
add_line(sys,[350,145;365,145;365,160;385,160])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
