function [ret,x0,str,ts,xts]=tstbterr(t,x,u,flag);
%TSTBTERR	is the M-file description of the SIMULINK system named TSTBTERR.
%	The block-diagram can be displayed by typing: TSTBTERR.
%
%	SYS=TSTBTERR(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTBTERR to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTBTERR with a FLAG of zero:
%	[SIZES]=TSTBTERR([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[79,112,698,276])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','M=16;td=.1;ts=.01;Fc=100/pi/2;[num,den]=butter(5,Fc*2*ts);');

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[445,81,480,114])


%     Subsystem  ['S-map QASK',13,'demod baseband1'].

new_system([sys,'/',['S-map QASK',13,'demod baseband1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1']],'Location',[33,553,383,660])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'demod baseband1/tab=qaskdeco(']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/tab=qaskdeco(']],...
		'position',[205,180,210,185])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband1/out_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/out_1']],...
		'position',[320,40,340,60])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband1/in_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/in_1']],...
		'position',[40,40,60,60])


%     Subsystem  ['S-map QASK',13,'demod baseband1/QADM',13,'baseband'].

new_system([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],'Location',[283,122,827,462])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/in_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/in_1']],...
		'position',[55,115,75,135])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Constant1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Sum1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/out_2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Filter',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Filter1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Product1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Demux',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Demux']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Constant']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Product2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Product3']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Sum']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Product']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Filter',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Filter']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/out_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[230,115;230,245;265,245])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[200,255;265,255])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[165,130;255,130])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[180,130;180,210;265,210])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[180,50;255,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[215,50;215,200;265,200])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[80,125;115,125])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[360,80;385,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[450,80;475,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[365,230;390,230])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],[455,230;480,230])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['S-map QASK',13,'demod baseband1/QADM',13,'baseband'].

set_param([sys,'/',['S-map QASK',13,'demod baseband1/QADM',13,'baseband']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[90,28,170,72])


%     Subsystem  ['S-map QASK',13,'demod baseband1/QASK',13,'square-demap'].

new_system([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],'Location',[57,374,831,674])

add_block('built-in/Zero-Order Hold',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[135,24,170,56])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/in_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/in_1']],...
		'position',[60,30,80,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[135,149,170,181])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/in_2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/in_2']],...
		'Port','2',...
		'position',[60,155,80,175])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Sum5']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Sum5']],...
		'ForeGround',2,...
		'position',[470,153,490,182])


%     Subsystem  ['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table'].

new_system([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],'Location',[436,148,718,302])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table/y0']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table/y0']],...
		'Port','2',...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table/table out']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table/table out']],...
		'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table/x0']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table/x0']],...
		'position',[20,25,40,45])

add_block('built-in/S-Function',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table/S-function']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table/S-function']],...
		'function name','sftable2',...
		'parameters','xindex, yindex, table',...
		'position',[140,52,190,78])

add_block('built-in/Mux',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table/Mux']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table/Mux']],...
		'inputs','2',...
		'position',[90,46,120,79])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],[45,90;65,90;65,70;85,70])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],[195,65;210,65])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],[45,35;65,35;65,55;85,55])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],[125,65;135,65])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],...
		'Mask Display','plot(-10,-10,110,110,[90,50,10],[90,40,30],[90,50,10],[50,26,20],[90,50,10],[22,13,10])',...
		'Mask Type','2-D Table Lookup')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],...
		'Mask Dialogue','Two Dimensional Table Lookup\nThe first input corresponds to X Index and the second input corresponds to the Y Index|X Index|Y Index|Table')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],...
		'Mask Translate','xindex=@1; yindex=@2; table=@3; sftab2chk(xindex,yindex,table);')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],...
		'Mask Help','This block returns a linearly interpolated intersection from the table using the X index (which corresponds to the rows of the table) and the Y index (which corresponds to the columns of the table).  Extrapolation is used.')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],...
		'Mask Entries','x\/y\/tab\/')


%     Finished composite block ['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table'].

set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/2-D Table']],...
		'position',[515,68,545,92])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Sum3']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Sum3']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[580,73,600,102])

add_block('built-in/Saturation',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Saturation']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','N-1',...
		'position',[630,78,660,102])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/out_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/out_1']],...
		'position',[685,80,705,100])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Sum4']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Sum4']],...
		'ForeGround',2,...
		'position',[470,58,490,87])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Sum1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[280,33,300,62])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Sum2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Sum2']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[290,158,310,187])

add_block('built-in/S-Function',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Minimum']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Minimum']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,165,450,185])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Shift key']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Shift key']],...
		'Value','sfty',...
		'position',[225,214,250,236])

add_block('built-in/S-Function',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Minimum1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,40,445,60])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Shift key1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Shift key1']],...
		'Value','sftx',...
		'position',[220,89,245,111])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Shift key2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Shift key2']],...
		'BackGround',5,...
		'position',[325,114,350,136])

add_block('built-in/Abs',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Abs1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Abs1']],...
		'position',[325,38,355,62])

add_block('built-in/Abs',[sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Abs']])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap/Abs']],...
		'position',[325,163,355,187])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[85,40;130,40])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[360,175;380,175])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[315,175;320,175])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[255,225;260,225;260,180;285,180])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[250,100;255,100;255,55;275,55])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[305,50;320,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[360,50;380,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[665,90;680,90])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[550,80;575,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[605,90;625,90])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[450,50;450,65;465,65])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[455,175;465,175])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[495,170;500,170;510,85])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[355,125;560,125;560,95;575,95])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[450,125;450,160;465,160])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[450,125;450,80;465,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[495,75;510,75])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[85,165;130,165])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[175,165;285,165])
add_line([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],[175,40;275,40])
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],...
		'Mask Display','QASK\nS-demap',...
		'Mask Type','QASK S-demap')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|QASK M-ary number (outputs are in range [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],...
		'Mask Translate','N=@1;td=@2;Ac=1;sftx=[1 -1 3 -3 5 -5 7 -7 9 -9 11 -11 13 -13 15 -15];sftx=sftx(1:2*ceil(sqrt(N)/2));sfty=sftx;if N==8,sfty=sfty(1:2);end;sftx=sftx/max(sftx)*Ac;sfty=sfty/max(sfty)*Ac;tab=qaskdeco(length(sftx),length(sfty),''fetch'')+1;x=[1:length(sftx)];y=[1:length(sfty)];')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using square constellation. You can place this block after a QAM demodulation block. This block assumes the maximum amplitude of the input signals is 1. The output symbols are integers in the range [0, M-1]. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0.')
set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['S-map QASK',13,'demod baseband1/QASK',13,'square-demap'].

set_param([sys,'/',['S-map QASK',13,'demod baseband1/QASK',13,'square-demap']],...
		'hide name',0,...
		'position',[205,28,285,72])
add_line([sys,'/',['S-map QASK',13,'demod baseband1']],[65,50;85,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband1']],[290,50;315,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband1']],[175,60;200,60])
add_line([sys,'/',['S-map QASK',13,'demod baseband1']],[175,40;200,40])
set_param([sys,'/',['S-map QASK',13,'demod baseband1']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);S-QASK',...
		'Mask Type','Baseband S-QASK demodulation')
set_param([sys,'/',['S-map QASK',13,'demod baseband1']],...
		'Mask Dialogue','Demodulate the complex envelope of a QASK modulated signal.  This block uses a fixed square constellation with M-ary number M=2^K, where K is an integer.|M-ary number (integer in range [0 M-1]):|Symbol interval and offset (sec):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['S-map QASK',13,'demod baseband1']],...
		'Mask Translate','M=@1;td=@2;num=@3;den=@4;Ph=@5;ts=@6;[x,y]=moduicon(6);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['S-map QASK',13,'demod baseband1']],...
		'Mask Help','This block demodulates a QASK modulated signal using square constellation. The output signals are digits in the range [0, M-1], where M is the M-ary number, M=2^K, K is an integer. When the symbol interval is a two-element vector, the second element is the offset (default 0). ')
set_param([sys,'/',['S-map QASK',13,'demod baseband1']],...
		'Mask Entries','M\/td\/num\/den\/0\/ts\/')


%     Finished composite block ['S-map QASK',13,'demod baseband1'].

set_param([sys,'/',['S-map QASK',13,'demod baseband1']],...
		'hide name',0,...
		'position',[325,108,405,152])


%     Subsystem  ['S-map QASK',13,'demod baseband'].

new_system([sys,'/',['S-map QASK',13,'demod baseband']])
set_param([sys,'/',['S-map QASK',13,'demod baseband']],'Location',[33,553,383,660])


%     Subsystem  ['S-map QASK',13,'demod baseband/QASK',13,'square-demap'].

new_system([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],'Location',[57,374,831,674])

add_block('built-in/Abs',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Abs']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Abs']],...
		'position',[325,163,355,187])

add_block('built-in/Abs',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Abs1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Abs1']],...
		'position',[325,38,355,62])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key2']],...
		'BackGround',5,...
		'position',[325,114,350,136])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key1']],...
		'Value','sftx',...
		'position',[220,89,245,111])

add_block('built-in/S-Function',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Minimum1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,40,445,60])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key']],...
		'Value','sfty',...
		'position',[225,214,250,236])

add_block('built-in/S-Function',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Minimum']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Minimum']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,165,450,185])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum2']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[290,158,310,187])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[280,33,300,62])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum4']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum4']],...
		'ForeGround',2,...
		'position',[470,58,490,87])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/out_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/out_1']],...
		'position',[685,80,705,100])

add_block('built-in/Saturation',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Saturation']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','N-1',...
		'position',[630,78,660,102])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum3']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum3']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[580,73,600,102])


%     Subsystem  ['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table'].

new_system([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],'Location',[436,148,718,302])

add_block('built-in/Mux',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/Mux']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/Mux']],...
		'inputs','2',...
		'position',[90,46,120,79])

add_block('built-in/S-Function',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/S-function']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/S-function']],...
		'function name','sftable2',...
		'parameters','xindex, yindex, table',...
		'position',[140,52,190,78])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/x0']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/x0']],...
		'position',[20,25,40,45])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/table out']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/table out']],...
		'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/y0']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/y0']],...
		'Port','2',...
		'position',[20,80,40,100])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],[125,65;135,65])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],[45,35;65,35;65,55;85,55])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],[195,65;210,65])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],[45,90;65,90;65,70;85,70])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'Mask Display','plot(-10,-10,110,110,[90,50,10],[90,40,30],[90,50,10],[50,26,20],[90,50,10],[22,13,10])',...
		'Mask Type','2-D Table Lookup')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'Mask Dialogue','Two Dimensional Table Lookup\nThe first input corresponds to X Index and the second input corresponds to the Y Index|X Index|Y Index|Table')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'Mask Translate','xindex=@1; yindex=@2; table=@3; sftab2chk(xindex,yindex,table);')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'Mask Help','This block returns a linearly interpolated intersection from the table using the X index (which corresponds to the rows of the table) and the Y index (which corresponds to the columns of the table).  Extrapolation is used.')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'Mask Entries','x\/y\/tab\/')


%     Finished composite block ['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table'].

set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'position',[515,68,545,92])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum5']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum5']],...
		'ForeGround',2,...
		'position',[470,153,490,182])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/in_2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/in_2']],...
		'Port','2',...
		'position',[60,155,80,175])

add_block('built-in/Zero-Order Hold',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[135,149,170,181])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/in_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/in_1']],...
		'position',[60,30,80,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[135,24,170,56])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[175,40;275,40])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[175,165;285,165])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[85,165;130,165])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[495,75;510,75])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[355,125;560,125;560,95;575,95])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[450,125;450,160;465,160])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[450,125;450,80;465,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[495,170;500,170;510,85])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[455,175;465,175])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[450,50;450,65;465,65])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[605,90;625,90])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[550,80;575,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[665,90;680,90])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[360,50;380,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[305,50;320,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[250,100;255,100;255,55;275,55])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[255,225;260,225;260,180;285,180])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[315,175;320,175])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[360,175;380,175])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[85,40;130,40])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'Mask Display','QASK\nS-demap',...
		'Mask Type','QASK S-demap')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|QASK M-ary number (outputs are in range [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'Mask Translate','N=@1;td=@2;Ac=1;sftx=[1 -1 3 -3 5 -5 7 -7 9 -9 11 -11 13 -13 15 -15];sftx=sftx(1:2*ceil(sqrt(N)/2));sfty=sftx;if N==8,sfty=sfty(1:2);end;sftx=sftx/max(sftx)*Ac;sfty=sfty/max(sfty)*Ac;tab=qaskdeco(length(sftx),length(sfty),''fetch'')+1;x=[1:length(sftx)];y=[1:length(sfty)];')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using square constellation. You can place this block after a QAM demodulation block. This block assumes the maximum amplitude of the input signals is 1. The output symbols are integers in the range [0, M-1]. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0.')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['S-map QASK',13,'demod baseband/QASK',13,'square-demap'].

set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'hide name',0,...
		'position',[205,28,285,72])


%     Subsystem  ['S-map QASK',13,'demod baseband/QADM',13,'baseband'].

new_system([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],'Location',[283,122,827,462])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/out_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Filter',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Filter']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Sum']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product3']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Constant']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Demux',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Demux']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Filter',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Filter1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/out_2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Sum1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Constant1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/in_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/in_1']],...
		'position',[55,115,75,135])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[455,230;480,230])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[365,230;390,230])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[450,80;475,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[360,80;385,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[80,125;115,125])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[180,50;255,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[215,50;215,200;265,200])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[165,130;255,130])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[180,130;180,210;265,210])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[200,255;265,255])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[230,115;230,245;265,245])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['S-map QASK',13,'demod baseband/QADM',13,'baseband'].

set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[90,28,170,72])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/in_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/in_1']],...
		'position',[40,40,60,60])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband/out_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/out_1']],...
		'position',[320,40,340,60])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'demod baseband/tab=qaskdeco(']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/tab=qaskdeco(']],...
		'position',[205,180,210,185])
add_line([sys,'/',['S-map QASK',13,'demod baseband']],[175,40;200,40])
add_line([sys,'/',['S-map QASK',13,'demod baseband']],[175,60;200,60])
add_line([sys,'/',['S-map QASK',13,'demod baseband']],[290,50;315,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband']],[65,50;85,50])
set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);S-QASK',...
		'Mask Type','Baseband S-QASK demodulation')
set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a QASK modulated signal.  This block uses a fixed square constellation with M-ary number M=2^K, where K is an integer.|M-ary number (integer in range [0 M-1]):|Symbol interval and offset (sec):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'Mask Translate','M=@1;td=@2;num=@3;den=@4;Ph=@5;ts=@6;[x,y]=moduicon(6);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'Mask Help','This block demodulates a QASK modulated signal using square constellation. The output signals are digits in the range [0, M-1], where M is the M-ary number, M=2^K, K is an integer. When the symbol interval is a two-element vector, the second element is the offset (default 0). ')
set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'Mask Entries','M\/td\/num\/den\/0\/ts\/')


%     Finished composite block ['S-map QASK',13,'demod baseband'].

set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'hide name',0,...
		'position',[325,38,405,82])


%     Subsystem  ['S-map QASK',13,'mod baseband'].

new_system([sys,'/',['S-map QASK',13,'mod baseband']])
set_param([sys,'/',['S-map QASK',13,'mod baseband']],'Location',[13,347,333,487])


%     Subsystem  ['S-map QASK',13,'mod baseband/QAM',13,'baseband'].

new_system([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],'Location',[321,500,954,793])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I_out']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Sum1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product2']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product3']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I2']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R2']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/in_2']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Constant1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Constant']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/out_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/in_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Mux',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/RI2C']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/RI2C']],...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R_out']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Sum']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R1']],...
		'position',[190,15,195,20])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[410,220;425,220;425,150;465,150])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[120,40;295,40])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[238,40;238,190;305,190])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[270,155;270,235;305,235])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[280,175;280,200;305,200])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[250,100;250,245;305,245])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[550,140;580,140])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'Mask Entries','Ph\/')


%     Finished composite block ['S-map QASK',13,'mod baseband/QAM',13,'baseband'].

set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[165,53,245,97])


%     Subsystem  ['S-map QASK',13,'mod baseband/QASK',13,'square-map'].

new_system([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],'Location',[214,372,642,541])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/in_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/in_1']],...
		'position',[45,30,65,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/Zero-Order',13,'Hold']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[110,24,145,56])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/out_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/out_1']],...
		'position',[325,30,345,50])

add_block('built-in/Look Up Table',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/s-x axis']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/s-x axis']],...
		'Input_Values','z',...
		'Output_Values','x',...
		'position',[245,25,280,55])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/out_2']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/out_2']],...
		'Port','2',...
		'position',[325,95,345,115])

add_block('built-in/Look Up Table',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/c-y axis']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/c-y axis']],...
		'Input_Values','z',...
		'Output_Values','y',...
		'position',[245,90,280,120])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],[285,40;320,40])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],[285,105;320,105])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],[150,40;240,40])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],[185,40;185,105;240,105])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],[70,40;105,40])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'Mask Display','QASK\nS-map',...
		'Mask Type','QASK S-map')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'Mask Dialogue','Use square constellation to map the\ninput digital signal into in-phase and\nquadrature components. M must be\nM=2^K with integer K.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'Mask Translate','N=@1;Ac=1;td=@2;z=[[1:N];[1:N]];z=z(:);[x,y]=qaskenco(z-1,N);z=z-1.5;z=[z(2:2*N);N-.5];x=x/max(x);y=y/max(y);')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The M-ary number must be M=2^K with integer K. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. The maximum amplitudes for the outputs are 1.')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['S-map QASK',13,'mod baseband/QASK',13,'square-map'].

set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'hide name',0,...
		'position',[50,53,130,97])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'mod baseband/out_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/out_1']],...
		'position',[275,65,295,85])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'mod baseband/in_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/in_1']],...
		'position',[5,65,20,85])
add_line([sys,'/',['S-map QASK',13,'mod baseband']],[135,65;160,65])
add_line([sys,'/',['S-map QASK',13,'mod baseband']],[135,85;160,85])
add_line([sys,'/',['S-map QASK',13,'mod baseband']],[250,75;270,75])
add_line([sys,'/',['S-map QASK',13,'mod baseband']],[25,75;45,75])
set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);S-QASK',...
		'Mask Type','Baseband S-QASK modulation')
set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'Mask Dialogue','Output the complex envelope of the QASK\nmodulated signal. This block uses a square\nconstellation with M-ary number M=2^K,\nK is an integer.|M-ary number (input digits in range [0, M-1]):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'Mask Translate','M=@1;td=@2;Ph=@3;ts=@4;[x,y]=moduicon(5);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'Mask Help','This block outputs the complex envelope of a QASK modulated signal. This block uses square constellation. The inputs are integers in the range [0, M-1], where M is the M-ary number, M=2^K, and K is an integer. When the symbol interval is a two-element vector, the second element is the offset (default 0). ')
set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'Mask Entries','M\/td\/0\/ts\/')


%     Finished composite block ['S-map QASK',13,'mod baseband'].

set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'hide name',0,...
		'position',[110,38,190,82])


%     Subsystem  ['Rayleigh fading',13,'channel'].

new_system([sys,'/',['Rayleigh fading',13,'channel']])
set_param([sys,'/',['Rayleigh fading',13,'channel']],'Location',[476,508,847,748])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading',13,'channel/out_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/out_1']],...
		'position',[290,125,310,145])

add_block('built-in/Mux',[sys,'/',['Rayleigh fading',13,'channel/Mux']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Mux']],...
		'inputs','2',...
		'position',[220,116,255,149])


%     Subsystem  ['Rayleigh fading',13,'channel/Inner',13,'Product1'].

new_system([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/Product']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/Sum']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/out_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/in_2']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/in_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],[40,100;60,70])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],[40,35;60,60])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],[95,65;120,65])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],[150,65;180,65])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Rayleigh fading',13,'channel/Inner',13,'Product1'].

set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product1']],...
		'position',[150,154,170,176])

add_block('built-in/Constant',[sys,'/',['Rayleigh fading',13,'channel/Constant1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Constant1']],...
		'Value','[quad, in_p]',...
		'position',[30,155,105,185])


%     Subsystem  ['Rayleigh fading',13,'channel/Inner',13,'Product'].

new_system([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/in_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/in_2']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/out_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/Sum']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/Product']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],[150,65;180,65])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],[40,100;60,70])
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Rayleigh fading',13,'channel/Inner',13,'Product'].

set_param([sys,'/',['Rayleigh fading',13,'channel/Inner',13,'Product']],...
		'position',[150,69,170,91])

add_block('built-in/Constant',[sys,'/',['Rayleigh fading',13,'channel/Constant']])
set_param([sys,'/',['Rayleigh fading',13,'channel/Constant']],...
		'Value','[in_p, -quad]',...
		'position',[30,70,105,100])

add_block('built-in/Inport',[sys,'/',['Rayleigh fading',13,'channel/in_1']])
set_param([sys,'/',['Rayleigh fading',13,'channel/in_1']],...
		'position',[30,20,50,40])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[260,135;285,135])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[175,165;190,165;190,140;215,140])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[175,80;190,80;190,125;215,125])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[55,30;120,30;120,75;145,75])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[120,75;120,160;145,160])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[110,170;145,170])
add_line([sys,'/',['Rayleigh fading',13,'channel']],[110,85;145,85])
set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rayl F',...
		'Mask Type','Rayleigh fading channel, fixed parameter')
set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'Mask Dialogue','Rayleigh fading channel with fixed\nfading envelope and phase shift.|Rayleigh fading envelope:|Phase shift of the channel (rad):')
set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'Mask Translate','a=@1;b=@2;in_p=a*cos(b);quad=a*sin(b);[x,y]=chanicon;[v,w]=cmplxicn(0,50,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'Mask Help','This block applies the fading and phase shifting to the transmitting signal. In general, the fading envelope should be no larger than one. The input and the output of this block are both complex signals.')
set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'Mask Entries','.95\/pi/40\/')


%     Finished composite block ['Rayleigh fading',13,'channel'].

set_param([sys,'/',['Rayleigh fading',13,'channel']],...
		'hide name',0,...
		'position',[230,38,310,82])


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(300,1,M)\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[10,38,90,82])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate1'],[105,65;125,65])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[40,70;60,70])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd signal.|Bit per symbol:|Number of digits on display:|Delay between 1st port and 2nd port:|Sample time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a delay to the first port signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','ceil(log10(M)/log10(2))\/16\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[520,18,600,62])


%     Subsystem  ['Rician noise',13,'channel1'].

new_system([sys,'/',['Rician noise',13,'channel1']])
set_param([sys,'/',['Rician noise',13,'channel1']],'Location',[496,318,758,464])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'channel1/Sum']])
set_param([sys,'/',['Rician noise',13,'channel1/Sum']],...
		'position',[150,55,170,75])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'channel1/out_1']])
set_param([sys,'/',['Rician noise',13,'channel1/out_1']],...
		'position',[200,55,220,75])


%     Subsystem  ['Rician noise',13,'channel1/Gaussian',13,'noise'].

new_system([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],'Location',[358,505,706,710])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/',...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],...
		'Mask Entries','[m1 m2]\/[d d]\/s\/')


%     Finished composite block ['Rician noise',13,'channel1/Gaussian',13,'noise'].

set_param([sys,'/',['Rician noise',13,'channel1/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Inport',[sys,'/',['Rician noise',13,'channel1/in_1']])
set_param([sys,'/',['Rician noise',13,'channel1/in_1']],...
		'position',[45,10,65,30])
add_line([sys,'/',['Rician noise',13,'channel1']],[90,70;145,70])
add_line([sys,'/',['Rician noise',13,'channel1']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['Rician noise',13,'channel1']],[175,65;195,65])
set_param([sys,'/',['Rician noise',13,'channel1']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rician N',...
		'Mask Type','Rician noise channel, fixed parameter')
set_param([sys,'/',['Rician noise',13,'channel1']],...
		'Mask Dialogue','Additive Rician noise channel for\nbaseband signal simulation. Input\nand output signals are complex.|In-phase m:|Quadrature m:|sigma:|Seed (1x2 vector):')
set_param([sys,'/',['Rician noise',13,'channel1']],...
		'Mask Translate','m1=@1;m2=@2;d=@3;s=@4;if length(s)<2,s=[s s+s];end;[x,y]=chanicon;[v,w]=cmplxicn(0,50,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rician noise',13,'channel1']],...
		'Mask Help','This block adds Rician noise to the input signal. The input and output of this block are complex signals. A Rician noise is composed with two independant Gaussian noise elements. The two Gaussian components have the same standard deviation, sigma. Their mean values are in-phase m and quadrature m respectively.')
set_param([sys,'/',['Rician noise',13,'channel1']],...
		'Mask Entries','.1\/.3\/.1\/[1234 4321]\/')


%     Finished composite block ['Rician noise',13,'channel1'].

set_param([sys,'/',['Rician noise',13,'channel1']],...
		'hide name',0,...
		'position',[225,108,305,152])
add_line(sys,[95,60;105,60])
add_line(sys,[485,100;495,100;495,50;515,50])
add_line(sys,[95,60;95,30;515,30])
add_line(sys,[410,60;420,60;420,90;440,90])
add_line(sys,[310,130;320,130])
add_line(sys,[195,60;210,60;220,130])
add_line(sys,[210,60;225,60])
add_line(sys,[315,60;320,60])
add_line(sys,[410,130;420,130;420,105;440,105])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
