function [ret,x0,str,ts,xts]=tstcdma(t,x,u,flag);
%TSTCDMA	is the M-file description of the SIMULINK system named TSTCDMA.
%	The block-diagram can be displayed by typing: TSTCDMA.
%
%	SYS=TSTCDMA(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTCDMA to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTCDMA with a FLAG of zero:
%	[SIZES]=TSTCDMA([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[63,50,992,332])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '400')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','F0=50;F2=80;F4=110;ts=.002;[num0,den0]=butter(2,F0/2*ts);[num4,den4]=butter(2,F4/2*ts);[num2,den2]=butter(2,F2/2*ts);');

add_block('built-in/Mux',[sys,'/','Mux5'])
set_param([sys,'/','Mux5'],...
		'hide name',0,...
		'inputs','2',...
		'position',[810,21,845,54])

add_block('built-in/Scope',[sys,'/','element 1'])
set_param([sys,'/','element 1'],...
		'Vgain','1.500000',...
		'Hgain','4.000000',...
		'Vmax','3.000000',...
		'Hmax','8.000000',...
		'Window',[3,348,344,632])
open_system([sys,'/','element 1'])
set_param([sys,'/','element 1'],...
		'position',[880,27,900,53])

add_block('built-in/Scope',[sys,'/','element 2'])
set_param([sys,'/','element 2'],...
		'Vgain','1.500000',...
		'Hgain','4.000000',...
		'Vmax','3.000000',...
		'Hmax','8.000000',...
		'Window',[344,348,678,635])
open_system([sys,'/','element 2'])
set_param([sys,'/','element 2'],...
		'position',[875,82,895,108])

add_block('built-in/Mux',[sys,'/','Mux4'])
set_param([sys,'/','Mux4'],...
		'hide name',0,...
		'inputs','2',...
		'position',[815,76,850,109])

add_block('built-in/Mux',[sys,'/','Mux3'])
set_param([sys,'/','Mux3'],...
		'hide name',0,...
		'inputs','2',...
		'position',[815,141,850,174])

add_block('built-in/Note',[sys,'/','Code division multiaccess example (frequency hoping method).'])
set_param([sys,'/','Code division multiaccess example (frequency hoping method).'],...
		'position',[300,220,305,225])

add_block('built-in/Note',[sys,'/','Time-division access combines with frequency-division access.'])
set_param([sys,'/','Time-division access combines with frequency-division access.'],...
		'position',[300,240,305,245])


%     Subsystem  ['Time delayed',13,'control pulse'].

new_system([sys,'/',['Time delayed',13,'control pulse']])
set_param([sys,'/',['Time delayed',13,'control pulse']],'Location',[442,574,1004,748])

add_block('built-in/Inport',[sys,'/',['Time delayed',13,'control pulse/in_1']])
set_param([sys,'/',['Time delayed',13,'control pulse/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/Unit Delay',[sys,'/',['Time delayed',13,'control pulse/Unit Delay']])
set_param([sys,'/',['Time delayed',13,'control pulse/Unit Delay']],...
		'Sample time','100*ts',...
		'position',[105,37,155,53])


%     Subsystem  ['Time delayed',13,'control pulse/Rising edge',13,'detector'].

new_system([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','0.5\/')


%     Finished composite block ['Time delayed',13,'control pulse/Rising edge',13,'detector'].

set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector']],...
		'position',[200,23,275,67])

add_block('built-in/Unit Delay',[sys,'/',['Time delayed',13,'control pulse/Unit Delay1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Unit Delay1']],...
		'Sample time','[100*ts, 50*ts]',...
		'position',[105,97,155,113])


%     Subsystem  ['Time delayed',13,'control pulse/Rising edge',13,'detector1'].

new_system([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],[300,35;335,35])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],[45,25;45,95;120,95])
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','0.5\/')


%     Finished composite block ['Time delayed',13,'control pulse/Rising edge',13,'detector1'].

set_param([sys,'/',['Time delayed',13,'control pulse/Rising edge',13,'detector1']],...
		'position',[250,83,325,127])

add_block('built-in/Zero-Order Hold',[sys,'/',['Time delayed',13,'control pulse/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Zero-Order',13,'Hold1']],...
		'Sample time','[20*ts, 10*ts]',...
		'position',[365,89,400,121])

add_block('built-in/Zero-Order Hold',[sys,'/',['Time delayed',13,'control pulse/Zero-Order',13,'Hold']])
set_param([sys,'/',['Time delayed',13,'control pulse/Zero-Order',13,'Hold']],...
		'Sample time','20*ts',...
		'position',[325,29,360,61])

add_block('built-in/Sum',[sys,'/',['Time delayed',13,'control pulse/Sum1']])
set_param([sys,'/',['Time delayed',13,'control pulse/Sum1']],...
		'position',[440,77,460,113])

add_block('built-in/Outport',[sys,'/',['Time delayed',13,'control pulse/out_1']])
set_param([sys,'/',['Time delayed',13,'control pulse/out_1']],...
		'position',[500,85,520,105])
add_line([sys,'/',['Time delayed',13,'control pulse']],[160,105;245,105])
add_line([sys,'/',['Time delayed',13,'control pulse']],[160,45;195,45])
add_line([sys,'/',['Time delayed',13,'control pulse']],[55,45;100,45])
add_line([sys,'/',['Time delayed',13,'control pulse']],[75,45;75,105;100,105])
add_line([sys,'/',['Time delayed',13,'control pulse']],[280,45;320,45])
add_line([sys,'/',['Time delayed',13,'control pulse']],[365,45;410,45;410,85;435,85])
add_line([sys,'/',['Time delayed',13,'control pulse']],[330,105;360,105])
add_line([sys,'/',['Time delayed',13,'control pulse']],[405,105;435,105])
add_line([sys,'/',['Time delayed',13,'control pulse']],[465,95;495,95])


%     Finished composite block ['Time delayed',13,'control pulse'].

set_param([sys,'/',['Time delayed',13,'control pulse']],...
		'position',[425,127,495,173])

add_block('built-in/Signal Generator',[sys,'/','Sin wave'])
set_param([sys,'/','Sin wave'],...
		'ForeGround',2,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','7.000000',...
		'Freq Range','7.000000',...
		'Wave','Sin',...
		'Units','Rads')
set_param([sys,'/','Sin wave'],...
		'position',[25,128,70,162])

add_block('built-in/Signal Generator',[sys,'/',['Sawtooth',13,'wave']])
set_param([sys,'/',['Sawtooth',13,'wave']],...
		'ForeGround',3,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','3.000000',...
		'Freq Range','5.000000',...
		'Wave','Saw',...
		'Units','Rads')
set_param([sys,'/',['Sawtooth',13,'wave']],...
		'position',[25,63,70,97])

add_block('built-in/Signal Generator',[sys,'/',['Square',13,'wave']])
set_param([sys,'/',['Square',13,'wave']],...
		'ForeGround',5,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','4.000000',...
		'Freq Range','5.000000',...
		'Wave','Sqr',...
		'Units','Rads')
set_param([sys,'/',['Square',13,'wave']],...
		'position',[25,13,70,47])

add_block('built-in/Scope',[sys,'/','element 3'])
set_param([sys,'/','element 3'],...
		'Vgain','1.500000',...
		'Hgain','4.000000',...
		'Vmax','3.000000',...
		'Hmax','8.000000',...
		'Window',[676,348,995,636])
open_system([sys,'/','element 3'])
set_param([sys,'/','element 3'],...
		'position',[875,147,895,173])


%     Subsystem  ['Pulses divide',13,'same sample time'].

new_system([sys,'/',['Pulses divide',13,'same sample time']])
set_param([sys,'/',['Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Entries','2\/1\/0\/')


%     Finished composite block ['Pulses divide',13,'same sample time'].

set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'hide name',0,...
		'position',[115,128,195,172])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','3',...
		'position',[130,52,165,108])


%     Subsystem  ['Triggered',13,'signal switch'].

new_system([sys,'/',['Triggered',13,'signal switch']])
set_param([sys,'/',['Triggered',13,'signal switch']],'Location',[672,516,1052,680])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'signal switch/in_1']])
set_param([sys,'/',['Triggered',13,'signal switch/in_1']],...
		'position',[65,20,85,40])

add_block('built-in/Mux',[sys,'/',['Triggered',13,'signal switch/Mux']])
set_param([sys,'/',['Triggered',13,'signal switch/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Outport',[sys,'/',['Triggered',13,'signal switch/out_1']])
set_param([sys,'/',['Triggered',13,'signal switch/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'signal switch/in_2']])
set_param([sys,'/',['Triggered',13,'signal switch/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/S-Function',[sys,'/',['Triggered',13,'signal switch/S-function']])
set_param([sys,'/',['Triggered',13,'signal switch/S-function']],...
		'function name','stdmamux',...
		'parameters','sw,ke,in,tt',...
		'position',[205,60,275,90])
add_line([sys,'/',['Triggered',13,'signal switch']],[90,30;120,30;120,65;140,65])
add_line([sys,'/',['Triggered',13,'signal switch']],[85,85;140,85])
add_line([sys,'/',['Triggered',13,'signal switch']],[180,75;200,75])
add_line([sys,'/',['Triggered',13,'signal switch']],[280,75;315,75])
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Display','plot(0,0,100,100,v,w);Vct re-arr',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Dialogue','The rising edge from the 2nd inport\ntriggers the block to output the input\nelement with the index given in the next row of the switch box.|Switch box (column number equals block output length):|Keeping value (flag 0 element in switch box):|Initial value (before the 1st trigger is detected):|Trigger threshold:')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Translate','sw=@1;ke=@2;in=@3;tt=@4;[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Help','When current switch box row is [i,j], the 1st and 2nd elements output the ith and jth input respectively. The switch_box column number must be same lengths as the output, keep_value, and init_value. The rising edge of the 2nd inport triggers the distribution pattern following the next row of the switch_box. With 0 element in switch_box, the output keeps the last output value with a >=0 keep_value; it equals init_val otherwise.')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Entries','[1 2 3;2 3 1;3 1 2]\/[-1 -1 -1]\/[0 0 0]\/.1\/')


%     Finished composite block ['Triggered',13,'signal switch'].

set_param([sys,'/',['Triggered',13,'signal switch']],...
		'hide name',0,...
		'position',[225,68,305,112])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'hide name',0,...
		'outputs','3',...
		'position',[730,73,775,127])


%     Subsystem  ['Triggered',13,'signal switch1'].

new_system([sys,'/',['Triggered',13,'signal switch1']])
set_param([sys,'/',['Triggered',13,'signal switch1']],'Location',[672,516,1052,680])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'signal switch1/in_1']])
set_param([sys,'/',['Triggered',13,'signal switch1/in_1']],...
		'position',[65,20,85,40])

add_block('built-in/Mux',[sys,'/',['Triggered',13,'signal switch1/Mux']])
set_param([sys,'/',['Triggered',13,'signal switch1/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Outport',[sys,'/',['Triggered',13,'signal switch1/out_1']])
set_param([sys,'/',['Triggered',13,'signal switch1/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'signal switch1/in_2']])
set_param([sys,'/',['Triggered',13,'signal switch1/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/S-Function',[sys,'/',['Triggered',13,'signal switch1/S-function']])
set_param([sys,'/',['Triggered',13,'signal switch1/S-function']],...
		'function name','stdmamux',...
		'parameters','sw,ke,in,tt',...
		'position',[205,60,275,90])
add_line([sys,'/',['Triggered',13,'signal switch1']],[90,30;120,30;120,65;140,65])
add_line([sys,'/',['Triggered',13,'signal switch1']],[85,85;140,85])
add_line([sys,'/',['Triggered',13,'signal switch1']],[180,75;200,75])
add_line([sys,'/',['Triggered',13,'signal switch1']],[280,75;315,75])
set_param([sys,'/',['Triggered',13,'signal switch1']],...
		'Mask Display','plot(0,0,100,100,v,w);Vct re-arr',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/',['Triggered',13,'signal switch1']],...
		'Mask Dialogue','The rising edge from the 2nd inport\ntriggers the block to output the input\nelement with the index given in the next row of the switch box.|Switch box (column number equals block output length):|Keeping value (flag 0 element in switch box):|Initial value (before the 1st trigger is detected):|Trigger threshold:')
set_param([sys,'/',['Triggered',13,'signal switch1']],...
		'Mask Translate','sw=@1;ke=@2;in=@3;tt=@4;[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered',13,'signal switch1']],...
		'Mask Help','When current switch box row is [i,j], the 1st and 2nd elements output the ith and jth input respectively. The switch_box column number must be same lengths as the output, keep_value, and init_value. The rising edge of the 2nd inport triggers the distribution pattern following the next row of the switch_box. With 0 element in switch_box, the output keeps the last output value with a >=0 keep_value; it equals init_val otherwise.')
set_param([sys,'/',['Triggered',13,'signal switch1']],...
		'Mask Entries','[0 0 0;1 2 3;0 0 0;3 1 2;0 0 0;2 3 1]\/[1 1 1]\/[0 0 0]\/.1\/')


%     Finished composite block ['Triggered',13,'signal switch1'].

set_param([sys,'/',['Triggered',13,'signal switch1']],...
		'hide name',0,...
		'position',[635,78,715,122])


%     Subsystem  ['Frequency division',13,'three-signal demux'].

new_system([sys,'/',['Frequency division',13,'three-signal demux']])
set_param([sys,'/',['Frequency division',13,'three-signal demux']],'Location',[485,490,886,737])

add_block('built-in/Discrete State-Space',[sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter4']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter4']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter4']],...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter4']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter4']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter4']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F0*ts*2\/0.05\/7\/ts\/')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter4']],...
		'position',[75,38,145,72])

add_block('built-in/Discrete State-Space',[sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter5']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter5']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter5']],...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter5']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter5']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter5']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F2*ts*2\/0.05\/7\/ts\/')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter5']],...
		'position',[85,108,155,142])

add_block('built-in/Discrete State-Space',[sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter6']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter6']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter6']],...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter6']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter6']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter6']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F4*ts*2\/0.05\/7\/ts\/')
set_param([sys,'/',['Frequency division',13,'three-signal demux/Butterworth',13,'IIR BP Filter6']],...
		'position',[85,178,155,212])


%     Subsystem  ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband'].

new_system([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],'Location',[588,690,716,690])


%     Subsystem  ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator'].

new_system([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])

add_block('built-in/Unit Delay',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/module']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[410,40;440,40])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[140,35;190,35])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator'].

set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])

add_block('built-in/Constant',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Carrier',13,'frequency']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Product1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Filter',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Filter2']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Sum']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Gain',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Gain1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Constant',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Carrier',13,'frequency1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Sum1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Product2']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/sin1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Product']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Note',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/sin']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Filter',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Filter']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Filter',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Filter1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/In-phase',13,'output']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband/In-phase',13,'output']],...
		'position',[695,50,715,70])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[260,130;215,130])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[240,130;240,180;225,180])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[530,120;465,120])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[155,60;335,60])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[435,125;430,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[605,120;600,120])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[70,55;120,55])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[90,55;90,230;120,230])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[155,225;420,225])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[485,225;655,225;645,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[360,125;345,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[305,125;290,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[315,185;300,185;290,135])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[400,60;690,60])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],[655,60;645,115])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB ADM',...
		'Mask Type','Passband DSB-SC ADM')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],...
		'Mask Dialogue','Demodulate a DSB-SC AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],...
		'Mask Help','This block demodulates a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],...
		'Mask Entries','F0\/num0\/den0\/0\/ts\/')


%     Finished composite block ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband'].

set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband']],...
		'hide name',0,...
		'position',[180,33,260,77])


%     Subsystem  ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1'].

new_system([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],'Location',[588,690,716,690])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/In-phase',13,'output']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/In-phase',13,'output']],...
		'position',[695,50,715,70])

add_block('built-in/Filter',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Filter1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Filter',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Filter']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/sin']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Note',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Product']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/sin1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Product2']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Sum1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Constant',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Carrier',13,'frequency1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Gain',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Gain1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Sum']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Filter',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Filter2']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Product1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Constant',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Carrier',13,'frequency']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])


%     Subsystem  ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator'].

new_system([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/module']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Unit Delay',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[410,40;440,40])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator'].

set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[400,60;690,60])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[655,60;645,115])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[315,185;300,185;290,135])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[305,125;290,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[360,125;345,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[485,225;655,225;645,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[155,225;420,225])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[70,55;120,55])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[90,55;90,230;120,230])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[605,120;600,120])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[435,125;430,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[155,60;335,60])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[530,120;465,120])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[260,130;215,130])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],[240,130;240,180;225,180])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB ADM',...
		'Mask Type','Passband DSB-SC ADM')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],...
		'Mask Dialogue','Demodulate a DSB-SC AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],...
		'Mask Help','This block demodulates a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],...
		'Mask Entries','F2\/num2\/den2\/0\/ts\/')


%     Finished composite block ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1'].

set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband1']],...
		'hide name',0,...
		'position',[180,103,260,147])


%     Subsystem  ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2'].

new_system([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],'Location',[588,690,716,690])


%     Subsystem  ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator'].

new_system([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])

add_block('built-in/Unit Delay',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/module']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[410,40;440,40])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[140,35;190,35])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator'].

set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])

add_block('built-in/Constant',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Carrier',13,'frequency']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Product1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Filter',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Filter2']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Sum']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Gain',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Gain1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Constant',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Carrier',13,'frequency1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Sum1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Product2']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/sin1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Product']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Note',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/sin']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Filter',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Filter']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Filter',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Filter1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/In-phase',13,'output']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2/In-phase',13,'output']],...
		'position',[695,50,715,70])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[260,130;215,130])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[240,130;240,180;225,180])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[530,120;465,120])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[155,60;335,60])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[435,125;430,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[605,120;600,120])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[70,55;120,55])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[90,55;90,230;120,230])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[155,225;420,225])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[485,225;655,225;645,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[360,125;345,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[305,125;290,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[315,185;300,185;290,135])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[400,60;690,60])
add_line([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],[655,60;645,115])
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB ADM',...
		'Mask Type','Passband DSB-SC ADM')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],...
		'Mask Dialogue','Demodulate a DSB-SC AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],...
		'Mask Help','This block demodulates a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],...
		'Mask Entries','F4\/num4\/den4\/0\/ts\/')


%     Finished composite block ['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2'].

set_param([sys,'/',['Frequency division',13,'three-signal demux/DSB-SC-ADM',13,'passband2']],...
		'hide name',0,...
		'position',[185,173,265,217])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal demux/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/in_1']],...
		'position',[15,115,35,135])

add_block('built-in/Mux',[sys,'/',['Frequency division',13,'three-signal demux/Mux']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/Mux']],...
		'inputs','3',...
		'position',[305,97,340,153])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal demux/out_1']])
set_param([sys,'/',['Frequency division',13,'three-signal demux/out_1']],...
		'position',[370,115,390,135])
add_line([sys,'/',['Frequency division',13,'three-signal demux']],[40,125;80,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux']],[265,55;290,105;300,105])
add_line([sys,'/',['Frequency division',13,'three-signal demux']],[270,195;285,145;300,145])
add_line([sys,'/',['Frequency division',13,'three-signal demux']],[265,125;300,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux']],[345,125;365,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux']],[160,195;180,195])
add_line([sys,'/',['Frequency division',13,'three-signal demux']],[150,55;175,55])
add_line([sys,'/',['Frequency division',13,'three-signal demux']],[160,125;175,125])
add_line([sys,'/',['Frequency division',13,'three-signal demux']],[50,125;70,195;80,195])
add_line([sys,'/',['Frequency division',13,'three-signal demux']],[50,125;60,55;70,55])


%     Finished composite block ['Frequency division',13,'three-signal demux'].

set_param([sys,'/',['Frequency division',13,'three-signal demux']],...
		'position',[520,66,605,114])


%     Subsystem  ['AWGN',13,'channel'].

new_system([sys,'/',['AWGN',13,'channel']])
set_param([sys,'/',['AWGN',13,'channel']],'Location',[86,493,348,639])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Sum']],...
		'position',[150,55,170,75])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/out_1']])
set_param([sys,'/',['AWGN',13,'channel/out_1']],...
		'position',[200,55,220,75])


%     Subsystem  ['AWGN',13,'channel/Gaussian',13,'noise'].

new_system([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],'Location',[409,168,757,373])

add_block('built-in/State-Space',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['AWGN',13,'channel/Gaussian',13,'noise'].

set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'channel/in_1']])
set_param([sys,'/',['AWGN',13,'channel/in_1']],...
		'position',[45,10,65,30])
add_line([sys,'/',['AWGN',13,'channel']],[90,70;145,70])
add_line([sys,'/',['AWGN',13,'channel']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['AWGN',13,'channel']],[175,65;195,65])
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);AWGN',...
		'Mask Type','AWGN channel, fixed parameter')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Dialogue','Additive white Gaussian noise channel\nwith fixed mean and variance.|Mean value:|Variance (std^2):|Initial Seed:')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);[x,y]=chanicon;')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Help','This block adds white Gaussian noise to the input signal. The mean and the variance can be a scalar or vector with the same length as the input signal.')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Entries','0\/.0001\/12345\/')


%     Finished composite block ['AWGN',13,'channel'].

set_param([sys,'/',['AWGN',13,'channel']],...
		'hide name',0,...
		'position',[425,68,505,112])


%     Subsystem  ['Frequency division',13,'three-signal mux'].

new_system([sys,'/',['Frequency division',13,'three-signal mux']])
set_param([sys,'/',['Frequency division',13,'three-signal mux']],'Location',[215,538,650,748])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal mux/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/in_1']],...
		'position',[20,100,40,120])

add_block('built-in/Demux',[sys,'/',['Frequency division',13,'three-signal mux/Demux']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/Demux']],...
		'outputs','3',...
		'position',[55,92,95,128])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal mux/Sum']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/Sum']],...
		'inputs','+++',...
		'position',[365,92,385,128])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal mux/out_1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/out_1']],...
		'position',[400,100,420,120])

add_block('built-in/Discrete State-Space',[sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter2']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter2']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter2']],...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter2']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter2']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter2']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F2*ts*2\/0.05\/7\/ts\/')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter2']],...
		'position',[235,93,305,127])

add_block('built-in/Discrete State-Space',[sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter3']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter3']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter3']],...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter3']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter3']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter3']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F4*ts*2\/0.05\/7\/ts\/')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter3']],...
		'position',[235,163,305,197])


%     Subsystem  ['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband'].

new_system([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],'Location',[103,459,555,641])

add_block('built-in/Zero-Order Hold',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Zero-Order',13,'Hold',13,'timing control']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Zero-Order',13,'Hold',13,'timing control']],...
		'Sample time','ts',...
		'position',[50,219,85,251])

add_block('built-in/Gain',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Gain']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Clock',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Clock']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Product']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/out_1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Constant',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Constant1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Fcn']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Sum2']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband/Sum2']],...
		'position',[170,90,190,110])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],[270,100;270,65;335,65])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],[370,60;375,60])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],[45,75;65,75])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],[195,100;200,100])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB AM',...
		'Mask Type','Passband DSB-SC AM')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using\nDSB-SC AM method.|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],...
		'Mask Translate','Fc=@1;Fc=Fc*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],...
		'Mask Help','This block modulates the input signal using the double-sideband suppressed-carrier amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],...
		'Mask Entries','F0\/0\/ts\/')


%     Finished composite block ['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband'].

set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband']],...
		'hide name',0,...
		'position',[125,23,205,67])


%     Subsystem  ['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1'].

new_system([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],'Location',[103,459,555,641])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Sum2']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Sum2']],...
		'position',[170,90,190,110])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Fcn']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Constant',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Constant1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/out_1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Product']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Clock',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Clock']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Gain',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Gain']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Zero-Order Hold',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Zero-Order',13,'Hold',13,'timing control']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1/Zero-Order',13,'Hold',13,'timing control']],...
		'Sample time','ts',...
		'position',[50,219,85,251])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],[195,100;200,100])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],[45,75;65,75])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],[370,60;375,60])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],[270,100;270,65;335,65])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB AM',...
		'Mask Type','Passband DSB-SC AM')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],...
		'Mask Dialogue','Modulate the input signal using\nDSB-SC AM method.|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],...
		'Mask Translate','Fc=@1;Fc=Fc*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],...
		'Mask Help','This block modulates the input signal using the double-sideband suppressed-carrier amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],...
		'Mask Entries','F2\/0\/ts\/')


%     Finished composite block ['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1'].

set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband1']],...
		'hide name',0,...
		'position',[125,88,205,132])


%     Subsystem  ['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2'].

new_system([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],'Location',[103,459,555,641])

add_block('built-in/Zero-Order Hold',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Zero-Order',13,'Hold',13,'timing control']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Zero-Order',13,'Hold',13,'timing control']],...
		'Sample time','ts',...
		'position',[50,219,85,251])

add_block('built-in/Gain',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Gain']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Clock',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Clock']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Product',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Product']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Outport',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/out_1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Inport',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/in_1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Constant',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Constant1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Fcn',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Fcn']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Sum',[sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Sum2']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2/Sum2']],...
		'position',[170,90,190,110])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],[270,100;270,65;335,65])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],[370,60;375,60])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],[45,75;65,75])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],[195,100;200,100])
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB AM',...
		'Mask Type','Passband DSB-SC AM')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],...
		'Mask Dialogue','Modulate the input signal using\nDSB-SC AM method.|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],...
		'Mask Translate','Fc=@1;Fc=Fc*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],...
		'Mask Help','This block modulates the input signal using the double-sideband suppressed-carrier amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],...
		'Mask Entries','F4\/0\/ts\/')


%     Finished composite block ['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2'].

set_param([sys,'/',['Frequency division',13,'three-signal mux/DSB-SC AM',13,'passband2']],...
		'hide name',0,...
		'position',[125,158,205,202])

add_block('built-in/Discrete State-Space',[sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter1']])
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter1']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter1']],...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter1']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter1']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter1']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F0*ts*2\/0.05\/7\/ts\/')
set_param([sys,'/',['Frequency division',13,'three-signal mux/Butterworth',13,'IIR BP Filter1']],...
		'position',[235,28,305,62])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[100,120;105,120;105,180;120,180])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[100,100;105,100;105,45;120,45])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[100,110;120,110])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[310,180;330,120;360,120])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[310,110;360,110])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[310,45;330,100;360,100])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[45,110;50,110])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[390,110;395,110])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[210,180;230,180])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[210,110;230,110])
add_line([sys,'/',['Frequency division',13,'three-signal mux']],[210,45;230,45])


%     Finished composite block ['Frequency division',13,'three-signal mux'].

set_param([sys,'/',['Frequency division',13,'three-signal mux']],...
		'position',[325,67,410,113])
add_line(sys,[415,90;420,90])
add_line(sys,[510,90;515,90])
add_line(sys,[75,80;125,80])
add_line(sys,[170,80;220,80])
add_line(sys,[310,90;320,90])
add_line(sys,[610,90;630,90])
add_line(sys,[200,150;420,150])
add_line(sys,[500,150;620,150;630,110])
add_line(sys,[855,160;870,160])
add_line(sys,[855,95;870,95])
add_line(sys,[850,40;875,40])
add_line(sys,[720,100;725,100])
add_line(sys,[75,30;805,30])
add_line(sys,[780,100;810,100])
add_line(sys,[75,145;90,145;90,205;790,205;790,165;810,165])
add_line(sys,[90,145;90,100;125,100])
add_line(sys,[90,30;90,60;125,60])
add_line(sys,[85,80;85,45;785,45;785,85;810,85])
add_line(sys,[780,120;790,120;790,150;810,150])
add_line(sys,[780,80;790,80;790,45;805,45])
add_line(sys,[210,150;220,100])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
