function [ret,x0,str,ts,xts]=tstconcd(t,x,u,flag);
%TSTCONCD	is the M-file description of the SIMULINK system named TSTCONCD.
%	The block-diagram can be displayed by typing: TSTCONCD.
%
%	SYS=TSTCONCD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTCONCD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTCONCD with a FLAG of zero:
%	[SIZES]=TSTCONCD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[18,146,825,383])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '3000')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback',['tf=sim2tran(''fig_10_9'');N_con_demo=tf(1,size(tf,2));K_con_demo=tf(2,size(tf,2));']);

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar']])
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Entries','2\/',...
		'position',[555,43,635,87])


%     Subsystem  ['Binary error',13,'channel'].

new_system([sys,'/',['Binary error',13,'channel']])
set_param([sys,'/',['Binary error',13,'channel']],'Location',[154,494,633,699])

add_block('built-in/Inport',[sys,'/',['Binary error',13,'channel/in_1']])
set_param([sys,'/',['Binary error',13,'channel/in_1']],...
		'position',[95,30,115,50])


%     Subsystem  ['Binary error',13,'channel/Poisson',13,'noise'].

new_system([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],'Location',[391,74,676,237])

add_block('built-in/S-Function',[sys,'/',['Binary error',13,'channel/Poisson',13,'noise/Poisson distribution',13,'number']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise/Poisson distribution',13,'number']],...
		'function name','srandpoi',...
		'parameters','seed,lambda',...
		'position',[65,55,135,95])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/Poisson',13,'noise/out_1']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise/out_1']],...
		'position',[165,65,185,85])
add_line([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],[140,75;160,75])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Display','Poison\nrand int',...
		'Mask Type','Poisson distribution noise.',...
		'Mask Dialogue','Poisson distribution number generator.|Lambda:|Seed:')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Translate','seed=@2;lambda=@1;')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Help','The output of this block is poisson distributed integers. The output size is the same as the vector size for seed. Please use function disttool to see the distribution of the outputof this block.')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Entries','P\/(randint(1, M)+100)*1000*max(P)\/')


%     Finished composite block ['Binary error',13,'channel/Poisson',13,'noise'].

set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'position',[40,94,115,136])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/out_1']])
set_param([sys,'/',['Binary error',13,'channel/out_1']],...
		'position',[390,65,410,85])

add_block('built-in/Sum',[sys,'/',['Binary error',13,'channel/Sum']])
set_param([sys,'/',['Binary error',13,'channel/Sum']],...
		'position',[235,65,255,85])

add_block('built-in/S-Function',[sys,'/',['Binary error',13,'channel/Modulo',13,'operation']])
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulo operation:|Modulo base:')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[300,56,360,94])

add_block('built-in/Saturation',[sys,'/',['Binary error',13,'channel/Saturation']])
set_param([sys,'/',['Binary error',13,'channel/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','1',...
		'position',[165,70,190,90])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/out_2']])
set_param([sys,'/',['Binary error',13,'channel/out_2']],...
		'Port','2',...
		'position',[275,125,295,145])
add_line([sys,'/',['Binary error',13,'channel']],[365,75;385,75])
add_line([sys,'/',['Binary error',13,'channel']],[120,40;210,40;210,70;230,70])
add_line([sys,'/',['Binary error',13,'channel']],[120,115;140,115;140,80;160,80])
add_line([sys,'/',['Binary error',13,'channel']],[260,75;295,75])
add_line([sys,'/',['Binary error',13,'channel']],[195,80;230,80])
add_line([sys,'/',['Binary error',13,'channel']],[210,80;210,135;270,135])
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);B-error',...
		'Mask Type','Add binary errors')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Dialogue','The error probability can be a scalar or a vector with the same length as the\ninput vector length.|Error probability:|Input vector length:')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Translate','M=@2;P=@1;if length(P)~=M,P=ones(1,M)*P(1);end;[x,y]=chanicon;')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Help','This block adds binary errors to transmitted binary signals. The error probability is given in the parameter setting. The first output port outputs the transmitting signal (after adding noise). The second port outputs the errors signal added to the transmitting signal.')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Entries','0.02\/N_con_demo\/')


%     Finished composite block ['Binary error',13,'channel'].

set_param([sys,'/',['Binary error',13,'channel']],...
		'hide name',0,...
		'position',[330,53,410,97])


%     Subsystem  ['Binary vector',13,'convol encode'].

new_system([sys,'/',['Binary vector',13,'convol encode']])
set_param([sys,'/',['Binary vector',13,'convol encode']],'Location',[214,496,926,747])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol encode/in_1']])
set_param([sys,'/',['Binary vector',13,'convol encode/in_1']],...
		'position',[25,60,45,80])


%     Subsystem  ['Binary vector',13,'convol encode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thd\/')


%     Finished composite block ['Binary vector',13,'convol encode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'position',[125,147,180,183])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'convol encode/Mux']])
set_param([sys,'/',['Binary vector',13,'convol encode/Mux']],...
		'inputs','2',...
		'Mask Display','',...
		'position',[220,71,255,104])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation1']],...
		'function name','sconvenc',...
		'parameters','tf',...
		'position',[285,75,345,105])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol encode/in_2']])
set_param([sys,'/',['Binary vector',13,'convol encode/in_2']],...
		'Port','2',...
		'position',[40,155,60,175])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convol encode/out_1']])
set_param([sys,'/',['Binary vector',13,'convol encode/out_1']],...
		'position',[380,80,400,100])
add_line([sys,'/',['Binary vector',13,'convol encode']],[260,90;280,90])
add_line([sys,'/',['Binary vector',13,'convol encode']],[185,165;190,165;190,95;215,95])
add_line([sys,'/',['Binary vector',13,'convol encode']],[65,165;120,165])
add_line([sys,'/',['Binary vector',13,'convol encode']],[50,70;125,70;125,80;215,80])
add_line([sys,'/',['Binary vector',13,'convol encode']],[350,90;375,90])
set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl en',...
		'Mask Type','Vector I/O convolution encode')
set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'Mask Dialogue','Convolution encode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Trigger signal threshold:')
set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'Mask Translate','tf=@1;tf=simviter(tf);thd=@2;[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using convolution code. The block refreshes its register memory and output at the rising edge of the second inport pulse. You can also use a SIMULINK block diagram to define the convolution code transfer function.')
set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'Mask Entries','tf\/.5\/')


%     Finished composite block ['Binary vector',13,'convol encode'].

set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'hide name',0,...
		'position',[230,53,310,97])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector']])
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter',...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Entries','K_con_demo\/2\/',...
		'position',[115,43,195,87])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate1'],[105,65;125,65])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[40,70;60,70])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','tf(2,size(tf,2))\/20\/10\/1\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[680,33,760,77])


%     Subsystem  ['Sampled read with',13,'synchronized pulse'].

new_system([sys,'/',['Sampled read with',13,'synchronized pulse']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],'Location',[355,527,737,674])

add_block('built-in/S-Function',[sys,'/',['Sampled read with',13,'synchronized pulse/Message source']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/out_2']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/out_2']],...
		'Port','2',...
		'position',[195,115,215,135])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/out_1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[115,75;175,75])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[135,75;135,125;190,125])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[260,75;290,75])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);[v,w]=trigicon(1,75,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reaches the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree. The second output is the synchronization pulse, which outputs a spike when the data is refreshed.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Entries','randint(300,1,2^tf(2,size(tf,2)))\/1\/1\/0\/')


%     Finished composite block ['Sampled read with',13,'synchronized pulse'].

set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'hide name',0,...
		'position',[10,53,90,97])


%     Subsystem  'transfer function'.

new_system([sys,'/','transfer function'])
set_param([sys,'/','transfer function'],'Location',[436,197,856,343])
set_param([sys,'/','transfer function'],...
		'Mask Display','Generate\ntran_func',...
		'Mask Dialogue','eval(''fig_10_9; tf = sim2tran(''''fig_10_9'''');N_con_demo=tf(1,size(tf,2));K_con_demo=tf(2,size(tf,2));'')')


%     Finished composite block 'transfer function'.

set_param([sys,'/','transfer function'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[685,85,765,132])


%     Subsystem  ['Binary vector',13,'convol decode1'].

new_system([sys,'/',['Binary vector',13,'convol decode1']])
set_param([sys,'/',['Binary vector',13,'convol decode1']],'Location',[719,297,1227,483])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol decode1/in_1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/in_1']],...
		'position',[65,35,85,55])


%     Subsystem  ['Binary vector',13,'convol decode1/Rising edge',13,'detector'].

new_system([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;',...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'Mask Entries','thd\/')


%     Finished composite block ['Binary vector',13,'convol decode1/Rising edge',13,'detector'].

set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'position',[75,112,130,148])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'convol decode1/Mux']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Mux']],...
		'inputs','[tf(1,size(tf,2)), 1]',...
		'Mask Display','',...
		'position',[170,36,205,69])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'convol decode1/Modulo',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Modulo',13,'operation1']],...
		'function name','sviterbi',...
		'parameters','tf, leng, tran_prob, plot_flag,v1,v2,v3,v4',...
		'position',[235,40,280,70])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convol decode1/out_2']])
set_param([sys,'/',['Binary vector',13,'convol decode1/out_2']],...
		'Port','2',...
		'position',[445,65,465,85])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convol decode1/out_1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/out_1']],...
		'position',[405,35,425,55])

add_block('built-in/Demux',[sys,'/',['Binary vector',13,'convol decode1/Demux']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Demux']],...
		'outputs','[tf(2,size(tf,2)), 1]',...
		'position',[305,35,345,70])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol decode1/in_2']])
set_param([sys,'/',['Binary vector',13,'convol decode1/in_2']],...
		'Port','2',...
		'position',[30,120,50,140])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[55,130;70,130])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[285,55;300,55])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[350,45;400,45])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[350,60;375,60;375,75;440,75])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[210,55;230,55])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[90,45;165,45])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[135,130;140,130;140,60;165,60])
set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl de',...
		'Mask Type','Vector I/O convolution decode')
set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'Mask Dialogue','Convolution decode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Path memory length (delay=path_length*K*T_out):|Transfer probability (3 row matrix, 0 for hard decision):|Trellis figure plot length (0 for no plot):|Trigger signal threshold:')
set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'Mask Translate','gen=@1;leng=@2;tran_prob=@3;plot_flag=@4;thd=@5;[tf,v2,v3,v4,v5,v6,M,nss]=simviter(gen);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);v1=zeros(7,1);v2=zeros(nss,1);v3=zeros(nss^2*leng,1);v4=zeros(nss,1);tf=simviter(gen);')
set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'Mask Help','This block decodes length N binary vector convolution code codeword into length K binary vector message using Viterbi algorithm. The block refreshes its register memory and decoding output at the rising edge of the second inport pulse. The second outport outputs the metric value for soft decision or the accumulative distance for hard\ndecision.')
set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'Mask Entries','tf\/10\/0\/15\/.5\/')


%     Finished composite block ['Binary vector',13,'convol decode1'].

set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'hide name',0,...
		'position',[455,53,535,97])

add_block('built-in/Note',[sys,'/',['This demo uses the convolutional code with the structure defined in file fig_10_9.m. It is a two input//three output//two',13,'memory convolution code. Double click the block "Generate tran_func" to generate the transfer function tf.']])
set_param([sys,'/',['This demo uses the convolutional code with the structure defined in file fig_10_9.m. It is a two input//three output//two',13,'memory convolution code. Double click the block "Generate tran_func" to generate the transfer function tf.']],...
		'position',[395,145,400,150])

add_block('built-in/Note',[sys,'/',['The convolutional code structure is taken from the figure 10.9 in Shu Lin and Daniel Costello''s book Error Control Coding:',13,'Fundamental and Applications.']])
set_param([sys,'/',['The convolutional code structure is taken from the figure 10.9 in Shu Lin and Daniel Costello''s book Error Control Coding:',13,'Fundamental and Applications.']],...
		'position',[415,175,420,180])
add_line(sys,[415,65;450,65])
add_line(sys,[640,65;675,65])
add_line(sys,[540,65;550,65])
add_line(sys,[200,65;225,65])
add_line(sys,[95,65;100,65;100,30;660,30;660,45;675,45])
add_line(sys,[95,85;110,85;110,120;200,120;200,85;225,85])
add_line(sys,[200,120;430,120;430,85;450,85])
add_line(sys,[315,75;325,75])
add_line(sys,[95,65;110,65])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
