function [ret,x0,str,ts,xts]=tstcyclc(t,x,u,flag);
%TSTCYCLC	is the M-file description of the SIMULINK system named TSTCYCLC.
%	The block-diagram can be displayed by typing: TSTCYCLC.
%
%	SYS=TSTCYCLC(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTCYCLC to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTCYCLC with a FLAG of zero:
%	[SIZES]=TSTCYCLC([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[8,64,1005,337])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate1'],[105,65;125,65])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[40,70;60,70])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','4\/20\/0\/1\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[820,8,900,52])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','3',...
		'position',[750,103,785,137])


%     Subsystem  ['Binary vector',13,'cyclic decode'].

new_system([sys,'/',['Binary vector',13,'cyclic decode']])
set_param([sys,'/',['Binary vector',13,'cyclic decode']],'Location',[267,160,850,320])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'cyclic decode/out_1']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/out_1']],...
		'position',[535,90,555,110])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation2']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain1']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/Sum',[sys,'/',['Binary vector',13,'cyclic decode/Sum']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary vector',13,'cyclic decode/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary vector',13,'cyclic decode/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'cyclic decode/in_1']])
set_param([sys,'/',['Binary vector',13,'cyclic decode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[520,100;530,100])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[445,100;450,100])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[405,100;410,100])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[330,100;335,100])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[55,45;95,45])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[205,45;220,45])
add_line([sys,'/',['Binary vector',13,'cyclic decode']],[130,45;135,45])
set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Cyclic de',...
		'Mask Type','Vector I/O cyclic decode')
set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'Mask Dialogue','Cyclic decode with codeword length N\nand message length K.|Codeword length N:|Message length K, or generator polynomial Pg:')
set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'Mask Translate','n=@1;p=@2;if length(p)==1, p=cyclpoly(n,p,''min'');end;if isempty(p),error(''No such cyclic code exist'');end;[H,G]=cyclgen(n,p);trt=htruthtb(G);[n,m]=size(G);G=[zeros(n,m-n),eye(n)];[x,y]=codeicon(2);')
set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using cyclic code. When Pg is specified instead of K, the block uses the user-defined cyclic polynomial Pg. Use function CYCLPOLY for a list of cyclic generator polynomials.')
set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'Mask Entries','7\/4\/')


%     Finished composite block ['Binary vector',13,'cyclic decode'].

set_param([sys,'/',['Binary vector',13,'cyclic decode']],...
		'hide name',0,...
		'position',[525,163,605,207])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar2']])
set_param([sys,'/',['Integer vector',13,'to scalar2']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar2']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar2']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar2']],...
		'Mask Entries','2\/',...
		'position',[635,163,715,207])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector']])
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter',...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Entries','4\/2\/',...
		'position',[140,28,220,72])


%     Subsystem  ['Binary vector',13,'cyclic encode'].

new_system([sys,'/',['Binary vector',13,'cyclic encode']])
set_param([sys,'/',['Binary vector',13,'cyclic encode']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'cyclic encode/out_1']])
set_param([sys,'/',['Binary vector',13,'cyclic encode/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'cyclic encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'cyclic encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'cyclic encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'cyclic encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'cyclic encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'cyclic encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'cyclic encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'cyclic encode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'cyclic encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'cyclic encode/in_1']])
set_param([sys,'/',['Binary vector',13,'cyclic encode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary vector',13,'cyclic encode']],[245,45;285,45])
add_line([sys,'/',['Binary vector',13,'cyclic encode']],[140,45;175,45])
add_line([sys,'/',['Binary vector',13,'cyclic encode']],[55,45;105,45])
set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'Mask Display','plot(0,0,100,100,x,y);Cyclic en',...
		'Mask Type','Vector I/O cyclic encode')
set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'Mask Dialogue','Cyclic encode with codeword length N\nand message length K.|Codeword length N:|Message length K, or generator polynomial Pg:')
set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'Mask Translate','n=@1;p=@2;if length(p)==1,p=cyclpoly(n,p,''min'');if isempty(p),error(''No such cyclic code exist'');end;end;[h,G]=cyclgen(n, p);G=G'';[x,y]=codeicon(1);')
set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using cyclic code. When Pg is specified instead of K, the block uses the user-defined cyclic polynomial Pg. Use function CYCLPOLY for a list of cyclic generator polynomials.')
set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'Mask Entries','7\/4\/')


%     Finished composite block ['Binary vector',13,'cyclic encode'].

set_param([sys,'/',['Binary vector',13,'cyclic encode']],...
		'hide name',0,...
		'position',[255,158,335,202])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'hide name',0,...
		'position',[370,175,390,195])

add_block('built-in/S-Function',[sys,'/',['Modulo',13,'operation2']])
set_param([sys,'/',['Modulo',13,'operation2']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Modulo',13,'operation2']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Modulo',13,'operation2']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.',...
		'Mask Entries','2\/')
set_param([sys,'/',['Modulo',13,'operation2']],...
		'position',[415,163,495,207])


%     Subsystem  ['Binary vector',13,'Hamming encode'].

new_system([sys,'/',['Binary vector',13,'Hamming encode']])
set_param([sys,'/',['Binary vector',13,'Hamming encode']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'Hamming encode/out_1']])
set_param([sys,'/',['Binary vector',13,'Hamming encode/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'Hamming encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'Hamming encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'Hamming encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'Hamming encode/in_1']])
set_param([sys,'/',['Binary vector',13,'Hamming encode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary vector',13,'Hamming encode']],[245,45;285,45])
add_line([sys,'/',['Binary vector',13,'Hamming encode']],[140,45;175,45])
add_line([sys,'/',['Binary vector',13,'Hamming encode']],[55,45;105,45])
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Display','plot(0,0,100,100,x,y);Hamming en',...
		'Mask Type','Vector I/O Hamming encode')
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Dialogue','Hamming encode with input message vector length K=2^M-M-1, output codeword vector length N=2^M-1, where M is a >=3 integer.|Codeword length N:|Message length K, or M-degree primitive polynomial:')
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,p=k;k=n-length(k)+1;else,p=gfprimdf(n-k);end;[h,G]=hammgen(n-k,p);G=G'';[x,y]=codeicon(1);')
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using Hamming code. Use function GFPRIMDF or GFPRIMFD to find M-degree primitive polynomials.')
set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'Mask Entries','7\/gfprimfd(3,''min'')\/')


%     Finished composite block ['Binary vector',13,'Hamming encode'].

set_param([sys,'/',['Binary vector',13,'Hamming encode']],...
		'hide name',0,...
		'position',[255,93,335,137])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'position',[370,110,390,130])

add_block('built-in/S-Function',[sys,'/',['Modulo',13,'operation1']])
set_param([sys,'/',['Modulo',13,'operation1']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Modulo',13,'operation1']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Modulo',13,'operation1']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.',...
		'Mask Entries','2\/')
set_param([sys,'/',['Modulo',13,'operation1']],...
		'position',[415,98,495,142])


%     Subsystem  ['Binary vector',13,'Hamming decode'].

new_system([sys,'/',['Binary vector',13,'Hamming decode']])
set_param([sys,'/',['Binary vector',13,'Hamming decode']],'Location',[267,160,850,320])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'Hamming decode/out_1']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/out_1']],...
		'position',[535,90,555,110])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation2']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/Sum',[sys,'/',['Binary vector',13,'Hamming decode/Sum']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary vector',13,'Hamming decode/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'Hamming decode/in_1']])
set_param([sys,'/',['Binary vector',13,'Hamming decode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[520,100;530,100])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[445,100;450,100])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[405,100;410,100])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[330,100;335,100])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[55,45;95,45])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[205,45;220,45])
add_line([sys,'/',['Binary vector',13,'Hamming decode']],[130,45;135,45])
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Hamming de',...
		'Mask Type','Vector I/O Hamming decode')
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Dialogue','Hamming decode with input codeword vector length N=2^M-1, output message vector length K=2^M-M-1, where M is a >=3 integer.|Codeword length N:|Message length K, or M-degree primitive polynomial:')
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,p=k;k=n-length(p)+1;else,p=gfprimdf(n-k);end;[H,G]=hammgen(n-k,p);trt=htruthtb(G);[n,m]=size(G);G=[zeros(n,m-n),eye(n)];[x,y]=codeicon(2);')
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using Hamming code. Use\nfunction GFPRIMDF or GFPRIMFD to find M-degree primitive polynomials.')
set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'Mask Entries','7\/gfprimfd(3,''min'')\/')


%     Finished composite block ['Binary vector',13,'Hamming decode'].

set_param([sys,'/',['Binary vector',13,'Hamming decode']],...
		'hide name',0,...
		'position',[525,98,605,142])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar1']])
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Entries','2\/',...
		'position',[635,98,715,142])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'position',[370,45,390,65])

add_block('built-in/S-Function',[sys,'/',['Modulo',13,'operation']])
set_param([sys,'/',['Modulo',13,'operation']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Modulo',13,'operation']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Modulo',13,'operation']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.',...
		'Mask Entries','2\/')
set_param([sys,'/',['Modulo',13,'operation']],...
		'position',[415,33,495,77])


%     Subsystem  ['Binary vector',13,'lin-blk decode'].

new_system([sys,'/',['Binary vector',13,'lin-blk decode']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],'Location',[267,160,850,320])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'lin-blk decode/in_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary vector',13,'lin-blk decode/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/Sum',[sys,'/',['Binary vector',13,'lin-blk decode/Sum']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'lin-blk decode/out_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/out_1']],...
		'position',[535,90,555,110])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[130,45;135,45])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[205,45;220,45])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[55,45;95,45])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[330,100;335,100])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[405,100;410,100])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[445,100;450,100])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[520,100;530,100])
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Linear de',...
		'Mask Type','Vector I/O linear block decode')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Dialogue','Linear block decode with input codeword vector length N and output message vector length K.|Generator matrix (binary K-by-N matrix):|Error-correction truth table (0 for single error-corr):')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Translate','G=@1;trt=@2;H=gen2par(G);if trt==0,trt=htruthtb(G);end;[n,m]=size(G);G=[zeros(n,m-n),eye(n)];[x,y]=codeicon(2);')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using linear block code. The generator matrix is a K-by-N matrix. Linear block code is a generic code. Use the HTRUTHTB function to generate a single error-correction truth table.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Entries','[[1 1 0; 0 1 1; 1 1 1;1 0 1] eye(4)]\/0\/')


%     Finished composite block ['Binary vector',13,'lin-blk decode'].

set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'hide name',0,...
		'position',[525,33,605,77])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar']])
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Entries','2\/',...
		'position',[635,33,715,77])


%     Subsystem  ['Binary vector',13,'lin-blk encode'].

new_system([sys,'/',['Binary vector',13,'lin-blk encode']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],'Location',[235,592,599,711])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'lin-blk encode/in_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'lin-blk encode/out_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/out_1']],...
		'position',[290,35,310,55])
add_line([sys,'/',['Binary vector',13,'lin-blk encode']],[55,45;105,45])
add_line([sys,'/',['Binary vector',13,'lin-blk encode']],[140,45;175,45])
add_line([sys,'/',['Binary vector',13,'lin-blk encode']],[245,45;285,45])
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Display','plot(0,0,100,100,x,y);Linear en',...
		'Mask Type','Vector I/O linear block encode')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Dialogue','Linear block encode with input message\nvector length K and output codeword vector length N.|Generator matrix (binary K-by-N matrix):')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Translate','G=@1'';[x,y]=codeicon(1);')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Help','Linear block encode with input message vector length K and output codeword vector length N. The generator matrix is a K-by-N matrix. Linear block code is a generic code.')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Entries','[[1 1 0; 0 1 1; 1 1 1; 1 0 1] eye(4)]\/')


%     Finished composite block ['Binary vector',13,'lin-blk encode'].

set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'hide name',0,...
		'position',[255,28,335,72])


%     Subsystem  ['Random-integer',13,'generator1'].

new_system([sys,'/',['Random-integer',13,'generator1']])
set_param([sys,'/',['Random-integer',13,'generator1']],'Location',[98,518,454,687])

add_block('built-in/Outport',[sys,'/',['Random-integer',13,'generator1/out_1']])
set_param([sys,'/',['Random-integer',13,'generator1/out_1']],...
		'position',[165,55,185,75])

add_block('built-in/S-Function',[sys,'/',['Random-integer',13,'generator1/Uniform',13,'number']])
set_param([sys,'/',['Random-integer',13,'generator1/Uniform',13,'number']],...
		'function name','srandint',...
		'parameters','seed,mul',...
		'position',[65,45,135,85])
add_line([sys,'/',['Random-integer',13,'generator1']],[140,65;160,65])
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Display','plot(0,0,100,100,x,y);Random int',...
		'Mask Type','Random integer generator')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Dialogue','Generate integers randomly distributed in range [0, M-1], where M is the M-ary number.|M-ary number:|Seed:')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Translate','seed=@2;mul=@1;[x,y]=srcsicon(4);')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Help','This block generates an integer number in the range [0 M-1], where M is the M-ary number. The probability of the appearance for each number is equal.')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Entries','16\/[12345]\/')


%     Finished composite block ['Random-integer',13,'generator1'].

set_param([sys,'/',['Random-integer',13,'generator1']],...
		'hide name',0,...
		'position',[15,28,95,72])


%     Subsystem  ['Binary vector',13,'noise generator'].

new_system([sys,'/',['Binary vector',13,'noise generator']])
set_param([sys,'/',['Binary vector',13,'noise generator']],'Location',[36,445,326,560])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'noise generator/out_1']])
set_param([sys,'/',['Binary vector',13,'noise generator/out_1']],...
		'position',[190,35,210,55])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'noise generator/S-function']])
set_param([sys,'/',['Binary vector',13,'noise generator/S-function']],...
		'function name','srandbit',...
		'parameters','n, prob, seed',...
		'position',[90,35,140,55])
add_line([sys,'/',['Binary vector',13,'noise generator']],[145,45;185,45])
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Display','plot(0,0,100,100,x,y);B-vector',...
		'Mask Type','Binary noise generator')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Dialogue','Generate a binary vector with the probability of "1"s in the vector being specified.|Vector length(can''t be changed during simulation):|Probability of a "one", two "ones",three "ones"...:|Seed:')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Translate','n=@1;prob=@2;seed=@3;[x,y]=srcsicon(5);')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Help','This block outputs a zero vector with "1"s randomly distributed the vector. The maximum number of "1"s in the vector is the same as the length of the vector probability. The value of ith element of the probability is the probability of i number of "1"s in the vector, e.g. [1/4 1/4 1/4] means probability of single "1", double "1"s, three "1"s or no "1" in the vector is 1/4.')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'Mask Entries','7\/1/2\/12345\/')


%     Finished composite block ['Binary vector',13,'noise generator'].

set_param([sys,'/',['Binary vector',13,'noise generator']],...
		'hide name',0,...
		'position',[115,203,195,247])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+',...
		'position',[760,215,780,235])

add_block('built-in/Scope',[sys,'/','Error-added'])
set_param([sys,'/','Error-added'],...
		'hide name',0,...
		'Vgain','1.500000',...
		'Hgain','5.000000',...
		'Vmax','3.000000',...
		'Hmax','10.000000',...
		'Window',[335,353,781,621])
open_system([sys,'/','Error-added'])
set_param([sys,'/','Error-added'],...
		'position',[805,212,825,238])
add_line(sys,[500,185;520,185])
add_line(sys,[395,185;410,185])
add_line(sys,[340,180;365,180])
add_line(sys,[610,55;630,55])
add_line(sys,[500,55;520,55])
add_line(sys,[100,50;135,50])
add_line(sys,[120,50;120,20;815,20])
add_line(sys,[785,225;800,225])
add_line(sys,[395,55;410,55])
add_line(sys,[340,50;365,50])
add_line(sys,[395,120;410,120])
add_line(sys,[340,115;365,115])
add_line(sys,[500,120;520,120])
add_line(sys,[610,120;630,120])
add_line(sys,[225,50;230,50;230,180;250,180])
add_line(sys,[230,115;250,115])
add_line(sys,[225,50;250,50])
add_line(sys,[610,185;630,185])
add_line(sys,[720,120;745,120])
add_line(sys,[720,55;725,55;725,110;745,110])
add_line(sys,[720,185;725,185;725,130;745,130])
add_line(sys,[790,120;795,120;795,40;815,40])
add_line(sys,[200,225;350,225;350,60;365,60])
add_line(sys,[350,125;365,125])
add_line(sys,[350,190;365,190])
add_line(sys,[350,225;755,225])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
