function [ret,x0,str,ts,xts]=tstdimo(t,x,u,flag);
%TSTDIMO	is the M-file description of the SIMULINK system named TSTDIMO.
%	The block-diagram can be displayed by typing: TSTDIMO.
%
%	SYS=TSTDIMO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTDIMO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTDIMO with a FLAG of zero:
%	[SIZES]=TSTDIMO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[112,54,876,665])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '99')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.003')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','N=8;T=.1;Fc=100;');

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'inputs','2',...
		'position',[315,47,345,83])


%     Subsystem  ['Random-number',13,'generator'].

new_system([sys,'/',['Random-number',13,'generator']])
set_param([sys,'/',['Random-number',13,'generator']],'Location',[115,400,471,569])

add_block('built-in/Constant',[sys,'/',['Random-number',13,'generator/Constant']])
set_param([sys,'/',['Random-number',13,'generator/Constant']],...
		'Value','x',...
		'position',[65,105,95,125])

add_block('built-in/State-Space',[sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']])
set_param([sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','ones(1,N-1)\/')
set_param([sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']],...
		'position',[230,35,275,65])

add_block('built-in/Outport',[sys,'/',['Random-number',13,'generator/out_1']])
set_param([sys,'/',['Random-number',13,'generator/out_1']],...
		'position',[310,40,330,60])

add_block('built-in/Relational Operator',[sys,'/',['Random-number',13,'generator/Relational',13,'Operator']])
set_param([sys,'/',['Random-number',13,'generator/Relational',13,'Operator']],...
		'position',[155,38,185,62])

add_block('built-in/White Noise',[sys,'/',['Random-number',13,'generator/Random',13,'Number']])
set_param([sys,'/',['Random-number',13,'generator/Random',13,'Number']],...
		'Seed','seed',...
		'position',[40,27,85,63])
add_line([sys,'/',['Random-number',13,'generator']],[90,45;150,45])
add_line([sys,'/',['Random-number',13,'generator']],[100,115;115,115;115,55;150,55])
add_line([sys,'/',['Random-number',13,'generator']],[190,50;225,50])
add_line([sys,'/',['Random-number',13,'generator']],[280,50;305,50])
set_param([sys,'/',['Random-number',13,'generator']],...
		'Mask Display','Random\nNumber',...
		'Mask Type','Random number generator',...
		'Mask Dialogue','Random number generator:|M-ary number:|Seed:')
set_param([sys,'/',['Random-number',13,'generator']],...
		'Mask Translate','N=@1;x=[(2-N)/N:2/N:(N-2)/N];seed=@2;')
set_param([sys,'/',['Random-number',13,'generator']],...
		'Mask Help','This block generate integer number 0 to M-1, where M is a integer. The probability of the apperance for each number is not guaranteed to be the same.')
set_param([sys,'/',['Random-number',13,'generator']],...
		'Mask Entries','N\/1234\/')


%     Finished composite block ['Random-number',13,'generator'].

set_param([sys,'/',['Random-number',13,'generator']],...
		'BackGround',5,...
		'position',[35,35,95,75])

add_block('built-in/Constant',[sys,'/','Const'])
set_param([sys,'/','Const'],...
		'BackGround',2,...
		'Value','N/2',...
		'position',[120,69,150,91])

add_block('built-in/Relational Operator',[sys,'/',['Random',13,'binary signal']])
set_param([sys,'/',['Random',13,'binary signal']],...
		'BackGround',2,...
		'position',[185,63,215,87])


%     Subsystem  'Hold and delay'.

new_system([sys,'/','Hold and delay'])
set_param([sys,'/','Hold and delay'],'Location',[354,383,814,533])
open_system([sys,'/','Hold and delay'])

add_block('built-in/Inport',[sys,'/','Hold and delay/in_2'])
set_param([sys,'/','Hold and delay/in_2'],...
		'Port','2',...
		'position',[45,45,65,65])

add_block('built-in/Inport',[sys,'/','Hold and delay/in_1'])
set_param([sys,'/','Hold and delay/in_1'],...
		'position',[15,25,35,45])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],'Location',[229,493,559,639])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/Switch',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Switch']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Switch']],...
		'Threshold','eps',...
		'position',[210,29,240,61])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_1']],...
		'position',[35,25,55,45])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
		'Mask Entries','thld\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
		'position',[80,58,140,102])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_2']],...
		'Port','2',...
		'position',[35,70,55,90])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Memory']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Memory']],...
		'orientation',2,...
		'position',[200,85,240,115])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[245,45;260,45;260,100;245,100])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[145,80;155,80;155,45;205,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[195,100;185,100;185,55;205,55])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[60,35;205,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[245,45;285,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[60,80;75,80])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
		'Mask Display','Hold\nBuffer',...
		'Mask Type','Hold Buffer',...
		'Mask Dialogue','Clock triggered hold buffer:|Threshold for clock signal:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
		'Mask Help','The first input port is for signal. The second input port is for clocks pulse. The rising edge of the clock signal locks the signal from the first port and outputs the value until next clock pulse rising edge.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
		'Mask Entries','.2\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
		'position',[130,23,190,67])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer1'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],'Location',[229,493,559,628])

add_block('built-in/Switch',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Switch']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Switch']],...
		'ForeGround',5,...
		'Threshold','eps',...
		'position',[210,29,240,61])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Memory']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Memory']],...
		'orientation',2,...
		'position',[200,80,240,110])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
		'Mask Entries','thld\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
		'position',[80,48,140,92])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_2']],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_1']],...
		'position',[40,25,60,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[40,70;75,70])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[245,45;285,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[65,35;205,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[195,95;185,95;185,55;205,55])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[145,70;155,70;155,45;205,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[245,45;260,45;260,95;245,95])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
		'Mask Display','Hold\nBuffer',...
		'Mask Type','Hold Buffer',...
		'Mask Dialogue','Clock triggered hold buffer:|Threshold for clock signal:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
		'Mask Help','The first input port is for signal. The second input port is for clocks pulse. The rising edge of the clock signal locks the signal from the first port and outputs the value until next clock pulse rising edge.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
		'Mask Entries','.2\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer1'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
		'position',[295,33,355,77])

add_block('built-in/Outport',[sys,'/','Hold and delay/out_1'])
set_param([sys,'/','Hold and delay/out_1'],...
		'position',[390,45,410,65])

add_block('built-in/Memory',[sys,'/','Hold and delay/Memory1'])
set_param([sys,'/','Hold and delay/Memory1'],...
		'position',[220,30,260,60])
add_line([sys,'/','Hold and delay'],[265,45;290,45])
add_line([sys,'/','Hold and delay'],[195,45;215,45])
add_line([sys,'/','Hold and delay'],[40,35;125,35])
add_line([sys,'/','Hold and delay'],[70,55;125,55])
add_line([sys,'/','Hold and delay'],[360,55;385,55])
add_line([sys,'/','Hold and delay'],[85,55;85,105;270,105;270,65;290,65])


%     Finished composite block 'Hold and delay'.

set_param([sys,'/','Hold and delay'],...
		'position',[460,54,515,96])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'position',[400,125,420,145])


%     Subsystem  ['Correlation',13,'MPSK demodu'].

new_system([sys,'/',['Correlation',13,'MPSK demodu']])
set_param([sys,'/',['Correlation',13,'MPSK demodu']],'Location',[4,407,852,667])

add_block('built-in/Switch',[sys,'/',['Correlation',13,'MPSK demodu/Switch1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Switch1']],...
		'Threshold','eps',...
		'position',[360,14,390,46])

add_block('built-in/Inport',[sys,'/',['Correlation',13,'MPSK demodu/in_1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/in_1']],...
		'position',[440,35,460,55])

add_block('built-in/Product',[sys,'/',['Correlation',13,'MPSK demodu/Product']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Product']],...
		'position',[540,36,565,69])

add_block('built-in/Reset Integrator',[sys,'/',['Correlation',13,'MPSK demodu/Reset',13,'integrator1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Reset',13,'integrator1']],...
		'position',[265,39,305,71])

add_block('built-in/S-Function',[sys,'/',['Correlation',13,'MPSK demodu/Array sin']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Array sin']],...
		'function name','arraysin',...
		'parameters','N',...
		'position',[455,80,505,100])

add_block('built-in/Sum',[sys,'/',['Correlation',13,'MPSK demodu/Sum1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Sum1']],...
		'inputs','+++',...
		'position',[415,72,435,108])

add_block('built-in/Constant',[sys,'/',['Correlation',13,'MPSK demodu/Shift key']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Shift key']],...
		'Value','sft',...
		'position',[355,78,375,102])

add_block('built-in/Constant',[sys,'/',['Correlation',13,'MPSK demodu/Initial phase']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Initial phase']],...
		'Value','Ph',...
		'position',[295,108,315,132])


%     Subsystem  ['Correlation',13,'MPSK demodu/Rising edge',13,'detector'].

new_system([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Correlation',13,'MPSK demodu/Rising edge',13,'detector'].

set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],...
		'position',[75,128,135,172])

add_block('built-in/Inport',[sys,'/',['Correlation',13,'MPSK demodu/in_2']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/in_2']],...
		'Port','2',...
		'position',[30,140,50,160])

add_block('built-in/Reset Integrator',[sys,'/',['Correlation',13,'MPSK demodu/Reset',13,'integrator']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Reset',13,'integrator']],...
		'position',[590,134,630,166])

add_block('built-in/Switch',[sys,'/',['Correlation',13,'MPSK demodu/Switch']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Switch']],...
		'Threshold','eps',...
		'position',[665,144,695,176])

add_block('built-in/Memory',[sys,'/',['Correlation',13,'MPSK demodu/Memory1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Memory1']],...
		'orientation',2,...
		'position',[660,200,700,230])

add_block('built-in/S-Function',[sys,'/',['Correlation',13,'MPSK demodu/Maximum']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Maximum']],...
		'function name','arraymax',...
		'position',[730,150,785,170])

add_block('built-in/Outport',[sys,'/',['Correlation',13,'MPSK demodu/out_1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/out_1']],...
		'position',[805,150,825,170])

add_block('built-in/Constant',[sys,'/',['Correlation',13,'MPSK demodu/Frequency']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Frequency']],...
		'Value','Fc',...
		'position',[180,33,205,57])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[55,150;70,150])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[465,45;535,45])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[140,150;585,150])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[570,55;575,55;585,140])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[440,90;450,90])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[210,45;260,45])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[380,90;410,90])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[510,90;515,90;515,60;535,60])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[655,215;650,215;660,170])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[310,55;345,55;355,40])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[635,150;660,150])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[790,160;800,160])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[700,160;725,160])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[395,30;400,30;410,80])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[320,120;390,120;390,100;410,100])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[155,150;155,200;640,200;640,160;660,160])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[155,150;155,90;235,90;235,55;260,55])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[715,160;705,215])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[155,90;155,30;355,30])
set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
		'Mask Display','MPSK\ndemodu',...
		'Mask Type','MPSK Demodulation')
set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
		'Mask Dialogue','M-ary Phase Shift Keying Demodulation:|M-ary number:|Carrier frequency:|Trigger signal threshold:|Initial phase:')
set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
		'Mask Translate','pi2=2*pi;N=@1;sft=[0:N-1]*pi2/N; Fc=@2*pi2; thld=@3;Ph=@4;')
set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
		'Mask Help','This block demodulates a MPSK modulated signal using coherent method. The first input port is for the received signal, which is MPSK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The initial phase should match those in the modulation. Becase the correlation computation, the output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
		'Mask Entries','N\/Fc\/.2\/0\/')


%     Finished composite block ['Correlation',13,'MPSK demodu'].

set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
		'ForeGround',4,...
		'position',[460,124,525,166])


%     Subsystem  ['MPSK',13,'modulation'].

new_system([sys,'/',['MPSK',13,'modulation']])
set_param([sys,'/',['MPSK',13,'modulation']],'Location',[202,332,862,590])


%     Subsystem  ['MPSK',13,'modulation/Rising edge',13,'detector'].

new_system([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']])
set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['MPSK',13,'modulation/Rising edge',13,'detector'].

set_param([sys,'/',['MPSK',13,'modulation/Rising edge',13,'detector']],...
		'position',[75,173,135,217])

add_block('built-in/Inport',[sys,'/',['MPSK',13,'modulation/in_2']])
set_param([sys,'/',['MPSK',13,'modulation/in_2']],...
		'Port','2',...
		'position',[30,185,50,205])

add_block('built-in/Switch',[sys,'/',['MPSK',13,'modulation/Switch']])
set_param([sys,'/',['MPSK',13,'modulation/Switch']],...
		'Threshold','eps',...
		'position',[190,29,220,61])

add_block('built-in/Inport',[sys,'/',['MPSK',13,'modulation/in_1']])
set_param([sys,'/',['MPSK',13,'modulation/in_1']],...
		'position',[85,25,105,45])

add_block('built-in/Memory',[sys,'/',['MPSK',13,'modulation/Memory1']])
set_param([sys,'/',['MPSK',13,'modulation/Memory1']],...
		'orientation',2,...
		'position',[185,85,225,115])

add_block('built-in/Sum',[sys,'/',['MPSK',13,'modulation/Sum']])
set_param([sys,'/',['MPSK',13,'modulation/Sum']],...
		'inputs','+++',...
		'position',[440,67,460,103])

add_block('built-in/Fcn',[sys,'/',['MPSK',13,'modulation/Oscilation']])
set_param([sys,'/',['MPSK',13,'modulation/Oscilation']],...
		'Expr','Ac*sin(u[1])',...
		'position',[480,70,555,100])

add_block('built-in/Outport',[sys,'/',['MPSK',13,'modulation/out_1']])
set_param([sys,'/',['MPSK',13,'modulation/out_1']],...
		'position',[580,75,600,95])

add_block('built-in/Gain',[sys,'/',['MPSK',13,'modulation/Gain']])
set_param([sys,'/',['MPSK',13,'modulation/Gain']],...
		'Gain','Sft',...
		'position',[315,28,365,62])

add_block('built-in/Constant',[sys,'/',['MPSK',13,'modulation/one']])
set_param([sys,'/',['MPSK',13,'modulation/one']],...
		'Value','Fc',...
		'position',[175,146,200,174])

add_block('built-in/Reset Integrator',[sys,'/',['MPSK',13,'modulation/Reset',13,'integrator']])
set_param([sys,'/',['MPSK',13,'modulation/Reset',13,'integrator']],...
		'position',[255,154,295,186])

add_block('built-in/Switch',[sys,'/',['MPSK',13,'modulation/Switch1']])
set_param([sys,'/',['MPSK',13,'modulation/Switch1']],...
		'Threshold','eps',...
		'position',[345,124,375,156])

add_block('built-in/Constant',[sys,'/',['MPSK',13,'modulation/Initial phase']])
set_param([sys,'/',['MPSK',13,'modulation/Initial phase']],...
		'Value','Ph',...
		'position',[355,178,375,202])
add_line([sys,'/',['MPSK',13,'modulation']],[465,85;475,85])
add_line([sys,'/',['MPSK',13,'modulation']],[205,160;250,160])
add_line([sys,'/',['MPSK',13,'modulation']],[560,85;575,85])
add_line([sys,'/',['MPSK',13,'modulation']],[55,195;70,195])
add_line([sys,'/',['MPSK',13,'modulation']],[110,35;185,35])
add_line([sys,'/',['MPSK',13,'modulation']],[225,45;250,45;250,100;230,100])
add_line([sys,'/',['MPSK',13,'modulation']],[180,100;165,100;165,55;185,55])
add_line([sys,'/',['MPSK',13,'modulation']],[380,140;415,140;415,85;435,85])
add_line([sys,'/',['MPSK',13,'modulation']],[140,195;150,195;150,45;185,45])
add_line([sys,'/',['MPSK',13,'modulation']],[150,195;220,195;220,170;250,170])
add_line([sys,'/',['MPSK',13,'modulation']],[150,140;340,140])
add_line([sys,'/',['MPSK',13,'modulation']],[380,190;420,190;420,95;435,95])
add_line([sys,'/',['MPSK',13,'modulation']],[300,170;320,170;320,150;340,150])
add_line([sys,'/',['MPSK',13,'modulation']],[370,45;415,45;415,75;435,75])
add_line([sys,'/',['MPSK',13,'modulation']],[250,45;310,45])
set_param([sys,'/',['MPSK',13,'modulation']],...
		'Mask Display','MPSK',...
		'Mask Type','MPSK')
set_param([sys,'/',['MPSK',13,'modulation']],...
		'Mask Dialogue','M-ary Phase Shift Keying Modulation:|M-ary number:|Carrier frequency:|Output amplitude:|Trigger signal threshold:|Initial phase:')
set_param([sys,'/',['MPSK',13,'modulation']],...
		'Mask Translate','pi2=2*pi;Sft=pi2/@1; Fc=@2*pi2; Ac=@3; thld=@4;Ph=@5;')
set_param([sys,'/',['MPSK',13,'modulation']],...
		'Mask Help','This block modulates an M-ary digital signal onto a given carrier frequency. The first input port is for the original digital signal, which is coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. For best solution, the carrier frequency should be integer times the clock frequency. The initial phase will affect every input process.')
set_param([sys,'/',['MPSK',13,'modulation']],...
		'Mask Entries','N\/Fc\/1\/.2\/0\/')


%     Finished composite block ['MPSK',13,'modulation'].

set_param([sys,'/',['MPSK',13,'modulation']],...
		'position',[300,108,360,152])


%     Subsystem  ['Differential',13,'PSK demodu'].

new_system([sys,'/',['Differential',13,'PSK demodu']])
set_param([sys,'/',['Differential',13,'PSK demodu']],'Location',[50,105,913,506])

add_block('built-in/Reset Integrator',[sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator']])
set_param([sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator']],...
		'position',[235,169,275,201])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK demodu/in_2']])
set_param([sys,'/',['Differential',13,'PSK demodu/in_2']],...
		'Port','2',...
		'position',[25,175,45,195])


%     Subsystem  ['Differential',13,'PSK demodu/Rising edge',13,'detector'].

new_system([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Differential',13,'PSK demodu/Rising edge',13,'detector'].

set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],...
		'position',[70,163,130,207])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK demodu/Memory1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Memory1']],...
		'orientation',2,...
		'position',[400,255,440,285])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK demodu/Switch']])
set_param([sys,'/',['Differential',13,'PSK demodu/Switch']],...
		'Threshold','eps',...
		'position',[405,184,435,216])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK demodu/Relational',13,'Operator']])
set_param([sys,'/',['Differential',13,'PSK demodu/Relational',13,'Operator']],...
		'position',[320,178,350,202])

add_block('built-in/Reset Integrator',[sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator2']])
set_param([sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator2']],...
		'position',[245,279,285,311])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK demodu/Const']])
set_param([sys,'/',['Differential',13,'PSK demodu/Const']],...
		'Value','Ac/4',...
		'position',[175,254,205,276])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK demodu/Frequency']])
set_param([sys,'/',['Differential',13,'PSK demodu/Frequency']],...
		'Value','Fc',...
		'position',[180,43,205,67])

add_block('built-in/Fcn',[sys,'/',['Differential',13,'PSK demodu/sin']])
set_param([sys,'/',['Differential',13,'PSK demodu/sin']],...
		'Expr','sin(u)',...
		'position',[465,87,505,113])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK demodu/Initial phase']])
set_param([sys,'/',['Differential',13,'PSK demodu/Initial phase']],...
		'Value','Ph',...
		'position',[335,93,355,117])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK demodu/Switch1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Switch1']],...
		'Threshold','eps',...
		'position',[360,24,390,56])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK demodu/in_1']])
set_param([sys,'/',['Differential',13,'PSK demodu/in_1']],...
		'position',[440,45,460,65])

add_block('built-in/Product',[sys,'/',['Differential',13,'PSK demodu/Product']])
set_param([sys,'/',['Differential',13,'PSK demodu/Product']],...
		'position',[540,46,565,79])

add_block('built-in/Reset Integrator',[sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator1']],...
		'position',[265,49,305,81])

add_block('built-in/Sum',[sys,'/',['Differential',13,'PSK demodu/Sum']])
set_param([sys,'/',['Differential',13,'PSK demodu/Sum']],...
		'position',[415,83,435,112])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK demodu/Memory2']])
set_param([sys,'/',['Differential',13,'PSK demodu/Memory2']],...
		'position',[485,185,525,215])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK demodu/Switch2']])
set_param([sys,'/',['Differential',13,'PSK demodu/Switch2']],...
		'Threshold','eps',...
		'position',[560,194,590,226])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK demodu/Memory3']])
set_param([sys,'/',['Differential',13,'PSK demodu/Memory3']],...
		'orientation',2,...
		'position',[560,260,600,290])

add_block('built-in/Note',[sys,'/',['Differential',13,'PSK demodu/delayed',13,'output']])
set_param([sys,'/',['Differential',13,'PSK demodu/delayed',13,'output']],...
		'position',[610,175,615,180])

add_block('built-in/Logical Operator',[sys,'/',['Differential',13,'PSK demodu/Logical',13,'Operator']])
set_param([sys,'/',['Differential',13,'PSK demodu/Logical',13,'Operator']],...
		'Operator','XOR',...
		'position',[655,163,685,187])

add_block('built-in/Logical Operator',[sys,'/',['Differential',13,'PSK demodu/Logical',13,'Operator1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Logical',13,'Operator1']],...
		'Operator','NOT',...
		'Number of Input Ports','1',...
		'position',[710,163,740,187])

add_block('built-in/Outport',[sys,'/',['Differential',13,'PSK demodu/out_1']])
set_param([sys,'/',['Differential',13,'PSK demodu/out_1']],...
		'position',[760,165,780,185])
add_line([sys,'/',['Differential',13,'PSK demodu']],[135,185;230,185])
add_line([sys,'/',['Differential',13,'PSK demodu']],[155,185;155,40;355,40])
add_line([sys,'/',['Differential',13,'PSK demodu']],[440,200;455,200;445,270])
add_line([sys,'/',['Differential',13,'PSK demodu']],[395,40;400,40;410,90])
add_line([sys,'/',['Differential',13,'PSK demodu']],[310,65;345,65;355,50])
add_line([sys,'/',['Differential',13,'PSK demodu']],[395,270;380,270;380,210;400,210])
add_line([sys,'/',['Differential',13,'PSK demodu']],[510,100;515,100;515,70;535,70])
add_line([sys,'/',['Differential',13,'PSK demodu']],[210,55;260,55])
add_line([sys,'/',['Differential',13,'PSK demodu']],[440,100;460,100])
add_line([sys,'/',['Differential',13,'PSK demodu']],[570,65;580,65;580,140;220,140;230,175])
add_line([sys,'/',['Differential',13,'PSK demodu']],[465,55;535,55])
add_line([sys,'/',['Differential',13,'PSK demodu']],[50,185;65,185])
add_line([sys,'/',['Differential',13,'PSK demodu']],[155,100;245,100;245,65;260,65])
add_line([sys,'/',['Differential',13,'PSK demodu']],[155,185;155,235;370,235;370,200;400,200])
add_line([sys,'/',['Differential',13,'PSK demodu']],[360,105;410,105])
add_line([sys,'/',['Differential',13,'PSK demodu']],[530,200;555,200])
add_line([sys,'/',['Differential',13,'PSK demodu']],[555,275;545,275;555,220])
add_line([sys,'/',['Differential',13,'PSK demodu']],[155,235;155,295;240,295])
add_line([sys,'/',['Differential',13,'PSK demodu']],[210,265;220,265;220,285;240,285])
add_line([sys,'/',['Differential',13,'PSK demodu']],[280,185;315,185])
add_line([sys,'/',['Differential',13,'PSK demodu']],[290,295;295,295;295,195;315,195])
add_line([sys,'/',['Differential',13,'PSK demodu']],[355,190;400,190])
add_line([sys,'/',['Differential',13,'PSK demodu']],[455,200;480,200])
add_line([sys,'/',['Differential',13,'PSK demodu']],[595,210;640,210;650,180])
add_line([sys,'/',['Differential',13,'PSK demodu']],[615,210;605,275])
add_line([sys,'/',['Differential',13,'PSK demodu']],[690,175;705,175])
add_line([sys,'/',['Differential',13,'PSK demodu']],[745,175;755,175])
add_line([sys,'/',['Differential',13,'PSK demodu']],[455,200;455,170;650,170])
set_param([sys,'/',['Differential',13,'PSK demodu']],...
		'Mask Display','DPSK\ndemodul',...
		'Mask Type','DPSK Demodulation')
set_param([sys,'/',['Differential',13,'PSK demodu']],...
		'Mask Dialogue','Differential Phase Shift Keying Demodulation:|Carrier frequency:|Carrier amplitude:|Trigger signal threshold:|Initial phase:')
set_param([sys,'/',['Differential',13,'PSK demodu']],...
		'Mask Translate','Fc=@1*pi*2; Ac=@2;thld=@3;Ph=@4;')
set_param([sys,'/',['Differential',13,'PSK demodu']],...
		'Mask Help','This block demodulates a MPSK modulated signal using coherent method. The first input port is for the received signal, which is MPSK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The initial phase should match those in the modulation. Becase the correlation computation, the output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Differential',13,'PSK demodu']],...
		'Mask Entries','Fc\/1\/.2\/0\/')


%     Finished composite block ['Differential',13,'PSK demodu'].

set_param([sys,'/',['Differential',13,'PSK demodu']],...
		'ForeGround',7,...
		'position',[460,199,530,241])


%     Subsystem  ['Differential',13,'PSK modu'].

new_system([sys,'/',['Differential',13,'PSK modu']])
set_param([sys,'/',['Differential',13,'PSK modu']],'Location',[146,38,930,343])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK modu/Switch2']])
set_param([sys,'/',['Differential',13,'PSK modu/Switch2']],...
		'Threshold','eps',...
		'position',[435,179,465,211])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK modu/one']])
set_param([sys,'/',['Differential',13,'PSK modu/one']],...
		'Value','Fc',...
		'position',[260,201,285,229])

add_block('built-in/Reset Integrator',[sys,'/',['Differential',13,'PSK modu/Reset',13,'integrator']])
set_param([sys,'/',['Differential',13,'PSK modu/Reset',13,'integrator']],...
		'position',[335,209,375,241])


%     Subsystem  ['Differential',13,'PSK modu/Rising edge',13,'detector'].

new_system([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Differential',13,'PSK modu/Rising edge',13,'detector'].

set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],...
		'position',[100,223,160,267])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK modu/in_2']])
set_param([sys,'/',['Differential',13,'PSK modu/in_2']],...
		'Port','2',...
		'position',[55,235,75,255])

add_block('built-in/Fcn',[sys,'/',['Differential',13,'PSK modu/Oscilation']])
set_param([sys,'/',['Differential',13,'PSK modu/Oscilation']],...
		'Expr','Ac*sin(u[1])',...
		'position',[595,150,670,180])

add_block('built-in/Sum',[sys,'/',['Differential',13,'PSK modu/Sum']])
set_param([sys,'/',['Differential',13,'PSK modu/Sum']],...
		'inputs','+++',...
		'position',[555,147,575,183])

add_block('built-in/Outport',[sys,'/',['Differential',13,'PSK modu/out_1']])
set_param([sys,'/',['Differential',13,'PSK modu/out_1']],...
		'position',[695,155,715,175])

add_block('built-in/Note',[sys,'/',['Differential',13,'PSK modu/delayed',13,'input']])
set_param([sys,'/',['Differential',13,'PSK modu/delayed',13,'input']],...
		'position',[485,50,490,55])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK modu/Switch1']])
set_param([sys,'/',['Differential',13,'PSK modu/Switch1']],...
		'Threshold','eps',...
		'position',[425,69,455,101])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK modu/Memory3']])
set_param([sys,'/',['Differential',13,'PSK modu/Memory3']],...
		'orientation',2,...
		'position',[420,125,460,155])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK modu/Memory2']])
set_param([sys,'/',['Differential',13,'PSK modu/Memory2']],...
		'position',[340,60,380,90])

add_block('built-in/Note',[sys,'/',['Differential',13,'PSK modu/zero-hold',13,'input']])
set_param([sys,'/',['Differential',13,'PSK modu/zero-hold',13,'input']],...
		'position',[280,35,285,40])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK modu/Memory1']])
set_param([sys,'/',['Differential',13,'PSK modu/Memory1']],...
		'orientation',2,...
		'position',[215,115,255,145])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK modu/Switch']])
set_param([sys,'/',['Differential',13,'PSK modu/Switch']],...
		'Threshold','eps',...
		'position',[220,59,250,91])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK modu/in_1']])
set_param([sys,'/',['Differential',13,'PSK modu/in_1']],...
		'position',[105,55,125,75])

add_block('built-in/Logical Operator',[sys,'/',['Differential',13,'PSK modu/Logical',13,'Operator']])
set_param([sys,'/',['Differential',13,'PSK modu/Logical',13,'Operator']],...
		'Operator','XOR',...
		'position',[535,43,565,67])

add_block('built-in/Gain',[sys,'/',['Differential',13,'PSK modu/Gain']])
set_param([sys,'/',['Differential',13,'PSK modu/Gain']],...
		'Gain','pi',...
		'position',[595,39,630,71])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK modu/Initial phase']])
set_param([sys,'/',['Differential',13,'PSK modu/Initial phase']],...
		'Value','Ph',...
		'position',[480,228,500,252])
add_line([sys,'/',['Differential',13,'PSK modu']],[505,240;535,240;535,175;550,175])
add_line([sys,'/',['Differential',13,'PSK modu']],[470,195;525,195;525,165;550,165])
add_line([sys,'/',['Differential',13,'PSK modu']],[675,165;690,165])
add_line([sys,'/',['Differential',13,'PSK modu']],[635,55;650,55;650,115;530,115;530,155;550,155])
add_line([sys,'/',['Differential',13,'PSK modu']],[255,75;335,75])
add_line([sys,'/',['Differential',13,'PSK modu']],[320,75;320,40;520,40;530,50])
add_line([sys,'/',['Differential',13,'PSK modu']],[280,75;280,130;260,130])
add_line([sys,'/',['Differential',13,'PSK modu']],[460,85;485,85;485,140;465,140])
add_line([sys,'/',['Differential',13,'PSK modu']],[485,85;520,85;530,60])
add_line([sys,'/',['Differential',13,'PSK modu']],[580,165;590,165])
add_line([sys,'/',['Differential',13,'PSK modu']],[165,245;190,245;190,75;215,75])
add_line([sys,'/',['Differential',13,'PSK modu']],[190,195;430,195])
add_line([sys,'/',['Differential',13,'PSK modu']],[190,245;305,245;305,225;330,225])
add_line([sys,'/',['Differential',13,'PSK modu']],[380,225;415,225;415,205;430,205])
add_line([sys,'/',['Differential',13,'PSK modu']],[290,215;330,215])
add_line([sys,'/',['Differential',13,'PSK modu']],[385,75;420,75])
add_line([sys,'/',['Differential',13,'PSK modu']],[415,140;400,140;400,95;420,95])
add_line([sys,'/',['Differential',13,'PSK modu']],[130,65;215,65])
add_line([sys,'/',['Differential',13,'PSK modu']],[210,130;200,130;200,85;215,85])
add_line([sys,'/',['Differential',13,'PSK modu']],[80,245;95,245])
add_line([sys,'/',['Differential',13,'PSK modu']],[570,55;590,55])
set_param([sys,'/',['Differential',13,'PSK modu']],...
		'Mask Display','DPSK',...
		'Mask Type','DPSK')
set_param([sys,'/',['Differential',13,'PSK modu']],...
		'Mask Dialogue','Differential Phase Shift Keying Modulation:|Carrier frequency:|Output amplitude:|Trigger signal threshold:|Initial phase:')
set_param([sys,'/',['Differential',13,'PSK modu']],...
		'Mask Translate','pi2=2*pi;Fc=@1*pi2; Ac=@2; thld=@3;Ph=@4;')
set_param([sys,'/',['Differential',13,'PSK modu']],...
		'Mask Help','This block modulates a binary digital signal onto a given carrier frequency. The first input port is for the binary signal, which is either 0 or 1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. For best solution, the carrier frequency should be integer times the clock frequency. The initial phase will affect every input process.')
set_param([sys,'/',['Differential',13,'PSK modu']],...
		'Mask Entries','Fc\/1\/1\/.2\/')


%     Finished composite block ['Differential',13,'PSK modu'].

set_param([sys,'/',['Differential',13,'PSK modu']],...
		'position',[300,184,365,226])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'position',[400,200,420,220])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'position',[395,350,415,370])


%     Subsystem  ['MFSK',13,'modulation'].

new_system([sys,'/',['MFSK',13,'modulation']])
set_param([sys,'/',['MFSK',13,'modulation']],'Location',[283,451,1036,711])

add_block('built-in/Inport',[sys,'/',['MFSK',13,'modulation/in_1']])
set_param([sys,'/',['MFSK',13,'modulation/in_1']],...
		'position',[105,20,125,40])

add_block('built-in/Switch',[sys,'/',['MFSK',13,'modulation/Switch']])
set_param([sys,'/',['MFSK',13,'modulation/Switch']],...
		'Threshold','eps',...
		'position',[180,39,210,71])

add_block('built-in/Memory',[sys,'/',['MFSK',13,'modulation/Memory1']])
set_param([sys,'/',['MFSK',13,'modulation/Memory1']],...
		'orientation',2,...
		'position',[175,90,215,120])

add_block('built-in/Gain',[sys,'/',['MFSK',13,'modulation/Gain']])
set_param([sys,'/',['MFSK',13,'modulation/Gain']],...
		'Gain','Ton',...
		'position',[255,38,305,72])

add_block('built-in/Switch',[sys,'/',['MFSK',13,'modulation/Switch1']])
set_param([sys,'/',['MFSK',13,'modulation/Switch1']],...
		'Threshold','eps',...
		'position',[475,124,505,156])

add_block('built-in/Sum',[sys,'/',['MFSK',13,'modulation/Sum']])
set_param([sys,'/',['MFSK',13,'modulation/Sum']],...
		'position',[555,133,575,162])

add_block('built-in/Fcn',[sys,'/',['MFSK',13,'modulation/Oscilation']])
set_param([sys,'/',['MFSK',13,'modulation/Oscilation']],...
		'Expr','Ac*sin(u[1])',...
		'position',[595,135,670,165])

add_block('built-in/Outport',[sys,'/',['MFSK',13,'modulation/out_1']])
set_param([sys,'/',['MFSK',13,'modulation/out_1']],...
		'position',[700,140,720,160])

add_block('built-in/Constant',[sys,'/',['MFSK',13,'modulation/one']])
set_param([sys,'/',['MFSK',13,'modulation/one']],...
		'Value','Fc',...
		'position',[275,158,295,182])

add_block('built-in/Sum',[sys,'/',['MFSK',13,'modulation/Sum1']])
set_param([sys,'/',['MFSK',13,'modulation/Sum1']],...
		'position',[340,148,360,177])

add_block('built-in/Reset Integrator',[sys,'/',['MFSK',13,'modulation/Reset',13,'integrator']])
set_param([sys,'/',['MFSK',13,'modulation/Reset',13,'integrator']],...
		'position',[395,159,435,191])


%     Subsystem  ['MFSK',13,'modulation/Rising edge',13,'detector'].

new_system([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['MFSK',13,'modulation/Rising edge',13,'detector'].

set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],...
		'position',[75,178,135,222])

add_block('built-in/Inport',[sys,'/',['MFSK',13,'modulation/in_2']])
set_param([sys,'/',['MFSK',13,'modulation/in_2']],...
		'Port','2',...
		'position',[30,190,50,210])

add_block('built-in/Constant',[sys,'/',['MFSK',13,'modulation/Initial phase']])
set_param([sys,'/',['MFSK',13,'modulation/Initial phase']],...
		'Value','Ph',...
		'position',[485,183,505,207])
add_line([sys,'/',['MFSK',13,'modulation']],[215,55;250,55])
add_line([sys,'/',['MFSK',13,'modulation']],[440,175;450,175;450,150;470,150])
add_line([sys,'/',['MFSK',13,'modulation']],[140,200;150,200;150,55;175,55])
add_line([sys,'/',['MFSK',13,'modulation']],[170,105;155,105;155,65;175,65])
add_line([sys,'/',['MFSK',13,'modulation']],[55,200;70,200])
add_line([sys,'/',['MFSK',13,'modulation']],[675,150;695,150])
add_line([sys,'/',['MFSK',13,'modulation']],[580,150;590,150])
add_line([sys,'/',['MFSK',13,'modulation']],[510,140;550,140])
add_line([sys,'/',['MFSK',13,'modulation']],[510,195;525,195;525,155;550,155])
add_line([sys,'/',['MFSK',13,'modulation']],[130,30;150,30;150,45;175,45])
add_line([sys,'/',['MFSK',13,'modulation']],[365,165;390,165])
add_line([sys,'/',['MFSK',13,'modulation']],[300,170;335,170])
add_line([sys,'/',['MFSK',13,'modulation']],[310,55;320,55;320,155;335,155])
add_line([sys,'/',['MFSK',13,'modulation']],[230,55;220,105])
add_line([sys,'/',['MFSK',13,'modulation']],[150,140;470,140])
add_line([sys,'/',['MFSK',13,'modulation']],[150,200;375,200;375,175;390,175])
set_param([sys,'/',['MFSK',13,'modulation']],...
		'Mask Display','MFSK',...
		'Mask Type','MFSK')
set_param([sys,'/',['MFSK',13,'modulation']],...
		'Mask Dialogue','M-ary Frequency Shift Keying Modulation:|M-ary number:|Carrier frequency (Hz):|Output amplitude:|Trigger signal threshold:|Initial phase:|Tone space (Hz):')
set_param([sys,'/',['MFSK',13,'modulation']],...
		'Mask Translate','pi2=2*pi;N=@1;Fc=@2*pi2;Ac=@3;thld=@4;Ph=@5;Ton=@6*pi2;')
set_param([sys,'/',['MFSK',13,'modulation']],...
		'Mask Help','MFSK modulates the input signal to carrier signal using M-ary frequency shift-keying method. The first input port is for the original digital signal, which is coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The tone space N/T is N times of clock frequency 1/T, N is 0.5 or positive integer. The carrier frequency should be integer times of clock frequency.')
set_param([sys,'/',['MFSK',13,'modulation']],...
		'Mask Entries','N\/Fc\/1\/.2\/0\/1/T\/')


%     Finished composite block ['MFSK',13,'modulation'].

set_param([sys,'/',['MFSK',13,'modulation']],...
		'position',[300,333,360,377])


%     Subsystem  ['Coherent',13,'MFSK demodu'].

new_system([sys,'/',['Coherent',13,'MFSK demodu']])
set_param([sys,'/',['Coherent',13,'MFSK demodu']],'Location',[80,310,915,581])

add_block('built-in/Inport',[sys,'/',['Coherent',13,'MFSK demodu/in_1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/in_1']],...
		'position',[440,35,460,55])

add_block('built-in/Sum',[sys,'/',['Coherent',13,'MFSK demodu/Sum2']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Sum2']],...
		'position',[240,38,260,67])

add_block('built-in/Inport',[sys,'/',['Coherent',13,'MFSK demodu/in_2']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/in_2']],...
		'Port','2',...
		'position',[30,160,50,180])


%     Subsystem  ['Coherent',13,'MFSK demodu/Rising edge',13,'detector'].

new_system([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Coherent',13,'MFSK demodu/Rising edge',13,'detector'].

set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],...
		'position',[75,148,135,192])

add_block('built-in/Constant',[sys,'/',['Coherent',13,'MFSK demodu/Frequency']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Frequency']],...
		'Value','Fc',...
		'position',[175,33,200,57])

add_block('built-in/Constant',[sys,'/',['Coherent',13,'MFSK demodu/Shift key']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Shift key']],...
		'Value','sft',...
		'position',[175,83,195,107])

add_block('built-in/Reset Integrator',[sys,'/',['Coherent',13,'MFSK demodu/Reset',13,'integrator1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Reset',13,'integrator1']],...
		'position',[285,49,325,81])

add_block('built-in/Constant',[sys,'/',['Coherent',13,'MFSK demodu/Initial phase']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Initial phase']],...
		'Value','Ph',...
		'position',[300,113,320,137])

add_block('built-in/Switch',[sys,'/',['Coherent',13,'MFSK demodu/Switch1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Switch1']],...
		'Threshold','eps',...
		'position',[350,14,380,46])

add_block('built-in/Sum',[sys,'/',['Coherent',13,'MFSK demodu/Sum1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Sum1']],...
		'position',[405,73,425,102])

add_block('built-in/S-Function',[sys,'/',['Coherent',13,'MFSK demodu/Array sin']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Array sin']],...
		'function name','arraysin',...
		'parameters','N',...
		'position',[445,80,495,100])

add_block('built-in/Product',[sys,'/',['Coherent',13,'MFSK demodu/Product']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Product']],...
		'position',[520,36,545,69])

add_block('built-in/Reset Integrator',[sys,'/',['Coherent',13,'MFSK demodu/Reset',13,'integrator']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Reset',13,'integrator']],...
		'position',[575,154,615,186])

add_block('built-in/Switch',[sys,'/',['Coherent',13,'MFSK demodu/Switch']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Switch']],...
		'Threshold','eps',...
		'position',[645,164,675,196])

add_block('built-in/Memory',[sys,'/',['Coherent',13,'MFSK demodu/Memory1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Memory1']],...
		'orientation',2,...
		'position',[640,220,680,250])

add_block('built-in/S-Function',[sys,'/',['Coherent',13,'MFSK demodu/Maximum']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Maximum']],...
		'function name','arraymax',...
		'position',[715,170,770,190])

add_block('built-in/Outport',[sys,'/',['Coherent',13,'MFSK demodu/out_1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/out_1']],...
		'position',[785,170,805,190])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[140,170;570,170])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[155,170;155,150;270,150;280,65])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[155,150;155,30;345,30])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[155,170;155,220;625,220;625,180;640,180])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[385,30;390,30;400,80])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[680,180;710,180])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[775,180;780,180])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[620,170;640,170])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[330,65;335,65;345,40])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[635,235;630,235;640,190])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[500,90;505,90;515,60])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[430,90;440,90])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[550,55;560,55;570,160])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[465,45;515,45])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[55,170;70,170])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[325,125;345,125;345,95;400,95])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[205,45;235,45])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[265,55;280,55])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[200,95;220,95;220,60;235,60])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[695,180;685,235])
set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
		'Mask Display','Coherent\nMFSK dm',...
		'Mask Type','MFSK Demodulation')
set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
		'Mask Dialogue','M-ary Frequency Shift Keying Demodulation:|M-ary number:|Carrier frequency:|Trigger signal threshold:|Initial phase:|Tone space (N/T):')
set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
		'Mask Translate','pi2=2*pi;N=@1;Fc=@2*pi2;thld=@3;Ph=@4;Ton=@5;sft=[0:N-1]*Ton*pi2;')
set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
		'Mask Help','This block demodulates a MFSK modulated signal using coherent method. The first input port is for the received signal, which is MFSK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The initial phase should match those in the modulation. Becase the correlation computation, the output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
		'Mask Entries','N\/Fc\/.2\/0\/1/T\/')


%     Finished composite block ['Coherent',13,'MFSK demodu'].

set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
		'ForeGround',3,...
		'position',[465,349,530,391])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'position',[400,275,420,295])

add_block('built-in/Constant',[sys,'/',['Added vector to',13,'seperate the plot']])
set_param([sys,'/',['Added vector to',13,'seperate the plot']],...
		'Value','[0 0 .03 .03 .06 .09 ]',...
		'position',[605,228,655,262])


%     Subsystem  ['Noncoherent',13,'MFSK demodu'].

new_system([sys,'/',['Noncoherent',13,'MFSK demodu']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],'Location',[52,135,966,390])

add_block('built-in/Switch',[sys,'/',['Noncoherent',13,'MFSK demodu/Switch']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Switch']],...
		'Threshold','eps',...
		'position',[650,144,680,176])

add_block('built-in/Memory',[sys,'/',['Noncoherent',13,'MFSK demodu/Memory1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Memory1']],...
		'orientation',2,...
		'position',[645,200,685,230])

add_block('built-in/S-Function',[sys,'/',['Noncoherent',13,'MFSK demodu/Maximum']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Maximum']],...
		'function name','arraymax',...
		'position',[720,150,775,170])

add_block('built-in/Outport',[sys,'/',['Noncoherent',13,'MFSK demodu/out_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/out_1']],...
		'position',[790,150,810,170])

add_block('built-in/Inport',[sys,'/',['Noncoherent',13,'MFSK demodu/in_2']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/in_2']],...
		'Port','2',...
		'position',[20,150,40,170])


%     Subsystem  ['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector'].

new_system([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector'].

set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],...
		'position',[65,138,125,182])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demodu/Initial phase1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Initial phase1']],...
		'Value','Ph',...
		'position',[395,118,415,142])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demodu/Initial phase']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Initial phase']],...
		'Value','Ph',...
		'position',[335,103,355,127])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demodu/Sum4']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Sum4']],...
		'position',[850,53,870,82])

add_block('built-in/Demux',[sys,'/',['Noncoherent',13,'MFSK demodu/Demux']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Demux']],...
		'outputs','[N N]',...
		'position',[780,50,820,85])

add_block('built-in/Product',[sys,'/',['Noncoherent',13,'MFSK demodu/Product1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Product1']],...
		'position',[730,51,755,84])

add_block('built-in/Reset Integrator',[sys,'/',['Noncoherent',13,'MFSK demodu/Reset',13,'integrator']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Reset',13,'integrator']],...
		'position',[655,54,695,86])

add_block('built-in/Inport',[sys,'/',['Noncoherent',13,'MFSK demodu/in_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/in_1']],...
		'position',[535,15,555,35])

add_block('built-in/Product',[sys,'/',['Noncoherent',13,'MFSK demodu/Product']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Product']],...
		'position',[600,41,625,74])

add_block('built-in/S-Function',[sys,'/',['Noncoherent',13,'MFSK demodu/Array sin']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Array sin']],...
		'function name','arraysin',...
		'parameters','N*2',...
		'position',[530,55,580,75])

add_block('built-in/Mux',[sys,'/',['Noncoherent',13,'MFSK demodu/Mux']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Mux']],...
		'inputs','[N N]',...
		'position',[485,43,515,87])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demodu/Sum3']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Sum3']],...
		'position',[445,78,465,107])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demodu/Sum1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Sum1']],...
		'position',[400,38,420,67])

add_block('built-in/Switch',[sys,'/',['Noncoherent',13,'MFSK demodu/Switch1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Switch1']],...
		'Threshold','eps',...
		'position',[345,29,375,61])

add_block('built-in/Reset Integrator',[sys,'/',['Noncoherent',13,'MFSK demodu/Reset',13,'integrator1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Reset',13,'integrator1']],...
		'position',[280,64,320,96])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demodu/Shift key']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Shift key']],...
		'Value','sft',...
		'position',[170,98,190,122])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demodu/Frequency']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Frequency']],...
		'Value','Fc',...
		'position',[170,48,195,72])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demodu/Sum2']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Sum2']],...
		'position',[235,53,255,82])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[685,160;715,160])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[700,160;690,215])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[195,110;215,110;215,75;230,75])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[260,70;275,70])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[200,60;230,60])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[360,115;385,115;395,60])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[45,160;60,160])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[130,160;530,160;530,100;635,100;635,70;650,70])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[640,215;635,215;645,170])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[325,80;330,80;340,55])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[780,160;785,160])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[380,45;395,45])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[425,55;430,55;440,85])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[420,130;430,130;440,100])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[425,55;480,55])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[470,95;480,75])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[520,65;525,65])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[585,65;595,65])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[560,25;580,25;580,50;595,50])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[630,60;650,60])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[700,70;705,70;705,60;725,60])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[700,70;705,70;705,75;725,75])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[760,70;775,70])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[825,60;845,60])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[825,75;845,75])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[875,70;885,70;885,125;620,125;620,150;645,150])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[140,160;140,45;340,45])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[265,160;275,80])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[530,160;645,160])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
		'Mask Display','Noncohe\nMFSK dm',...
		'Mask Type','MPSK Demodulation')
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
		'Mask Dialogue','Noncoherent M-ary Frequency Shift Keying Demodulation:|M-ary number:|Carrier frequency:|Trigger signal threshold:|Initial phase:|Tone space (N/T):')
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
		'Mask Translate','pi2=2*pi;N=@1;Fc=@2*pi2;thld=@3;Ph=@4;Ton=@5;sft=[0:N-1]*Ton*pi2;')
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
		'Mask Help','This block demodulates a MFSK modulated signal using noncoherent method. The first input port is for the received signal, which is MFSK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The initial phase can be assigned for testing. It should not effect the demodulation result. Becase the correlation computation, the output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
		'Mask Entries','N\/Fc\/.2\/pi/3\/1/T\/')


%     Finished composite block ['Noncoherent',13,'MFSK demodu'].

set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
		'position',[465,424,530,466])


%     Subsystem  ['MASK',13,'modulation'].

new_system([sys,'/',['MASK',13,'modulation']])
set_param([sys,'/',['MASK',13,'modulation']],'Location',[145,136,638,408])

add_block('built-in/Memory',[sys,'/',['MASK',13,'modulation/Memory1']])
set_param([sys,'/',['MASK',13,'modulation/Memory1']],...
		'orientation',2,...
		'position',[185,80,225,110])

add_block('built-in/Gain',[sys,'/',['MASK',13,'modulation/Gain']])
set_param([sys,'/',['MASK',13,'modulation/Gain']],...
		'Gain','Kc',...
		'position',[265,30,305,60])


%     Subsystem  ['MASK',13,'modulation/Rising edge',13,'detector'].

new_system([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['MASK',13,'modulation/Rising edge',13,'detector'].

set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],...
		'position',[75,78,135,122])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/in_2']])
set_param([sys,'/',['MASK',13,'modulation/in_2']],...
		'Port','2',...
		'position',[30,90,50,110])

add_block('built-in/Switch',[sys,'/',['MASK',13,'modulation/Switch']])
set_param([sys,'/',['MASK',13,'modulation/Switch']],...
		'Threshold','eps',...
		'position',[190,29,220,61])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/in_1']])
set_param([sys,'/',['MASK',13,'modulation/in_1']],...
		'position',[85,25,105,45])

add_block('built-in/Product',[sys,'/',['MASK',13,'modulation/Product']])
set_param([sys,'/',['MASK',13,'modulation/Product']],...
		'position',[395,100,420,120])

add_block('built-in/Outport',[sys,'/',['MASK',13,'modulation/out_1']])
set_param([sys,'/',['MASK',13,'modulation/out_1']],...
		'position',[450,100,470,120])

add_block('built-in/Sum',[sys,'/',['MASK',13,'modulation/Sum1']])
set_param([sys,'/',['MASK',13,'modulation/Sum1']],...
		'inputs','+-',...
		'position',[335,68,355,92])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Gain diff']])
set_param([sys,'/',['MASK',13,'modulation/Gain diff']],...
		'Value','Ac',...
		'position',[265,103,285,127])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/one']])
set_param([sys,'/',['MASK',13,'modulation/one']],...
		'Value','Fc',...
		'position',[30,171,55,199])


%     Subsystem  ['MASK',13,'modulation/Module',13,'Integrator'].

new_system([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/in_1']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/in_1']],...
		'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Memory']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/module']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/one']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Sum']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['MASK',13,'modulation/Module',13,'Integrator/out_1']])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator/out_1']],...
		'position',[370,30,390,50])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator',...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['MASK',13,'modulation/Module',13,'Integrator'].

set_param([sys,'/',['MASK',13,'modulation/Module',13,'Integrator']],...
		'position',[80,166,140,204])

add_block('built-in/Gain',[sys,'/',['MASK',13,'modulation/Gain1']])
set_param([sys,'/',['MASK',13,'modulation/Gain1']],...
		'Gain','pi2',...
		'position',[165,171,200,199])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'modulation/Oscilation']])
set_param([sys,'/',['MASK',13,'modulation/Oscilation']],...
		'Expr','sin(u)',...
		'position',[270,178,310,202])

add_block('built-in/Sum',[sys,'/',['MASK',13,'modulation/Sum']])
set_param([sys,'/',['MASK',13,'modulation/Sum']],...
		'position',[230,178,250,202])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Initial phase']])
set_param([sys,'/',['MASK',13,'modulation/Initial phase']],...
		'Value','Ph',...
		'position',[190,218,210,242])
add_line([sys,'/',['MASK',13,'modulation']],[425,110;445,110])
add_line([sys,'/',['MASK',13,'modulation']],[315,190;340,190;340,115;390,115])
add_line([sys,'/',['MASK',13,'modulation']],[215,230;225,195])
add_line([sys,'/',['MASK',13,'modulation']],[145,185;160,185])
add_line([sys,'/',['MASK',13,'modulation']],[60,185;75,185])
add_line([sys,'/',['MASK',13,'modulation']],[255,190;265,190])
add_line([sys,'/',['MASK',13,'modulation']],[55,100;70,100])
add_line([sys,'/',['MASK',13,'modulation']],[110,35;185,35])
add_line([sys,'/',['MASK',13,'modulation']],[180,95;165,95;165,55;185,55])
add_line([sys,'/',['MASK',13,'modulation']],[140,100;150,100;150,45;185,45])
add_line([sys,'/',['MASK',13,'modulation']],[205,185;225,185])
add_line([sys,'/',['MASK',13,'modulation']],[225,45;250,45;250,95;230,95])
add_line([sys,'/',['MASK',13,'modulation']],[250,45;260,45])
add_line([sys,'/',['MASK',13,'modulation']],[310,45;315,45;315,75;330,75])
add_line([sys,'/',['MASK',13,'modulation']],[360,80;370,80;370,105;390,105])
add_line([sys,'/',['MASK',13,'modulation']],[290,115;315,115;315,85;330,85])
set_param([sys,'/',['MASK',13,'modulation']],...
		'Mask Display','MASK',...
		'Mask Type','MASK')
set_param([sys,'/',['MASK',13,'modulation']],...
		'Mask Dialogue','M-ary Amplitude Shift Keying Modulation:|M-ary number:|Carrier frequency:|Maximum amplitude:|Trigger signal threshold:|Initial phase:')
set_param([sys,'/',['MASK',13,'modulation']],...
		'Mask Translate','pi2=2*pi;N=@1;Fc=@2;Ac=@3;Kc=Ac*2/(N-1);thld=@4;Ph=@5;')
set_param([sys,'/',['MASK',13,'modulation']],...
		'Mask Help','This block modulates an M-ary digital signal onto a given carrier frequency using amplitude shift keying method. The first input port is for the original digital signal, which is coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input.')
set_param([sys,'/',['MASK',13,'modulation']],...
		'Mask Entries','N\/Fc\/1\/.2\/0\/')


%     Finished composite block ['MASK',13,'modulation'].

set_param([sys,'/',['MASK',13,'modulation']],...
		'position',[300,258,360,302])


%     Subsystem  ['MASK',13,'demodulation'].

new_system([sys,'/',['MASK',13,'demodulation']])
set_param([sys,'/',['MASK',13,'demodulation']],'Location',[206,532,924,740])


%     Subsystem  ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas'].

new_system([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],'Location',[150,97,844,378])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/out_1']],...
		'position',[660,50,680,70])

add_block('built-in/Gain',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Gain']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Gain']],...
		'Gain','G',...
		'position',[605,45,630,75])

add_block('built-in/Product',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product1']],...
		'orientation',2,...
		'position',[525,110,555,130])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[460,175,480,195])

add_block('built-in/Transfer Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter1']],...
		'orientation',2,...
		'Numerator','Fn',...
		'Denominator','Fd',...
		'position',[450,100,500,140])

add_block('built-in/Sum',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Sum']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Sum']],...
		'orientation',2,...
		'position',[380,115,400,135])


%     Subsystem  ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator'].

new_system([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],'Location',[529,321,954,458])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/in_1']],...
		'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Memory']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Memory']],...
		'orientation',2,...
		'x0','init',...
		'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/module']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Reset',13,'integrator']],...
		'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/one']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/one']],...
		'orientation',3,...
		'move name',0,...
		'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Sum']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/out_1']],...
		'position',[370,30,390,50])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
		'Mask Display','Mod\nint',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
		'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator'].

set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
		'orientation',2,...
		'position',[290,110,350,140])

add_block('built-in/Transfer Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter2']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter2']],...
		'Numerator','Fn',...
		'Denominator','Fd',...
		'position',[325,204,375,246])

add_block('built-in/Product',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product2']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin1']],...
		'orientation',2,...
		'Expr','sin(u[1]*pi2+pih)',...
		'position',[120,160,220,190])

add_block('built-in/Transfer Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter']],...
		'Numerator','Fn',...
		'Denominator','Fd',...
		'position',[240,39,290,81])

add_block('built-in/Product',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin']],...
		'orientation',2,...
		'Expr','sin(u[1]*pi2)',...
		'position',[120,113,205,137])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Note',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[295,60;600,60])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[580,60;580,115;560,115])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[285,125;210,125])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[250,125;250,175;225,175])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[635,60;655,60])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[155,60;235,60])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[115,125;105,125;105,65;120,65])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[455,185;430,185;430,130;405,130])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[375,125;355,125])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[520,120;505,120])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[445,120;405,120])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[115,175;105,175;105,220;120,220])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[70,55;120,55])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[90,55;90,230;120,230])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[155,225;320,225])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[380,225;580,225;580,125;560,125])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Display','Costas PL\nDSB ADM',...
		'Mask Type','DSB-SC ADM')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Dialogue','Double-sideband suppressed-carrier amplitude demodulation:|Carrier frequency:|Filter numerator:|Filter denominator:|Output gain:')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Translate','Fc=@1;Fn=@2;Fd=@3;G=@4;pi2=pi*2;pih=pi/2;')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Help','The Double-Sideband Supressed-Carrier Amplitude Modulation demodulates a DSB-SC-AM signal using Costas Phase-Locked Loop method.')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'Mask Entries','Fc\/num\/den\/2\/')


%     Finished composite block ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas'].

set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
		'position',[150,25,220,65])

add_block('built-in/Memory',[sys,'/',['MASK',13,'demodulation/Memory2']])
set_param([sys,'/',['MASK',13,'demodulation/Memory2']],...
		'orientation',2,...
		'ForeGround',2,...
		'x0','-Ac',...
		'position',[345,95,385,125])

add_block('built-in/Switch',[sys,'/',['MASK',13,'demodulation/Switch2']])
set_param([sys,'/',['MASK',13,'demodulation/Switch2']],...
		'ForeGround',2,...
		'Threshold','eps',...
		'position',[350,39,380,71])

add_block('built-in/Sum',[sys,'/',['MASK',13,'demodulation/Sum2']])
set_param([sys,'/',['MASK',13,'demodulation/Sum2']],...
		'inputs','+-',...
		'position',[495,48,515,77])

add_block('built-in/Abs',[sys,'/',['MASK',13,'demodulation/Abs']])
set_param([sys,'/',['MASK',13,'demodulation/Abs']],...
		'position',[545,53,575,77])

add_block('built-in/S-Function',[sys,'/',['MASK',13,'demodulation/Minimum']])
set_param([sys,'/',['MASK',13,'demodulation/Minimum']],...
		'function name','arraymin',...
		'position',[600,55,655,75])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/out_1']],...
		'position',[685,55,705,75])

add_block('built-in/Note',[sys,'/',['MASK',13,'demodulation/zero hold']])
set_param([sys,'/',['MASK',13,'demodulation/zero hold']],...
		'ForeGround',2,...
		'position',[370,15,375,20])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/Shift key']])
set_param([sys,'/',['MASK',13,'demodulation/Shift key']],...
		'Value','sft',...
		'position',[435,103,455,127])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/in_1']],...
		'position',[15,35,35,55])


%     Subsystem  ['MASK',13,'demodulation/Rising edge',13,'detector'].

new_system([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],'Location',[431,241,820,415])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Memory1']],...
		'x0','ini',...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:|Initial condition:')
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;ini=@2;',...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
		'Mask Entries','thld\/1\/')


%     Finished composite block ['MASK',13,'demodulation/Rising edge',13,'detector'].

set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
		'ForeGround',4,...
		'position',[170,123,230,167])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/in_2']])
set_param([sys,'/',['MASK',13,'demodulation/in_2']],...
		'Port','2',...
		'position',[70,135,90,155])
add_line([sys,'/',['MASK',13,'demodulation']],[225,45;345,45])
add_line([sys,'/',['MASK',13,'demodulation']],[660,65;680,65])
add_line([sys,'/',['MASK',13,'demodulation']],[95,145;165,145])
add_line([sys,'/',['MASK',13,'demodulation']],[340,110;335,110;345,65])
add_line([sys,'/',['MASK',13,'demodulation']],[235,145;305,145;305,55;345,55])
add_line([sys,'/',['MASK',13,'demodulation']],[385,55;400,55;390,110])
add_line([sys,'/',['MASK',13,'demodulation']],[400,55;490,55])
add_line([sys,'/',['MASK',13,'demodulation']],[460,115;465,115;465,70;490,70])
add_line([sys,'/',['MASK',13,'demodulation']],[520,65;540,65])
add_line([sys,'/',['MASK',13,'demodulation']],[580,65;595,65])
add_line([sys,'/',['MASK',13,'demodulation']],[40,45;145,45])
set_param([sys,'/',['MASK',13,'demodulation']],...
		'Mask Display','MASK\ndemodu',...
		'Mask Type','MASK Demodulation')
set_param([sys,'/',['MASK',13,'demodulation']],...
		'Mask Dialogue','M-ary Amplitude Shift Keying Demodulation:|M-ary number:|Carrier Frequency:|Carrier signal maximum amplitude:|Trigger signal threshold:')
set_param([sys,'/',['MASK',13,'demodulation']],...
		'Mask Translate','N=@1;Fc=@2;Ac=@3;thld=@4;sft=[0:N-1]*Ac*2/(N-1)-Ac;[num,den]=cheby1(2,.1,Fc*pi/5,''s'');')
set_param([sys,'/',['MASK',13,'demodulation']],...
		'Mask Help','This block demodulates a MASK modulated signal using noncoherent method. The first input port is for the received signal, which is MASK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The output signal has one clock period delay over the original signal.')
set_param([sys,'/',['MASK',13,'demodulation']],...
		'Mask Entries','N\/Fc\/1\/.2\/')


%     Finished composite block ['MASK',13,'demodulation'].

set_param([sys,'/',['MASK',13,'demodulation']],...
		'ForeGround',6,...
		'position',[465,275,535,315])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[60,51,910,326])

add_block('built-in/Note',[sys,'/',['Subsystem/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']])
set_param([sys,'/',['Subsystem/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']],...
		'ForeGround',5)
set_param([sys,'/',['Subsystem/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']],...
		'position',[350,45,355,50])

add_block('built-in/Note',[sys,'/','Subsystem/Blue signal is the Phase shift-keying modulated//demodulated result. It should match the yellow signal'])
set_param([sys,'/','Subsystem/Blue signal is the Phase shift-keying modulated//demodulated result. It should match the yellow signal'],...
		'ForeGround',4,...
		'position',[340,100,345,105])

add_block('built-in/Note',[sys,'/','Subsystem/White signal, which is a black block in the block diagram is the nocoherent FSK demodulated signal. It should match the yellow signal.'])
set_param([sys,'/','Subsystem/White signal, which is a black block in the block diagram is the nocoherent FSK demodulated signal. It should match the yellow signal.'],...
		'position',[440,195,445,200])

add_block('built-in/Note',[sys,'/','Subsystem/Gree signal is the frequency shift-keying modulated//demodulated result. It should match the yellow signal.'])
set_param([sys,'/','Subsystem/Gree signal is the frequency shift-keying modulated//demodulated result. It should match the yellow signal.'],...
		'ForeGround',3,...
		'position',[350,170,355,175])

add_block('built-in/Note',[sys,'/','Subsystem/The last block, the red signal is a test of a single sided MASK modulation//demodulation signal.'])
set_param([sys,'/','Subsystem/The last block, the red signal is a test of a single sided MASK modulation//demodulation signal.'],...
		'ForeGround',2,...
		'position',[320,215,325,220])

add_block('built-in/Note',[sys,'/','Subsystem/Magenta signal is the amplitude shift keying modulated//demodulated result. It should match the yellow signal.'])
set_param([sys,'/','Subsystem/Magenta signal is the amplitude shift keying modulated//demodulated result. It should match the yellow signal.'],...
		'ForeGround',6,...
		'BackGround',6,...
		'position',[365,150,370,155])

add_block('built-in/Note',[sys,'/',['Subsystem/Cyan signal is the differential modulated//demodulated result. It is limited to process',13,'binary signal only. It should maches the red input signal']])
set_param([sys,'/',['Subsystem/Cyan signal is the differential modulated//demodulated result. It is limited to process',13,'binary signal only. It should maches the red input signal']],...
		'ForeGround',7,...
		'position',[285,120,290,125])

add_block('built-in/Note',[sys,'/','Subsystem/Red signal is a binary message which is either 0 or 1.'])
set_param([sys,'/','Subsystem/Red signal is a binary message which is either 0 or 1.'],...
		'ForeGround',2,...
		'position',[200,80,205,85])

add_block('built-in/Note',[sys,'/','Subsystem/This test file is designed to test digital modulation//demodulation schemes.'])
set_param([sys,'/','Subsystem/This test file is designed to test digital modulation//demodulation schemes.'],...
		'position',[260,25,265,30])
set_param([sys,'/','Subsystem'],...
		'Mask Display','?')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[685,500,715,536])

add_block('built-in/Sum',[sys,'/','Sum4'])
set_param([sys,'/','Sum4'],...
		'position',[680,153,700,182])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','.5\/-1.1\/N-.8\/''y-/r--/b-./c:/m:/g-./w:/r:''\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'position',[730,151,760,189])


%     Subsystem  'Additive Noise'.

new_system([sys,'/','Additive Noise'])
set_param([sys,'/','Additive Noise'],'Location',[54,341,339,470])

add_block('built-in/Outport',[sys,'/','Additive Noise/Out_1'])
set_param([sys,'/','Additive Noise/Out_1'],...
		'position',[230,40,250,60])

add_block('built-in/Gain',[sys,'/','Additive Noise/Gain'])
set_param([sys,'/','Additive Noise/Gain'],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Zero-Order Hold',[sys,'/',['Additive Noise/Zero-Order',13,'Hold']])
set_param([sys,'/',['Additive Noise/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/White Noise',[sys,'/','Additive Noise/White Noise'])
set_param([sys,'/','Additive Noise/White Noise'],...
		'Seed','seed',...
		'position',[25,40,45,60])
add_line([sys,'/','Additive Noise'],[50,50;80,50])
add_line([sys,'/','Additive Noise'],[200,50;225,50])
add_line([sys,'/','Additive Noise'],[125,50;150,50])
set_param([sys,'/','Additive Noise'],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/','Additive Noise'],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/','Additive Noise'],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/','Additive Noise'],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/','Additive Noise'],...
		'Mask Entries','.0001\/0.003\/[23341]\/')


%     Finished composite block 'Additive Noise'.

set_param([sys,'/','Additive Noise'],...
		'BackGround',3,...
		'position',[290,417,335,453])

add_block('built-in/Note',[sys,'/',['The curve color in the graphical scope matches the color of the',13,'blocks in the block diagram                                                   ']])
set_param([sys,'/',['The curve color in the graphical scope matches the color of the',13,'blocks in the block diagram                                                   ']],...
		'position',[365,495,370,500])

add_block('built-in/Note',[sys,'/',['Change MATLAB workspace variable for different parameters:',13,'N -- M-ary number (default 8)       ',13,'T -- Clock sample time (default .1)  ',13,'Fc -- Carrier frequency (default 100)']])
set_param([sys,'/',['Change MATLAB workspace variable for different parameters:',13,'N -- M-ary number (default 8)       ',13,'T -- Clock sample time (default .1)  ',13,'Fc -- Carrier frequency (default 100)']],...
		'position',[360,525,365,530])


%     Subsystem  ['Clock',13,'pulse'].

new_system([sys,'/',['Clock',13,'pulse']])
set_param([sys,'/',['Clock',13,'pulse']],'Location',[272,165,909,406])

add_block('built-in/Outport',[sys,'/',['Clock',13,'pulse/out_1']])
set_param([sys,'/',['Clock',13,'pulse/out_1']],...
		'hide name',0,...
		'position',[590,105,610,125])

add_block('built-in/Constant',[sys,'/',['Clock',13,'pulse/Constant1']])
set_param([sys,'/',['Clock',13,'pulse/Constant1']],...
		'Value','stt',...
		'position',[295,149,320,171])

add_block('built-in/Clock',[sys,'/',['Clock',13,'pulse/Clock1']])
set_param([sys,'/',['Clock',13,'pulse/Clock1']],...
		'hide name',0,...
		'position',[295,100,315,120])

add_block('built-in/Product',[sys,'/',['Clock',13,'pulse/Product']])
set_param([sys,'/',['Clock',13,'pulse/Product']],...
		'hide name',0,...
		'position',[470,105,495,125])

add_block('built-in/Gain',[sys,'/',['Clock',13,'pulse/Gain']])
set_param([sys,'/',['Clock',13,'pulse/Gain']],...
		'hide name',0,...
		'Gain','ht',...
		'position',[540,102,565,128])

add_block('built-in/Relational Operator',[sys,'/',['Clock',13,'pulse/Relational',13,'operator']])
set_param([sys,'/',['Clock',13,'pulse/Relational',13,'operator']],...
		'hide name',0,...
		'position',[370,102,400,133])

add_block('built-in/Sum',[sys,'/',['Clock',13,'pulse/Sum1']])
set_param([sys,'/',['Clock',13,'pulse/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[130,120,150,140])

add_block('built-in/Sum',[sys,'/',['Clock',13,'pulse/Sum']])
set_param([sys,'/',['Clock',13,'pulse/Sum']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[135,35,155,55])

add_block('built-in/Sum',[sys,'/',['Clock',13,'pulse/Sum2']])
set_param([sys,'/',['Clock',13,'pulse/Sum2']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[300,40,320,60])

add_block('built-in/Saturation',[sys,'/',['Clock',13,'pulse/Saturation']])
set_param([sys,'/',['Clock',13,'pulse/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','1',...
		'position',[365,40,390,60])

add_block('built-in/Constant',[sys,'/',['Clock',13,'pulse/Constant']])
set_param([sys,'/',['Clock',13,'pulse/Constant']],...
		'position',[25,30,45,50])

add_block('built-in/Gain',[sys,'/',['Clock',13,'pulse/Gain1']])
set_param([sys,'/',['Clock',13,'pulse/Gain1']],...
		'Gain','g',...
		'position',[235,122,255,138])

add_block('built-in/Unit Delay',[sys,'/',['Clock',13,'pulse/Unit Delay']])
set_param([sys,'/',['Clock',13,'pulse/Unit Delay']],...
		'orientation',2,...
		'Sample time','[Ts/2,st1]',...
		'position',[145,75,195,95])

add_block('built-in/Unit Delay',[sys,'/',['Clock',13,'pulse/Unit Delay1']])
set_param([sys,'/',['Clock',13,'pulse/Unit Delay1']],...
		'orientation',2,...
		'Sample time','[Ts/2,st2]',...
		'x0','ini',...
		'position',[140,165,190,185])
add_line([sys,'/',['Clock',13,'pulse']],[395,50;430,50;430,110;465,110])
add_line([sys,'/',['Clock',13,'pulse']],[325,160;345,160;345,125;365,125])
add_line([sys,'/',['Clock',13,'pulse']],[570,115;585,115])
add_line([sys,'/',['Clock',13,'pulse']],[500,115;535,115])
add_line([sys,'/',['Clock',13,'pulse']],[405,120;465,120])
add_line([sys,'/',['Clock',13,'pulse']],[320,110;365,110])
add_line([sys,'/',['Clock',13,'pulse']],[140,85;105,85;105,50;130,50])
add_line([sys,'/',['Clock',13,'pulse']],[160,45;230,45;230,85;200,85])
add_line([sys,'/',['Clock',13,'pulse']],[50,40;130,40])
add_line([sys,'/',['Clock',13,'pulse']],[155,130;210,130;210,175;195,175])
add_line([sys,'/',['Clock',13,'pulse']],[135,175;100,175;100,135;125,135])
add_line([sys,'/',['Clock',13,'pulse']],[50,40;70,40;70,125;125,125])
add_line([sys,'/',['Clock',13,'pulse']],[160,45;295,45])
add_line([sys,'/',['Clock',13,'pulse']],[325,50;360,50])
add_line([sys,'/',['Clock',13,'pulse']],[155,130;230,130])
add_line([sys,'/',['Clock',13,'pulse']],[260,130;275,130;275,55;295,55])
set_param([sys,'/',['Clock',13,'pulse']],...
		'Mask Display','plot(0,0,100,100,[90,75,75,60,60,35,35,20,20,10],[20,20,80,80,20,20,80,80,20,20])',...
		'Mask Type','Pulse Generator')
set_param([sys,'/',['Clock',13,'pulse']],...
		'Mask Dialogue','Pulse Generator.|Pulse period (secs):|Pulse width:|Pulse height:|Pulse start time:')
set_param([sys,'/',['Clock',13,'pulse']],...
		'Mask Translate','Ts=@1; du=@2; ht=@3; stt=@4; g=1; ini=ones(length(@3),1); if (Ts<2*du), g=-1; du=du-Ts/2; ini=zeros(length(@3),1); end; st1=rem(stt,Ts); st2=rem(stt+du,Ts);')
set_param([sys,'/',['Clock',13,'pulse']],...
		'Mask Help','Pulse generator which ensures pulse\ntransitions are hit. Provides a vector of pulses when the height is entered as a vector.\nUnmask to see how it works.')
set_param([sys,'/',['Clock',13,'pulse']],...
		'Mask Entries','T\/.05\/1\/0\/')


%     Finished composite block ['Clock',13,'pulse'].

set_param([sys,'/',['Clock',13,'pulse']],...
		'BackGround',4,...
		'position',[145,457,180,493])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','[1 1 1 1 1 1]',...
		'position',[620,135,650,185])
add_line(sys,[530,145;615,145])
add_line(sys,[520,75;555,75;555,135;615,135])
add_line(sys,[535,220;550,220;550,155;615,155])
add_line(sys,[350,65;455,65])
add_line(sys,[100,55;310,55])
add_line(sys,[155,80;180,80])
add_line(sys,[100,55;160,55;160,70;180,70])
add_line(sys,[220,75;310,75])
add_line(sys,[240,75;240,195;295,195])
add_line(sys,[250,55;250,120;295,120])
add_line(sys,[250,120;250,270;295,270])
add_line(sys,[540,295;560,295;560,165;615,165])
add_line(sys,[425,285;460,285])
add_line(sys,[365,280;395,280])
add_line(sys,[370,205;395,205])
add_line(sys,[425,210;455,210])
add_line(sys,[365,130;395,130])
add_line(sys,[425,135;455,135])
add_line(sys,[185,475;435,475;435,230;455,230])
add_line(sys,[435,230;435,155;455,155])
add_line(sys,[435,155;435,85;455,85])
add_line(sys,[185,475;260,475;260,215;295,215])
add_line(sys,[260,215;260,140;295,140])
add_line(sys,[340,435;375,435;375,215;395,215])
add_line(sys,[375,215;375,140;395,140])
add_line(sys,[250,270;250,345;295,345])
add_line(sys,[365,355;390,355])
add_line(sys,[340,435;375,435;375,365;390,365])
add_line(sys,[420,360;460,360])
add_line(sys,[535,370;570,370;570,175;615,175])
add_line(sys,[655,160;675,160])
add_line(sys,[705,170;725,170])
add_line(sys,[660,245;665,245;675,175])
add_line(sys,[420,360;425,360;425,435;460,435])
add_line(sys,[535,445;580,445;580,185;615,185])
add_line(sys,[435,380;460,380])
add_line(sys,[435,305;460,305])
add_line(sys,[260,290;295,290])
add_line(sys,[260,365;295,365])
add_line(sys,[375,290;395,290])
add_line(sys,[435,455;460,455])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
