function [ret,x0,str,ts,xts]=tstdpcms(t,x,u,flag);
%TSTDPCMS	is the M-file description of the SIMULINK system named TSTDPCMS.
%	The block-diagram can be displayed by typing: TSTDPCMS.
%
%	SYS=TSTDPCMS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTDPCMS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTDPCMS with a FLAG of zero:
%	[SIZES]=TSTDPCMS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[75,397,631,656])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','x=sin(0:.1:40);[p_trans,codebook,partition]=dpcmopt(x,1,8);');

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'BackGround',5,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1.000000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator']],...
		'position',[30,13,75,47])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[420,20,455,55])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','10\/-1.2\/1.2\/''y-/r--/y*/g*/yo/go/b+''\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'hide name',0,...
		'position',[490,21,520,59])


%     Subsystem  ['DPCM',13,'decode'].

new_system([sys,'/',['DPCM',13,'decode']])
set_param([sys,'/',['DPCM',13,'decode']],'Location',[32,515,384,677])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'decode/out_2']])
set_param([sys,'/',['DPCM',13,'decode/out_2']],...
		'Port','2',...
		'position',[235,10,255,30])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'decode/out_1']])
set_param([sys,'/',['DPCM',13,'decode/out_1']],...
		'position',[315,45,335,65])

add_block('built-in/Filter',[sys,'/',['DPCM',13,'decode/Filter']])
set_param([sys,'/',['DPCM',13,'decode/Filter']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','sample_time',...
		'position',[200,90,260,130])

add_block('built-in/Sum',[sys,'/',['DPCM',13,'decode/Sum1']])
set_param([sys,'/',['DPCM',13,'decode/Sum1']],...
		'position',[185,45,205,65])


%     Subsystem  ['DPCM',13,'decode/Quantizer',13,'decode'].

new_system([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']])
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],'Location',[596,274,888,411])

add_block('built-in/S-Function',[sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/Index lookup',13,'table']])
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/Index lookup',13,'table']],...
		'function name','indxtabl',...
		'parameters','codebook',...
		'Mask Display','Index\nLookup tb',...
		'Mask Type','No-intepret Lookup table')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/Index lookup',13,'table']],...
		'Mask Dialogue','Output one of the values in the look-up table.|Codebook:',...
		'Mask Translate','codebook=@1;')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/Index lookup',13,'table']],...
		'Mask Help','When codebook is a matrix, the block input can only be a scalar. The block output the row with the column index provided in the input. When codebook is a vector, the block output the same length as the input vector. The output is one of the values in codebook with the index provided by the input.')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/Index lookup',13,'table']],...
		'Mask Entries','codebook\/',...
		'position',[105,19,165,61])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/out_1']])
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/out_1']],...
		'position',[225,30,245,50])

add_block('built-in/Inport',[sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/in_1']])
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode/in_1']],...
		'position',[20,30,40,50])
add_line([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],[45,40;100,40])
add_line([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],[170,40;220,40])
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],...
		'Mask Display','Quantizer\ndecode',...
		'Mask Type','Scalar quantization decode')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],...
		'Mask Dialogue','Output is one of the elements in codebook. Output vector length is the same as the input length.|Quantization codebook:',...
		'Mask Translate','codebook=@1;')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],...
		'Mask Help','This block takes the quantized index as input and returns the quantization value. The output vector size the the same as the input vector size. Input 0, 1, ..., N-1 leads to CK(1), CK(2), .. CK(N) ouptut.')
set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],...
		'Mask Entries','codebook\/')


%     Finished composite block ['DPCM',13,'decode/Quantizer',13,'decode'].

set_param([sys,'/',['DPCM',13,'decode/Quantizer',13,'decode']],...
		'position',[85,30,145,70])

add_block('built-in/Inport',[sys,'/',['DPCM',13,'decode/in_1']])
set_param([sys,'/',['DPCM',13,'decode/in_1']],...
		'position',[30,40,50,60])
add_line([sys,'/',['DPCM',13,'decode']],[150,50;180,50])
add_line([sys,'/',['DPCM',13,'decode']],[160,50;160,20;230,20])
add_line([sys,'/',['DPCM',13,'decode']],[210,55;310,55])
add_line([sys,'/',['DPCM',13,'decode']],[285,55;285,110;265,110])
add_line([sys,'/',['DPCM',13,'decode']],[195,110;165,110;165,60;180,60])
add_line([sys,'/',['DPCM',13,'decode']],[55,50;80,50])
set_param([sys,'/',['DPCM',13,'decode']],...
		'Mask Display','DPCM\ndecode',...
		'Mask Type','DPCM decode')
set_param([sys,'/',['DPCM',13,'decode']],...
		'Mask Dialogue','Input the DPCM coded index. Output\nDPCM decodes to the 1st outport and\nquantization decode to the 2nd outport.|Predictor transfer function numerator:|Predictor transfer function denominator:|Quantization codebook:|Sample time (sec):')
set_param([sys,'/',['DPCM',13,'decode']],...
		'Mask Translate','num=@1;den=@2;codebook=@3;sample_time=@4;')
set_param([sys,'/',['DPCM',13,'decode']],...
		'Mask Help','This block recovers the source code using the DPCM decode method. The parameters in this block should match the parameters in the DPCM encoder.')
set_param([sys,'/',['DPCM',13,'decode']],...
		'Mask Entries','p_trans\/1\/codebook\/.1\/')


%     Finished composite block ['DPCM',13,'decode'].

set_param([sys,'/',['DPCM',13,'decode']],...
		'hide name',0,...
		'position',[265,43,345,87])


%     Subsystem  ['DPCM',13,'encode'].

new_system([sys,'/',['DPCM',13,'encode']])
set_param([sys,'/',['DPCM',13,'encode']],'Location',[469,413,916,648])


%     Subsystem  ['DPCM',13,'encode/Sampled',13,'quantizer enco'].

new_system([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],'Location',[37,120,369,253])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_3']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_3']],...
		'Port','3',...
		'position',[255,85,275,105])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_2']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_2']],...
		'Port','2',...
		'position',[290,55,310,75])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_1']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/out_1']],...
		'position',[260,20,280,40])

add_block('built-in/Inport',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/in_1']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Demux',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/Demux']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/Demux']],...
		'outputs','[n n n]',...
		'position',[175,47,215,83])

add_block('built-in/S-Function',[sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/S-function']])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco/S-function']],...
		'function name','simquans',...
		'parameters','n, partition, codebook,sample_time',...
		'position',[80,55,135,75])
add_line([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],[220,75;235,75;235,95;250,95])
add_line([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],[220,65;285,65])
add_line([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],[220,55;235,55;235,30;255,30])
add_line([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],[140,65;170,65])
add_line([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],[40,65;75,65])
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'Mask Display','Scalar\nquantizer',...
		'Mask Type','Scalar quantization encode')
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'Mask Dialogue','Quantize an analog signal to finite digital\nindex (1st outport), quantization value (2nd outport), and distortion (3rd outport) at every sample time point.|Quantization partition:|Quantization codebook:|Input signal vector length:|Sample time (sec):')
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'Mask Translate','partition=@1;codebook=@2;n=@3;sample_time=@4;')
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'Mask Help','This block quantizes the input signal to quantization index (1st outport), quantized value (2nd outport), and distortion (3rd outport) at every sample point. The inptu signa can be a vector. When the sample time is a two elements vector, the second element is the offset value. The length of partition is one less than the length of codebook. Use LLOYDS to optimize the partition and codebook.')
set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'Mask Entries','partition\/codebook\/1\/sample_time\/')


%     Finished composite block ['DPCM',13,'encode/Sampled',13,'quantizer enco'].

set_param([sys,'/',['DPCM',13,'encode/Sampled',13,'quantizer enco']],...
		'position',[155,43,220,87])

add_block('built-in/Filter',[sys,'/',['DPCM',13,'encode/Filter']])
set_param([sys,'/',['DPCM',13,'encode/Filter']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','sample_time',...
		'position',[150,120,210,160])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'encode/out_2']])
set_param([sys,'/',['DPCM',13,'encode/out_2']],...
		'Port','2',...
		'position',[295,55,315,75])

add_block('built-in/Outport',[sys,'/',['DPCM',13,'encode/out_1']])
set_param([sys,'/',['DPCM',13,'encode/out_1']],...
		'position',[295,10,315,30])

add_block('built-in/Sum',[sys,'/',['DPCM',13,'encode/Sum1']])
set_param([sys,'/',['DPCM',13,'encode/Sum1']],...
		'position',[265,100,285,120])

add_block('built-in/Sum',[sys,'/',['DPCM',13,'encode/Sum']])
set_param([sys,'/',['DPCM',13,'encode/Sum']],...
		'inputs','+-',...
		'position',[105,55,125,75])

add_block('built-in/Inport',[sys,'/',['DPCM',13,'encode/in_1']])
set_param([sys,'/',['DPCM',13,'encode/in_1']],...
		'position',[40,50,60,70])
add_line([sys,'/',['DPCM',13,'encode']],[225,65;250,65;260,105])
add_line([sys,'/',['DPCM',13,'encode']],[250,65;290,65])
add_line([sys,'/',['DPCM',13,'encode']],[225,50;250,50;250,20;290,20])
add_line([sys,'/',['DPCM',13,'encode']],[145,140;80,140;80,70;100,70])
add_line([sys,'/',['DPCM',13,'encode']],[80,115;260,115])
add_line([sys,'/',['DPCM',13,'encode']],[290,110;300,110;300,140;215,140])
add_line([sys,'/',['DPCM',13,'encode']],[130,65;150,65])
add_line([sys,'/',['DPCM',13,'encode']],[65,60;100,60])
set_param([sys,'/',['DPCM',13,'encode']],...
		'Mask Display','DPCM\nencode',...
		'Mask Type','DPCM encode')
set_param([sys,'/',['DPCM',13,'encode']],...
		'Mask Dialogue','Output the DPCM encoded index to the\n1st outport and the quantization\nrecovered value to the 2nd outport.|Predictor numerator:|Predictor denominator:|Quantization partition:|Quantization codebook:|Sample time (sec):')
set_param([sys,'/',['DPCM',13,'encode']],...
		'Mask Translate','num=@1;den=@2;partition=@3;codebook=@4;sample_time=@5;')
set_param([sys,'/',['DPCM',13,'encode']],...
		'Mask Help','The 1st outport outputs the index of the predictive error. The 2nd outport outputs the predictive error. Use the DPCMOPT function for the FIR filter training. A delta modulation is a special case with the numerator as [0,x], the denominator as 1 for the\npredictor.')
set_param([sys,'/',['DPCM',13,'encode']],...
		'Mask Entries','p_trans\/1\/partition\/codebook\/.1\/')


%     Finished composite block ['DPCM',13,'encode'].

set_param([sys,'/',['DPCM',13,'encode']],...
		'hide name',0,...
		'position',[120,53,200,97])

add_block('built-in/Note',[sys,'/',['The parameters are trained by double clicking "Load Data" block. p_trans is a',13,'1st order FIR filter, codebook is a length 8 vector, partition is a length 7 vector.']])
set_param([sys,'/',['The parameters are trained by double clicking "Load Data" block. p_trans is a',13,'1st order FIR filter, codebook is a length 8 vector, partition is a length 7 vector.']],...
		'position',[265,140,270,145])

add_block('built-in/Note',[sys,'/',['The commands used for the parameter training are as follows. You may train the',13,'parameter if you have changed the signal source.',13,'x=sin([0:.1:40]);[p_trans,codebook,partition]=dpcmopt(x,1,8);']])
set_param([sys,'/',['The commands used for the parameter training are as follows. You may train the',13,'parameter if you have changed the signal source.',13,'x=sin([0:.1:40]);[p_trans,codebook,partition]=dpcmopt(x,1,8);']],...
		'position',[270,175,275,180])


%     Subsystem  ['DPCM data',13,'training'].

new_system([sys,'/',['DPCM data',13,'training']])
set_param([sys,'/',['DPCM data',13,'training']],'Location',[111,168,452,354])
set_param([sys,'/',['DPCM data',13,'training']],...
		'Mask Display','Load\nData',...
		'Mask Dialogue','eval(''x=sin([0:.1:40]);[p_trans,codebook,partition]=dpcmopt(x,1,8);'')')


%     Finished composite block ['DPCM data',13,'training'].

set_param([sys,'/',['DPCM data',13,'training']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[465,68,525,112])

add_block('built-in/Note',[sys,'/','This example converts the analog signal to a 3-bits digital signal.'])
set_param([sys,'/','This example converts the analog signal to a 3-bits digital signal.'],...
		'position',[225,220,230,225])

add_block('built-in/Note',[sys,'/','This example demonstrates a delta modulation.'])
set_param([sys,'/','This example demonstrates a delta modulation.'],...
		'position',[150,115,155,120])
add_line(sys,[80,30;415,30])
add_line(sys,[105,30;115,75])
add_line(sys,[350,55;365,55;365,45;415,45])
add_line(sys,[205,65;260,65])
add_line(sys,[460,40;485,40])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
