function [ret,x0,str,ts,xts]=tstenv(t,x,u,flag);
%TSTENV is the M-file description of the SIMULINK system named TSTENV.
% The block-diagram can be displayed by typing: TSTENV.
%
% SYS=TSTENV(T,X,U,FLAG) returns depending on FLAG certain
%       system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes TSTENV to return state derivatives, FLAG=2
%       discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling TSTENV with a FLAG of zero:
%    [SIZES]=TSTENV([],[],[],0),  returns a vector, SIZES, which
%    contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs
%              SIZES(5) number of roots (currently unsupported)
%               SIZES(6) direct feedthrough flag
%               SIZES(7) number of sample times
%
%       For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[212,428,775,683])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.010')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Envelop',13,'Detector2'].

new_system([sys,'/',['Envelop',13,'Detector2']])
set_param([sys,'/',['Envelop',13,'Detector2']],'Location',[86,374,774,617])

add_block('built-in/Gain',[sys,'/',['Envelop',13,'Detector2/Gain1']])
set_param([sys,'/',['Envelop',13,'Detector2/Gain1']],...
           'Gain','g',...
          'position',[585,100,605,120])

add_block('built-in/Outport',[sys,'/',['Envelop',13,'Detector2/out_1']])
set_param([sys,'/',['Envelop',13,'Detector2/out_1']],...
           'position',[625,100,645,120])

add_block('built-in/Gain',[sys,'/',['Envelop',13,'Detector2/Gain']])
set_param([sys,'/',['Envelop',13,'Detector2/Gain']],...
                'Gain','g',...
          'position',[65,100,85,120])

add_block('built-in/Inport',[sys,'/',['Envelop',13,'Detector2/in_1']])
set_param([sys,'/',['Envelop',13,'Detector2/in_1']],...
                'position',[15,100,35,120])

add_block('built-in/Switch',[sys,'/',['Envelop',13,'Detector2/Switch']])
set_param([sys,'/',['Envelop',13,'Detector2/Switch']],...
            'Threshold','eps',...
           'position',[505,94,530,126])

add_block('built-in/Memory',[sys,'/',['Envelop',13,'Detector2/Memory']])
set_param([sys,'/',['Envelop',13,'Detector2/Memory']],...
           'position',[140,35,180,65])

add_block('built-in/Memory',[sys,'/',['Envelop',13,'Detector2/Memory2']])
set_param([sys,'/',['Envelop',13,'Detector2/Memory2']],...
          'orientation',2,...
             'position',[495,155,535,185])

add_block('built-in/Relational Operator',[sys,'/',['Envelop',13,'Detector2/Relational',13,'Operator1']])
set_param([sys,'/',['Envelop',13,'Detector2/Relational',13,'Operator1']],...
               'Operator','>',...
              'position',[385,98,415,122])

add_block('built-in/Memory',[sys,'/',['Envelop',13,'Detector2/Memory1']])
set_param([sys,'/',['Envelop',13,'Detector2/Memory1']],...
         'position',[300,125,340,155])

add_block('built-in/Relational Operator',[sys,'/',['Envelop',13,'Detector2/Relational',13,'Operator']])
set_param([sys,'/',['Envelop',13,'Detector2/Relational',13,'Operator']],...
         'position',[225,93,255,117])
add_line([sys,'/',['Envelop',13,'Detector2']],[610,110;620,110])
add_line([sys,'/',['Envelop',13,'Detector2']],[535,110;560,110;560,170;540,170])
add_line([sys,'/',['Envelop',13,'Detector2']],[560,110;580,110])
add_line([sys,'/',['Envelop',13,'Detector2']],[90,110;105,110;105,50;135,50])
add_line([sys,'/',['Envelop',13,'Detector2']],[105,110;220,110])
add_line([sys,'/',['Envelop',13,'Detector2']],[40,110;60,110])
add_line([sys,'/',['Envelop',13,'Detector2']],[490,170;480,170;480,120;500,120])
add_line([sys,'/',['Envelop',13,'Detector2']],[420,110;500,110])
add_line([sys,'/',['Envelop',13,'Detector2']],[260,105;270,105;270,140;295,140])
add_line([sys,'/',['Envelop',13,'Detector2']],[270,105;380,105])
add_line([sys,'/',['Envelop',13,'Detector2']],[345,140;355,140;355,115;380,115])
add_line([sys,'/',['Envelop',13,'Detector2']],[185,50;195,50;195,100;220,100])
add_line([sys,'/',['Envelop',13,'Detector2']],[195,50;490,50;500,100])
set_param([sys,'/',['Envelop',13,'Detector2']],...
           'Mask Display','Envelop\nDetector',...
          'Mask Type','Envelop Detector',...
              'Mask Dialogue','Envelop Detector:|Boundary Side (''upper'' or ''lower''):')
set_param([sys,'/',['Envelop',13,'Detector2']],...
          'Mask Translate','x=@1;if length(x)<2, error(''Error in Envelop Detector''); end; x=x(1:2); g=1; if x==''lo'', g=-1; end;',...
          'Mask Help','Envelop Detector detects the envelop of a signal.')
set_param([sys,'/',['Envelop',13,'Detector2']],...
              'Mask Entries','''upper''\/')


%     Finished composite block ['Envelop',13,'Detector2'].

set_param([sys,'/',['Envelop',13,'Detector2']],...
               'ForeGround',3,...
              'position',[235,44,295,96])


%     Subsystem  ['Envelop',13,'Detector1'].

new_system([sys,'/',['Envelop',13,'Detector1']])
set_param([sys,'/',['Envelop',13,'Detector1']],'Location',[86,374,774,617])

add_block('built-in/Relational Operator',[sys,'/',['Envelop',13,'Detector1/Relational',13,'Operator']])
set_param([sys,'/',['Envelop',13,'Detector1/Relational',13,'Operator']],...
            'position',[225,93,255,117])

add_block('built-in/Memory',[sys,'/',['Envelop',13,'Detector1/Memory1']])
set_param([sys,'/',['Envelop',13,'Detector1/Memory1']],...
         'position',[300,125,340,155])

add_block('built-in/Relational Operator',[sys,'/',['Envelop',13,'Detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Envelop',13,'Detector1/Relational',13,'Operator1']],...
               'Operator','>',...
              'position',[385,98,415,122])

add_block('built-in/Memory',[sys,'/',['Envelop',13,'Detector1/Memory2']])
set_param([sys,'/',['Envelop',13,'Detector1/Memory2']],...
         'orientation',2,...
             'position',[495,155,535,185])

add_block('built-in/Memory',[sys,'/',['Envelop',13,'Detector1/Memory']])
set_param([sys,'/',['Envelop',13,'Detector1/Memory']],...
          'position',[140,35,180,65])

add_block('built-in/Switch',[sys,'/',['Envelop',13,'Detector1/Switch']])
set_param([sys,'/',['Envelop',13,'Detector1/Switch']],...
            'Threshold','eps',...
           'position',[505,94,530,126])

add_block('built-in/Inport',[sys,'/',['Envelop',13,'Detector1/in_1']])
set_param([sys,'/',['Envelop',13,'Detector1/in_1']],...
               'position',[15,100,35,120])

add_block('built-in/Gain',[sys,'/',['Envelop',13,'Detector1/Gain']])
set_param([sys,'/',['Envelop',13,'Detector1/Gain']],...
          'Gain','g',...
          'position',[65,100,85,120])

add_block('built-in/Outport',[sys,'/',['Envelop',13,'Detector1/out_1']])
set_param([sys,'/',['Envelop',13,'Detector1/out_1']],...
             'position',[625,100,645,120])

add_block('built-in/Gain',[sys,'/',['Envelop',13,'Detector1/Gain1']])
set_param([sys,'/',['Envelop',13,'Detector1/Gain1']],...
              'Gain','g',...
          'position',[585,100,605,120])
add_line([sys,'/',['Envelop',13,'Detector1']],[185,50;195,50;195,100;220,100])
add_line([sys,'/',['Envelop',13,'Detector1']],[195,50;490,50;500,100])
add_line([sys,'/',['Envelop',13,'Detector1']],[345,140;355,140;355,115;380,115])
add_line([sys,'/',['Envelop',13,'Detector1']],[260,105;270,105;270,140;295,140])
add_line([sys,'/',['Envelop',13,'Detector1']],[270,105;380,105])
add_line([sys,'/',['Envelop',13,'Detector1']],[420,110;500,110])
add_line([sys,'/',['Envelop',13,'Detector1']],[535,110;560,110;560,170;540,170])
add_line([sys,'/',['Envelop',13,'Detector1']],[490,170;480,170;480,120;500,120])
add_line([sys,'/',['Envelop',13,'Detector1']],[40,110;60,110])
add_line([sys,'/',['Envelop',13,'Detector1']],[90,110;105,110;105,50;135,50])
add_line([sys,'/',['Envelop',13,'Detector1']],[105,110;220,110])
add_line([sys,'/',['Envelop',13,'Detector1']],[560,110;580,110])
add_line([sys,'/',['Envelop',13,'Detector1']],[610,110;620,110])
set_param([sys,'/',['Envelop',13,'Detector1']],...
          'Mask Display','Envelop\nDetector',...
          'Mask Type','Envelop Detector',...
              'Mask Dialogue','Envelop Detector:|Boundary Side (''upper'' or ''lower''):')
set_param([sys,'/',['Envelop',13,'Detector1']],...
          'Mask Translate','x=@1;if length(x)<2, error(''Error in Envelop Detector''); end; x=x(1:2); g=1; if x==''lo'', g=-1; end;',...
          'Mask Help','Envelop Detector detects the envelop of a signal.')
set_param([sys,'/',['Envelop',13,'Detector1']],...
              'Mask Entries','''lower''\/')


%     Finished composite block ['Envelop',13,'Detector1'].

set_param([sys,'/',['Envelop',13,'Detector1']],...
               'ForeGround',2,...
              'position',[235,134,295,186])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator']])
set_param([sys,'/',['Signal',13,'Generator']],...
                'ForeGround',5,...
              'Peak','0.370000',...
           'Peak Range','5.000000',...
             'Freq','1.000000',...
           'Freq Range','50.000000',...
            'Wave','Sin',...
                'Units','Rads')
set_param([sys,'/',['Signal',13,'Generator']],...
                'position',[35,53,80,87])


%     Subsystem  ['DSB-SC',13,'AM'].

new_system([sys,'/',['DSB-SC',13,'AM']])
set_param([sys,'/',['DSB-SC',13,'AM']],'Location',[112,331,527,488])

add_block('built-in/Product',[sys,'/',['DSB-SC',13,'AM/Product']])
set_param([sys,'/',['DSB-SC',13,'AM/Product']],...
           'position',[340,42,365,73])

add_block('built-in/Inport',[sys,'/',['DSB-SC',13,'AM/in_1']])
set_param([sys,'/',['DSB-SC',13,'AM/in_1']],...
                'position',[230,15,250,35])

add_block('built-in/Outport',[sys,'/',['DSB-SC',13,'AM/out_1']])
set_param([sys,'/',['DSB-SC',13,'AM/out_1']],...
             'position',[380,50,400,70])

add_block('built-in/Fcn',[sys,'/',['DSB-SC',13,'AM/Fcn']])
set_param([sys,'/',['DSB-SC',13,'AM/Fcn']],...
             'Expr','sin(u[1]*pi2+Ph)',...
           'position',[160,71,280,99])


%     Subsystem  ['DSB-SC',13,'AM/Module',13,'Integrator'].

new_system([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/in_1']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/in_1']],...
             'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Memory']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Memory']],...
                'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/module']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/module']],...
                'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Reset',13,'integrator']],...
              'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/one']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/one']],...
          'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Sum']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/Sum']],...
         'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/out_1']])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator/out_1']],...
               'position',[370,30,390,50])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator',...
             'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],...
                'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],...
          'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],...
          'Mask Entries','1\/0\/')


%     Finished composite block ['DSB-SC',13,'AM/Module',13,'Integrator'].

set_param([sys,'/',['DSB-SC',13,'AM/Module',13,'Integrator']],...
              'position',[75,64,140,106])

add_block('built-in/Constant',[sys,'/',['DSB-SC',13,'AM/Constant']])
set_param([sys,'/',['DSB-SC',13,'AM/Constant']],...
              'Value','Fc',...
                'position',[30,75,50,95])
add_line([sys,'/',['DSB-SC',13,'AM']],[285,85;305,85;305,65;335,65])
add_line([sys,'/',['DSB-SC',13,'AM']],[145,85;155,85])
add_line([sys,'/',['DSB-SC',13,'AM']],[55,85;70,85])
add_line([sys,'/',['DSB-SC',13,'AM']],[370,60;375,60])
add_line([sys,'/',['DSB-SC',13,'AM']],[255,25;310,25;310,50;335,50])
set_param([sys,'/',['DSB-SC',13,'AM']],...
             'Mask Display','DSB-SC\nAM',...
         'Mask Type','DSB-SC AM')
set_param([sys,'/',['DSB-SC',13,'AM']],...
              'Mask Dialogue','Double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency (Hz):|Initial Phase (rad):',...
             'Mask Translate','Ac=@1;Fc=@2;Ph=@3;pi2=2*pi;')
set_param([sys,'/',['DSB-SC',13,'AM']],...
               'Mask Help','The Double-Sideband-Supressed-Carrier Amplitude Modulation causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation.')
set_param([sys,'/',['DSB-SC',13,'AM']],...
            'Mask Entries','1\/10\/0\/')


%     Finished composite block ['DSB-SC',13,'AM'].

set_param([sys,'/',['DSB-SC',13,'AM']],...
                'ForeGround',7,...
              'position',[125,52,185,88])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
               'position',[385,48,415,82])


%     Subsystem  ['Auto-Scale',13,'Graph'].

new_system([sys,'/',['Auto-Scale',13,'Graph']])
set_param([sys,'/',['Auto-Scale',13,'Graph']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph/x']],...
              'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
          'function name','sfunyst',...
           'parameters','ax, color, npts, dt',...
          'position',[130,55,180,75])
add_line([sys,'/',['Auto-Scale',13,'Graph']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph']],...
                'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
              'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph']],...
          'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):|Sample time:')
set_param([sys,'/',['Auto-Scale',13,'Graph']],...
          'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=@6;')
set_param([sys,'/',['Auto-Scale',13,'Graph']],...
                'Mask Help','Uses MATLAB''s graph window.\nUse only one block per system.\nLine type must be in quotes.\nSee the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph']],...
           'Mask Entries','5\/-1.2\/1.2\/200\/''y-/c-/g--/r-./w:/m*/ro/b+''\/0\/')


%     Finished composite block ['Auto-Scale',13,'Graph'].

set_param([sys,'/',['Auto-Scale',13,'Graph']],...
               'position',[465,45,495,85])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[137,87,780,222])

add_block('built-in/Note',[sys,'/',['Subsystem/The yellow signal is the inputed signal to be modulated. The signal is modulated by a amplitude',13,'modulator. The modulated signal is demodulated using PLL.                                                   ']])
set_param([sys,'/',['Subsystem/The yellow signal is the inputed signal to be modulated. The signal is modulated by a amplitude',13,'modulator. The modulated signal is demodulated using PLL.                                                   ']],...
                'ForeGround',5)
set_param([sys,'/',['Subsystem/The yellow signal is the inputed signal to be modulated. The signal is modulated by a amplitude',13,'modulator. The modulated signal is demodulated using PLL.                                                   ']],...
          'position',[330,45,335,50])

add_block('built-in/Note',[sys,'/','Subsystem/This test file is to test Envelop Detector, which is in utility section..'])
set_param([sys,'/','Subsystem/This test file is to test Envelop Detector, which is in utility section..'],...
              'ForeGround',2,...
              'position',[250,25,255,30])

add_block('built-in/Note',[sys,'/','Subsystem/The envelop detector can detector the upper envelop or the lower envelop of the input signal.'])
set_param([sys,'/','Subsystem/The envelop detector can detector the upper envelop or the lower envelop of the input signal.'],...
              'ForeGround',3,...
              'BackGround',6,...
              'position',[320,80,325,85])
set_param([sys,'/','Subsystem'],...
          'Mask Display','?')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
               'ForeGround',3,...
              'hide name',0,...
               'Drop Shadow',4,...
             'position',[440,165,470,201])
add_line(sys,[420,65;460,65])
add_line(sys,[85,70;120,70])
add_line(sys,[190,70;230,70])
add_line(sys,[105,70;105,20;345,20;345,50;380,50])
add_line(sys,[205,70;205,160;230,160])
add_line(sys,[300,160;335,160;335,80;380,80])
add_line(sys,[300,70;380,70])
add_line(sys,[205,70;205,35;325,35;325,60;380,60])

drawnow

% Return any arguments.
if (nargin | nargout)
      % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
else
 drawnow % Flash up the model and execute load callback
end
