function [ret,x0,str,ts,xts]=tstfdma(t,x,u,flag);
%TSTFDMA	is the M-file description of the SIMULINK system named TSTFDMA.
%	The block-diagram can be displayed by typing: TSTFDMA.
%
%	SYS=TSTFDMA(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTFDMA to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTFDMA with a FLAG of zero:
%	[SIZES]=TSTFDMA([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[11,61,896,319])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '4')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','F0=50;F2=80;F4=110;ts=.002;[num0,den0]=butter(2,F0/2*ts);[num4,den4]=butter(2,F4/2*ts);[num2,den2]=butter(2,F2/2*ts);');

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'ForeGround',5,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','4.000000',...
		'Freq Range','5.000000',...
		'Wave','Sqr',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator']],...
		'position',[35,48,80,82])

add_block('built-in/Discrete State-Space',[sys,'/',['Butterworth',13,'IIR BP Filter2']])
set_param([sys,'/',['Butterworth',13,'IIR BP Filter2']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))',...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter2']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter2']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter2']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F2*ts*2\/0.05\/7\/ts\/',...
		'position',[250,113,320,147])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+++',...
		'position',[355,112,375,148])

add_block('built-in/Discrete State-Space',[sys,'/',['Butterworth',13,'IIR BP Filter3']])
set_param([sys,'/',['Butterworth',13,'IIR BP Filter3']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))',...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter3']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter3']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter3']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F4*ts*2\/0.05\/7\/ts\/',...
		'position',[250,183,320,217])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator1']])
set_param([sys,'/',['Signal',13,'generator1']],...
		'ForeGround',3,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','3.000000',...
		'Freq Range','5.000000',...
		'Wave','Saw',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator1']],...
		'position',[35,113,80,147])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator2']])
set_param([sys,'/',['Signal',13,'generator2']],...
		'ForeGround',2,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','2.000000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator2']],...
		'position',[35,183,80,217])


%     Subsystem  ['DSB-SC AM',13,'passband'].

new_system([sys,'/',['DSB-SC AM',13,'passband']])
set_param([sys,'/',['DSB-SC AM',13,'passband']],'Location',[103,459,555,641])

add_block('built-in/Sum',[sys,'/',['DSB-SC AM',13,'passband/Sum2']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Sum2']],...
		'position',[170,90,190,110])

add_block('built-in/Fcn',[sys,'/',['DSB-SC AM',13,'passband/Fcn']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Constant',[sys,'/',['DSB-SC AM',13,'passband/Constant1']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Inport',[sys,'/',['DSB-SC AM',13,'passband/in_1']])
set_param([sys,'/',['DSB-SC AM',13,'passband/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Outport',[sys,'/',['DSB-SC AM',13,'passband/out_1']])
set_param([sys,'/',['DSB-SC AM',13,'passband/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Product',[sys,'/',['DSB-SC AM',13,'passband/Product']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Clock',[sys,'/',['DSB-SC AM',13,'passband/Clock']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Gain',[sys,'/',['DSB-SC AM',13,'passband/Gain']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Zero-Order Hold',[sys,'/',['DSB-SC AM',13,'passband/Zero-Order',13,'Hold',13,'timing control']])
set_param([sys,'/',['DSB-SC AM',13,'passband/Zero-Order',13,'Hold',13,'timing control']],...
		'Sample time','ts',...
		'position',[50,219,85,251])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[195,100;200,100])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[45,75;65,75])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[370,60;375,60])
add_line([sys,'/',['DSB-SC AM',13,'passband']],[270,100;270,65;335,65])
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB AM',...
		'Mask Type','Passband DSB-SC AM')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Dialogue','Modulate the input signal using\nDSB-SC AM method.|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Translate','Fc=@1;Fc=Fc*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Help','This block modulates the input signal using the double-sideband suppressed-carrier amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'Mask Entries','F0\/0\/ts\/')


%     Finished composite block ['DSB-SC AM',13,'passband'].

set_param([sys,'/',['DSB-SC AM',13,'passband']],...
		'hide name',0,...
		'position',[140,43,220,87])


%     Subsystem  ['DSB-SC AM',13,'passband1'].

new_system([sys,'/',['DSB-SC AM',13,'passband1']])
set_param([sys,'/',['DSB-SC AM',13,'passband1']],'Location',[103,459,555,641])

add_block('built-in/Zero-Order Hold',[sys,'/',['DSB-SC AM',13,'passband1/Zero-Order',13,'Hold',13,'timing control']])
set_param([sys,'/',['DSB-SC AM',13,'passband1/Zero-Order',13,'Hold',13,'timing control']],...
		'Sample time','ts',...
		'position',[50,219,85,251])

add_block('built-in/Gain',[sys,'/',['DSB-SC AM',13,'passband1/Gain']])
set_param([sys,'/',['DSB-SC AM',13,'passband1/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Clock',[sys,'/',['DSB-SC AM',13,'passband1/Clock']])
set_param([sys,'/',['DSB-SC AM',13,'passband1/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Product',[sys,'/',['DSB-SC AM',13,'passband1/Product']])
set_param([sys,'/',['DSB-SC AM',13,'passband1/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Outport',[sys,'/',['DSB-SC AM',13,'passband1/out_1']])
set_param([sys,'/',['DSB-SC AM',13,'passband1/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Inport',[sys,'/',['DSB-SC AM',13,'passband1/in_1']])
set_param([sys,'/',['DSB-SC AM',13,'passband1/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Constant',[sys,'/',['DSB-SC AM',13,'passband1/Constant1']])
set_param([sys,'/',['DSB-SC AM',13,'passband1/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Fcn',[sys,'/',['DSB-SC AM',13,'passband1/Fcn']])
set_param([sys,'/',['DSB-SC AM',13,'passband1/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Sum',[sys,'/',['DSB-SC AM',13,'passband1/Sum2']])
set_param([sys,'/',['DSB-SC AM',13,'passband1/Sum2']],...
		'position',[170,90,190,110])
add_line([sys,'/',['DSB-SC AM',13,'passband1']],[270,100;270,65;335,65])
add_line([sys,'/',['DSB-SC AM',13,'passband1']],[370,60;375,60])
add_line([sys,'/',['DSB-SC AM',13,'passband1']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['DSB-SC AM',13,'passband1']],[45,75;65,75])
add_line([sys,'/',['DSB-SC AM',13,'passband1']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['DSB-SC AM',13,'passband1']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['DSB-SC AM',13,'passband1']],[195,100;200,100])
set_param([sys,'/',['DSB-SC AM',13,'passband1']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB AM',...
		'Mask Type','Passband DSB-SC AM')
set_param([sys,'/',['DSB-SC AM',13,'passband1']],...
		'Mask Dialogue','Modulate the input signal using\nDSB-SC AM method.|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-SC AM',13,'passband1']],...
		'Mask Translate','Fc=@1;Fc=Fc*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['DSB-SC AM',13,'passband1']],...
		'Mask Help','This block modulates the input signal using the double-sideband suppressed-carrier amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['DSB-SC AM',13,'passband1']],...
		'Mask Entries','F2\/0\/ts\/')


%     Finished composite block ['DSB-SC AM',13,'passband1'].

set_param([sys,'/',['DSB-SC AM',13,'passband1']],...
		'hide name',0,...
		'position',[140,108,220,152])


%     Subsystem  ['DSB-SC AM',13,'passband2'].

new_system([sys,'/',['DSB-SC AM',13,'passband2']])
set_param([sys,'/',['DSB-SC AM',13,'passband2']],'Location',[103,459,555,641])

add_block('built-in/Sum',[sys,'/',['DSB-SC AM',13,'passband2/Sum2']])
set_param([sys,'/',['DSB-SC AM',13,'passband2/Sum2']],...
		'position',[170,90,190,110])

add_block('built-in/Fcn',[sys,'/',['DSB-SC AM',13,'passband2/Fcn']])
set_param([sys,'/',['DSB-SC AM',13,'passband2/Fcn']],...
		'Expr','cos(u[1])',...
		'position',[205,85,265,115])

add_block('built-in/Constant',[sys,'/',['DSB-SC AM',13,'passband2/Constant1']])
set_param([sys,'/',['DSB-SC AM',13,'passband2/Constant1']],...
		'Value','Ph',...
		'position',[60,115,100,145])

add_block('built-in/Inport',[sys,'/',['DSB-SC AM',13,'passband2/in_1']])
set_param([sys,'/',['DSB-SC AM',13,'passband2/in_1']],...
		'position',[205,20,225,40])

add_block('built-in/Outport',[sys,'/',['DSB-SC AM',13,'passband2/out_1']])
set_param([sys,'/',['DSB-SC AM',13,'passband2/out_1']],...
		'position',[380,50,400,70])

add_block('built-in/Product',[sys,'/',['DSB-SC AM',13,'passband2/Product']])
set_param([sys,'/',['DSB-SC AM',13,'passband2/Product']],...
		'position',[340,42,365,73])

add_block('built-in/Clock',[sys,'/',['DSB-SC AM',13,'passband2/Clock']])
set_param([sys,'/',['DSB-SC AM',13,'passband2/Clock']],...
		'position',[20,65,40,85])

add_block('built-in/Gain',[sys,'/',['DSB-SC AM',13,'passband2/Gain']])
set_param([sys,'/',['DSB-SC AM',13,'passband2/Gain']],...
		'Gain','Fc',...
		'position',[70,56,120,94])

add_block('built-in/Zero-Order Hold',[sys,'/',['DSB-SC AM',13,'passband2/Zero-Order',13,'Hold',13,'timing control']])
set_param([sys,'/',['DSB-SC AM',13,'passband2/Zero-Order',13,'Hold',13,'timing control']],...
		'Sample time','ts',...
		'position',[50,219,85,251])
add_line([sys,'/',['DSB-SC AM',13,'passband2']],[195,100;200,100])
add_line([sys,'/',['DSB-SC AM',13,'passband2']],[105,130;130,130;130,105;165,105])
add_line([sys,'/',['DSB-SC AM',13,'passband2']],[125,75;150,75;150,95;165,95])
add_line([sys,'/',['DSB-SC AM',13,'passband2']],[45,75;65,75])
add_line([sys,'/',['DSB-SC AM',13,'passband2']],[230,30;270,30;270,50;335,50])
add_line([sys,'/',['DSB-SC AM',13,'passband2']],[370,60;375,60])
add_line([sys,'/',['DSB-SC AM',13,'passband2']],[270,100;270,65;335,65])
set_param([sys,'/',['DSB-SC AM',13,'passband2']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB AM',...
		'Mask Type','Passband DSB-SC AM')
set_param([sys,'/',['DSB-SC AM',13,'passband2']],...
		'Mask Dialogue','Modulate the input signal using\nDSB-SC AM method.|Carrier frequency (Hz):|Initial Phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-SC AM',13,'passband2']],...
		'Mask Translate','Fc=@1;Fc=Fc*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['DSB-SC AM',13,'passband2']],...
		'Mask Help','This block modulates the input signal using the double-sideband suppressed-carrier amplitude modulation. In general, the carrier frequency should be much higher than the message signal frequency.')
set_param([sys,'/',['DSB-SC AM',13,'passband2']],...
		'Mask Entries','F4\/0\/ts\/')


%     Finished composite block ['DSB-SC AM',13,'passband2'].

set_param([sys,'/',['DSB-SC AM',13,'passband2']],...
		'hide name',0,...
		'position',[140,178,220,222])


%     Subsystem  ['AWGN',13,'channel'].

new_system([sys,'/',['AWGN',13,'channel']])
set_param([sys,'/',['AWGN',13,'channel']],'Location',[86,493,348,639])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'channel/in_1']])
set_param([sys,'/',['AWGN',13,'channel/in_1']],...
		'position',[45,10,65,30])


%     Subsystem  ['AWGN',13,'channel/Gaussian',13,'noise'].

new_system([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],'Location',[409,168,757,373])

add_block('built-in/White Noise',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[240,95;290,95])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['AWGN',13,'channel/Gaussian',13,'noise'].

set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/out_1']])
set_param([sys,'/',['AWGN',13,'channel/out_1']],...
		'position',[200,55,220,75])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Sum']],...
		'position',[150,55,170,75])
add_line([sys,'/',['AWGN',13,'channel']],[175,65;195,65])
add_line([sys,'/',['AWGN',13,'channel']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['AWGN',13,'channel']],[90,70;145,70])
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);AWGN',...
		'Mask Type','AWGN channel, fixed parameter')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Dialogue','Additive white Gaussian noise channel\nwith fixed mean and variance.|Mean value:|Variance (std^2):|Initial Seed:')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);[x,y]=chanicon;')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Help','This block adds white Gaussian noise to the input signal. The mean and the variance can be a scalar or vector with the same length as the input signal.')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Entries','0\/.0001\/12345\/')


%     Finished composite block ['AWGN',13,'channel'].

set_param([sys,'/',['AWGN',13,'channel']],...
		'hide name',0,...
		'position',[400,108,480,152])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[755,36,790,69])

add_block('built-in/Scope',[sys,'/','element 1'])
set_param([sys,'/','element 1'],...
		'Vgain','1.500000',...
		'Hgain','4.000000',...
		'Vmax','3.000000',...
		'Hmax','8.000000',...
		'Window',[254,339,523,623])
open_system([sys,'/','element 1'])
set_param([sys,'/','element 1'],...
		'position',[825,42,845,68])

add_block('built-in/Mux',[sys,'/','Mux3'])
set_param([sys,'/','Mux3'],...
		'hide name',0,...
		'inputs','2',...
		'position',[755,191,790,224])

add_block('built-in/Scope',[sys,'/','element 3'])
set_param([sys,'/','element 3'],...
		'Vgain','1.500000',...
		'Hgain','4.000000',...
		'Vmax','3.000000',...
		'Hmax','8.000000',...
		'Window',[768,337,1014,625])
open_system([sys,'/','element 3'])
set_param([sys,'/','element 3'],...
		'position',[825,197,845,223])

add_block('built-in/Discrete State-Space',[sys,'/',['Butterworth',13,'IIR BP Filter1']])
set_param([sys,'/',['Butterworth',13,'IIR BP Filter1']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))',...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter1']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter1']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter1']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F0*ts*2\/0.05\/7\/ts\/',...
		'position',[250,48,320,82])

add_block('built-in/Scope',[sys,'/','multiplex signal'])
set_param([sys,'/','multiplex signal'],...
		'Vgain','3.000000',...
		'Hgain','4.000000',...
		'Vmax','6.000000',...
		'Hmax','8.000000',...
		'Window',[0,335,262,621])
open_system([sys,'/','multiplex signal'])
set_param([sys,'/','multiplex signal'],...
		'position',[425,182,445,208])

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'hide name',0,...
		'inputs','2',...
		'position',[755,106,790,139])

add_block('built-in/Scope',[sys,'/','element 2'])
set_param([sys,'/','element 2'],...
		'Vgain','1.500000',...
		'Hgain','4.000000',...
		'Vmax','3.000000',...
		'Hmax','8.000000',...
		'Window',[515,339,770,626])
open_system([sys,'/','element 2'])
set_param([sys,'/','element 2'],...
		'position',[825,112,845,138])

add_block('built-in/Discrete State-Space',[sys,'/',['Butterworth',13,'IIR BP Filter4']])
set_param([sys,'/',['Butterworth',13,'IIR BP Filter4']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))',...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter4']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter4']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter4']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F0*ts*2\/0.05\/7\/ts\/',...
		'position',[520,43,590,77])


%     Subsystem  ['DSB-SC-ADM',13,'passband2'].

new_system([sys,'/',['DSB-SC-ADM',13,'passband2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2']],'Location',[588,690,716,690])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'passband2/In-phase',13,'output']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/In-phase',13,'output']],...
		'position',[695,50,715,70])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband2/Filter1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband2/Filter']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband2/sin']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Note',[sys,'/',['DSB-SC-ADM',13,'passband2/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'passband2/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband2/Product']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband2/sin1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband2/Product2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband2/Sum1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'passband2/Carrier',13,'frequency1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Gain',[sys,'/',['DSB-SC-ADM',13,'passband2/Gain1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband2/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband2/Filter2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband2/Product1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'passband2/Carrier',13,'frequency']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])


%     Subsystem  ['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator'].

new_system([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/module']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Unit Delay',[sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],[410,40;440,40])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator'].

set_param([sys,'/',['DSB-SC-ADM',13,'passband2/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[400,60;690,60])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[655,60;645,115])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[315,185;300,185;290,135])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[305,125;290,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[360,125;345,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[485,225;655,225;645,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[155,225;420,225])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[70,55;120,55])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[90,55;90,230;120,230])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[605,120;600,120])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[435,125;430,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[155,60;335,60])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[530,120;465,120])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[260,130;215,130])
add_line([sys,'/',['DSB-SC-ADM',13,'passband2']],[240,130;240,180;225,180])
set_param([sys,'/',['DSB-SC-ADM',13,'passband2']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB ADM',...
		'Mask Type','Passband DSB-SC ADM')
set_param([sys,'/',['DSB-SC-ADM',13,'passband2']],...
		'Mask Dialogue','Demodulate a DSB-SC AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-SC-ADM',13,'passband2']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['DSB-SC-ADM',13,'passband2']],...
		'Mask Help','This block demodulates a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['DSB-SC-ADM',13,'passband2']],...
		'Mask Entries','F4\/num4\/den4\/0\/ts\/')


%     Finished composite block ['DSB-SC-ADM',13,'passband2'].

set_param([sys,'/',['DSB-SC-ADM',13,'passband2']],...
		'hide name',0,...
		'position',[620,178,700,222])


%     Subsystem  ['DSB-SC-ADM',13,'passband1'].

new_system([sys,'/',['DSB-SC-ADM',13,'passband1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1']],'Location',[588,690,716,690])


%     Subsystem  ['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator'].

new_system([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])

add_block('built-in/Unit Delay',[sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/module']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[410,40;440,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],[140,35;190,35])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator'].

set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'passband1/Carrier',13,'frequency']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband1/Product1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband1/Filter2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband1/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Gain',[sys,'/',['DSB-SC-ADM',13,'passband1/Gain1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'passband1/Carrier',13,'frequency1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband1/Sum1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband1/Product2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband1/sin1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband1/Product']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'passband1/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Note',[sys,'/',['DSB-SC-ADM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband1/sin']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband1/Filter']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband1/Filter1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'passband1/In-phase',13,'output']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1/In-phase',13,'output']],...
		'position',[695,50,715,70])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[260,130;215,130])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[240,130;240,180;225,180])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[530,120;465,120])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[155,60;335,60])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[435,125;430,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[605,120;600,120])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[70,55;120,55])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[90,55;90,230;120,230])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[155,225;420,225])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[485,225;655,225;645,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[360,125;345,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[305,125;290,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[315,185;300,185;290,135])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[400,60;690,60])
add_line([sys,'/',['DSB-SC-ADM',13,'passband1']],[655,60;645,115])
set_param([sys,'/',['DSB-SC-ADM',13,'passband1']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB ADM',...
		'Mask Type','Passband DSB-SC ADM')
set_param([sys,'/',['DSB-SC-ADM',13,'passband1']],...
		'Mask Dialogue','Demodulate a DSB-SC AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-SC-ADM',13,'passband1']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['DSB-SC-ADM',13,'passband1']],...
		'Mask Help','This block demodulates a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['DSB-SC-ADM',13,'passband1']],...
		'Mask Entries','F2\/num2\/den2\/0\/ts\/')


%     Finished composite block ['DSB-SC-ADM',13,'passband1'].

set_param([sys,'/',['DSB-SC-ADM',13,'passband1']],...
		'hide name',0,...
		'position',[620,108,700,152])


%     Subsystem  ['DSB-SC-ADM',13,'passband'].

new_system([sys,'/',['DSB-SC-ADM',13,'passband']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],'Location',[588,690,716,690])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'passband/In-phase',13,'output']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/In-phase',13,'output']],...
		'position',[695,50,715,70])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband/Filter1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[425,206,480,244])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband/Filter']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[340,41,395,79])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/sin']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/sin']],...
		'orientation',2,...
		'Expr','2*cos(u[1])',...
		'position',[125,118,210,142])

add_block('built-in/Note',[sys,'/',['DSB-SC-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
		'position',[260,350,265,355])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'passband/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband/Product']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Product']],...
		'position',[125,50,150,70])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/sin1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/sin1']],...
		'orientation',2,...
		'Expr','-2*sin(u[1])',...
		'position',[115,167,220,193])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband/Product2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Product2']],...
		'position',[125,215,150,235])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband/Sum1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Sum1']],...
		'orientation',2,...
		'position',[265,120,285,140])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[320,175,340,195])

add_block('built-in/Gain',[sys,'/',['DSB-SC-ADM',13,'passband/Gain1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Gain1']],...
		'orientation',2,...
		'Gain','pi2',...
		'position',[310,110,340,140])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Sum']],...
		'orientation',2,...
		'position',[440,115,460,135])

add_block('built-in/Filter',[sys,'/',['DSB-SC-ADM',13,'passband/Filter2']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[535,100,595,140])

add_block('built-in/Product',[sys,'/',['DSB-SC-ADM',13,'passband/Product1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Product1']],...
		'orientation',2,...
		'position',[610,110,640,130])

add_block('built-in/Constant',[sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Carrier',13,'frequency']],...
		'orientation',2,...
		'Value','Fc',...
		'position',[510,165,530,185])


%     Subsystem  ['DSB-SC-ADM',13,'passband/Dis module',13,'integrator'].

new_system([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])

add_block('built-in/Inport',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/module']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Unit Delay',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Outport',[sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],[410,40;440,40])
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'Mask Entries','1\/0\/ts\/')


%     Finished composite block ['DSB-SC-ADM',13,'passband/Dis module',13,'integrator'].

set_param([sys,'/',['DSB-SC-ADM',13,'passband/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[365,105,425,145])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[400,60;690,60])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[655,60;645,115])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[315,185;300,185;290,135])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[305,125;290,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[360,125;345,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[485,225;655,225;645,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[155,225;420,225])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[70,55;120,55])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[90,55;90,230;120,230])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[110,180;105,180;105,220;120,220])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[605,120;600,120])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[435,125;430,125])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[505,175;480,175;480,130;465,130])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[120,130;105,130;105,65;120,65])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[155,60;335,60])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[530,120;465,120])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[260,130;215,130])
add_line([sys,'/',['DSB-SC-ADM',13,'passband']],[240,130;240,180;225,180])
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);DSB ADM',...
		'Mask Type','Passband DSB-SC ADM')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Dialogue','Demodulate a DSB-SC AM modulated signal.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Translate','Fc=@1;num=@2;den=@3;Ph=@4;pi2=pi*2;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Help','This block demodulates a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'Mask Entries','F0\/num0\/den0\/0\/ts\/')


%     Finished composite block ['DSB-SC-ADM',13,'passband'].

set_param([sys,'/',['DSB-SC-ADM',13,'passband']],...
		'hide name',0,...
		'position',[620,38,700,82])

add_block('built-in/Discrete State-Space',[sys,'/',['Butterworth',13,'IIR BP Filter6']])
set_param([sys,'/',['Butterworth',13,'IIR BP Filter6']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))',...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter6']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter6']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter6']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F4*ts*2\/0.05\/7\/ts\/',...
		'position',[520,183,590,217])

add_block('built-in/Discrete State-Space',[sys,'/',['Butterworth',13,'IIR BP Filter5']])
set_param([sys,'/',['Butterworth',13,'IIR BP Filter5']],...
		'hide name',0,...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'Sample time','ts',...
		'Mask Display','plot(1:64,abs(h))',...
		'Mask Type','butter(BP)')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter5']],...
		'Mask Dialogue','Butterworth band pass filter.\n(Requires Signal Processing Toolbox)|Center frequency (0 to 1):|Bandwidth (0 to 1):|Order:|Sample time:')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter5']],...
		'Mask Translate','bw = @2/2; [a,b,c,d]=butter(@3,[@1-bw,@1+bw] ); ts=@4; [num,den]=ss2tf(a,b,c,d,1); if (@3 <= 8), [a,b,c,d]=tf2ss(num,den); end; h=freqz(num,den,64); ')
set_param([sys,'/',['Butterworth',13,'IIR BP Filter5']],...
		'Mask Help','IIR Butterworth band pass filter using MATLAB''s butter command.',...
		'Mask Entries','F2*ts*2\/0.05\/7\/ts\/',...
		'position',[520,113,590,147])
add_line(sys,[85,65;135,65])
add_line(sys,[325,65;335,65;335,120;350,120])
add_line(sys,[325,130;350,130])
add_line(sys,[325,200;335,200;335,140;350,140])
add_line(sys,[705,130;750,130])
add_line(sys,[705,60;750,60])
add_line(sys,[110,65;110,25;740,25;750,45])
add_line(sys,[380,130;395,130])
add_line(sys,[485,130;515,130])
add_line(sys,[225,65;245,65])
add_line(sys,[225,130;245,130])
add_line(sys,[225,200;245,200])
add_line(sys,[595,130;615,130])
add_line(sys,[595,60;615,60])
add_line(sys,[595,200;615,200])
add_line(sys,[85,130;135,130])
add_line(sys,[85,200;135,200])
add_line(sys,[795,55;820,55])
add_line(sys,[95,130;95,10;725,10;725,115;750,115])
add_line(sys,[795,125;820,125])
add_line(sys,[705,200;750,200])
add_line(sys,[795,210;820,210])
add_line(sys,[105,200;105,245;720,245;720,215;750,215])
add_line(sys,[495,130;495,200;515,200])
add_line(sys,[495,130;495,60;515,60])
add_line(sys,[380,130;385,130;385,195;420,195])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
