function [ret,x0,str,ts,xts]=tstfmpm(t,x,u,flag);
%TSTFMPM       is the M-file description of the SIMULINK system named TSTFMPM.
%        The block-diagram can be displayed by typing: TSTFMPM.
%
%        SYS=TSTFMPM(T,X,U,FLAG) returns depending on FLAG certain
%      system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes TSTFMPM to return state derivatives, FLAG=2
%      discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling TSTFMPM with a FLAG of zero:
%   [SIZES]=TSTFMPM([],[],[],0),  returns a vector, SIZES, which
%   contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs
%              SIZES(5) number of roots (currently unsupported)
%               SIZES(6) direct feedthrough flag
%               SIZES(7) number of sample times
%
%       For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[447,193,1033,516])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.001')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
           'ForeGround',5,...
              'Peak','1.000000',...
           'Peak Range','5.000000',...
             'Freq','7.100000',...
           'Freq Range','50.000000',...
            'Wave','Sin',...
                'Units','Rads')
set_param([sys,'/',['Signal',13,'generator']],...
                'position',[30,68,75,102])


%     Subsystem  ['Frequency',13,'Modulation'].

new_system([sys,'/',['Frequency',13,'Modulation']])
set_param([sys,'/',['Frequency',13,'Modulation']],'Location',[568,328,1027,475])

add_block('built-in/Outport',[sys,'/',['Frequency',13,'Modulation/out_1']])
set_param([sys,'/',['Frequency',13,'Modulation/out_1']],...
              'position',[425,30,445,50])

add_block('built-in/Gain',[sys,'/',['Frequency',13,'Modulation/Sensitivity']])
set_param([sys,'/',['Frequency',13,'Modulation/Sensitivity']],...
              'Gain','Kc',...
         'position',[80,21,120,49])

add_block('built-in/Inport',[sys,'/',['Frequency',13,'Modulation/in_1']])
set_param([sys,'/',['Frequency',13,'Modulation/in_1']],...
           'position',[35,25,55,45])

add_block('built-in/Constant',[sys,'/',['Frequency',13,'Modulation/Carrier',13,'frequency']])
set_param([sys,'/',['Frequency',13,'Modulation/Carrier',13,'frequency']],...
              'Value','Fc',...
                'position',[95,85,115,105])

add_block('built-in/Sum',[sys,'/',['Frequency',13,'Modulation/Sum']])
set_param([sys,'/',['Frequency',13,'Modulation/Sum']],...
               'position',[165,30,185,50])


%     Subsystem  ['Frequency',13,'Modulation/Module',13,'Integrator'].

new_system([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']])
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/in_1']],...
              'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/Memory']],...
          'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/module']])
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/module']],...
          'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/Reset',13,'integrator']],...
                'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/one']])
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/one']],...
            'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/Sum']],...
           'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator/out_1']],...
         'position',[370,30,390,50])
add_line([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator',...
             'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],...
             'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],...
               'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],...
               'Mask Entries','1\/0\/')


%     Finished composite block ['Frequency',13,'Modulation/Module',13,'Integrator'].

set_param([sys,'/',['Frequency',13,'Modulation/Module',13,'Integrator']],...
                'position',[210,24,265,56])

add_block('built-in/Fcn',[sys,'/',['Frequency',13,'Modulation/sin']])
set_param([sys,'/',['Frequency',13,'Modulation/sin']],...
               'Expr','Ac*sin(u[1]*pi2+Ph)',...
                'position',[285,25,410,55])
add_line([sys,'/',['Frequency',13,'Modulation']],[415,40;420,40])
add_line([sys,'/',['Frequency',13,'Modulation']],[270,40;280,40])
add_line([sys,'/',['Frequency',13,'Modulation']],[190,40;205,40])
add_line([sys,'/',['Frequency',13,'Modulation']],[120,95;140,95;140,45;160,45])
add_line([sys,'/',['Frequency',13,'Modulation']],[125,35;160,35])
add_line([sys,'/',['Frequency',13,'Modulation']],[60,35;75,35])
set_param([sys,'/',['Frequency',13,'Modulation']],...
              'Mask Display','FM',...
         'Mask Type','FM',...
            'Mask Dialogue','Frequency modulation:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):')
set_param([sys,'/',['Frequency',13,'Modulation']],...
             'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;')
set_param([sys,'/',['Frequency',13,'Modulation']],...
              'Mask Help','The FM block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['Frequency',13,'Modulation']],...
               'Mask Entries','1\/100/2/pi\/1\/0\/')


%     Finished composite block ['Frequency',13,'Modulation'].

set_param([sys,'/',['Frequency',13,'Modulation']],...
         'position',[145,66,190,104])


%     Subsystem  ['PLL Freq.',13,'demodulation'].

new_system([sys,'/',['PLL Freq.',13,'demodulation']])
set_param([sys,'/',['PLL Freq.',13,'demodulation']],'Location',[461,211,916,386])

add_block('built-in/Inport',[sys,'/',['PLL Freq.',13,'demodulation/in_1']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/in_1']],...
              'position',[45,30,65,50])

add_block('built-in/Product',[sys,'/',['PLL Freq.',13,'demodulation/Multiplier',13,'phase detector']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Multiplier',13,'phase detector']],...
           'position',[140,35,165,55])

add_block('built-in/Transfer Fcn',[sys,'/',['PLL Freq.',13,'demodulation/Lowpass',13,'filter']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Lowpass',13,'filter']],...
          'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[225,24,275,66])


%     Subsystem  ['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator'].

new_system([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],'Location',[422,82,872,213])

add_block('built-in/Constant',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Carrier',13,'frequency']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Carrier',13,'frequency']],...
                'Value','Fc',...
                'position',[90,75,110,95])

add_block('built-in/Fcn',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/sin']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/sin']],...
                'Expr','Ac*sin(u[1]*pi2+Ph)',...
                'position',[270,25,395,55])


%     Subsystem  ['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator'].

new_system([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],'Location',[529,321,954,458])

add_block('built-in/Inport',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/in_1']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/in_1']],...
          'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Memory']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Memory']],...
          'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/module']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/module']],...
          'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Reset',13,'integrator']],...
                'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/one']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/one']],...
            'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Sum']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Sum']],...
           'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/out_1']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator/out_1']],...
         'position',[370,30,390,50])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator')
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
                'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
         'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
           'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
           'Mask Entries','1\/0\/')


%     Finished composite block ['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator'].

set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
                'position',[195,24,250,56])

add_block('built-in/Sum',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Sum']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Sum']],...
               'position',[150,30,170,50])

add_block('built-in/Inport',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/in_1']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/in_1']],...
          'position',[20,25,40,45])

add_block('built-in/Gain',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Sensitivity']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/Sensitivity']],...
                'Gain','Kc',...
         'position',[65,21,105,49])

add_block('built-in/Outport',[sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/out_1']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator/out_1']],...
                'position',[410,30,430,50])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],[400,40;405,40])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],[175,40;190,40])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],[115,85;125,85;125,45;145,45])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],[110,35;145,35])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],[45,35;60,35])
add_line([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],[255,40;265,40])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],...
          'Mask Display','VCO',...
                'Mask Type','VCO')
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],...
             'Mask Dialogue','Voltage-Controlled Oscilator:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):')
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],...
         'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;')
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],...
          'Mask Help','The VCO block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],...
          'Mask Entries','Ac\/Fc\/1\/Ph\/')


%     Finished composite block ['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator'].

set_param([sys,'/',['PLL Freq.',13,'demodulation/Voltage-controlled',13,'oscilator']],...
             'orientation',2,...
             'position',[175,102,230,138])

add_block('built-in/Gain',[sys,'/',['PLL Freq.',13,'demodulation/Gain']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/Gain']],...
              'Gain','G',...
          'position',[350,32,375,58])

add_block('built-in/Outport',[sys,'/',['PLL Freq.',13,'demodulation/out_1']])
set_param([sys,'/',['PLL Freq.',13,'demodulation/out_1']],...
           'position',[405,35,425,55])
add_line([sys,'/',['PLL Freq.',13,'demodulation']],[380,45;400,45])
add_line([sys,'/',['PLL Freq.',13,'demodulation']],[280,45;320,45;320,120;235,120])
add_line([sys,'/',['PLL Freq.',13,'demodulation']],[320,45;345,45])
add_line([sys,'/',['PLL Freq.',13,'demodulation']],[170,120;95,120;95,50;135,50])
add_line([sys,'/',['PLL Freq.',13,'demodulation']],[170,45;220,45])
add_line([sys,'/',['PLL Freq.',13,'demodulation']],[70,40;135,40])
set_param([sys,'/',['PLL Freq.',13,'demodulation']],...
               'Mask Display','PLL\nFDM',...
           'Mask Type','PLL FDM')
set_param([sys,'/',['PLL Freq.',13,'demodulation']],...
           'Mask Dialogue','Phase-Locked Loop Frequency Demodulation:|Filter numerator:|Filter Denominator:|VCO frequency:|VCO Phase:|VCO Amplitude:|Gain at the output:')
set_param([sys,'/',['PLL Freq.',13,'demodulation']],...
          'Mask Translate','Fn=@1;Fd=@2;Fc=@3;Ph=@4;Ac=@5;G=@6;')
set_param([sys,'/',['PLL Freq.',13,'demodulation']],...
          'Mask Help','Phase-Locked Loop Frequency Demodulation is to recover the original signal modulated by a carrier frequency. The phase detector used in this block is a multiplier.')
set_param([sys,'/',['PLL Freq.',13,'demodulation']],...
               'Mask Entries','[3.0002,  0, 40002]\/[1, 67.46, 2270.9, 40002]\/100/2/pi\/pi/2\/1\/2\/')


%     Finished composite block ['PLL Freq.',13,'demodulation'].

set_param([sys,'/',['PLL Freq.',13,'demodulation']],...
          'ForeGround',3,...
              'position',[260,65,330,105])


%     Subsystem  ['Discriminat',13,'freq. demodulator'].

new_system([sys,'/',['Discriminat',13,'freq. demodulator']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator']],'Location',[174,409,898,612])

add_block('built-in/Inport',[sys,'/',['Discriminat',13,'freq. demodulator/in_1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/in_1']],...
           'position',[10,30,30,50])

add_block('built-in/Derivative',[sys,'/',['Discriminat',13,'freq. demodulator/Derivative1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Derivative1']],...
                'position',[145,30,175,50])


%     Subsystem  ['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2'].

new_system([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],'Location',[139,34,906,277])

add_block('built-in/Relational Operator',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Relational',13,'Operator2']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Relational',13,'Operator2']],...
           'position',[495,103,525,127])

add_block('built-in/Outport',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/out_1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/out_1']],...
             'position',[690,105,710,125])

add_block('built-in/Gain',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Gain1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Gain1']],...
                'Gain','g',...
          'position',[635,105,655,125])

add_block('built-in/Switch',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Switch1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Switch1']],...
          'Threshold','eps',...
           'position',[575,99,600,131])

add_block('built-in/Memory',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Memory2']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Memory2']],...
           'orientation',2,...
             'position',[410,155,450,185])

add_block('built-in/Switch',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Switch']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Switch']],...
            'Threshold','eps',...
           'position',[420,94,445,126])

add_block('built-in/Relational Operator',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Relational',13,'Operator1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Relational',13,'Operator1']],...
          'Operator','>',...
              'position',[345,98,375,122])

add_block('built-in/Relational Operator',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Relational',13,'Operator']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Relational',13,'Operator']],...
            'position',[210,93,240,117])

add_block('built-in/Memory',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Memory']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Memory']],...
             'position',[120,35,160,65])

add_block('built-in/Gain',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Gain']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Gain']],...
            'Gain','g',...
          'position',[75,100,95,120])

add_block('built-in/Inport',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/in_1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/in_1']],...
          'position',[30,100,50,120])

add_block('built-in/Memory',[sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Memory1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2/Memory1']],...
            'position',[285,125,325,155])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[450,110;470,110;470,170;455,170])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[470,110;490,110])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[470,110;470,85;550,85;550,105;570,105])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[530,115;570,115])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[605,115;630,115])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[165,50;195,50;205,100])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[195,50;395,50;395,100;415,100])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[330,140;340,115])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[245,105;270,105;280,140])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[270,105;340,105])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[380,110;415,110])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[405,170;395,170;395,120;415,120])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[55,110;70,110])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[100,110;105,110;115,50])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[100,110;205,110])
add_line([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],[660,115;685,115])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],...
               'Mask Display','Envelop\nDetector',...
          'Mask Type','Envelop Detector',...
              'Mask Dialogue','Envelop Detector:|Boundary Side (''upper'' or ''lower''):')
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],...
               'Mask Translate','x=@1;if length(x)<2, error(''Error in Envelop Detector''); end; x=x(1:2); g=1; if x==''lo'', g=-1; end;')
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],...
                'Mask Help','Envelop Detector detects the envelop of a signal.',...
             'Mask Entries','''upper''\/')


%     Finished composite block ['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2'].

set_param([sys,'/',['Discriminat',13,'freq. demodulator/Envelop',13,'Detector2']],...
         'position',[205,17,270,63])

add_block('built-in/Constant',[sys,'/',['Discriminat',13,'freq. demodulator/Constant']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Constant']],...
              'Value','Fc*2*pi',...
           'position',[325,73,390,97])

add_block('built-in/Gain',[sys,'/',['Discriminat',13,'freq. demodulator/Gain2']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Gain2']],...
                'Gain','.5',...
         'position',[430,71,470,99])

add_block('built-in/Relational Operator',[sys,'/',['Discriminat',13,'freq. demodulator/Relational',13,'Operator2']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Relational',13,'Operator2']],...
         'Operator','<=',...
             'position',[490,123,520,147])

add_block('built-in/Sum',[sys,'/',['Discriminat',13,'freq. demodulator/Sum3']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Sum3']],...
         'inputs','+-',...
               'position',[475,35,495,55])

add_block('built-in/Switch',[sys,'/',['Discriminat',13,'freq. demodulator/Switch1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Switch1']],...
          'Threshold','eps',...
           'position',[555,39,580,71])

add_block('built-in/Gain',[sys,'/',['Discriminat',13,'freq. demodulator/Gain1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Gain1']],...
                'Gain','G',...
          'position',[615,42,640,68])

add_block('built-in/Outport',[sys,'/',['Discriminat',13,'freq. demodulator/out_1']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/out_1']],...
             'position',[675,45,695,65])

add_block('built-in/Transfer Fcn',[sys,'/',['Discriminat',13,'freq. demodulator/Transfer Fcn4']])
set_param([sys,'/',['Discriminat',13,'freq. demodulator/Transfer Fcn4']],...
                'Numerator','nb',...
            'Denominator','db',...
          'position',[75,22,110,58])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[645,55;670,55])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[275,40;470,40])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[475,85;485,130])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[525,135;540,135;550,55])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[500,45;550,45])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[180,40;200,40])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[395,85;425,85])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[295,40;295,140;485,140])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[405,85;405,50;470,50])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[585,55;610,55])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[35,40;70,40])
add_line([sys,'/',['Discriminat',13,'freq. demodulator']],[115,40;140,40])
set_param([sys,'/',['Discriminat',13,'freq. demodulator']],...
                'Mask Display','Discriminant\nFDM',...
          'Mask Type','Discriminant FDM')
set_param([sys,'/',['Discriminat',13,'freq. demodulator']],...
           'Mask Dialogue','Discriminant Frequency Demodulation:|Modulation Amplitude:|Modulation frequency:|Order of filters:|Output gain:|Pre-processing filter numerator:|Pre-processing filter denominator:')
set_param([sys,'/',['Discriminat',13,'freq. demodulator']],...
            'Mask Translate','Ac=@1;Fc=@2;Order=@3;G=@4/2/pi;nb=@5;db=@6;')
set_param([sys,'/',['Discriminat',13,'freq. demodulator']],...
           'Mask Help','Discriminant Frequency Demodulator detects the original signal which is modulated by a frequency modulation method. The pre-processing filter should be a band pass filter to eliminate transfer noise.')
set_param([sys,'/',['Discriminat',13,'freq. demodulator']],...
            'Mask Entries','1\/100/2/pi\/2\/1\/1\/1\/')


%     Finished composite block ['Discriminat',13,'freq. demodulator'].

set_param([sys,'/',['Discriminat',13,'freq. demodulator']],...
         'ForeGround',2,...
              'position',[260,143,335,187])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
             'position',[385,65,420,115])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
           'function name','sfuny',...
             'parameters','ax, color,dt',...
         'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
            'position',[65,55,85,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
              'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
                'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
              'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph'],...
         'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph'],...
           'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
         'Mask Entries','4\/-1.5\/1.5\/''y-/g--/r-/m:/w-/r:/b+''\/0.03\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
         'position',[455,71,485,109])


%     Subsystem  ['PLL Phase',13,'demodulation1'].

new_system([sys,'/',['PLL Phase',13,'demodulation1']])
set_param([sys,'/',['PLL Phase',13,'demodulation1']],'Location',[31,435,558,610])

add_block('built-in/Inport',[sys,'/',['PLL Phase',13,'demodulation1/in_1']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/in_1']],...
          'position',[45,30,65,50])

add_block('built-in/Product',[sys,'/',['PLL Phase',13,'demodulation1/Multiplier',13,'phase detector']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Multiplier',13,'phase detector']],...
         'position',[140,35,165,55])


%     Subsystem  ['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator'].

new_system([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],'Location',[422,82,872,213])

add_block('built-in/Constant',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Carrier',13,'frequency']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Carrier',13,'frequency']],...
           'Value','Fc',...
                'position',[90,75,110,95])

add_block('built-in/Fcn',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/sin']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/sin']],...
              'Expr','Ac*sin(u[1]*pi2+Ph)',...
                'position',[270,25,395,55])


%     Subsystem  ['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator'].

new_system([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],'Location',[529,321,954,458])

add_block('built-in/Inport',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/in_1']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/in_1']],...
             'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Memory']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Memory']],...
                'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/module']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/module']],...
                'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Reset',13,'integrator']],...
              'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/one']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/one']],...
          'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Sum']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/Sum']],...
         'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/out_1']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator/out_1']],...
               'position',[370,30,390,50])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator')
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
               'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
                'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
          'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
          'Mask Entries','1\/0\/')


%     Finished composite block ['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator'].

set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Module',13,'Integrator']],...
              'position',[195,24,250,56])

add_block('built-in/Sum',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Sum']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Sum']],...
             'position',[150,30,170,50])

add_block('built-in/Inport',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/in_1']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/in_1']],...
                'position',[20,25,40,45])

add_block('built-in/Gain',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Sensitivity']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/Sensitivity']],...
              'Gain','Kc',...
         'position',[65,21,105,49])

add_block('built-in/Outport',[sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/out_1']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator/out_1']],...
              'position',[410,30,430,50])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],[400,40;405,40])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],[175,40;190,40])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],[115,85;125,85;125,45;145,45])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],[110,35;145,35])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],[45,35;60,35])
add_line([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],[255,40;265,40])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],...
           'Mask Display','VCO',...
                'Mask Type','VCO')
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],...
            'Mask Dialogue','Voltage-Controlled Oscilator:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):')
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],...
                'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;')
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],...
         'Mask Help','The VCO block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],...
         'Mask Entries','Ac\/Fc\/1\/Ph\/')


%     Finished composite block ['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator'].

set_param([sys,'/',['PLL Phase',13,'demodulation1/Voltage-controlled',13,'oscilator']],...
           'orientation',2,...
             'position',[175,102,230,138])

add_block('built-in/Outport',[sys,'/',['PLL Phase',13,'demodulation1/out_1']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/out_1']],...
               'position',[465,35,485,55])

add_block('built-in/Gain',[sys,'/',['PLL Phase',13,'demodulation1/Gain']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Gain']],...
              'Gain','G',...
          'position',[405,32,430,58])

add_block('built-in/Transfer Fcn',[sys,'/',['PLL Phase',13,'demodulation1/Lowpass',13,'filter']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Lowpass',13,'filter']],...
                'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[210,24,260,66])

add_block('built-in/Transfer Fcn',[sys,'/',['PLL Phase',13,'demodulation1/Transfer Fcn1']])
set_param([sys,'/',['PLL Phase',13,'demodulation1/Transfer Fcn1']],...
            'Numerator','2*pi',...
          'Denominator','[1 0]',...
               'position',[325,27,360,63])
add_line([sys,'/',['PLL Phase',13,'demodulation1']],[435,45;460,45])
add_line([sys,'/',['PLL Phase',13,'demodulation1']],[170,120;95,120;95,50;135,50])
add_line([sys,'/',['PLL Phase',13,'demodulation1']],[170,45;205,45])
add_line([sys,'/',['PLL Phase',13,'demodulation1']],[70,40;135,40])
add_line([sys,'/',['PLL Phase',13,'demodulation1']],[365,45;400,45])
add_line([sys,'/',['PLL Phase',13,'demodulation1']],[265,45;320,45])
add_line([sys,'/',['PLL Phase',13,'demodulation1']],[290,45;290,120;235,120])
set_param([sys,'/',['PLL Phase',13,'demodulation1']],...
           'Mask Display','PLL\nPDM',...
           'Mask Type','PLL PDM')
set_param([sys,'/',['PLL Phase',13,'demodulation1']],...
          'Mask Dialogue','Phase-Locked Loop Frequency Demodulation:|Filter numerator:|Filter Denominator:|VCO frequency:|VCO Phase:|VCO Amplitude:|Gain at the output:')
set_param([sys,'/',['PLL Phase',13,'demodulation1']],...
         'Mask Translate','Fn=@1;Fd=@2;Fc=@3;Ph=@4;Ac=@5;G=@6;')
set_param([sys,'/',['PLL Phase',13,'demodulation1']],...
         'Mask Help','Phase-Locked Loop Phase Demodulation is to recover the original signal modulated by a carrier frequency. The phase detector used in this block is a multiplier.')
set_param([sys,'/',['PLL Phase',13,'demodulation1']],...
          'Mask Entries','[3.0002,  0, 40002]\/[1, 67.46, 2270.9, 40002]\/100/2/pi\/pi/2\/1\/2\/')


%     Finished composite block ['PLL Phase',13,'demodulation1'].

set_param([sys,'/',['PLL Phase',13,'demodulation1']],...
                'ForeGround',6,...
              'position',[255,230,325,270])


%     Subsystem  ['Phase',13,'Modulation'].

new_system([sys,'/',['Phase',13,'Modulation']])
set_param([sys,'/',['Phase',13,'Modulation']],'Location',[352,181,811,348])

add_block('built-in/Clock',[sys,'/',['Phase',13,'Modulation/Clock']])
set_param([sys,'/',['Phase',13,'Modulation/Clock']],...
          'position',[25,70,45,90])

add_block('built-in/Fcn',[sys,'/',['Phase',13,'Modulation/module']])
set_param([sys,'/',['Phase',13,'Modulation/module']],...
           'Expr','pi2*rem(u[1]*Fc,1)',...
         'position',[90,65,200,95])

add_block('built-in/Constant',[sys,'/',['Phase',13,'Modulation/Initial value']])
set_param([sys,'/',['Phase',13,'Modulation/Initial value']],...
               'Value','Ph',...
                'position',[165,120,185,140])

add_block('built-in/Sum',[sys,'/',['Phase',13,'Modulation/Sum1']])
set_param([sys,'/',['Phase',13,'Modulation/Sum1']],...
           'inputs','+++',...
              'position',[240,62,260,98])

add_block('built-in/Fcn',[sys,'/',['Phase',13,'Modulation/Fcn']])
set_param([sys,'/',['Phase',13,'Modulation/Fcn']],...
               'Expr','Ac*sin(u[1])',...
               'position',[285,65,360,95])

add_block('built-in/Outport',[sys,'/',['Phase',13,'Modulation/out_1']])
set_param([sys,'/',['Phase',13,'Modulation/out_1']],...
               'position',[390,70,410,90])

add_block('built-in/Gain',[sys,'/',['Phase',13,'Modulation/Sensitivity']])
set_param([sys,'/',['Phase',13,'Modulation/Sensitivity']],...
              'Gain','Kc',...
         'position',[115,11,155,39])

add_block('built-in/Inport',[sys,'/',['Phase',13,'Modulation/in_1']])
set_param([sys,'/',['Phase',13,'Modulation/in_1']],...
          'position',[25,15,45,35])
add_line([sys,'/',['Phase',13,'Modulation']],[205,80;235,80])
add_line([sys,'/',['Phase',13,'Modulation']],[190,130;215,130;215,90;235,90])
add_line([sys,'/',['Phase',13,'Modulation']],[365,80;385,80])
add_line([sys,'/',['Phase',13,'Modulation']],[50,80;85,80])
add_line([sys,'/',['Phase',13,'Modulation']],[265,80;280,80])
add_line([sys,'/',['Phase',13,'Modulation']],[160,25;215,25;215,70;235,70])
add_line([sys,'/',['Phase',13,'Modulation']],[50,25;110,25])
set_param([sys,'/',['Phase',13,'Modulation']],...
                'Mask Display','PM',...
         'Mask Type','PM',...
            'Mask Dialogue','Phase modulation:|Amplitude constant:|Carier frequency (Hz):|Sensitivity constant:|Initial phase (rad):')
set_param([sys,'/',['Phase',13,'Modulation']],...
             'Mask Translate','Ac=@1;Fc=@2;Kc=@3;Ph=@4;pi2=2*pi;')
set_param([sys,'/',['Phase',13,'Modulation']],...
          'Mask Help','The PM block cause the phase of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['Phase',13,'Modulation']],...
               'Mask Entries','1\/100/2/pi\/1\/0\/')


%     Finished composite block ['Phase',13,'Modulation'].

set_param([sys,'/',['Phase',13,'Modulation']],...
         'position',[145,232,190,268])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[162,381,780,562])

add_block('built-in/Note',[sys,'/','Subsystem/This block diagram tests frequency modulator//demodulators and phase modulator//demodulator.'])
set_param([sys,'/','Subsystem/This block diagram tests frequency modulator//demodulators and phase modulator//demodulator.'],...
           'position',[290,15,295,20])

add_block('built-in/Note',[sys,'/','Subsystem/The yellow signal is the inputed signal to be modulated.'])
set_param([sys,'/','Subsystem/The yellow signal is the inputed signal to be modulated.'],...
                'ForeGround',5,...
              'position',[175,40,180,45])

add_block('built-in/Note',[sys,'/','Subsystem/The magenta signal is the PLL phase demodulator output'])
set_param([sys,'/','Subsystem/The magenta signal is the PLL phase demodulator output'],...
            'ForeGround',6,...
              'position',[180,115,185,120])

add_block('built-in/Note',[sys,'/','Subsystem/The demodulated signal matches the input signal with some time delay. The delay is caused by filters.'])
set_param([sys,'/','Subsystem/The demodulated signal matches the input signal with some time delay. The delay is caused by filters.'],...
            'position',[310,140,315,145])

add_block('built-in/Note',[sys,'/','Subsystem/The red signal is the discriminant frequency demodulator output'])
set_param([sys,'/','Subsystem/The red signal is the discriminant frequency demodulator output'],...
                'ForeGround',2,...
              'position',[195,90,200,95])

add_block('built-in/Note',[sys,'/','Subsystem/The green signal is the PLL frequency demodulator output'])
set_param([sys,'/','Subsystem/The green signal is the PLL frequency demodulator output'],...
                'ForeGround',3,...
              'position',[180,65,185,70])
set_param([sys,'/','Subsystem'],...
          'Mask Display','?')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
               'hide name',0,...
               'Drop Shadow',4,...
             'position',[455,235,485,271])
add_line(sys,[195,85;255,85])
add_line(sys,[80,85;140,85])
add_line(sys,[335,85;380,85])
add_line(sys,[425,90;450,90])
add_line(sys,[100,85;100,45;360,45;360,75;380,75])
add_line(sys,[220,85;220,165;255,165])
add_line(sys,[340,165;355,165;355,95;380,95])
add_line(sys,[330,250;365,250;365,105;380,105])
add_line(sys,[195,250;250,250])
add_line(sys,[100,85;100,250;140,250])

drawnow

% Return any arguments.
if (nargin | nargout)
    % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
else
 drawnow % Flash up the model and execute load callback
end
