function [ret,x0,str,ts,xts]=tstfskcd(t,x,u,flag);
%TSTFSKCD	is the M-file description of the SIMULINK system named TSTFSKCD.
%	The block-diagram can be displayed by typing: TSTFSKCD.
%
%	SYS=TSTFSKCD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTFSKCD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTFSKCD with a FLAG of zero:
%	[SIZES]=TSTFSKCD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[59,99,745,383])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;[num,den]=butter(4,100/pi*ts);td=.2;M=64;');

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[560,68,595,117])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','20*td\/-1\/M\/''y-/g--/r-/m:/w-/r:/b+''\/td\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'position',[615,76,645,114])


%     Subsystem  ['K-step',13,'delay'].

new_system([sys,'/',['K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay']],'Location',[4,432,349,702])

add_block('built-in/Inport',[sys,'/',['K-step',13,'delay/in_1']])
set_param([sys,'/',['K-step',13,'delay/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['K-step',13,'delay/out_1']])
set_param([sys,'/',['K-step',13,'delay/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Filter',[sys,'/',['K-step',13,'delay/K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Switch',[sys,'/',['K-step',13,'delay/Switch']])
set_param([sys,'/',['K-step',13,'delay/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant']])
set_param([sys,'/',['K-step',13,'delay/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Clock',[sys,'/',['K-step',13,'delay/Clock']])
set_param([sys,'/',['K-step',13,'delay/Clock']],...
		'position',[75,145,95,165])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant1']])
set_param([sys,'/',['K-step',13,'delay/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Relational Operator',[sys,'/',['K-step',13,'delay/Relational',13,'Operator']])
set_param([sys,'/',['K-step',13,'delay/Relational',13,'Operator']],...
		'position',[150,168,180,192])
add_line([sys,'/',['K-step',13,'delay']],[300,130;320,130])
add_line([sys,'/',['K-step',13,'delay']],[45,90;55,90])
add_line([sys,'/',['K-step',13,'delay']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['K-step',13,'delay']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['K-step',13,'delay']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['K-step',13,'delay']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['K-step',13,'delay']],[185,180;220,180;220,130;265,130])
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay',...
		'Mask Dialogue','Output is K steps delay of the input signal.|Delay steps (integer):|Sample time (sec):|Inital condition:')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;',...
		'Mask Help','This block equivalent to K unit delay.',...
		'Mask Entries','1\/td\/0\/')


%     Finished composite block ['K-step',13,'delay'].

set_param([sys,'/',['K-step',13,'delay']],...
		'BackGround',5,...
		'position',[285,13,340,57])


%     Subsystem  ['QASK',13,'decode'].

new_system([sys,'/',['QASK',13,'decode']])
set_param([sys,'/',['QASK',13,'decode']],'Location',[57,374,831,674])

add_block('built-in/Abs',[sys,'/',['QASK',13,'decode/Abs1']])
set_param([sys,'/',['QASK',13,'decode/Abs1']],...
		'position',[325,38,355,62])

add_block('built-in/Constant',[sys,'/',['QASK',13,'decode/Shift key2']])
set_param([sys,'/',['QASK',13,'decode/Shift key2']],...
		'BackGround',5,...
		'position',[325,114,350,136])

add_block('built-in/Constant',[sys,'/',['QASK',13,'decode/Shift key1']])
set_param([sys,'/',['QASK',13,'decode/Shift key1']],...
		'Value','sftx',...
		'position',[220,89,245,111])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'decode/Minimum1']])
set_param([sys,'/',['QASK',13,'decode/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,40,445,60])

add_block('built-in/Constant',[sys,'/',['QASK',13,'decode/Shift key']])
set_param([sys,'/',['QASK',13,'decode/Shift key']],...
		'Value','sfty',...
		'position',[225,214,250,236])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'decode/Minimum']])
set_param([sys,'/',['QASK',13,'decode/Minimum']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,165,450,185])

add_block('built-in/Abs',[sys,'/',['QASK',13,'decode/Abs']])
set_param([sys,'/',['QASK',13,'decode/Abs']],...
		'position',[340,163,370,187])

add_block('built-in/Sum',[sys,'/',['QASK',13,'decode/Sum2']])
set_param([sys,'/',['QASK',13,'decode/Sum2']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[290,158,310,187])

add_block('built-in/Sum',[sys,'/',['QASK',13,'decode/Sum1']])
set_param([sys,'/',['QASK',13,'decode/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[280,33,300,62])

add_block('built-in/Sum',[sys,'/',['QASK',13,'decode/Sum4']])
set_param([sys,'/',['QASK',13,'decode/Sum4']],...
		'ForeGround',2,...
		'position',[470,58,490,87])

add_block('built-in/Outport',[sys,'/',['QASK',13,'decode/out_1']])
set_param([sys,'/',['QASK',13,'decode/out_1']],...
		'position',[685,80,705,100])

add_block('built-in/Saturation',[sys,'/',['QASK',13,'decode/Saturation']])
set_param([sys,'/',['QASK',13,'decode/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','N-1',...
		'position',[630,78,660,102])

add_block('built-in/Sum',[sys,'/',['QASK',13,'decode/Sum3']])
set_param([sys,'/',['QASK',13,'decode/Sum3']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[580,73,600,102])


%     Subsystem  ['QASK',13,'decode/2-D Table'].

new_system([sys,'/',['QASK',13,'decode/2-D Table']])
set_param([sys,'/',['QASK',13,'decode/2-D Table']],'Location',[436,148,718,302])

add_block('built-in/Mux',[sys,'/',['QASK',13,'decode/2-D Table/Mux']])
set_param([sys,'/',['QASK',13,'decode/2-D Table/Mux']],...
		'inputs','2',...
		'position',[90,46,120,79])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'decode/2-D Table/S-function']])
set_param([sys,'/',['QASK',13,'decode/2-D Table/S-function']],...
		'function name','sftable2',...
		'parameters','xindex, yindex, table',...
		'position',[140,52,190,78])

add_block('built-in/Inport',[sys,'/',['QASK',13,'decode/2-D Table/x0']])
set_param([sys,'/',['QASK',13,'decode/2-D Table/x0']],...
		'position',[20,25,40,45])

add_block('built-in/Outport',[sys,'/',['QASK',13,'decode/2-D Table/table out']])
set_param([sys,'/',['QASK',13,'decode/2-D Table/table out']],...
		'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/',['QASK',13,'decode/2-D Table/y0']])
set_param([sys,'/',['QASK',13,'decode/2-D Table/y0']],...
		'Port','2',...
		'position',[20,80,40,100])
add_line([sys,'/',['QASK',13,'decode/2-D Table']],[125,65;135,65])
add_line([sys,'/',['QASK',13,'decode/2-D Table']],[45,35;65,35;65,55;85,55])
add_line([sys,'/',['QASK',13,'decode/2-D Table']],[195,65;210,65])
add_line([sys,'/',['QASK',13,'decode/2-D Table']],[45,90;65,90;65,70;85,70])
set_param([sys,'/',['QASK',13,'decode/2-D Table']],...
		'Mask Display','plot(-10,-10,110,110,[90,50,10],[90,40,30],[90,50,10],[50,26,20],[90,50,10],[22,13,10])',...
		'Mask Type','2-D Table Lookup')
set_param([sys,'/',['QASK',13,'decode/2-D Table']],...
		'Mask Dialogue','Two Dimensional Table Lookup\nThe first input corresponds to X Index and the second input corresponds to the Y Index|X Index|Y Index|Table')
set_param([sys,'/',['QASK',13,'decode/2-D Table']],...
		'Mask Translate','xindex=@1; yindex=@2; table=@3; sftab2chk(xindex,yindex,table);')
set_param([sys,'/',['QASK',13,'decode/2-D Table']],...
		'Mask Help','This block returns a linearly interpolated intersection from the table using the X index (which corresponds to the rows of the table) and the Y index (which corresponds to the columns of the table).  Extrapolation is used.')
set_param([sys,'/',['QASK',13,'decode/2-D Table']],...
		'Mask Entries','x\/y\/tab\/')


%     Finished composite block ['QASK',13,'decode/2-D Table'].

set_param([sys,'/',['QASK',13,'decode/2-D Table']],...
		'position',[515,68,545,92])

add_block('built-in/Sum',[sys,'/',['QASK',13,'decode/Sum5']])
set_param([sys,'/',['QASK',13,'decode/Sum5']],...
		'ForeGround',2,...
		'position',[470,153,490,182])

add_block('built-in/Inport',[sys,'/',['QASK',13,'decode/in_2']])
set_param([sys,'/',['QASK',13,'decode/in_2']],...
		'Port','2',...
		'position',[60,155,80,175])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'decode/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'decode/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[135,149,170,181])

add_block('built-in/Inport',[sys,'/',['QASK',13,'decode/in_1']])
set_param([sys,'/',['QASK',13,'decode/in_1']],...
		'position',[60,30,80,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'decode/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'decode/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[135,24,170,56])
add_line([sys,'/',['QASK',13,'decode']],[175,40;275,40])
add_line([sys,'/',['QASK',13,'decode']],[175,165;285,165])
add_line([sys,'/',['QASK',13,'decode']],[85,165;130,165])
add_line([sys,'/',['QASK',13,'decode']],[495,75;510,75])
add_line([sys,'/',['QASK',13,'decode']],[355,125;560,125;560,95;575,95])
add_line([sys,'/',['QASK',13,'decode']],[450,125;450,80;465,80])
add_line([sys,'/',['QASK',13,'decode']],[450,125;450,160;465,160])
add_line([sys,'/',['QASK',13,'decode']],[495,170;500,170;510,85])
add_line([sys,'/',['QASK',13,'decode']],[455,175;465,175])
add_line([sys,'/',['QASK',13,'decode']],[450,50;450,65;465,65])
add_line([sys,'/',['QASK',13,'decode']],[605,90;625,90])
add_line([sys,'/',['QASK',13,'decode']],[550,80;575,80])
add_line([sys,'/',['QASK',13,'decode']],[665,90;680,90])
add_line([sys,'/',['QASK',13,'decode']],[360,50;380,50])
add_line([sys,'/',['QASK',13,'decode']],[305,50;320,50])
add_line([sys,'/',['QASK',13,'decode']],[250,100;255,100;255,55;275,55])
add_line([sys,'/',['QASK',13,'decode']],[255,225;260,225;260,180;285,180])
add_line([sys,'/',['QASK',13,'decode']],[315,175;335,175])
add_line([sys,'/',['QASK',13,'decode']],[375,175;380,175])
add_line([sys,'/',['QASK',13,'decode']],[85,40;130,40])
set_param([sys,'/',['QASK',13,'decode']],...
		'Mask Display','MQASK\ndecode',...
		'Mask Type','MASK Demodulation')
set_param([sys,'/',['QASK',13,'decode']],...
		'Mask Dialogue','M-ary Amplitude Shift Keying Demodulation:|QASK M-ary number (outputs are in range (0, M-1):|Symbol interval and decision offset timing:')
set_param([sys,'/',['QASK',13,'decode']],...
		'Mask Translate','N=@1;td=@2;Ac=1;sftx=[1 -1 3 -3 5 -5 7 -7 9 -9 11 -11 13 -13 15 -15];sftx=sftx(1:2*ceil(sqrt(N)/2));sfty=sftx;if N==8,sfty=sfty(1:2);end;sftx=sftx/max(sftx)*Ac;sfty=sfty/max(sfty)*Ac;tab=qaskdeco(length(sftx),length(sfty),''fetch'');x=[1:length(sftx)];y=[1:length(sfty)];')
set_param([sys,'/',['QASK',13,'decode']],...
		'Mask Help','This decodes maximum amplitude 1 in-phase (1st input) and quadreture (2nd input) signal onto a integer in range [0, M-1]. The decision is at the begining of each symbol interval. The offset of the symbol interval can be set as the second element of the interval. The default offset is 0.')
set_param([sys,'/',['QASK',13,'decode']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['QASK',13,'decode'].

set_param([sys,'/',['QASK',13,'decode']],...
		'position',[440,85,515,125])


%     Subsystem  ['QASK',13,'code'].

new_system([sys,'/',['QASK',13,'code']])
set_param([sys,'/',['QASK',13,'code']],'Location',[214,372,642,541])

add_block('built-in/Inport',[sys,'/',['QASK',13,'code/in_1']])
set_param([sys,'/',['QASK',13,'code/in_1']],...
		'position',[45,30,65,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'code/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'code/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[110,24,145,56])

add_block('built-in/Outport',[sys,'/',['QASK',13,'code/out_1']])
set_param([sys,'/',['QASK',13,'code/out_1']],...
		'position',[325,30,345,50])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'code/s-x axis']])
set_param([sys,'/',['QASK',13,'code/s-x axis']],...
		'Input_Values','z',...
		'Output_Values','x',...
		'position',[245,25,280,55])

add_block('built-in/Outport',[sys,'/',['QASK',13,'code/out_2']])
set_param([sys,'/',['QASK',13,'code/out_2']],...
		'Port','2',...
		'position',[325,95,345,115])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'code/c-y axis']])
set_param([sys,'/',['QASK',13,'code/c-y axis']],...
		'Input_Values','z',...
		'Output_Values','y',...
		'position',[245,90,280,120])
add_line([sys,'/',['QASK',13,'code']],[285,40;320,40])
add_line([sys,'/',['QASK',13,'code']],[285,105;320,105])
add_line([sys,'/',['QASK',13,'code']],[150,40;240,40])
add_line([sys,'/',['QASK',13,'code']],[185,40;185,105;240,105])
add_line([sys,'/',['QASK',13,'code']],[70,40;105,40])
set_param([sys,'/',['QASK',13,'code']],...
		'Mask Display','MQASK\ncode',...
		'Mask Type','MQASK')
set_param([sys,'/',['QASK',13,'code']],...
		'Mask Dialogue','M-ary Amplitude Shift Keying Modulation:|M-ary number (input are integers in range [0, M-1]):|Input symbol interval (second):')
set_param([sys,'/',['QASK',13,'code']],...
		'Mask Translate','N=@1;Ac=1;td=@2;z=[[1:N];[1:N]];z=z(:);[x,y]=qaskenco(z,N);z=z-1.5;z=[z(2:2*N);N-.5];x=x/max(x);y=y/max(y);')
set_param([sys,'/',['QASK',13,'code']],...
		'Mask Help','This block a digital signal onto in-phase and quadratic two components. The input signal is held in the input symbol interval. The interval can be a two elements vector with the first element being offset. The default offset is zero. The first and second are in-phase and quandratic components respectively. The maximum amplitude of the outputs are 1.')
set_param([sys,'/',['QASK',13,'code']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['QASK',13,'code'].

set_param([sys,'/',['QASK',13,'code']],...
		'position',[115,84,185,126])


%     Subsystem  'QAM discr-filt'.

new_system([sys,'/','QAM discr-filt'])
set_param([sys,'/','QAM discr-filt'],'Location',[302,478,834,743])

add_block('built-in/Fcn',[sys,'/','QAM discr-filt/Fcn'])
set_param([sys,'/','QAM discr-filt/Fcn'],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])

add_block('built-in/Fcn',[sys,'/','QAM discr-filt/Fcn1'])
set_param([sys,'/','QAM discr-filt/Fcn1'],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Note',[sys,'/','QAM discr-filt/Ref: Hambley: An Intro to Comm. Systems. pp72'])
set_param([sys,'/','QAM discr-filt/Ref: Hambley: An Intro to Comm. Systems. pp72'],...
		'position',[250,305,255,310])

add_block('built-in/Product',[sys,'/','QAM discr-filt/Product'])
set_param([sys,'/','QAM discr-filt/Product'],...
		'position',[355,47,380,78])

add_block('built-in/Product',[sys,'/','QAM discr-filt/Product1'])
set_param([sys,'/','QAM discr-filt/Product1'],...
		'position',[355,112,380,143])

add_block('built-in/Sum',[sys,'/','QAM discr-filt/Sum2'])
set_param([sys,'/','QAM discr-filt/Sum2'],...
		'position',[430,90,450,110])

add_block('built-in/Outport',[sys,'/','QAM discr-filt/out_1'])
set_param([sys,'/','QAM discr-filt/out_1'],...
		'position',[490,90,510,110])

add_block('built-in/Inport',[sys,'/','QAM discr-filt/in_1'])
set_param([sys,'/','QAM discr-filt/in_1'],...
		'position',[160,30,180,50])

add_block('built-in/Inport',[sys,'/','QAM discr-filt/in_2'])
set_param([sys,'/','QAM discr-filt/in_2'],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Gain',[sys,'/','QAM discr-filt/Gain'])
set_param([sys,'/','QAM discr-filt/Gain'],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Clock',[sys,'/','QAM discr-filt/Clock'])
set_param([sys,'/','QAM discr-filt/Clock'],...
		'position',[80,85,100,105])
add_line([sys,'/','QAM discr-filt'],[455,100;485,100])
add_line([sys,'/','QAM discr-filt'],[330,70;350,70])
add_line([sys,'/','QAM discr-filt'],[185,40;335,40;335,55;350,55])
add_line([sys,'/','QAM discr-filt'],[330,120;350,120])
add_line([sys,'/','QAM discr-filt'],[185,155;330,155;330,135;350,135])
add_line([sys,'/','QAM discr-filt'],[385,65;400,65;400,95;425,95])
add_line([sys,'/','QAM discr-filt'],[385,130;400,130;400,105;425,105])
add_line([sys,'/','QAM discr-filt'],[105,95;125,95])
add_line([sys,'/','QAM discr-filt'],[185,95;200,95;200,70;225,70])
add_line([sys,'/','QAM discr-filt'],[200,95;200,120;225,120])
set_param([sys,'/','QAM discr-filt'],...
		'Mask Display','QM DSB\nAM',...
		'Mask Type','Quadrature Multiplexed DSB-SC AM')
set_param([sys,'/','QAM discr-filt'],...
		'Mask Dialogue','Quadrature multiplexed double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency (Hz):|Initial phase (rad):|Sample time:')
set_param([sys,'/','QAM discr-filt'],...
		'Mask Translate','Am=@1;Fc=@2*2*pi;Ph=@3;ts=@4;')
set_param([sys,'/','QAM discr-filt'],...
		'Mask Help','The Quadratic Multiplexed Double-Sideband-Supressed-Carrier AM block causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. There are two input signal being modulated at the same time by using two orthogonal sinusoidal carriers.')
set_param([sys,'/','QAM discr-filt'],...
		'Mask Entries','1\/100/2/pi\/0\/ts\/')


%     Finished composite block 'QAM discr-filt'.

set_param([sys,'/','QAM discr-filt'],...
		'position',[210,84,290,126])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'inputs','2',...
		'position',[460,168,495,217])


%     Subsystem  'QADM discr-filt'.

new_system([sys,'/','QADM discr-filt'])
set_param([sys,'/','QADM discr-filt'],'Location',[456,480,1000,743])

add_block('built-in/Filter',[sys,'/','QADM discr-filt/Filter1'])
set_param([sys,'/','QADM discr-filt/Filter1'],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,166,445,204])

add_block('built-in/Filter',[sys,'/','QADM discr-filt/Filter'])
set_param([sys,'/','QADM discr-filt/Filter'],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Gain',[sys,'/','QADM discr-filt/Gain1'])
set_param([sys,'/','QADM discr-filt/Gain1'],...
		'Gain','2',...
		'position',[270,118,295,142])

add_block('built-in/Inport',[sys,'/','QADM discr-filt/in_1'])
set_param([sys,'/','QADM discr-filt/in_1'],...
		'position',[230,120,250,140])

add_block('built-in/Note',[sys,'/','QADM discr-filt/Ref: Hambley: An Intro to Comm. Systems. pp72'])
set_param([sys,'/','QADM discr-filt/Ref: Hambley: An Intro to Comm. Systems. pp72'],...
		'position',[285,280,290,285])

add_block('built-in/Fcn',[sys,'/','QADM discr-filt/Fcn'])
set_param([sys,'/','QADM discr-filt/Fcn'],...
		'Expr','cos(u[1]+Ph)',...
		'position',[205,55,300,85])

add_block('built-in/Fcn',[sys,'/','QADM discr-filt/Fcn1'])
set_param([sys,'/','QADM discr-filt/Fcn1'],...
		'Expr','sin(u[1]+Ph)',...
		'position',[200,175,300,205])

add_block('built-in/Product',[sys,'/','QADM discr-filt/Product'])
set_param([sys,'/','QADM discr-filt/Product'],...
		'position',[330,62,355,93])

add_block('built-in/Product',[sys,'/','QADM discr-filt/Product1'])
set_param([sys,'/','QADM discr-filt/Product1'],...
		'position',[330,167,355,198])

add_block('built-in/Outport',[sys,'/','QADM discr-filt/out_2'])
set_param([sys,'/','QADM discr-filt/out_2'],...
		'Port','2',...
		'position',[480,175,500,195])

add_block('built-in/Outport',[sys,'/','QADM discr-filt/out_1'])
set_param([sys,'/','QADM discr-filt/out_1'],...
		'position',[480,70,500,90])

add_block('built-in/Gain',[sys,'/','QADM discr-filt/Gain'])
set_param([sys,'/','QADM discr-filt/Gain'],...
		'Gain','Fc',...
		'position',[110,111,160,149])

add_block('built-in/Clock',[sys,'/','QADM discr-filt/Clock'])
set_param([sys,'/','QADM discr-filt/Clock'],...
		'position',[60,120,80,140])
add_line([sys,'/','QADM discr-filt'],[300,130;305,130;305,175;325,175])
add_line([sys,'/','QADM discr-filt'],[300,130;305,130;305,85;325,85])
add_line([sys,'/','QADM discr-filt'],[255,130;265,130])
add_line([sys,'/','QADM discr-filt'],[165,130;185,130;185,70;200,70])
add_line([sys,'/','QADM discr-filt'],[185,125;195,190])
add_line([sys,'/','QADM discr-filt'],[305,70;325,70])
add_line([sys,'/','QADM discr-filt'],[305,190;325,190])
add_line([sys,'/','QADM discr-filt'],[360,80;385,80])
add_line([sys,'/','QADM discr-filt'],[450,80;475,80])
add_line([sys,'/','QADM discr-filt'],[360,185;385,185])
add_line([sys,'/','QADM discr-filt'],[450,185;475,185])
add_line([sys,'/','QADM discr-filt'],[85,130;105,130])
set_param([sys,'/','QADM discr-filt'],...
		'Mask Display','QM\nDSB-SC\nADM',...
		'Mask Type','Quadrature Demultiplexed DSB-SC AM')
set_param([sys,'/','QADM discr-filt'],...
		'Mask Dialogue','Quadrature Demultiplexed Double-Sideband Suppressed-Carrier Amplitude Demodulation:|Carrier frequency (Hz):|Low-pass filter numerator:|Low-pass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/','QADM discr-filt'],...
		'Mask Translate','Fc=@1*2*pi;num=@2;den=@3;Ph=@4;ts=@5;')
set_param([sys,'/','QADM discr-filt'],...
		'Mask Help','The Quadratic Demultiplexed Double-Sideband Supressed-Carrier Amplitude Demodulation block demodulates the QM-DSB-SC-AM signal using quadratic duplex method. The filter to be speficed by the users is a lowpass filter which should pass the signal message and eliminate the carrier signal.')
set_param([sys,'/','QADM discr-filt'],...
		'Mask Entries','100/2/pi\/num\/den\/0\/ts\/')


%     Finished composite block 'QADM discr-filt'.

set_param([sys,'/','QADM discr-filt'],...
		'position',[315,84,395,126])


%     Subsystem  'plot'.

new_system([sys,'/','plot'])
set_param([sys,'/','plot'],'Location',[165,242,460,428])

add_block('built-in/Inport',[sys,'/','plot/in_1'])
set_param([sys,'/','plot/in_1'],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/','plot/in_2'])
set_param([sys,'/','plot/in_2'],...
		'Port','2',...
		'position',[20,115,40,135])

add_block('built-in/Mux',[sys,'/','plot/Mux'])
set_param([sys,'/','plot/Mux'],...
		'inputs','2',...
		'position',[65,70,100,105])

add_block('built-in/S-Function',[sys,'/','plot/Plot1'])
set_param([sys,'/','plot/Plot1'],...
		'function name','eyediasi',...
		'parameters','time_range, boundary, kept_length, eye_line, scatter_line, two_d_line',...
		'position',[130,70,200,110])
add_line([sys,'/','plot'],[40,65;45,65;45,80;60,80])
add_line([sys,'/','plot'],[45,125;50,125;60,95])
add_line([sys,'/','plot'],[105,90;125,90])
set_param([sys,'/','plot'],...
		'Mask Display','Eye/Scatter\nPlot',...
		'Mask Type','Eye-Pattern/Scatter Plot')
set_param([sys,'/','plot'],...
		'Mask Dialogue','Eye-Pattern/Scatter/X-Y Plot.|Eye-pattern plot time frame:|Lower and upper bound of in-coming signal:|Length of kept traces:|Line-type for eye-pattern plot (0 for no such plot):|Line-type for scatter plot (0 for no such plot):|Line-type for X-Y plot (0 for no such plot):')
set_param([sys,'/','plot'],...
		'Mask Translate','time_range=@1;boundary=@2;kept_length=@3;eye_line=@4;scatter_line=@5;two_d_line=@6;')
set_param([sys,'/','plot'],...
		'Mask Help','This plot may open one-two-three plots at the same time by giving parameters. The scatter plot point is selected by the raising edge of a trigger signal.')
set_param([sys,'/','plot'],...
		'Mask Entries','2*td\/[-1.2 1.2]\/10\/''r-/g--/b-.''\/''rx/y+''\/''y-/r-''\/')


%     Finished composite block 'plot'.

set_param([sys,'/','plot'],...
		'position',[530,185,605,240])


%     Subsystem  ['Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Pulses deivide',13,'same sample time1']],...
		'Mask Entries','td\/1\/-ts\/')


%     Finished composite block ['Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Pulses deivide',13,'same sample time1']],...
		'position',[350,221,410,259])


%     Subsystem  'Sampled read'.

new_system([sys,'/','Sampled read'])
set_param([sys,'/','Sampled read'],'Location',[355,528,737,675])


%     Subsystem  ['Sampled read/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/','Sampled read/out_1'])
set_param([sys,'/','Sampled read/out_1'],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/','Sampled read/Message source'])
set_param([sys,'/','Sampled read/Message source'],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;',...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])
add_line([sys,'/','Sampled read'],[260,75;290,75])
add_line([sys,'/','Sampled read'],[115,75;175,75])
set_param([sys,'/','Sampled read'],...
		'Mask Display','Sampled\nread\nvariable',...
		'Mask Type','Read from a variable at given sample time.')
set_param([sys,'/','Sampled read'],...
		'Mask Dialogue','Read from a workspace variable at a given interval:|Variable (column_number=block_output_length):|Output symbol interval:|Cyclic read (1) or amend zero (0):|Initial output:')
set_param([sys,'/','Sampled read'],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;')
set_param([sys,'/','Sampled read'],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable row, the block will cyclically output from the first row of the the variable or output zero based on the cyclic read entree.')
set_param([sys,'/','Sampled read'],...
		'Mask Entries','randint(300,1,M)\/td\/1\/10\/')


%     Finished composite block 'Sampled read'.

set_param([sys,'/','Sampled read'],...
		'BackGround',5,...
		'position',[10,83,80,127])
add_line(sys,[600,95;610,95])
add_line(sys,[85,105;110,105])
add_line(sys,[90,105;90,35;280,35])
add_line(sys,[345,35;525,35;525,80;555,80])
add_line(sys,[520,105;555,105])
add_line(sys,[295,105;310,105])
add_line(sys,[400,95;435,95])
add_line(sys,[400,115;435,115])
add_line(sys,[190,95;205,95])
add_line(sys,[190,115;205,115])
add_line(sys,[415,95;415,180;455,180])
add_line(sys,[400,115;400,205;455,205])
add_line(sys,[500,195;500,200;525,200])
add_line(sys,[415,240;465,240;465,225;525,225])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
