function [ret,x0,str,ts,xts]=tsthamsq(t,x,u,flag);
%TSTHAMSQ	is the M-file description of the SIMULINK system named TSTHAMSQ.
%	The block-diagram can be displayed by typing: TSTHAMSQ.
%
%	SYS=TSTHAMSQ(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTHAMSQ to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTHAMSQ with a FLAG of zero:
%	[SIZES]=TSTHAMSQ([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[65,317,661,533])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','N_ham_demo=7;K_ham_demo=4;M_ham_demo=3;GWN=.01;');


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate1'],[105,65;125,65])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[40,70;60,70])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','1\/20\/2\/1/K_ham_demo\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[500,8,580,52])


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(200,1)\/1/K_ham_demo\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[20,53,100,97])


%     Subsystem  ['Binary sequence',13,'Hamming decode'].

new_system([sys,'/',['Binary sequence',13,'Hamming decode']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],'Location',[284,88,882,241])


%     Subsystem  ['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode'].

new_system([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],'Location',[267,160,850,320])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/out_1']],...
		'position',[535,90,555,110])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation2']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/Sum',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Sum']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[520,100;530,100])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[445,100;450,100])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[405,100;410,100])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[330,100;335,100])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[55,45;95,45])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[205,45;220,45])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],[130,45;135,45])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'Mask Display','Hamming\ndecode',...
		'Mask Type','Hamming code')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'Mask Dialogue','Single error-correction Hamming decode. For M>2 integer, N=2^M-1; K=2^M-M-1.|Code word length N:|Message length K or M-degree primitive polynomial:')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,p=k;k=n-length(p)+1;else,p=gfprimdf(n-k);end;[H,G]=hammgen(n-k,p);trt=htruthtb(G);[n,m]=size(G);G=[zeros(n,m-n),eye(n)];')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'Mask Help','This block decodes code word binary vecotr using Hamming coding method. The code word has length N=2^M-1. The message has length K=2^M-M-1. M is an integernot less than 3. The second entree could be a M-degreee primitive polynomail, which can be found by using commands gfprimdf or gfprimfd. This block takes N-ary code word input and results K-ary message output.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'Mask Entries','n\/p\/')


%     Finished composite block ['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode'].

set_param([sys,'/',['Binary sequence',13,'Hamming decode/Binary-vector',13,'Hamming decode']],...
		'position',[310,15,370,55])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/sequential',13,'message-out']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/sequential',13,'message-out']],...
		'position',[540,30,560,50])


%     Subsystem  ['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'Hamming decode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[440,28,500,72])


%     Subsystem  ['Binary sequence',13,'Hamming decode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/in_1']],...
		'position',[10,55,30,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[65,80;75,80])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[35,65;75,65])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'Hamming decode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'Hamming decode/Register-shift']],...
		'BackGround',3,...
		'position',[205,25,260,65])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming decode/sequential',13,'code-word-in']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/sequential',13,'code-word-in']],...
		'position',[120,25,140,45])


%     Subsystem  ['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n, k]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'Hamming decode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[45,81,105,119])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming decode/Demux']],...
		'outputs','2',...
		'position',[130,80,170,115])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[175,105;410,105;410,65;435,65])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[505,40;535,40])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[110,100;125,100])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[145,35;200,35])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[375,35;435,35])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[265,35;305,35])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[265,55;280,55;280,90;400,90;400,50;435,50])
add_line([sys,'/',['Binary sequence',13,'Hamming decode']],[175,90;180,90;180,55;200,55])
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Hamming de',...
		'Mask Type','Sequence I/O Hamming decode')
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'Mask Dialogue','Single error-correction Hamming decode with codeword length N=2^M-1, message length K=2^M-M-1, where M is a >=3 integer.|Codeword length N:|Message length K, or M-degree primitive polynomial:|Input sample time T_out (sec):')
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,p=k;k=n-length(p)+1;else,p=gfprimdf(n-k);end;samp=@3;[x,y]=codeicon(4);')
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'Mask Help','This block decodes length N binary codeword into length K message using Hamming code. The block uses sequential input/output format. The input sequence sample time is K*T_out/N. The block causes a K*T_out delay. Use function GFPRIMDF or GFPRIMFD to find M-degree\nprimitive polynomials.')
set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'Mask Entries','7\/K_ham_demo\/1/K_ham_demo\/')


%     Finished composite block ['Binary sequence',13,'Hamming decode'].

set_param([sys,'/',['Binary sequence',13,'Hamming decode']],...
		'hide name',0,...
		'position',[375,33,455,77])


%     Subsystem  ['Binary sequence',13,'Hamming encode'].

new_system([sys,'/',['Binary sequence',13,'Hamming encode']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],'Location',[68,475,675,670])


%     Subsystem  ['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode'].

new_system([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],[245,45;285,45])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],[140,45;175,45])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],[55,45;105,45])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'Mask Display','Hamming\nencode',...
		'Mask Type','Hamming encoding')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'Mask Dialogue','Single error-correction Hamming encode. For integer M>2, N=2^M-1; K=2^M-M-1.|Code-word length N:|Message length K or M-degree primitive polynomial:')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,p=k; k=n-length(k)+1;else,p=gfprimdf(n-k);end;[h,G]=hammgen(n-k,p);G=G'';')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'Mask Help','This block encodes the input binary signal using Hamming coding method.  The code length is N=2^M-1. The message length should be K=2^M-M-1. M is a integer no less than 3. The second entree of this block could also be a M-degree primitive polynomial, which can be found by using commands gfprimfd or gfprimdf. This block takes K-ary binary message input and results N-ary binary code-word output.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'Mask Entries','n\/p\/')


%     Finished composite block ['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode'].

set_param([sys,'/',['Binary sequence',13,'Hamming encode/Binary-vector',13,'Hamming encode']],...
		'position',[330,25,395,65])


%     Subsystem  ['Binary sequence',13,'Hamming encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'Hamming encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'Hamming encode/Register-shift']],...
		'BackGround',3,...
		'position',[230,36,285,69])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/in_1']],...
		'position',[55,35,75,55])


%     Subsystem  ['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k, n]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'Hamming encode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[45,91,105,129])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Demux']],...
		'outputs','2',...
		'position',[140,90,180,125])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/out_1']],...
		'position',[575,40,595,60])


%     Subsystem  ['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'Mask Entries','n\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'Hamming encode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[445,38,505,72])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'Hamming encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'Hamming encode/out_2']],...
		'Port','2',...
		'position',[535,55,555,75])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[185,115;420,115;420,65;440,65])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[185,100;195,100;195,60;225,60])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[110,110;135,110])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[290,60;305,60;305,95;410,95;410,55;440,55])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[80,45;225,45])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[290,45;325,45])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[400,45;440,45])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[510,50;570,50])
add_line([sys,'/',['Binary sequence',13,'Hamming encode']],[510,65;530,65])
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Hamming en',...
		'Mask Type','Sequence I/O Hamming encode')
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'Mask Dialogue','Single error-correction Hamming encode with codeword length N=2^M-1, message length K=2^M-M-1, where M is a >=3 integer.|Codeword length N:|Message length K, or M-degree primitive polynomial:|Input sample time T_in (sec):')
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'Mask Translate','n=@1;k=@2;samp=@3;if length(k)>1,p=k;k=n-length(k)+1;else,p=gfprimdf(n-k);end;[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'Mask Help','This block encodes length K binary message into length N binary codeword using Hamming code. The block uses sequential input/output format. The output sequence sample time is K*T_in/N. The block causes a K*T_in delay. The second outport outputs a pulse when Kth message signal is received. Use function GFPRIMDF or GFPRIMFD to find M-degree\nprimitive polynomials.')
set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'Mask Entries','N_ham_demo\/K_ham_demo\/1/K_ham_demo\/')


%     Finished composite block ['Binary sequence',13,'Hamming encode'].

set_param([sys,'/',['Binary sequence',13,'Hamming encode']],...
		'hide name',0,...
		'position',[160,53,240,97])


%     Subsystem  ['Binary error',13,'channel'].

new_system([sys,'/',['Binary error',13,'channel']])
set_param([sys,'/',['Binary error',13,'channel']],'Location',[259,203,738,408])

add_block('built-in/Inport',[sys,'/',['Binary error',13,'channel/in_1']])
set_param([sys,'/',['Binary error',13,'channel/in_1']],...
		'position',[95,30,115,50])


%     Subsystem  ['Binary error',13,'channel/Poisson',13,'noise'].

new_system([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],'Location',[391,74,676,237])

add_block('built-in/S-Function',[sys,'/',['Binary error',13,'channel/Poisson',13,'noise/Poisson distribution',13,'number']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise/Poisson distribution',13,'number']],...
		'function name','srandpoi',...
		'parameters','seed,lambda',...
		'position',[65,55,135,95])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/Poisson',13,'noise/out_1']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise/out_1']],...
		'position',[165,65,185,85])
add_line([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],[140,75;160,75])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Display','Poison\nrand int',...
		'Mask Type','Poisson distribution noise.',...
		'Mask Dialogue','Poisson distribution number generator.|Lambda:|Seed:')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Translate','seed=@2;lambda=@1;')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Help','The output of this block is poisson distributed integers. The output size is the same as the vector size for seed. Please use function disttool to see the distribution of the outputof this block.')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Entries','P\/(randint(1, M)+100)*1000*max(P)\/')


%     Finished composite block ['Binary error',13,'channel/Poisson',13,'noise'].

set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'position',[40,94,115,136])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/out_1']])
set_param([sys,'/',['Binary error',13,'channel/out_1']],...
		'position',[390,65,410,85])

add_block('built-in/Sum',[sys,'/',['Binary error',13,'channel/Sum']])
set_param([sys,'/',['Binary error',13,'channel/Sum']],...
		'position',[235,65,255,85])

add_block('built-in/S-Function',[sys,'/',['Binary error',13,'channel/Modulo',13,'operation']])
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulo operation:|Modulo base:')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[300,56,360,94])

add_block('built-in/Saturation',[sys,'/',['Binary error',13,'channel/Saturation']])
set_param([sys,'/',['Binary error',13,'channel/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','1',...
		'position',[165,70,190,90])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/out_2']])
set_param([sys,'/',['Binary error',13,'channel/out_2']],...
		'Port','2',...
		'position',[275,125,295,145])
add_line([sys,'/',['Binary error',13,'channel']],[365,75;385,75])
add_line([sys,'/',['Binary error',13,'channel']],[120,40;210,40;210,70;230,70])
add_line([sys,'/',['Binary error',13,'channel']],[120,115;140,115;140,80;160,80])
add_line([sys,'/',['Binary error',13,'channel']],[260,75;295,75])
add_line([sys,'/',['Binary error',13,'channel']],[195,80;230,80])
add_line([sys,'/',['Binary error',13,'channel']],[210,80;210,135;270,135])
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);B-error',...
		'Mask Type','Add binary errors')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Dialogue','The error probability can be a scalar or a vector with the same length as the\ninput vector length.|Error probability:|Input vector length:')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Translate','M=@2;P=@1;if length(P)~=M,P=ones(1,M)*P(1);end;[x,y]=chanicon;')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Help','This block adds binary errors to transmitted binary signals. The error probability is given in the parameter setting. The first output port outputs the transmitting signal (after adding noise). The second port outputs the errors signal added to the transmitting signal.')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Entries','.04\/1\/')


%     Finished composite block ['Binary error',13,'channel'].

set_param([sys,'/',['Binary error',13,'channel']],...
		'hide name',0,...
		'position',[265,43,345,87])


%     Subsystem  'Counter'.

new_system([sys,'/','Counter'])
set_param([sys,'/','Counter'],'Location',[128,50,722,374])

add_block('built-in/Constant',[sys,'/','Counter/Constant'])
set_param([sys,'/','Counter/Constant'],...
		'ForeGround',3,...
		'Value','thld',...
		'position',[105,100,135,120])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Relational',13,'Operator1']],...
		'ForeGround',2,...
		'Operator','>',...
		'position',[225,53,255,77])

add_block('built-in/Sum',[sys,'/','Counter/Sum'])
set_param([sys,'/','Counter/Sum'],...
		'ForeGround',3,...
		'position',[295,100,315,120])

add_block('built-in/Switch',[sys,'/','Counter/Switch2'])
set_param([sys,'/','Counter/Switch2'],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[345,149,370,181])

add_block('built-in/Inport',[sys,'/','Counter/in_1'])
set_param([sys,'/','Counter/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Inport',[sys,'/','Counter/in_2'])
set_param([sys,'/','Counter/in_2'],...
		'Port','2',...
		'position',[15,155,35,175])


%     Subsystem  ['Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'ForeGround',4,...
		'position',[80,148,140,182])

add_block('built-in/Outport',[sys,'/','Counter/out_1'])
set_param([sys,'/','Counter/out_1'],...
		'position',[550,145,570,165])

add_block('built-in/Switch',[sys,'/','Counter/Switch3'])
set_param([sys,'/','Counter/Switch3'],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[470,139,495,171])

add_block('built-in/Memory',[sys,'/','Counter/Memory3'])
set_param([sys,'/','Counter/Memory3'],...
		'orientation',2,...
		'ForeGround',3,...
		'position',[400,205,440,235])

add_block('built-in/Inport',[sys,'/','Counter/in_3'])
set_param([sys,'/','Counter/in_3'],...
		'Port','3',...
		'position',[315,60,335,80])


%     Subsystem  ['Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[300,35;335,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'ForeGround',4,...
		'position',[375,53,435,87])
add_line([sys,'/','Counter'],[440,70;450,70;450,155;465,155])
add_line([sys,'/','Counter'],[395,220;275,220;275,175;340,175])
add_line([sys,'/','Counter'],[275,175;275,115;290,115])
add_line([sys,'/','Counter'],[145,165;340,165])
add_line([sys,'/','Counter'],[260,65;275,65;275,105;290,105])
add_line([sys,'/','Counter'],[140,110;190,110;190,70;220,70])
add_line([sys,'/','Counter'],[320,110;330,110;340,155])
add_line([sys,'/','Counter'],[40,60;220,60])
add_line([sys,'/','Counter'],[40,165;75,165])
add_line([sys,'/','Counter'],[340,70;370,70])
add_line([sys,'/','Counter'],[375,165;465,165])
add_line([sys,'/','Counter'],[500,155;545,155])
add_line([sys,'/','Counter'],[520,155;520,220;445,220])
set_param([sys,'/','Counter'],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Counter',...
		'Mask Type','Resettable number counter')
set_param([sys,'/','Counter'],...
		'Mask Dialogue','If the 1st inport value is larger than the threshold, the counter increases one at the rising edge of the 2nd inport pulse.|Threshold:')
set_param([sys,'/','Counter'],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(0,20,get_param(gcb,''orientation''),2);')
set_param([sys,'/','Counter'],...
		'Mask Help','If the signal at the 1st inport is larger than or equal to the given threshold at the rising edge of the 2nd inport, the counter increases by one. The rising edge of the 3rd port resets the counter to zero.')
set_param([sys,'/','Counter'],...
		'Mask Entries','.2\/')


%     Finished composite block 'Counter'.

set_param([sys,'/','Counter'],...
		'hide name',0,...
		'position',[375,83,455,127])

add_block('built-in/Scope',[sys,'/','Error placed'])
set_param([sys,'/','Error placed'],...
		'hide name',0,...
		'Vgain','3.000000',...
		'Hgain','7.000000',...
		'Vmax','6.000000',...
		'Hmax','14.000000',...
		'Window',[336,126,800,417])
open_system([sys,'/','Error placed'])
set_param([sys,'/','Error placed'],...
		'position',[500,92,520,118])

add_block('built-in/Note',[sys,'/',['This demo uses the MATLAB workspace variable to set the code world length N_ham_demo=7,',13,'and message length K_ham_demo= 4. You may assign the variables to be different values.      ']])
set_param([sys,'/',['This demo uses the MATLAB workspace variable to set the code world length N_ham_demo=7,',13,'and message length K_ham_demo= 4. You may assign the variables to be different values.      ']],...
		'position',[300,135,305,140])

add_block('built-in/Note',[sys,'/',['Hamming code is a single error correction code, the transmitted symbol may not be recovered',13,'if more than one error is encounted within N codeword transfer.                                          ']])
set_param([sys,'/',['Hamming code is a single error correction code, the transmitted symbol may not be recovered',13,'if more than one error is encounted within N codeword transfer.                                          ']],...
		'position',[295,165,300,170])
add_line(sys,[105,75;155,75])
add_line(sys,[245,65;260,65])
add_line(sys,[350,55;370,55])
add_line(sys,[460,55;475,55;475,40;495,40])
add_line(sys,[125,75;125,20;495,20])
add_line(sys,[350,75;355,75;355,90;370,90])
add_line(sys,[355,90;355,105;370,105])
add_line(sys,[460,105;495,105])
add_line(sys,[245,85;250,85;250,120;370,120])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
