function [ret,x0,str,ts,xts]=tstlinco(t,x,u,flag);
%TSTLINCO	is the M-file description of the SIMULINK system named TSTLINCO.
%	The block-diagram can be displayed by typing: TSTLINCO.
%
%	SYS=TSTLINCO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTLINCO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTLINCO with a FLAG of zero:
%	[SIZES]=TSTLINCO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[34,127,848,267])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Scope',[sys,'/','Error-added'])
set_param([sys,'/','Error-added'],...
		'hide name',0,...
		'Vgain','1.500000',...
		'Hgain','5.000000',...
		'Vmax','3.000000',...
		'Hmax','10.000000',...
		'Window',[367,288,813,556])
open_system([sys,'/','Error-added'])
set_param([sys,'/','Error-added'],...
		'position',[540,97,560,123])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+',...
		'position',[475,100,495,120])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar']])
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Entries','2\/',...
		'position',[585,43,665,87])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate1'],[40,70;60,70])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[105,65;125,65])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','4\/20\/0\/1\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[695,18,775,62])


%     Subsystem  ['Max-err lmtd',13,'b-err channel'].

new_system([sys,'/',['Max-err lmtd',13,'b-err channel']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],'Location',[124,322,430,428])

add_block('built-in/Outport',[sys,'/',['Max-err lmtd',13,'b-err channel/out_1']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/out_1']],...
		'hide name',0,...
		'position',[275,20,295,40])

add_block('built-in/S-Function',[sys,'/',['Max-err lmtd',13,'b-err channel/Mdu']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/Mdu']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/Mdu']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/Mdu']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/Mdu']],...
		'Mask Entries','2\/',...
		'position',[195,11,255,49])

add_block('built-in/Sum',[sys,'/',['Max-err lmtd',13,'b-err channel/S']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/S']],...
		'hide name',0,...
		'position',[150,20,170,40])

add_block('built-in/Inport',[sys,'/',['Max-err lmtd',13,'b-err channel/in_1']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/in_1']],...
		'hide name',0,...
		'position',[40,5,60,25])

add_block('built-in/Outport',[sys,'/',['Max-err lmtd',13,'b-err channel/out_2']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/out_2']],...
		'hide name',0,...
		'Port','2',...
		'position',[275,50,295,70])


%     Subsystem  ['Max-err lmtd',13,'b-err channel/B-n'].

new_system([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],'Location',[36,445,326,560])

add_block('built-in/S-Function',[sys,'/',['Max-err lmtd',13,'b-err channel/B-n/S-function']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n/S-function']],...
		'function name','srandbit',...
		'parameters','n, prob, seed',...
		'position',[90,35,140,55])

add_block('built-in/Outport',[sys,'/',['Max-err lmtd',13,'b-err channel/B-n/out_1']])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n/out_1']],...
		'position',[190,35,210,55])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],[145,45;185,45])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'Mask Display','B-vector\ngenerator',...
		'Mask Type','Binary noise generator')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'Mask Dialogue','Generate a binary vector with the probability of "1"s in the vector being specified.|Vector length(can''t be changed during simulation):|Probability of a "one", two "ones",three "ones"...:|Seed:')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'Mask Translate','n=@1;prob=@2;seed=@3;')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'Mask Help','This block outputs a zero vector with "1"s randomly distributed the vector. The maximum number of "1"s in the vector is the same as the length of the vector probability. The value of ith element of the probability is the probability of i number of "1"s in the vector.')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'Mask Entries','leng\/prob\/seed\/')


%     Finished composite block ['Max-err lmtd',13,'b-err channel/B-n'].

set_param([sys,'/',['Max-err lmtd',13,'b-err channel/B-n']],...
		'hide name',0,...
		'position',[30,38,110,82])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel']],[175,30;190,30])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel']],[260,30;270,30])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel']],[115,60;130,60;130,35;145,35])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel']],[115,60;270,60])
add_line([sys,'/',['Max-err lmtd',13,'b-err channel']],[65,15;90,15;90,25;145,25])
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'Mask Display','plot(0,0,100,100,x,y);Lmtd b-err',...
		'Mask Type','Limited binary error channel')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'Mask Dialogue','Add binary errors with specified error\nnumber probability.|Vector length(can''t be changed during simulation):|Probability of one err, two errs, three errs...:|Seed:')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'Mask Translate','leng=@1;prob=@2;seed=@3;[x,y]=chanicon;')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'Mask Help','This block adds binary errors to the input signal. The maximum number of errors added to the signal is the same as the length of the vector probability. The value of ith element of the probability is the probability of i number of errors in the vector. The 1st outport is the signal with added noise. The 2nd outport is the added noise.')
set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'Mask Entries','7\/1/2\/12345\/')


%     Finished composite block ['Max-err lmtd',13,'b-err channel'].

set_param([sys,'/',['Max-err lmtd',13,'b-err channel']],...
		'hide name',0,...
		'position',[360,53,440,97])


%     Subsystem  ['Random-integer',13,'generator1'].

new_system([sys,'/',['Random-integer',13,'generator1']])
set_param([sys,'/',['Random-integer',13,'generator1']],'Location',[98,518,454,687])

add_block('built-in/S-Function',[sys,'/',['Random-integer',13,'generator1/Uniform',13,'number']])
set_param([sys,'/',['Random-integer',13,'generator1/Uniform',13,'number']],...
		'function name','srandint',...
		'parameters','seed,mul',...
		'position',[65,45,135,85])

add_block('built-in/Outport',[sys,'/',['Random-integer',13,'generator1/out_1']])
set_param([sys,'/',['Random-integer',13,'generator1/out_1']],...
		'position',[165,55,185,75])
add_line([sys,'/',['Random-integer',13,'generator1']],[140,65;160,65])
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Display','plot(0,0,100,100,x,y);Random int',...
		'Mask Type','Random integer generator')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Dialogue','Generate integers randomly distributed in range [0, M-1], where M is the M-ary number.|M-ary number:|Seed:')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Translate','seed=@2;mul=@1;[x,y]=srcsicon(4);')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Help','This block generates an integer number in the range [0 M-1], where M is the M-ary number. The probability of the appearance for each number is equal.')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Entries','16\/[12345]\/')


%     Finished composite block ['Random-integer',13,'generator1'].

set_param([sys,'/',['Random-integer',13,'generator1']],...
		'hide name',0,...
		'position',[30,53,110,97])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector']])
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter',...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Entries','4\/2\/',...
		'position',[145,53,225,97])


%     Subsystem  ['Binary vector',13,'lin-blk decode'].

new_system([sys,'/',['Binary vector',13,'lin-blk decode']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],'Location',[267,160,850,320])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'lin-blk decode/out_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/out_1']],...
		'position',[535,90,555,110])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/Sum',[sys,'/',['Binary vector',13,'lin-blk decode/Sum']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary vector',13,'lin-blk decode/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary vector',13,'lin-blk decode/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'lin-blk decode/in_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk decode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[520,100;530,100])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[445,100;450,100])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[405,100;410,100])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[330,100;335,100])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[55,45;95,45])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[205,45;220,45])
add_line([sys,'/',['Binary vector',13,'lin-blk decode']],[130,45;135,45])
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Linear de',...
		'Mask Type','Vector I/O linear block decode')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Dialogue','Linear block decode with input codeword vector length N and output message vector length K.|Generator matrix (binary K-by-N matrix):|Error-correction truth table (0 for single error-corr):')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Translate','G=@1;trt=@2;H=gen2par(G);if trt==0,trt=htruthtb(G);end;[n,m]=size(G);G=[zeros(n,m-n),eye(n)];[x,y]=codeicon(2);')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using linear block code. The generator matrix is a K-by-N matrix. Linear block code is a generic code. Use the HTRUTHTB function to generate a single error-correction truth table.')
set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'Mask Entries','[[1 1 0; 0 1 1; 1 1 1;1 0 1] eye(4)]\/0\/')


%     Finished composite block ['Binary vector',13,'lin-blk decode'].

set_param([sys,'/',['Binary vector',13,'lin-blk decode']],...
		'hide name',0,...
		'position',[475,43,555,87])


%     Subsystem  ['Binary vector',13,'lin-blk encode'].

new_system([sys,'/',['Binary vector',13,'lin-blk encode']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'lin-blk encode/out_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'lin-blk encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'lin-blk encode/in_1']])
set_param([sys,'/',['Binary vector',13,'lin-blk encode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary vector',13,'lin-blk encode']],[245,45;285,45])
add_line([sys,'/',['Binary vector',13,'lin-blk encode']],[140,45;175,45])
add_line([sys,'/',['Binary vector',13,'lin-blk encode']],[55,45;105,45])
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Display','plot(0,0,100,100,x,y);Linear en',...
		'Mask Type','Vector I/O linear block encode')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Dialogue','Linear block encode with input message\nvector length K and output codeword vector length N.|Generator matrix (binary K-by-N matrix):')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Translate','G=@1'';[x,y]=codeicon(1);')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Help','Linear block encode with input message vector length K and output codeword vector length N. The generator matrix is a K-by-N matrix. Linear block code is a generic code.')
set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'Mask Entries','[[1 1 0; 0 1 1; 1 1 1; 1 0 1] eye(4)]\/')


%     Finished composite block ['Binary vector',13,'lin-blk encode'].

set_param([sys,'/',['Binary vector',13,'lin-blk encode']],...
		'hide name',0,...
		'position',[245,53,325,97])
add_line(sys,[500,110;535,110])
add_line(sys,[445,85;455,85;455,110;470,110])
add_line(sys,[115,75;140,75])
add_line(sys,[125,75;125,30;690,30])
add_line(sys,[670,65;670,50;690,50])
add_line(sys,[330,75;355,75])
add_line(sys,[445,65;470,65])
add_line(sys,[560,65;580,65])
add_line(sys,[230,75;240,75])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
