function [ret,x0,str,ts,xts]=tstlinsq(t,x,u,flag);
%TSTLINSQ	is the M-file description of the SIMULINK system named TSTLINSQ.
%	The block-diagram can be displayed by typing: TSTLINSQ.
%
%	SYS=TSTLINSQ(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTLINSQ to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTLINSQ with a FLAG of zero:
%	[SIZES]=TSTLINSQ([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[47,105,688,292])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','[wast,G_lin]=hammgen(3);trt=0;GWN=.01;');

add_block('built-in/Scope',[sys,'/','Error placed'])
set_param([sys,'/','Error placed'],...
		'hide name',0,...
		'Vgain','3.000000',...
		'Hgain','7.000000',...
		'Vmax','6.000000',...
		'Hmax','14.000000',...
		'Window',[343,293,807,584])
open_system([sys,'/','Error placed'])
set_param([sys,'/','Error placed'],...
		'position',[505,107,525,133])


%     Subsystem  'Counter'.

new_system([sys,'/','Counter'])
set_param([sys,'/','Counter'],'Location',[128,50,722,374])


%     Subsystem  ['Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[300,35;335,35])
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'ForeGround',4,...
		'position',[375,53,435,87])

add_block('built-in/Inport',[sys,'/','Counter/in_3'])
set_param([sys,'/','Counter/in_3'],...
		'Port','3',...
		'position',[315,60,335,80])

add_block('built-in/Memory',[sys,'/','Counter/Memory3'])
set_param([sys,'/','Counter/Memory3'],...
		'orientation',2,...
		'ForeGround',3,...
		'position',[400,205,440,235])

add_block('built-in/Switch',[sys,'/','Counter/Switch3'])
set_param([sys,'/','Counter/Switch3'],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[470,139,495,171])

add_block('built-in/Outport',[sys,'/','Counter/out_1'])
set_param([sys,'/','Counter/out_1'],...
		'position',[550,145,570,165])


%     Subsystem  ['Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'ForeGround',4,...
		'position',[80,148,140,182])

add_block('built-in/Inport',[sys,'/','Counter/in_2'])
set_param([sys,'/','Counter/in_2'],...
		'Port','2',...
		'position',[15,155,35,175])

add_block('built-in/Inport',[sys,'/','Counter/in_1'])
set_param([sys,'/','Counter/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Switch',[sys,'/','Counter/Switch2'])
set_param([sys,'/','Counter/Switch2'],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[345,149,370,181])

add_block('built-in/Sum',[sys,'/','Counter/Sum'])
set_param([sys,'/','Counter/Sum'],...
		'ForeGround',3,...
		'position',[295,100,315,120])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Relational',13,'Operator1']],...
		'ForeGround',2,...
		'Operator','>',...
		'position',[225,53,255,77])

add_block('built-in/Constant',[sys,'/','Counter/Constant'])
set_param([sys,'/','Counter/Constant'],...
		'ForeGround',3,...
		'Value','thld',...
		'position',[105,100,135,120])
add_line([sys,'/','Counter'],[500,155;545,155])
add_line([sys,'/','Counter'],[520,155;520,220;445,220])
add_line([sys,'/','Counter'],[375,165;465,165])
add_line([sys,'/','Counter'],[340,70;370,70])
add_line([sys,'/','Counter'],[40,165;75,165])
add_line([sys,'/','Counter'],[40,60;220,60])
add_line([sys,'/','Counter'],[320,110;330,110;340,155])
add_line([sys,'/','Counter'],[140,110;190,110;190,70;220,70])
add_line([sys,'/','Counter'],[260,65;275,65;275,105;290,105])
add_line([sys,'/','Counter'],[145,165;340,165])
add_line([sys,'/','Counter'],[395,220;275,220;275,175;340,175])
add_line([sys,'/','Counter'],[275,175;275,115;290,115])
add_line([sys,'/','Counter'],[440,70;450,70;450,155;465,155])
set_param([sys,'/','Counter'],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Counter',...
		'Mask Type','Resettable number counter')
set_param([sys,'/','Counter'],...
		'Mask Dialogue','If the 1st inport value is larger than the threshold, the counter increases one at the rising edge of the 2nd inport pulse.|Threshold:')
set_param([sys,'/','Counter'],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(0,20,get_param(gcb,''orientation''),2);')
set_param([sys,'/','Counter'],...
		'Mask Help','If the signal at the 1st inport is larger than or equal to the given threshold at the rising edge of the 2nd inport, the counter increases by one. The rising edge of the 3rd port resets the counter to zero.')
set_param([sys,'/','Counter'],...
		'Mask Entries','.2\/')


%     Finished composite block 'Counter'.

set_param([sys,'/','Counter'],...
		'hide name',0,...
		'position',[380,98,460,142])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate1'],[40,70;60,70])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[105,65;125,65])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','1\/20\/2\/1/size(G_lin,1)\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[505,23,585,67])


%     Subsystem  ['Binary sequence',13,'lin-blk decode'].

new_system([sys,'/',['Binary sequence',13,'lin-blk decode']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],'Location',[267,160,850,320])


%     Subsystem  ['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding'].

new_system([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],'Location',[267,160,850,320])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','H\/')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain']],...
		'position',[100,31,125,59])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[140,26,200,64])

add_block('built-in/Combinatorial Logic',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Combinatorial',13,'Logic']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Combinatorial',13,'Logic']],...
		'Truth Table','trt',...
		'position',[225,33,255,57])

add_block('built-in/Sum',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Sum']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Sum']],...
		'position',[305,90,325,110])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation1']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[340,81,400,119])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain1']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain1']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Matrix',13,'Gain1']],...
		'position',[415,86,440,114])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation2']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation2']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation2']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/Modulus',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[455,81,515,119])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding/out_1']],...
		'position',[535,90,555,110])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[130,45;135,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[205,45;220,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[260,45;285,45;285,95;300,95])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[55,45;95,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[80,45;80,105;300,105])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[330,100;335,100])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[405,100;410,100])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[445,100;450,100])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],[520,100;530,100])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'Mask Display','Linear\ndecode',...
		'Mask Type','Linear coding')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'Mask Dialogue','Linear block coding:|Generator matrix:|Error-correction truth table (0 for single error-correction default):')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'Mask Translate','G=@1;trt=@2;H=gen2par(G);if trt==0,trt=htruthtb(G);end;[n,m]=size(G);G=[zeros(n,m-n),eye(n)];')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'Mask Help','This block decodes code word binary vecotr using linear block coding method. The m-by-n generator matrix should match the generator matrix defined in the encode block. This block input n-array code word and output m-array message. This is a generic styke block for linear block code.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'Mask Entries','G\/trt\/')


%     Finished composite block ['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding'].

set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Linear block',13,'decoding']],...
		'position',[295,15,355,55])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Demux']],...
		'outputs','2',...
		'position',[115,80,155,115])


%     Subsystem  ['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n, k]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[30,81,90,119])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/sequential',13,'code-word-in']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/sequential',13,'code-word-in']],...
		'position',[105,25,125,45])


%     Subsystem  ['Binary sequence',13,'lin-blk decode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/in_1']],...
		'position',[10,55,30,75])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[35,65;75,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],[65,80;75,80])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'lin-blk decode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Register-shift']],...
		'BackGround',3,...
		'position',[190,25,245,65])


%     Subsystem  ['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'lin-blk decode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[425,28,485,72])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk decode/sequential',13,'message-out']])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode/sequential',13,'message-out']],...
		'position',[525,30,545,50])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[160,90;165,90;165,55;185,55])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[250,55;265,55;265,90;385,90;385,50;420,50])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[250,35;290,35])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[360,35;420,35])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[130,35;185,35])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[95,100;110,100])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[490,40;520,40])
add_line([sys,'/',['Binary sequence',13,'lin-blk decode']],[160,105;395,105;395,65;420,65])
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'Mask Display','plot(0,0,100,100,x,y);Linear de',...
		'Mask Type','Sequence I/O linear block decode')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'Mask Dialogue','Linear block decode with message length K and codeword length N.|Generator matrix (binary K-by-N matrix):|Error-correction truth table (0 for single error-corr):|Output sample time T_out (sec):')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'Mask Translate','G=@1;trt=@2;samp=@3;[k,n]=size(G);[x,y]=codeicon(4);')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'Mask Help','This block decodes length N binary codeword into length K message using linear block code. The block uses sequential input/output format. The input sequence sample time is K*T_out/N. The block causes a K*T_out delay. The generator matrix is a K-by-N matrix. Linear block code is a generic code.')
set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'Mask Entries','G_lin\/trt\/1/size(G_lin,1)\/')


%     Finished composite block ['Binary sequence',13,'lin-blk decode'].

set_param([sys,'/',['Binary sequence',13,'lin-blk decode']],...
		'hide name',0,...
		'position',[380,43,460,87])


%     Subsystem  ['Binary sequence',13,'lin-blk encode'].

new_system([sys,'/',['Binary sequence',13,'lin-blk encode']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],'Location',[159,155,829,298])


%     Subsystem  ['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding'].

new_system([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],'Location',[235,592,599,711])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/State-Space',[sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Matrix',13,'Gain']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Modulus',13,'operation']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding/out_1']],...
		'position',[290,35,310,55])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],[55,45;105,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],[140,45;175,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],[245,45;285,45])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],...
		'Mask Display','Linear\nencode',...
		'Mask Type','Linear coding',...
		'Mask Dialogue','Linear block coding:|Generator matrix:')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],...
		'Mask Translate','G=@1'';')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],...
		'Mask Help','This block encodes the input binary signal using linear block coding method. The generator matrix has the dimension of m-by-n. The input of this block is a m-array binary message vector. The output of this block is an n-array code word vector. This is a generic style block for linear block coding.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],...
		'Mask Entries','G\/')


%     Finished composite block ['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding'].

set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Linear block',13,'encoding']],...
		'position',[325,11,390,49])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/out_2']],...
		'Port','2',...
		'position',[530,40,550,60])


%     Subsystem  ['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'Mask Entries','n\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[440,23,500,57])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/out_1']],...
		'position',[570,25,590,45])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Demux']],...
		'outputs','2',...
		'position',[135,75,175,110])


%     Subsystem  ['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k, n]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[40,76,100,114])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/in_1']],...
		'position',[50,20,70,40])


%     Subsystem  ['Binary sequence',13,'lin-blk encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[55,80;75,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'lin-blk encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'lin-blk encode/Register-shift']],...
		'BackGround',3,...
		'position',[225,21,280,54])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[505,50;525,50])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[505,35;565,35])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[395,30;435,30])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[285,30;320,30])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[75,30;220,30])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[285,45;300,45;300,80;405,80;405,40;435,40])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[105,95;130,95])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[180,85;190,85;190,45;220,45])
add_line([sys,'/',['Binary sequence',13,'lin-blk encode']],[180,100;415,100;415,50;435,50])
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Linear en',...
		'Mask Type','Sequence I/O linear block encode')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'Mask Dialogue','Linear block encode with message length K and codeword length N.|Generator matrix (binary K-by-N matrix):|Input sample time T_in (sec):')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'Mask Translate','G=@1;samp=@2;[k, n]=size(G);[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'Mask Help','This block encodes length K binary message into length N binary codeword using linear block code. The block uses sequential input/output format. The output sequence sample time is K*T_in/N. The block causes a K*T_in delay. The second outport outputs a pulse when Kth message signal is received. The generator matrix is a K-by-N matrix. Linear block code is a generic code.')
set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'Mask Entries','G_lin\/1/size(G_lin,1)\/')


%     Finished composite block ['Binary sequence',13,'lin-blk encode'].

set_param([sys,'/',['Binary sequence',13,'lin-blk encode']],...
		'hide name',0,...
		'position',[165,63,245,107])


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(200,1)\/1/size(G_lin,1)\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[25,63,105,107])


%     Subsystem  ['Binary error',13,'channel'].

new_system([sys,'/',['Binary error',13,'channel']])
set_param([sys,'/',['Binary error',13,'channel']],'Location',[259,203,738,408])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/out_2']])
set_param([sys,'/',['Binary error',13,'channel/out_2']],...
		'Port','2',...
		'position',[275,125,295,145])

add_block('built-in/Saturation',[sys,'/',['Binary error',13,'channel/Saturation']])
set_param([sys,'/',['Binary error',13,'channel/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','1',...
		'position',[165,70,190,90])

add_block('built-in/S-Function',[sys,'/',['Binary error',13,'channel/Modulo',13,'operation']])
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulo operation:|Modulo base:')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary error',13,'channel/Modulo',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[300,56,360,94])

add_block('built-in/Sum',[sys,'/',['Binary error',13,'channel/Sum']])
set_param([sys,'/',['Binary error',13,'channel/Sum']],...
		'position',[235,65,255,85])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/out_1']])
set_param([sys,'/',['Binary error',13,'channel/out_1']],...
		'position',[390,65,410,85])


%     Subsystem  ['Binary error',13,'channel/Poisson',13,'noise'].

new_system([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],'Location',[391,74,676,237])

add_block('built-in/Outport',[sys,'/',['Binary error',13,'channel/Poisson',13,'noise/out_1']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise/out_1']],...
		'position',[165,65,185,85])

add_block('built-in/S-Function',[sys,'/',['Binary error',13,'channel/Poisson',13,'noise/Poisson distribution',13,'number']])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise/Poisson distribution',13,'number']],...
		'function name','srandpoi',...
		'parameters','seed,lambda',...
		'position',[65,55,135,95])
add_line([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],[140,75;160,75])
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Display','Poison\nrand int',...
		'Mask Type','Poisson distribution noise.',...
		'Mask Dialogue','Poisson distribution number generator.|Lambda:|Seed:')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Translate','seed=@2;lambda=@1;')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Help','The output of this block is poisson distributed integers. The output size is the same as the vector size for seed. Please use function disttool to see the distribution of the outputof this block.')
set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'Mask Entries','P\/(randint(1, M)+100)*1000*max(P)\/')


%     Finished composite block ['Binary error',13,'channel/Poisson',13,'noise'].

set_param([sys,'/',['Binary error',13,'channel/Poisson',13,'noise']],...
		'position',[40,94,115,136])

add_block('built-in/Inport',[sys,'/',['Binary error',13,'channel/in_1']])
set_param([sys,'/',['Binary error',13,'channel/in_1']],...
		'position',[95,30,115,50])
add_line([sys,'/',['Binary error',13,'channel']],[195,80;230,80])
add_line([sys,'/',['Binary error',13,'channel']],[210,80;210,135;270,135])
add_line([sys,'/',['Binary error',13,'channel']],[260,75;295,75])
add_line([sys,'/',['Binary error',13,'channel']],[120,115;140,115;140,80;160,80])
add_line([sys,'/',['Binary error',13,'channel']],[120,40;210,40;210,70;230,70])
add_line([sys,'/',['Binary error',13,'channel']],[365,75;385,75])
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);B-error',...
		'Mask Type','Add binary errors')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Dialogue','The error probability can be a scalar or a vector with the same length as the\ninput vector length.|Error probability:|Input vector length:')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Translate','M=@2;P=@1;if length(P)~=M,P=ones(1,M)*P(1);end;[x,y]=chanicon;')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Help','This block adds binary errors to transmitted binary signals. The error probability is given in the parameter setting. The first output port outputs the transmitting signal (after adding noise). The second port outputs the errors signal added to the transmitting signal.')
set_param([sys,'/',['Binary error',13,'channel']],...
		'Mask Entries','.02\/1\/')


%     Finished composite block ['Binary error',13,'channel'].

set_param([sys,'/',['Binary error',13,'channel']],...
		'hide name',0,...
		'position',[270,53,350,97])

add_block('built-in/Note',[sys,'/','In this demo, generator matrix is G_lin=[1 0 1 1;1 1 1 0;0 1 1 1;eye(4)]; trt=0;'])
set_param([sys,'/','In this demo, generator matrix is G_lin=[1 0 1 1;1 1 1 0;0 1 1 1;eye(4)]; trt=0;'],...
		'position',[245,155,250,160])
add_line(sys,[465,120;500,120])
add_line(sys,[355,85;360,85;360,105;375,105])
add_line(sys,[360,105;360,120;375,120])
add_line(sys,[110,85;160,85])
add_line(sys,[130,85;130,35;500,35])
add_line(sys,[465,65;480,65;480,55;500,55])
add_line(sys,[355,65;375,65])
add_line(sys,[250,75;265,75])
add_line(sys,[250,95;260,95;260,135;375,135])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
