function [ret,x0,str,ts,xts]=tstps2cd(t,x,u,flag);
%TSTPS2CD	is the M-file description of the SIMULINK system named TSTPS2CD.
%	The block-diagram can be displayed by typing: TSTPS2CD.
%
%	SYS=TSTPS2CD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTPS2CD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTPS2CD with a FLAG of zero:
%	[SIZES]=TSTPS2CD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[222,174,966,381])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', 'ts')
set_param(sys,'Max step size', 'ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;td=.2;Fc=100/2/pi;NIR=[6 12 18 24 30 38];AIR=[1 1.93 2.88 3.83 4.78 6.05];PIR=zeros(1,6);[num,den]=butter(4,100/pi*ts);M=sum(NIR);');


%     Subsystem  ['QAM',13,'passband1'].

new_system([sys,'/',['QAM',13,'passband1']])
set_param([sys,'/',['QAM',13,'passband1']],'Location',[302,478,834,743])

add_block('built-in/Fcn',[sys,'/',['QAM',13,'passband1/Fcn']])
set_param([sys,'/',['QAM',13,'passband1/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])

add_block('built-in/Fcn',[sys,'/',['QAM',13,'passband1/Fcn1']])
set_param([sys,'/',['QAM',13,'passband1/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Note',[sys,'/',['QAM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QAM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[250,305,255,310])

add_block('built-in/Product',[sys,'/',['QAM',13,'passband1/Product']])
set_param([sys,'/',['QAM',13,'passband1/Product']],...
		'position',[355,47,380,78])

add_block('built-in/Product',[sys,'/',['QAM',13,'passband1/Product1']])
set_param([sys,'/',['QAM',13,'passband1/Product1']],...
		'position',[355,112,380,143])

add_block('built-in/Sum',[sys,'/',['QAM',13,'passband1/Sum2']])
set_param([sys,'/',['QAM',13,'passband1/Sum2']],...
		'position',[430,90,450,110])

add_block('built-in/Outport',[sys,'/',['QAM',13,'passband1/out_1']])
set_param([sys,'/',['QAM',13,'passband1/out_1']],...
		'position',[490,90,510,110])

add_block('built-in/Inport',[sys,'/',['QAM',13,'passband1/in_1']])
set_param([sys,'/',['QAM',13,'passband1/in_1']],...
		'position',[160,30,180,50])

add_block('built-in/Inport',[sys,'/',['QAM',13,'passband1/in_2']])
set_param([sys,'/',['QAM',13,'passband1/in_2']],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Gain',[sys,'/',['QAM',13,'passband1/Gain']])
set_param([sys,'/',['QAM',13,'passband1/Gain']],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Clock',[sys,'/',['QAM',13,'passband1/Clock']])
set_param([sys,'/',['QAM',13,'passband1/Clock']],...
		'position',[80,85,100,105])
add_line([sys,'/',['QAM',13,'passband1']],[455,100;485,100])
add_line([sys,'/',['QAM',13,'passband1']],[330,70;350,70])
add_line([sys,'/',['QAM',13,'passband1']],[185,40;335,40;335,55;350,55])
add_line([sys,'/',['QAM',13,'passband1']],[330,120;350,120])
add_line([sys,'/',['QAM',13,'passband1']],[185,155;330,155;330,135;350,135])
add_line([sys,'/',['QAM',13,'passband1']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['QAM',13,'passband1']],[385,130;400,130;400,105;425,105])
add_line([sys,'/',['QAM',13,'passband1']],[105,95;125,95])
add_line([sys,'/',['QAM',13,'passband1']],[185,95;200,95;200,70;225,70])
add_line([sys,'/',['QAM',13,'passband1']],[200,95;200,120;225,120])
set_param([sys,'/',['QAM',13,'passband1']],...
		'Mask Display','plot(0,0,100,100,x,y);QAM',...
		'Mask Type','Passband DSB-SC QAM')
set_param([sys,'/',['QAM',13,'passband1']],...
		'Mask Dialogue','Modulate the in-phase signal from first input port and quadrature signal from\nthe second port using QAM.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QAM',13,'passband1']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['QAM',13,'passband1']],...
		'Mask Help','This block modulates the in-phase component inputted from the first port and the quadrature component inputted from the second port by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['QAM',13,'passband1']],...
		'Mask Entries','100/2/pi\/0\/ts\/')


%     Finished composite block ['QAM',13,'passband1'].

set_param([sys,'/',['QAM',13,'passband1']],...
		'hide name',0,...
		'position',[265,48,345,92])


%     Subsystem  ['QASK',13,'circle-map'].

new_system([sys,'/',['QASK',13,'circle-map']])
set_param([sys,'/',['QASK',13,'circle-map']],'Location',[58,103,403,268])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-map/Imag']])
set_param([sys,'/',['QASK',13,'circle-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-map/Real']])
set_param([sys,'/',['QASK',13,'circle-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'circle-map/imag part1']])
set_param([sys,'/',['QASK',13,'circle-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'circle-map/real part']])
set_param([sys,'/',['QASK',13,'circle-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-map/in_1']])
set_param([sys,'/',['QASK',13,'circle-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'circle-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])
add_line([sys,'/',['QASK',13,'circle-map']],[215,110;270,110])
add_line([sys,'/',['QASK',13,'circle-map']],[220,30;270,30])
add_line([sys,'/',['QASK',13,'circle-map']],[120,30;175,30])
add_line([sys,'/',['QASK',13,'circle-map']],[145,30;145,110;170,110])
add_line([sys,'/',['QASK',13,'circle-map']],[50,30;75,30])
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Display','QASK\nC-map',...
		'Mask Type','QASK C-map')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Dialogue','QASK mapping with circle constellation. The constellation is defined in NIC, RIC and PIC.|Number of symbols in each circle NIC:|Radii in each circle RIC:|Phase shift in each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y1=[y1;y1];y1=y1(:);y2=imag(y1);y1=real(y1);x=[-sum(N) 1:sum(N)-1;1:sum(N)-1 10*sum(N)]-.5;x=x(:);')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The circle constellation is defined in NIC, RIC, and PIC. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Entries','[6 12 18 24 30 38]\/[1 1.93 2.88 3.83 4.78 6.05]\/[0 0 0 0 0 0]\/td\/')


%     Finished composite block ['QASK',13,'circle-map'].

set_param([sys,'/',['QASK',13,'circle-map']],...
		'hide name',0,...
		'position',[150,48,230,92])


%     Subsystem  ['QASK',13,'circle-demap'].

new_system([sys,'/',['QASK',13,'circle-demap']])
set_param([sys,'/',['QASK',13,'circle-demap']],'Location',[96,182,645,417])

add_block('built-in/Constant',[sys,'/',['QASK',13,'circle-demap/imag_pt']])
set_param([sys,'/',['QASK',13,'circle-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])

add_block('built-in/Constant',[sys,'/',['QASK',13,'circle-demap/real_pt']])
set_param([sys,'/',['QASK',13,'circle-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-demap/out_1']])
set_param([sys,'/',['QASK',13,'circle-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'circle-demap/Minimum1']])
set_param([sys,'/',['QASK',13,'circle-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum2']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/Product',[sys,'/',['QASK',13,'circle-demap/Product1']])
set_param([sys,'/',['QASK',13,'circle-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Product',[sys,'/',['QASK',13,'circle-demap/Product']])
set_param([sys,'/',['QASK',13,'circle-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum6']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum1']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-demap/imag']])
set_param([sys,'/',['QASK',13,'circle-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-demap/real']])
set_param([sys,'/',['QASK',13,'circle-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])
add_line([sys,'/',['QASK',13,'circle-demap']],[480,95;490,95])
add_line([sys,'/',['QASK',13,'circle-demap']],[395,95;410,95])
add_line([sys,'/',['QASK',13,'circle-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['QASK',13,'circle-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['QASK',13,'circle-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['QASK',13,'circle-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['QASK',13,'circle-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['QASK',13,'circle-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['QASK',13,'circle-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['QASK',13,'circle-demap']],[160,130;225,130])
add_line([sys,'/',['QASK',13,'circle-demap']],[160,45;225,45])
add_line([sys,'/',['QASK',13,'circle-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['QASK',13,'circle-demap']],[70,130;115,130])
add_line([sys,'/',['QASK',13,'circle-demap']],[70,45;115,45])
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Display','QASK\nC-demap',...
		'Mask Type','QASK C-demap')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Number of symbols on each circle NIC::|Radii for each circle RIC:|Phase shift on each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y2=imag(y1);y1=real(y1);')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using circle constellation. You can place this block after a QAM demodulation block. The circle constellation is defined in NIC, RIC, and PIC. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero. Use function MODMAP to view the constellation.')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Entries','[6 12 18 24 30 38]\/[1 1.93 2.88 3.83 4.78 6.05]\/[0 0 0 0 0 0]\/[td, td-ts]\/')


%     Finished composite block ['QASK',13,'circle-demap'].

set_param([sys,'/',['QASK',13,'circle-demap']],...
		'hide name',0,...
		'position',[515,48,595,92])


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(1000,1,M)\/td\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[20,48,95,92])


%     Subsystem  'Error rate1'.

new_system([sys,'/','Error rate1'])
set_param([sys,'/','Error rate1'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate1/S-function'])
set_param([sys,'/','Error rate1/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate1/Mux'])
set_param([sys,'/','Error rate1/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate1/in_1'])
set_param([sys,'/','Error rate1/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate1/in_2'])
set_param([sys,'/','Error rate1/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate1'],[105,65;125,65])
add_line([sys,'/','Error rate1'],[40,55;60,55])
add_line([sys,'/','Error rate1'],[40,70;60,70])
set_param([sys,'/','Error rate1'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate1'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate1'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate1'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate1'],...
		'Mask Entries','7\/20\/td\/td\/')


%     Finished composite block 'Error rate1'.

set_param([sys,'/','Error rate1'],...
		'hide name',0,...
		'position',[635,38,715,82])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[525,103,560,152])


%     Subsystem  ['Eye-diagram',13,'scatter plot'].

new_system([sys,'/',['Eye-diagram',13,'scatter plot']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],'Location',[165,242,460,428])

add_block('built-in/S-Function',[sys,'/',['Eye-diagram',13,'scatter plot/Plot1']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/Plot1']],...
		'function name','eyediasi',...
		'parameters','time_range, boundary, kept_length, eye_line, scatter_line, two_d_line',...
		'position',[130,70,200,110])

add_block('built-in/Mux',[sys,'/',['Eye-diagram',13,'scatter plot/Mux']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/Mux']],...
		'inputs','2',...
		'position',[65,70,100,105])

add_block('built-in/Inport',[sys,'/',['Eye-diagram',13,'scatter plot/in_2']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/in_2']],...
		'Port','2',...
		'position',[20,115,40,135])

add_block('built-in/Inport',[sys,'/',['Eye-diagram',13,'scatter plot/in_1']])
set_param([sys,'/',['Eye-diagram',13,'scatter plot/in_1']],...
		'position',[15,55,35,75])
add_line([sys,'/',['Eye-diagram',13,'scatter plot']],[105,90;125,90])
add_line([sys,'/',['Eye-diagram',13,'scatter plot']],[45,125;50,125;60,95])
add_line([sys,'/',['Eye-diagram',13,'scatter plot']],[40,65;45,65;45,80;60,80])
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);',...
		'Mask Type','Eye-diagram/scatter plot')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Dialogue','Produce eye-pattern diagram/scatter\nplot/x-y plot with the rising edge of the second input as the decision line.|Eye-pattern plot time frame:|Lower and upper bound of in-coming signal (1x2 vector):|Number of saved traces:|Line-type for eye-pattern diagram (0 for no such plot):|Line-type for scatter plot (0 for no such plot):|Line-type for x-y plot (0 for no such plot):')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Translate','time_range=@1;boundary=@2;kept_length=@3;eye_line=@4;scatter_line=@5;two_d_line=@6;[x,y]=srcsicon(10);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Help','This plot opens one, two, or three plots by assigning the line type parameters. The scatter plot point is selected by the rising edge of a trigger signal. A decision line is drawn at the rising edge of the trigger signal.')
set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'Mask Entries','td*2\/[-7 7]\/10\/0\/''m./g*/bo''\/0\/')


%     Finished composite block ['Eye-diagram',13,'scatter plot'].

set_param([sys,'/',['Eye-diagram',13,'scatter plot']],...
		'hide name',0,...
		'position',[630,133,710,177])


%     Subsystem  ['QADM',13,'passband1'].

new_system([sys,'/',['QADM',13,'passband1']])
set_param([sys,'/',['QADM',13,'passband1']],'Location',[194,478,738,741])

add_block('built-in/Clock',[sys,'/',['QADM',13,'passband1/Clock']])
set_param([sys,'/',['QADM',13,'passband1/Clock']],...
		'position',[60,110,80,130])

add_block('built-in/Gain',[sys,'/',['QADM',13,'passband1/Gain']])
set_param([sys,'/',['QADM',13,'passband1/Gain']],...
		'Gain','Fc',...
		'position',[110,101,160,139])

add_block('built-in/Filter',[sys,'/',['QADM',13,'passband1/Filter1']])
set_param([sys,'/',['QADM',13,'passband1/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,166,445,204])

add_block('built-in/Filter',[sys,'/',['QADM',13,'passband1/Filter']])
set_param([sys,'/',['QADM',13,'passband1/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Gain',[sys,'/',['QADM',13,'passband1/Gain1']])
set_param([sys,'/',['QADM',13,'passband1/Gain1']],...
		'Gain','2',...
		'position',[270,118,295,142])

add_block('built-in/Inport',[sys,'/',['QADM',13,'passband1/in_1']])
set_param([sys,'/',['QADM',13,'passband1/in_1']],...
		'position',[230,120,250,140])

add_block('built-in/Note',[sys,'/',['QADM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QADM',13,'passband1/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Fcn',[sys,'/',['QADM',13,'passband1/Fcn']])
set_param([sys,'/',['QADM',13,'passband1/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[205,55,300,85])

add_block('built-in/Fcn',[sys,'/',['QADM',13,'passband1/Fcn1']])
set_param([sys,'/',['QADM',13,'passband1/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[200,175,300,205])

add_block('built-in/Product',[sys,'/',['QADM',13,'passband1/Product']])
set_param([sys,'/',['QADM',13,'passband1/Product']],...
		'position',[330,62,355,93])

add_block('built-in/Product',[sys,'/',['QADM',13,'passband1/Product1']])
set_param([sys,'/',['QADM',13,'passband1/Product1']],...
		'position',[330,167,355,198])

add_block('built-in/Outport',[sys,'/',['QADM',13,'passband1/out_2']])
set_param([sys,'/',['QADM',13,'passband1/out_2']],...
		'Port','2',...
		'position',[480,175,500,195])

add_block('built-in/Outport',[sys,'/',['QADM',13,'passband1/out_1']])
set_param([sys,'/',['QADM',13,'passband1/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['QADM',13,'passband1']],[300,130;305,130;305,175;325,175])
add_line([sys,'/',['QADM',13,'passband1']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['QADM',13,'passband1']],[255,130;265,130])
add_line([sys,'/',['QADM',13,'passband1']],[165,120;185,120;185,70;200,70])
add_line([sys,'/',['QADM',13,'passband1']],[185,120;195,190])
add_line([sys,'/',['QADM',13,'passband1']],[305,70;325,70])
add_line([sys,'/',['QADM',13,'passband1']],[305,190;325,190])
add_line([sys,'/',['QADM',13,'passband1']],[360,80;385,80])
add_line([sys,'/',['QADM',13,'passband1']],[450,80;475,80])
add_line([sys,'/',['QADM',13,'passband1']],[360,185;385,185])
add_line([sys,'/',['QADM',13,'passband1']],[450,185;475,185])
add_line([sys,'/',['QADM',13,'passband1']],[85,120;105,120])
set_param([sys,'/',['QADM',13,'passband1']],...
		'Mask Display','plot(0,0,100,100,x,y);QADM',...
		'Mask Type','Passband DSB-SC QADM')
set_param([sys,'/',['QADM',13,'passband1']],...
		'Mask Dialogue','Demodulate a DSB-SC QAM modulated\nsignal into in-phase and quadrature\ncomponents.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QADM',13,'passband1']],...
		'Mask Translate','Fc=@1*2*pi;num=@2;den=@3;Ph=@4;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['QADM',13,'passband1']],...
		'Mask Help','This block demodulates the QM-DSB-SC-AM modulated signal. The first output port outputs the in-phase component and the second port outputs the quadrature component. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['QADM',13,'passband1']],...
		'Mask Entries','100/2/pi\/num\/den\/0\/ts\/')


%     Finished composite block ['QADM',13,'passband1'].

set_param([sys,'/',['QADM',13,'passband1']],...
		'hide name',0,...
		'position',[375,48,455,92])


%     Subsystem  ['Pulses divide',13,'same sample time'].

new_system([sys,'/',['Pulses divide',13,'same sample time']])
set_param([sys,'/',['Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Entries','td\/1\/-ts\/')


%     Finished composite block ['Pulses divide',13,'same sample time'].

set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'hide name',0,...
		'position',[385,143,465,187])


%     Subsystem  ['ASK Mo//Dem',13,'demo1'].

new_system([sys,'/',['ASK Mo//Dem',13,'demo1']])
set_param([sys,'/',['ASK Mo//Dem',13,'demo1']],'Location',[175,552,335,697])
set_param([sys,'/',['ASK Mo//Dem',13,'demo1']],...
		'Mask Display','View\nconstellation',...
		'Mask Dialogue','eval(''modmap(''''qask/cir'''',[6 12 18 24 30 38],[1 1.93 2.88 3.83 4.78 6.05],[0 0 0 0 0 0])'')')


%     Finished composite block ['ASK Mo//Dem',13,'demo1'].

set_param([sys,'/',['ASK Mo//Dem',13,'demo1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[80,133,160,177])
add_line(sys,[100,70;145,70])
add_line(sys,[115,70;115,20;620,20;630,50])
add_line(sys,[565,130;590,130;590,145;625,145])
add_line(sys,[600,70;630,70])
add_line(sys,[350,70;370,70])
add_line(sys,[460,60;510,60])
add_line(sys,[235,60;260,60])
add_line(sys,[460,80;510,80])
add_line(sys,[490,80;490,115;520,115])
add_line(sys,[470,60;470,140;520,140])
add_line(sys,[470,165;625,165])
add_line(sys,[235,80;260,80])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
