function [ret,x0,str,ts,xts]=tstqam(t,x,u,flag);
%TSTQAM is the M-file description of the SIMULINK system named TSTQAM.
% The block-diagram can be displayed by typing: TSTQAM.
%
% SYS=TSTQAM(T,X,U,FLAG) returns depending on FLAG certain
%       system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes TSTQAM to return state derivatives, FLAG=2
%       discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling TSTQAM with a FLAG of zero:
%    [SIZES]=TSTQAM([],[],[],0),  returns a vector, SIZES, which
%    contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs
%              SIZES(5) number of roots (currently unsupported)
%               SIZES(6) direct feedthrough flag
%               SIZES(7) number of sample times
%
%       For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[35,209,751,399])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.002')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['modulated',13,'output']])
set_param([sys,'/',['modulated',13,'output']],...
         'ForeGround',4,...
              'position',[320,55,325,60])


%     Subsystem  ['Quad multi',13,'DSB-SC-ADM'].

new_system([sys,'/',['Quad multi',13,'DSB-SC-ADM']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM']],'Location',[353,42,897,305])

add_block('built-in/Outport',[sys,'/',['Quad multi',13,'DSB-SC-ADM/out_1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/out_1']],...
          'position',[480,70,500,90])

add_block('built-in/Outport',[sys,'/',['Quad multi',13,'DSB-SC-ADM/out_2']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/out_2']],...
             'Port','2',...
          'position',[480,175,500,195])

add_block('built-in/Transfer Fcn',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter1']],...
                'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[395,164,445,206])

add_block('built-in/Transfer Fcn',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter']],...
          'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[395,59,445,101])

add_block('built-in/Product',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Product1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Product1']],...
              'position',[330,167,355,198])

add_block('built-in/Product',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Product']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Product']],...
               'position',[330,62,355,93])

add_block('built-in/Fcn',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Fcn1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Fcn1']],...
           'Expr','sin(u[1]+Pg)',...
               'position',[220,176,295,204])

add_block('built-in/Fcn',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Fcn']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Fcn']],...
           'Expr','sin(u[1]+Ph)',...
               'position',[225,56,300,84])

add_block('built-in/Gain',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Gain']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Gain']],...
          'Gain','pi2',...
                'position',[165,109,200,141])


%     Subsystem  ['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator'].

new_system([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Outport',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/out_1']],...
            'position',[370,30,390,50])

add_block('built-in/Sum',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Sum']],...
               'position',[195,30,215,50])

add_block('built-in/Constant',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/one']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/one']],...
          'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Reset Integrator',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Reset',13,'integrator']],...
                'position',[110,19,150,51])

add_block('built-in/Fcn',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/module']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/module']],...
         'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Memory',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Memory']],...
              'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Inport',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/in_1']],...
         'position',[35,15,55,35])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[340,40;340,90;265,90])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[205,90;180,90;190,45])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
         'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator',...
             'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
            'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'Mask Entries','1\/0\/')


%     Finished composite block ['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator'].

set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'position',[80,109,140,141])

add_block('built-in/Constant',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Constant']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Constant']],...
             'Value','Fc',...
                'position',[35,115,55,135])

add_block('built-in/Note',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
                'position',[285,280,290,285])

add_block('built-in/Inport',[sys,'/',['Quad multi',13,'DSB-SC-ADM/in_1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/in_1']],...
              'position',[230,120,250,140])

add_block('built-in/Gain',[sys,'/',['Quad multi',13,'DSB-SC-ADM/Gain1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM/Gain1']],...
              'Gain','2',...
          'position',[270,118,295,142])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[450,185;475,185])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[360,185;390,185])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[450,80;475,80])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[360,80;390,80])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[300,190;325,190])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[305,70;325,70])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[205,125;215,190])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[205,125;205,70;220,70])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[145,125;160,125])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[60,125;75,125])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[255,130;265,130])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['Quad multi',13,'DSB-SC-ADM']],[300,130;305,130;305,175;325,175])
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM']],...
             'Mask Display','QM\nDSB-SC\nADM',...
            'Mask Type','Quadrature Demultiplexed DSB-SC AM')
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM']],...
         'Mask Dialogue','Quadrature Demultiplexed Double-Sideband Suppressed-Carrier Amplitude Demodulation:|Carrier amplitude:|Carrier frequency:|Initial phase:|Filter numerator:|Filter denominator:')
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM']],...
         'Mask Translate','Ac=@1;Fc=@2;Ph=@3;Fn=@4;Fd=@5;pi2=2*pi;Pg=Ph+pi/2;')
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM']],...
            'Mask Help','The Quadratic Demultiplexed Double-Sideband Supressed-Carrier Amplitude Demodulation block demodulates the QM-DSB-SC-AM signal using quadratic duplex method.')
set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM']],...
           'Mask Entries','1\/100\/0\/[3.0002, 0, 40002]\/[1, 67.46, 2270.9, 40002]\/')


%     Finished composite block ['Quad multi',13,'DSB-SC-ADM'].

set_param([sys,'/',['Quad multi',13,'DSB-SC-ADM']],...
                'ForeGround',5,...
              'position',[375,64,450,111])


%     Subsystem  ['Auto-Scale',13,'Graph1'].

new_system([sys,'/',['Auto-Scale',13,'Graph1']])
set_param([sys,'/',['Auto-Scale',13,'Graph1']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph1/S-function',13,'M-file which plots',13,'lines',13,'']],...
                'function name','sfunyst',...
           'parameters','ax, color, npts, dt',...
          'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph1/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph1/x']],...
              'position',[65,55,85,75])
add_line([sys,'/',['Auto-Scale',13,'Graph1']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
                'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
              'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
         'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):|Sample time:')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
         'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=@6;')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
               'Mask Help','Uses MATLAB''s graph window.\nUse only one block per system.\nLine type must be in quotes.\nSee the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
          'Mask Entries','.5\/-1.5\/1.5\/200\/''r-/r:/b-/y-/y:/ro/b+''\/0\/')


%     Finished composite block ['Auto-Scale',13,'Graph1'].

set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
         'position',[655,35,685,75])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
             'inputs','5',...
                'position',[590,30,630,80])

add_block('built-in/Note',[sys,'/','demodulated output'])
set_param([sys,'/','demodulated output'],...
                'ForeGround',5,...
              'position',[505,75,510,80])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[258,104,727,268])

add_block('built-in/Note',[sys,'/',['Subsystem/There is a time delay between the original signal and the demodulated',13,'signal because the filters are used in the demodulation.                    ']])
set_param([sys,'/',['Subsystem/There is a time delay between the original signal and the demodulated',13,'signal because the filters are used in the demodulation.                    ']],...
           'position',[230,105,235,110])

add_block('built-in/Note',[sys,'/','Subsystem/The blue signal is the modulated output'])
set_param([sys,'/','Subsystem/The blue signal is the modulated output'],...
                'ForeGround',4,...
              'position',[145,65,150,70])

add_block('built-in/Note',[sys,'/','Subsystem/This test file is to test Quadrature Multiplier Output.'])
set_param([sys,'/','Subsystem/This test file is to test Quadrature Multiplier Output.'],...
          'position',[180,25,185,30])

add_block('built-in/Note',[sys,'/','Subsystem/The red signals are the system input signals.'])
set_param([sys,'/','Subsystem/The red signals are the system input signals.'],...
              'ForeGround',2,...
              'position',[160,45,165,50])

add_block('built-in/Note',[sys,'/','Subsystem/The yellow signal is the demodulated output.'])
set_param([sys,'/','Subsystem/The yellow signal is the demodulated output.'],...
                'ForeGround',5,...
              'position',[160,85,165,90])
set_param([sys,'/','Subsystem'],...
          'Mask Display','?')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
               'hide name',0,...
               'Drop Shadow',4,...
             'position',[600,120,630,156])


%     Subsystem  ['Quad multi',13,'DSB-SC-AM'].

new_system([sys,'/',['Quad multi',13,'DSB-SC-AM']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM']],'Location',[99,142,631,346])

add_block('built-in/Inport',[sys,'/',['Quad multi',13,'DSB-SC-AM/in_2']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/in_2']],...
                'Port','2',...
          'position',[160,145,180,165])

add_block('built-in/Inport',[sys,'/',['Quad multi',13,'DSB-SC-AM/in_1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/in_1']],...
                'position',[160,30,180,50])

add_block('built-in/Gain',[sys,'/',['Quad multi',13,'DSB-SC-AM/Gain']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Gain']],...
            'Gain','pi2',...
                'position',[155,79,190,111])

add_block('built-in/Fcn',[sys,'/',['Quad multi',13,'DSB-SC-AM/Fcn1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Fcn1']],...
            'Expr','sin(u[1]+Pg)',...
               'position',[235,106,310,134])

add_block('built-in/Outport',[sys,'/',['Quad multi',13,'DSB-SC-AM/out_1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/out_1']],...
             'position',[490,90,510,110])

add_block('built-in/Sum',[sys,'/',['Quad multi',13,'DSB-SC-AM/Sum2']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Sum2']],...
            'position',[430,90,450,110])

add_block('built-in/Product',[sys,'/',['Quad multi',13,'DSB-SC-AM/Product1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Product1']],...
                'position',[355,112,380,143])

add_block('built-in/Product',[sys,'/',['Quad multi',13,'DSB-SC-AM/Product']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Product']],...
         'position',[355,47,380,78])

add_block('built-in/Fcn',[sys,'/',['Quad multi',13,'DSB-SC-AM/Fcn']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Fcn']],...
               'Expr','sin(u[1]+Ph)',...
               'position',[235,56,310,84])

add_block('built-in/Note',[sys,'/',['Quad multi',13,'DSB-SC-AM/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
          'position',[250,305,255,310])

add_block('built-in/Constant',[sys,'/',['Quad multi',13,'DSB-SC-AM/Constant']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Constant']],...
              'Value','Fc',...
                'position',[25,85,45,105])


%     Subsystem  ['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator'].

new_system([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/in_1']],...
               'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Memory']],...
          'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/module']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/module']],...
          'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Reset',13,'integrator']],...
                'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/one']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/one']],...
            'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Sum']],...
           'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/out_1']],...
         'position',[370,30,390,50])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator',...
             'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
             'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
               'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
               'Mask Entries','1\/0\/')


%     Finished composite block ['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator'].

set_param([sys,'/',['Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
                'position',[70,79,130,111])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[385,130;400,130;400,105;425,105])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[185,155;320,155;320,135;350,135])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[315,120;350,120])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[185,40;325,40;325,55;350,55])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[315,70;350,70])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[195,95;205,95;205,70;230,70])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[205,95;205,120;230,120])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[455,100;485,100])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[135,95;150,95])
add_line([sys,'/',['Quad multi',13,'DSB-SC-AM']],[50,95;65,95])
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM']],...
            'Mask Display','QM\nDSB-SC\nAM',...
             'Mask Type','Quadrature Multiplexed DSB-SC AM')
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM']],...
            'Mask Dialogue','Quadrature multiplexed double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency:|Initial phase:')
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM']],...
               'Mask Translate','Am=@1;Fc=@2;Ph=@3;Pg=Ph+pi/2;pi2=pi*2;')
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM']],...
         'Mask Help','The Quadratic Multiplexed Double-sideband-supressed-carrier AM block causes the amplitude of the sinusoidal carrier to depend on the input message Signal, resulting in amplitude modulation. There are two input Signal being modulated at the same time using quadratic multiplex method.')
set_param([sys,'/',['Quad multi',13,'DSB-SC-AM']],...
              'Mask Entries','1\/100\/0\/')


%     Finished composite block ['Quad multi',13,'DSB-SC-AM'].

set_param([sys,'/',['Quad multi',13,'DSB-SC-AM']],...
         'ForeGround',4,...
              'position',[215,68,285,112])

add_block('built-in/Note',[sys,'/','The curve color in the graphical scope matches the color of the blocks in the block diagram'])
set_param([sys,'/','The curve color in the graphical scope matches the color of the blocks in the block diagram'],...
             'position',[325,150,330,155])

add_block('built-in/Note',[sys,'/','signal source 2'])
set_param([sys,'/','signal source 2'],...
            'ForeGround',2,...
              'position',[135,75,140,80])

add_block('built-in/Note',[sys,'/','signal source 1'])
set_param([sys,'/','signal source 1'],...
              'ForeGround',2,...
              'position',[135,10,140,15])

add_block('built-in/Sine Wave',[sys,'/','Sine wave'])
set_param([sys,'/','Sine wave'],...
             'ForeGround',2,...
              'frequency','5',...
             'phase','pi/2',...
              'position',[65,25,85,45])

add_block('built-in/Sine Wave',[sys,'/','Sine wave1'])
set_param([sys,'/','Sine wave1'],...
             'ForeGround',2,...
              'frequency','7',...
             'position',[65,90,85,110])
add_line(sys,[90,35;130,35;130,80;210,80])
add_line(sys,[90,100;210,100])
add_line(sys,[290,90;370,90])
add_line(sys,[455,100;565,100;565,75;585,75])
add_line(sys,[455,75;485,75;485,65;585,65])
add_line(sys,[130,35;585,35])
add_line(sys,[635,55;650,55])
add_line(sys,[355,90;355,55;585,55])
add_line(sys,[195,100;195,45;585,45])

drawnow

% Return any arguments.
if (nargin | nargout)
   % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
else
 drawnow % Flash up the model and execute load callback
end
