function [ret,x0,str,ts,xts]=tstqask(t,x,u,flag);
%TSTQASK       is the M-file description of the SIMULINK system named TSTQASK.
%        The block-diagram can be displayed by typing: TSTQASK.
%
%        SYS=TSTQASK(T,X,U,FLAG) returns depending on FLAG certain
%      system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes TSTQASK to return state derivatives, FLAG=2
%      discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling TSTQASK with a FLAG of zero:
%   [SIZES]=TSTQASK([],[],[],0),  returns a vector, SIZES, which
%   contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs
%              SIZES(5) number of roots (currently unsupported)
%               SIZES(6) direct feedthrough flag
%               SIZES(7) number of sample times
%
%       For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[2,429,830,856])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '.003')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','N=16;T=.1;Fc=100;');


%     Subsystem  ['Random-number',13,'generator'].

new_system([sys,'/',['Random-number',13,'generator']])
set_param([sys,'/',['Random-number',13,'generator']],'Location',[115,400,471,569])

add_block('built-in/White Noise',[sys,'/',['Random-number',13,'generator/Random',13,'Number']])
set_param([sys,'/',['Random-number',13,'generator/Random',13,'Number']],...
              'Seed','seed',...
               'position',[40,27,85,63])

add_block('built-in/Relational Operator',[sys,'/',['Random-number',13,'generator/Relational',13,'Operator']])
set_param([sys,'/',['Random-number',13,'generator/Relational',13,'Operator']],...
         'position',[155,38,185,62])

add_block('built-in/Outport',[sys,'/',['Random-number',13,'generator/out_1']])
set_param([sys,'/',['Random-number',13,'generator/out_1']],...
         'position',[310,40,330,60])

add_block('built-in/State-Space',[sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']])
set_param([sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']],...
               'A','[]',...
            'B','[]',...
            'C','[]',...
            'D','K',...
             'Mask Display','K',...
          'Mask Type','Matrix Gain',...
           'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']],...
           'Mask Translate','K = @1;',...
          'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
            'Mask Entries','ones(1,N-1)\/')
set_param([sys,'/',['Random-number',13,'generator/Matrix',13,'Gain']],...
                'position',[230,35,275,65])

add_block('built-in/Constant',[sys,'/',['Random-number',13,'generator/Constant']])
set_param([sys,'/',['Random-number',13,'generator/Constant']],...
          'Value','x',...
         'position',[65,105,95,125])
add_line([sys,'/',['Random-number',13,'generator']],[280,50;305,50])
add_line([sys,'/',['Random-number',13,'generator']],[190,50;225,50])
add_line([sys,'/',['Random-number',13,'generator']],[100,115;115,115;115,55;150,55])
add_line([sys,'/',['Random-number',13,'generator']],[90,45;150,45])
set_param([sys,'/',['Random-number',13,'generator']],...
              'Mask Display','Random\nNumber',...
             'Mask Type','Random number generator',...
               'Mask Dialogue','Random number generator:|M-ary number:|Seed:')
set_param([sys,'/',['Random-number',13,'generator']],...
              'Mask Translate','N=@1;x=[(2-N)/N:2/N:(N-2)/N];seed=@2;')
set_param([sys,'/',['Random-number',13,'generator']],...
               'Mask Help','This block generate integer number 0 to M-1, where M is a integer. The probability of the apperance for each number is not guaranteed to be the same.')
set_param([sys,'/',['Random-number',13,'generator']],...
            'Mask Entries','N\/4432\/')


%     Finished composite block ['Random-number',13,'generator'].

set_param([sys,'/',['Random-number',13,'generator']],...
             'BackGround',5,...
              'position',[50,30,110,70])


%     Subsystem  ['Clock',13,'pulse'].

new_system([sys,'/',['Clock',13,'pulse']])
set_param([sys,'/',['Clock',13,'pulse']],'Location',[272,165,909,406])

add_block('built-in/Unit Delay',[sys,'/',['Clock',13,'pulse/Unit Delay1']])
set_param([sys,'/',['Clock',13,'pulse/Unit Delay1']],...
             'orientation',2,...
             'Sample time','[Ts/2,st2]',...
          'x0','ini',...
          'position',[140,165,190,185])

add_block('built-in/Unit Delay',[sys,'/',['Clock',13,'pulse/Unit Delay']])
set_param([sys,'/',['Clock',13,'pulse/Unit Delay']],...
          'orientation',2,...
             'Sample time','[Ts/2,st1]',...
          'position',[145,75,195,95])

add_block('built-in/Gain',[sys,'/',['Clock',13,'pulse/Gain1']])
set_param([sys,'/',['Clock',13,'pulse/Gain1']],...
            'Gain','g',...
          'position',[235,122,255,138])

add_block('built-in/Constant',[sys,'/',['Clock',13,'pulse/Constant']])
set_param([sys,'/',['Clock',13,'pulse/Constant']],...
                'position',[25,30,45,50])

add_block('built-in/Saturation',[sys,'/',['Clock',13,'pulse/Saturation']])
set_param([sys,'/',['Clock',13,'pulse/Saturation']],...
              'Lower Limit','0',...
           'Upper Limit','1',...
           'position',[365,40,390,60])

add_block('built-in/Sum',[sys,'/',['Clock',13,'pulse/Sum2']])
set_param([sys,'/',['Clock',13,'pulse/Sum2']],...
               'hide name',0,...
               'inputs','+-',...
               'position',[300,40,320,60])

add_block('built-in/Sum',[sys,'/',['Clock',13,'pulse/Sum']])
set_param([sys,'/',['Clock',13,'pulse/Sum']],...
         'hide name',0,...
               'inputs','+-',...
               'position',[135,35,155,55])

add_block('built-in/Sum',[sys,'/',['Clock',13,'pulse/Sum1']])
set_param([sys,'/',['Clock',13,'pulse/Sum1']],...
               'hide name',0,...
               'inputs','+-',...
               'position',[130,120,150,140])

add_block('built-in/Relational Operator',[sys,'/',['Clock',13,'pulse/Relational',13,'operator']])
set_param([sys,'/',['Clock',13,'pulse/Relational',13,'operator']],...
             'hide name',0,...
               'position',[370,102,400,133])

add_block('built-in/Gain',[sys,'/',['Clock',13,'pulse/Gain']])
set_param([sys,'/',['Clock',13,'pulse/Gain']],...
            'hide name',0,...
               'Gain','ht',...
         'position',[540,102,565,128])

add_block('built-in/Product',[sys,'/',['Clock',13,'pulse/Product']])
set_param([sys,'/',['Clock',13,'pulse/Product']],...
           'hide name',0,...
               'position',[470,105,495,125])

add_block('built-in/Clock',[sys,'/',['Clock',13,'pulse/Clock1']])
set_param([sys,'/',['Clock',13,'pulse/Clock1']],...
               'hide name',0,...
               'position',[295,100,315,120])

add_block('built-in/Constant',[sys,'/',['Clock',13,'pulse/Constant1']])
set_param([sys,'/',['Clock',13,'pulse/Constant1']],...
              'Value','stt',...
               'position',[295,149,320,171])

add_block('built-in/Outport',[sys,'/',['Clock',13,'pulse/out_1']])
set_param([sys,'/',['Clock',13,'pulse/out_1']],...
               'hide name',0,...
               'position',[590,105,610,125])
add_line([sys,'/',['Clock',13,'pulse']],[260,130;275,130;275,55;295,55])
add_line([sys,'/',['Clock',13,'pulse']],[155,130;230,130])
add_line([sys,'/',['Clock',13,'pulse']],[325,50;360,50])
add_line([sys,'/',['Clock',13,'pulse']],[160,45;295,45])
add_line([sys,'/',['Clock',13,'pulse']],[50,40;70,40;70,125;125,125])
add_line([sys,'/',['Clock',13,'pulse']],[135,175;100,175;100,135;125,135])
add_line([sys,'/',['Clock',13,'pulse']],[155,130;210,130;210,175;195,175])
add_line([sys,'/',['Clock',13,'pulse']],[50,40;130,40])
add_line([sys,'/',['Clock',13,'pulse']],[160,45;230,45;230,85;200,85])
add_line([sys,'/',['Clock',13,'pulse']],[140,85;105,85;105,50;130,50])
add_line([sys,'/',['Clock',13,'pulse']],[320,110;365,110])
add_line([sys,'/',['Clock',13,'pulse']],[405,120;465,120])
add_line([sys,'/',['Clock',13,'pulse']],[500,115;535,115])
add_line([sys,'/',['Clock',13,'pulse']],[570,115;585,115])
add_line([sys,'/',['Clock',13,'pulse']],[325,160;345,160;345,125;365,125])
add_line([sys,'/',['Clock',13,'pulse']],[395,50;430,50;430,110;465,110])
set_param([sys,'/',['Clock',13,'pulse']],...
               'Mask Display','plot(0,0,100,100,[90,75,75,60,60,35,35,20,20,10],[20,20,80,80,20,20,80,80,20,20])',...
          'Mask Type','Pulse Generator')
set_param([sys,'/',['Clock',13,'pulse']],...
              'Mask Dialogue','Pulse Generator.|Pulse period (secs):|Pulse width:|Pulse height:|Pulse start time:')
set_param([sys,'/',['Clock',13,'pulse']],...
               'Mask Translate','Ts=@1; du=@2; ht=@3; stt=@4; g=1; ini=ones(length(@3),1); if (Ts<2*du), g=-1; du=du-Ts/2; ini=zeros(length(@3),1); end; st1=rem(stt,Ts); st2=rem(stt+du,Ts);')
set_param([sys,'/',['Clock',13,'pulse']],...
            'Mask Help','Pulse generator which ensures pulse\ntransitions are hit. Provides a vector of pulses when the height is entered as a vector.\nUnmask to see how it works.')
set_param([sys,'/',['Clock',13,'pulse']],...
           'Mask Entries','T\/.05\/1\/0\/')


%     Finished composite block ['Clock',13,'pulse'].

set_param([sys,'/',['Clock',13,'pulse']],...
                'BackGround',4,...
              'position',[65,267,100,303])


%     Subsystem  ['Encoding only',13,'no-modu'].

new_system([sys,'/',['Encoding only',13,'no-modu']])
set_param([sys,'/',['Encoding only',13,'no-modu']],'Location',[162,454,805,711])

add_block('built-in/Outport',[sys,'/',['Encoding only',13,'no-modu/out_1']])
set_param([sys,'/',['Encoding only',13,'no-modu/out_1']],...
                'position',[565,85,585,105])

add_block('built-in/Inport',[sys,'/',['Encoding only',13,'no-modu/in_1']])
set_param([sys,'/',['Encoding only',13,'no-modu/in_1']],...
               'position',[65,50,85,70])

add_block('built-in/Look Up Table',[sys,'/',['Encoding only',13,'no-modu/c-y axis']])
set_param([sys,'/',['Encoding only',13,'no-modu/c-y axis']],...
           'Input_Values','z',...
          'Output_Values','y',...
         'position',[355,110,380,130])

add_block('built-in/Look Up Table',[sys,'/',['Encoding only',13,'no-modu/s-x axis']])
set_param([sys,'/',['Encoding only',13,'no-modu/s-x axis']],...
               'Input_Values','z',...
          'Output_Values','x',...
         'position',[355,60,380,80])

add_block('built-in/Switch',[sys,'/',['Encoding only',13,'no-modu/Switch']])
set_param([sys,'/',['Encoding only',13,'no-modu/Switch']],...
            'Threshold','eps',...
           'position',[215,54,245,86])

add_block('built-in/Memory',[sys,'/',['Encoding only',13,'no-modu/Memory1']])
set_param([sys,'/',['Encoding only',13,'no-modu/Memory1']],...
          'orientation',2,...
             'position',[210,105,250,135])


%     Subsystem  ['Encoding only',13,'no-modu/Rising edge',13,'detector'].

new_system([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']])
set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/out_1']],...
             'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/Relational',13,'Operator1']],...
             'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/Relational',13,'Operator2']],...
            'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/one1']],...
          'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/Memory1']],...
              'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/in_1']],...
           'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector/Relational',13,'Operator']],...
         'position',[135,18,165,42])
add_line([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],...
                'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],...
            'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['Encoding only',13,'no-modu/Rising edge',13,'detector'].

set_param([sys,'/',['Encoding only',13,'no-modu/Rising edge',13,'detector']],...
                'position',[115,138,175,182])

add_block('built-in/Inport',[sys,'/',['Encoding only',13,'no-modu/in_2']])
set_param([sys,'/',['Encoding only',13,'no-modu/in_2']],...
              'Port','2',...
          'position',[65,150,85,170])

add_block('built-in/Outport',[sys,'/',['Encoding only',13,'no-modu/out_2']])
set_param([sys,'/',['Encoding only',13,'no-modu/out_2']],...
             'Port','2',...
          'position',[565,130,585,150])
add_line([sys,'/',['Encoding only',13,'no-modu']],[385,120;400,120;400,105;430,105;560,140])
add_line([sys,'/',['Encoding only',13,'no-modu']],[385,70;400,70;400,85;430,85;510,95;560,95])
add_line([sys,'/',['Encoding only',13,'no-modu']],[250,70;275,70;275,120;255,120])
add_line([sys,'/',['Encoding only',13,'no-modu']],[275,120;350,120])
add_line([sys,'/',['Encoding only',13,'no-modu']],[275,70;350,70])
add_line([sys,'/',['Encoding only',13,'no-modu']],[90,60;210,60])
add_line([sys,'/',['Encoding only',13,'no-modu']],[90,160;110,160])
add_line([sys,'/',['Encoding only',13,'no-modu']],[205,120;190,120;190,80;210,80])
add_line([sys,'/',['Encoding only',13,'no-modu']],[180,160;185,160;185,70;210,70])
set_param([sys,'/',['Encoding only',13,'no-modu']],...
           'Mask Display','MQASK',...
              'Mask Type','MQASK')
set_param([sys,'/',['Encoding only',13,'no-modu']],...
              'Mask Dialogue','M-ary Amplitude Shift Keying Modulation:|M-ary number:|Carrier frequency:|Maximum amplitude:|Trigger signal threshold:|Initial phase:')
set_param([sys,'/',['Encoding only',13,'no-modu']],...
            'Mask Translate','N=@1;Fc=@2;Ac=@3;thld=@4;Ph=@5;z=[[1:N];[1:N]];z=z(:);[x,y]=qaskenco(z,N);z=z-1.5;z=[z(2:2*N);N-.5];x=x/max(x);y=y/max(y);')
set_param([sys,'/',['Encoding only',13,'no-modu']],...
            'Mask Help','This block modulates an M-ary digital signal onto a given carrier frequency using amplitude shift keying method. The first input port is for the original digital signal, which is coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input.')
set_param([sys,'/',['Encoding only',13,'no-modu']],...
         'Mask Entries','N\/Fc\/1\/.2\/0\/')


%     Finished composite block ['Encoding only',13,'no-modu'].

set_param([sys,'/',['Encoding only',13,'no-modu']],...
         'position',[185,198,245,242])


%     Subsystem  ['Multiple',13,'QASK'].

new_system([sys,'/',['Multiple',13,'QASK']])
set_param([sys,'/',['Multiple',13,'QASK']],'Location',[130,348,773,605])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/in_2']])
set_param([sys,'/',['Multiple',13,'QASK/in_2']],...
          'Port','2',...
          'position',[65,150,85,170])


%     Subsystem  ['Multiple',13,'QASK/Rising edge',13,'detector'].

new_system([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator']],...
             'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/in_1']],...
            'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Memory1']],...
                'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/one1']],...
         'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator2']],...
             'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator1']],...
             'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/out_1']],...
                'position',[340,25,360,45])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],...
                'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],...
            'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['Multiple',13,'QASK/Rising edge',13,'detector'].

set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],...
                'position',[115,138,175,182])

add_block('built-in/Memory',[sys,'/',['Multiple',13,'QASK/Memory1']])
set_param([sys,'/',['Multiple',13,'QASK/Memory1']],...
                'orientation',2,...
             'position',[210,105,250,135])

add_block('built-in/Switch',[sys,'/',['Multiple',13,'QASK/Switch']])
set_param([sys,'/',['Multiple',13,'QASK/Switch']],...
          'Threshold','eps',...
           'position',[215,54,245,86])

add_block('built-in/Look Up Table',[sys,'/',['Multiple',13,'QASK/s-x axis']])
set_param([sys,'/',['Multiple',13,'QASK/s-x axis']],...
         'Input_Values','z',...
          'Output_Values','x',...
         'position',[355,60,380,80])

add_block('built-in/Look Up Table',[sys,'/',['Multiple',13,'QASK/c-y axis']])
set_param([sys,'/',['Multiple',13,'QASK/c-y axis']],...
         'Input_Values','z',...
          'Output_Values','y',...
         'position',[355,110,380,130])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/in_1']])
set_param([sys,'/',['Multiple',13,'QASK/in_1']],...
              'position',[65,50,85,70])

add_block('built-in/Outport',[sys,'/',['Multiple',13,'QASK/out_1']])
set_param([sys,'/',['Multiple',13,'QASK/out_1']],...
               'position',[565,85,585,105])


%     Subsystem  ['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM'].

new_system([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],'Location',[122,503,654,707])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/in_2']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/in_2']],...
         'Port','2',...
          'position',[160,145,180,165])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/in_1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/in_1']],...
          'position',[160,30,180,50])

add_block('built-in/Gain',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Gain']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Gain']],...
              'Gain','pi2',...
                'position',[155,79,190,111])

add_block('built-in/Fcn',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Fcn1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Fcn1']],...
              'Expr','sin(u[1]+Pg)',...
               'position',[235,106,310,134])

add_block('built-in/Outport',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/out_1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/out_1']],...
               'position',[490,90,510,110])

add_block('built-in/Sum',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Sum2']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Sum2']],...
              'position',[430,90,450,110])

add_block('built-in/Product',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Product1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Product1']],...
          'position',[355,112,380,143])

add_block('built-in/Product',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Product']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Product']],...
           'position',[355,47,380,78])

add_block('built-in/Fcn',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Fcn']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Fcn']],...
         'Expr','sin(u[1]+Ph)',...
               'position',[235,56,310,84])

add_block('built-in/Note',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
            'position',[250,305,255,310])

add_block('built-in/Constant',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Constant']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Constant']],...
                'Value','Fc',...
                'position',[25,85,45,105])


%     Subsystem  ['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator'].

new_system([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/in_1']],...
                'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Memory']],...
            'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/module']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/module']],...
            'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Reset',13,'integrator']],...
          'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/one']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/one']],...
              'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Sum']],...
             'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/out_1']],...
           'position',[370,30,390,50])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
         'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
              'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
            'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
            'Mask Entries','1\/0\/')


%     Finished composite block ['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator'].

set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
          'position',[70,79,130,111])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[385,130;400,130;400,105;425,105])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[185,155;320,155;320,135;350,135])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[315,120;350,120])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[185,40;325,40;325,55;350,55])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[315,70;350,70])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[195,95;205,95;205,70;230,70])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[205,95;205,120;230,120])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[455,100;485,100])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[135,95;150,95])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[50,95;65,95])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
                'Mask Display','QM\nDSB-SC\nAM',...
             'Mask Type','Quadrature Multiplexed DSB-SC AM')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
         'Mask Dialogue','Quadrature multiplexed double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency:|Initial phase:')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
            'Mask Translate','Am=@1;Fc=@2;Ph=@3;Pg=Ph+pi/2;pi2=pi*2;')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
              'Mask Help','The Quadratic Multiplexed Double-sideband-supressed-carrier AM block causes the amplitude of the sinusoidal carrier to depend on the input message Signal, resulting in amplitude modulation. There are two input Signal being modulated at the same time using quadratic multiplex method.')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
           'Mask Entries','Ac\/Fc\/Ph\/')


%     Finished composite block ['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM'].

set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
          'ForeGround',4,...
              'position',[435,73,505,117])
add_line([sys,'/',['Multiple',13,'QASK']],[250,70;275,70;275,120;255,120])
add_line([sys,'/',['Multiple',13,'QASK']],[180,160;185,160;185,70;210,70])
add_line([sys,'/',['Multiple',13,'QASK']],[205,120;190,120;190,80;210,80])
add_line([sys,'/',['Multiple',13,'QASK']],[90,160;110,160])
add_line([sys,'/',['Multiple',13,'QASK']],[90,60;210,60])
add_line([sys,'/',['Multiple',13,'QASK']],[275,70;350,70])
add_line([sys,'/',['Multiple',13,'QASK']],[275,120;350,120])
add_line([sys,'/',['Multiple',13,'QASK']],[385,70;400,70;400,85;430,85])
add_line([sys,'/',['Multiple',13,'QASK']],[385,120;400,120;400,105;430,105])
add_line([sys,'/',['Multiple',13,'QASK']],[510,95;560,95])
set_param([sys,'/',['Multiple',13,'QASK']],...
                'Mask Display','MQASK',...
              'Mask Type','MQASK')
set_param([sys,'/',['Multiple',13,'QASK']],...
              'Mask Dialogue','M-ary Amplitude Shift Keying Modulation:|M-ary number:|Carrier frequency:|Maximum amplitude:|Trigger signal threshold:|Initial phase:')
set_param([sys,'/',['Multiple',13,'QASK']],...
            'Mask Translate','N=@1;Fc=@2;Ac=@3;thld=@4;Ph=@5;z=[[1:N];[1:N]];z=z(:);[x,y]=qaskenco(z,N);z=z-1.5;z=[z(2:2*N);N-.5];x=x/max(x);y=y/max(y);')
set_param([sys,'/',['Multiple',13,'QASK']],...
            'Mask Help','This block modulates modulates the first port inputted message by quadrature amplitude shift keying method. The message should be coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. You may change the coding method by modifying functions QASKENCO and QASKDECO.')
set_param([sys,'/',['Multiple',13,'QASK']],...
                'Mask Entries','N\/Fc\/1\/.2\/0\/')


%     Finished composite block ['Multiple',13,'QASK'].

set_param([sys,'/',['Multiple',13,'QASK']],...
         'position',[185,108,245,152])

add_block('built-in/Sum',[sys,'/','Sum5'])
set_param([sys,'/','Sum5'],...
           'position',[295,125,315,145])


%     Subsystem  ['Decoding only',13,'no-demo'].

new_system([sys,'/',['Decoding only',13,'no-demo']])
set_param([sys,'/',['Decoding only',13,'no-demo']],'Location',[73,484,948,784])

add_block('built-in/Sum',[sys,'/',['Decoding only',13,'no-demo/Sum5']])
set_param([sys,'/',['Decoding only',13,'no-demo/Sum5']],...
              'position',[635,143,655,172])

add_block('built-in/Sum',[sys,'/',['Decoding only',13,'no-demo/Sum4']])
set_param([sys,'/',['Decoding only',13,'no-demo/Sum4']],...
         'position',[630,58,650,87])

add_block('built-in/Constant',[sys,'/',['Decoding only',13,'no-demo/Shift key2']])
set_param([sys,'/',['Decoding only',13,'no-demo/Shift key2']],...
          'position',[540,119,565,141])

add_block('built-in/Sum',[sys,'/',['Decoding only',13,'no-demo/Sum3']])
set_param([sys,'/',['Decoding only',13,'no-demo/Sum3']],...
         'inputs','+-',...
               'position',[740,98,760,127])

add_block('built-in/Saturation',[sys,'/',['Decoding only',13,'no-demo/Saturation']])
set_param([sys,'/',['Decoding only',13,'no-demo/Saturation']],...
               'Lower Limit','0',...
           'Upper Limit','N-1',...
         'position',[785,103,815,127])

add_block('built-in/Outport',[sys,'/',['Decoding only',13,'no-demo/out_1']])
set_param([sys,'/',['Decoding only',13,'no-demo/out_1']],...
           'position',[845,105,865,125])

add_block('built-in/Sum',[sys,'/',['Decoding only',13,'no-demo/Sum1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Sum1']],...
         'inputs','+-',...
               'position',[440,33,460,62])


%     Subsystem  ['Decoding only',13,'no-demo/2-D Look-Up',13,'Table'].

new_system([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']])
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],'Location',[436,148,718,302])

add_block('built-in/Mux',[sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table/Mux']])
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table/Mux']],...
              'inputs','2',...
                'position',[90,46,120,79])

add_block('built-in/S-Function',[sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table/S-function']])
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table/S-function']],...
           'function name','sftable2',...
          'parameters','xindex, yindex, table',...
                'position',[140,52,190,78])

add_block('built-in/Inport',[sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table/x0']])
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table/x0']],...
              'position',[20,25,40,45])

add_block('built-in/Outport',[sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table/table out']])
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table/table out']],...
         'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table/y0']])
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table/y0']],...
              'Port','2',...
          'position',[20,80,40,100])
add_line([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],[125,65;135,65])
add_line([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],[45,35;65,35;65,55;85,55])
add_line([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],[195,65;210,65])
add_line([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],[45,90;65,90;65,70;85,70])
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],...
         'Mask Display','plot(-10,-10,110,110,[90,50,10],[90,40,30],[90,50,10],[50,26,20],[90,50,10],[22,13,10])',...
            'Mask Type','2-D Table Lookup')
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],...
            'Mask Dialogue','Two Dimensional Table Lookup\nThe first input corresponds to X Index and the second input corresponds to the Y Index|X Index|Y Index|Table')
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],...
              'Mask Translate','xindex=@1; yindex=@2; table=@3; sftab2chk(xindex,yindex,table);')
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],...
                'Mask Help','This block returns a linearly interpolated intersection from the table using the X index (which corresponds to the rows of the table) and the Y index (which corresponds to the columns of the table).  Extrapolation is used.')
set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],...
              'Mask Entries','x\/y\/tab\/')


%     Finished composite block ['Decoding only',13,'no-demo/2-D Look-Up',13,'Table'].

set_param([sys,'/',['Decoding only',13,'no-demo/2-D Look-Up',13,'Table']],...
         'position',[675,93,705,117])

add_block('built-in/Memory',[sys,'/',['Decoding only',13,'no-demo/Memory2']])
set_param([sys,'/',['Decoding only',13,'no-demo/Memory2']],...
         'orientation',2,...
             'ForeGround',2,...
              'position',[300,205,340,235])

add_block('built-in/Switch',[sys,'/',['Decoding only',13,'no-demo/Switch2']])
set_param([sys,'/',['Decoding only',13,'no-demo/Switch2']],...
                'ForeGround',2,...
              'Threshold','eps',...
           'position',[305,149,335,181])

add_block('built-in/Sum',[sys,'/',['Decoding only',13,'no-demo/Sum2']])
set_param([sys,'/',['Decoding only',13,'no-demo/Sum2']],...
         'inputs','+-',...
               'position',[450,158,470,187])

add_block('built-in/Abs',[sys,'/',['Decoding only',13,'no-demo/Abs']])
set_param([sys,'/',['Decoding only',13,'no-demo/Abs']],...
           'position',[500,163,530,187])

add_block('built-in/S-Function',[sys,'/',['Decoding only',13,'no-demo/Minimum']])
set_param([sys,'/',['Decoding only',13,'no-demo/Minimum']],...
            'function name','arraymin',...
          'position',[555,165,610,185])

add_block('built-in/Constant',[sys,'/',['Decoding only',13,'no-demo/Shift key']])
set_param([sys,'/',['Decoding only',13,'no-demo/Shift key']],...
          'Value','sfty',...
              'position',[385,214,410,236])

add_block('built-in/Memory',[sys,'/',['Decoding only',13,'no-demo/Memory1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Memory1']],...
                'orientation',2,...
             'ForeGround',2,...
              'position',[295,80,335,110])

add_block('built-in/Switch',[sys,'/',['Decoding only',13,'no-demo/Switch1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Switch1']],...
         'ForeGround',2,...
              'Threshold','eps',...
           'position',[300,24,330,56])

add_block('built-in/Abs',[sys,'/',['Decoding only',13,'no-demo/Abs1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Abs1']],...
           'position',[495,38,525,62])

add_block('built-in/S-Function',[sys,'/',['Decoding only',13,'no-demo/Minimum1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Minimum1']],...
            'function name','arraymin',...
          'position',[550,40,605,60])

add_block('built-in/Constant',[sys,'/',['Decoding only',13,'no-demo/Shift key1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Shift key1']],...
          'Value','sftx',...
              'position',[380,89,405,111])


%     Subsystem  ['Decoding only',13,'no-demo/Rising edge',13,'detector'].

new_system([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']])
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],'Location',[431,241,820,415])

add_block('built-in/Relational Operator',[sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/Relational',13,'Operator']],...
            'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/in_1']],...
            'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/Memory1']],...
                'x0','ini',...
          'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/one1']],...
         'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/Relational',13,'Operator2']],...
             'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/Relational',13,'Operator1']],...
             'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector/out_1']],...
                'position',[340,25,360,45])
add_line([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],...
                'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:|Initial condition:')
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],...
         'Mask Translate','thld=@1;ini=@2;',...
          'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],...
            'Mask Entries','thld\/0\/')


%     Finished composite block ['Decoding only',13,'no-demo/Rising edge',13,'detector'].

set_param([sys,'/',['Decoding only',13,'no-demo/Rising edge',13,'detector']],...
             'ForeGround',4,...
              'position',[125,168,185,212])

add_block('built-in/Inport',[sys,'/',['Decoding only',13,'no-demo/in_3']])
set_param([sys,'/',['Decoding only',13,'no-demo/in_3']],...
              'Port','3',...
          'position',[35,180,55,200])

add_block('built-in/Inport',[sys,'/',['Decoding only',13,'no-demo/in_1']])
set_param([sys,'/',['Decoding only',13,'no-demo/in_1']],...
                'position',[45,20,65,40])

add_block('built-in/Inport',[sys,'/',['Decoding only',13,'no-demo/in_2']])
set_param([sys,'/',['Decoding only',13,'no-demo/in_2']],...
          'Port','2',...
          'position',[90,45,110,65])
add_line([sys,'/',['Decoding only',13,'no-demo']],[655,75;655,100;670,100])
add_line([sys,'/',['Decoding only',13,'no-demo']],[570,130;715,130;715,120;735,120])
add_line([sys,'/',['Decoding only',13,'no-demo']],[610,130;610,80;625,80])
add_line([sys,'/',['Decoding only',13,'no-demo']],[610,130;610,150;630,150])
add_line([sys,'/',['Decoding only',13,'no-demo']],[660,160;670,110])
add_line([sys,'/',['Decoding only',13,'no-demo']],[615,175;615,165;630,165])
add_line([sys,'/',['Decoding only',13,'no-demo']],[610,50;610,65;625,65])
add_line([sys,'/',['Decoding only',13,'no-demo']],[765,115;780,115])
add_line([sys,'/',['Decoding only',13,'no-demo']],[710,105;735,105])
add_line([sys,'/',['Decoding only',13,'no-demo']],[820,115;840,115])
add_line([sys,'/',['Decoding only',13,'no-demo']],[190,190;260,190;260,165;300,165])
add_line([sys,'/',['Decoding only',13,'no-demo']],[260,165;260,40;295,40])
add_line([sys,'/',['Decoding only',13,'no-demo']],[530,50;545,50])
add_line([sys,'/',['Decoding only',13,'no-demo']],[465,50;490,50])
add_line([sys,'/',['Decoding only',13,'no-demo']],[410,100;415,100;415,55;435,55])
add_line([sys,'/',['Decoding only',13,'no-demo']],[335,40;350,40;340,95])
add_line([sys,'/',['Decoding only',13,'no-demo']],[350,40;435,40])
add_line([sys,'/',['Decoding only',13,'no-demo']],[290,95;285,95;295,50])
add_line([sys,'/',['Decoding only',13,'no-demo']],[295,220;290,220;300,175])
add_line([sys,'/',['Decoding only',13,'no-demo']],[340,165;355,165;345,220])
add_line([sys,'/',['Decoding only',13,'no-demo']],[355,165;445,165])
add_line([sys,'/',['Decoding only',13,'no-demo']],[415,225;420,225;420,180;445,180])
add_line([sys,'/',['Decoding only',13,'no-demo']],[475,175;495,175])
add_line([sys,'/',['Decoding only',13,'no-demo']],[535,175;550,175])
add_line([sys,'/',['Decoding only',13,'no-demo']],[70,30;295,30])
add_line([sys,'/',['Decoding only',13,'no-demo']],[115,55;250,55;250,155;300,155])
add_line([sys,'/',['Decoding only',13,'no-demo']],[60,190;120,190])
set_param([sys,'/',['Decoding only',13,'no-demo']],...
                'Mask Display','MQASK\ndemodu',...
              'Mask Type','MASK Demodulation')
set_param([sys,'/',['Decoding only',13,'no-demo']],...
          'Mask Dialogue','M-ary Amplitude Shift Keying Demodulation:|M-ary number:|Carrier Frequency:|Carrier signal maximum amplitude:|Trigger signal threshold:')
set_param([sys,'/',['Decoding only',13,'no-demo']],...
          'Mask Translate','N=@1;Fc=@2;Ac=@3;thld=@4;[num,den]=cheby1(2,.5,Fc*pi/5,''s'');sftx=[1 -1 3 -3 5 -5 7 -7 9 -9 11 -11 13 -13 15 -15];sftx=sftx(1:2*ceil(sqrt(N)/2));sfty=sftx;if N==8,sfty=sfty(1:2);end;sftx=sftx/max(sftx)*Ac;sfty=sfty/max(sfty)*Ac;tab=qaskdeco(length(sftx),length(sfty),''fetch'');x=[1:length(sftx)];y=[1:length(sfty)];')
set_param([sys,'/',['Decoding only',13,'no-demo']],...
         'Mask Help','This block demodulates a MASK modulated signal using noncoherent method. The first input port is for the received signal, which is MASK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Decoding only',13,'no-demo']],...
            'Mask Entries','N\/Fc\/1\/.2\/')


%     Finished composite block ['Decoding only',13,'no-demo'].

set_param([sys,'/',['Decoding only',13,'no-demo']],...
            'position',[370,210,440,250])


%     Subsystem  ['Multiplel',13,'QASDK'].

new_system([sys,'/',['Multiplel',13,'QASDK']])
set_param([sys,'/',['Multiplel',13,'QASDK']],'Location',[129,443,1004,743])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/in_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/in_1']],...
               'position',[15,35,35,55])


%     Subsystem  ['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM'].

new_system([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],'Location',[353,42,897,305])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/out_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/out_1']],...
           'position',[480,70,500,90])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/out_2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/out_2']],...
           'Port','2',...
          'position',[480,175,500,195])

add_block('built-in/Transfer Fcn',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter1']],...
              'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[395,164,445,206])

add_block('built-in/Transfer Fcn',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter']],...
                'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[395,59,445,101])

add_block('built-in/Product',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Product1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Product1']],...
            'position',[330,167,355,198])

add_block('built-in/Product',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Product']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Product']],...
             'position',[330,62,355,93])

add_block('built-in/Fcn',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Fcn1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Fcn1']],...
         'Expr','sin(u[1]+Pg)',...
               'position',[220,176,295,204])

add_block('built-in/Fcn',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Fcn']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Fcn']],...
         'Expr','sin(u[1]+Ph)',...
               'position',[225,56,300,84])

add_block('built-in/Gain',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Gain']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Gain']],...
                'Gain','pi2',...
                'position',[165,109,200,141])


%     Subsystem  ['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator'].

new_system([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/out_1']],...
           'position',[370,30,390,50])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Sum']],...
             'position',[195,30,215,50])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/one']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/one']],...
                'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Reset Integrator',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Reset',13,'integrator']],...
              'position',[110,19,150,51])

add_block('built-in/Fcn',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/module']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/module']],...
               'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Memory',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Memory']],...
            'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/in_1']],...
               'position',[35,15,55,35])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[340,40;340,90;265,90])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[205,90;180,90;190,45])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
         'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
              'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
         'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
         'Mask Entries','1\/0\/')


%     Finished composite block ['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator'].

set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
            'position',[80,109,140,141])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Constant']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Constant']],...
           'Value','Fc',...
                'position',[35,115,55,135])

add_block('built-in/Note',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
              'position',[285,280,290,285])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/in_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/in_1']],...
            'position',[230,120,250,140])

add_block('built-in/Gain',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Gain1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Gain1']],...
            'Gain','2',...
          'position',[270,118,295,142])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[450,185;475,185])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[360,185;390,185])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[450,80;475,80])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[360,80;390,80])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[300,190;325,190])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[305,70;325,70])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[205,125;215,190])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[205,125;205,70;220,70])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[145,125;160,125])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[60,125;75,125])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[255,130;265,130])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[300,130;305,130;305,175;325,175])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
               'Mask Display','QM\nDSB-SC\nADM',...
            'Mask Type','Quadrature Demultiplexed DSB-SC AM')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
            'Mask Dialogue','Quadrature Demultiplexed Double-Sideband Suppressed-Carrier Amplitude Demodulation:|Carrier amplitude:|Carrier frequency:|Initial phase:|Filter numerator:|Filter denominator:')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
            'Mask Translate','Ac=@1;Fc=@2;Ph=@3;Fn=@4;Fd=@5;pi2=2*pi;Pg=Ph+pi/2;')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
               'Mask Help','The Quadratic Demultiplexed Double-Sideband Supressed-Carrier Amplitude Demodulation block demodulates the QM-DSB-SC-AM signal using quadratic duplex method.')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
              'Mask Entries','Ac\/Fc\/Ph\/num\/den\/')


%     Finished composite block ['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM'].

set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
          'ForeGround',5,...
              'position',[140,19,215,66])


%     Subsystem  ['Multiplel',13,'QASDK/Rising edge',13,'detector'].

new_system([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],'Location',[431,241,820,415])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/out_1']],...
             'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator2']],...
                'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/one1']],...
              'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Memory1']],...
          'x0','ini',...
          'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/in_1']],...
               'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator']],...
             'position',[135,18,165,42])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],...
              'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:|Initial condition:')
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],...
               'Mask Translate','thld=@1;ini=@2;',...
          'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],...
          'Mask Entries','thld\/0\/')


%     Finished composite block ['Multiplel',13,'QASDK/Rising edge',13,'detector'].

set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],...
         'ForeGround',4,...
              'position',[125,168,185,212])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/in_2']])
set_param([sys,'/',['Multiplel',13,'QASDK/in_2']],...
          'Port','2',...
          'position',[20,180,40,200])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Shift key1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Shift key1']],...
              'Value','sftx',...
              'position',[380,89,405,111])

add_block('built-in/S-Function',[sys,'/',['Multiplel',13,'QASDK/Minimum1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Minimum1']],...
               'function name','arraymin',...
          'position',[550,40,605,60])

add_block('built-in/Abs',[sys,'/',['Multiplel',13,'QASDK/Abs1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Abs1']],...
               'position',[495,38,525,62])

add_block('built-in/Switch',[sys,'/',['Multiplel',13,'QASDK/Switch1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Switch1']],...
              'ForeGround',2,...
              'Threshold','eps',...
           'position',[300,24,330,56])

add_block('built-in/Memory',[sys,'/',['Multiplel',13,'QASDK/Memory1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Memory1']],...
              'orientation',2,...
             'ForeGround',2,...
              'position',[295,80,335,110])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Shift key']])
set_param([sys,'/',['Multiplel',13,'QASDK/Shift key']],...
               'Value','sfty',...
              'position',[385,214,410,236])

add_block('built-in/S-Function',[sys,'/',['Multiplel',13,'QASDK/Minimum']])
set_param([sys,'/',['Multiplel',13,'QASDK/Minimum']],...
                'function name','arraymin',...
          'position',[555,165,610,185])

add_block('built-in/Abs',[sys,'/',['Multiplel',13,'QASDK/Abs']])
set_param([sys,'/',['Multiplel',13,'QASDK/Abs']],...
               'position',[500,163,530,187])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Sum2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Sum2']],...
             'inputs','+-',...
               'position',[450,158,470,187])

add_block('built-in/Switch',[sys,'/',['Multiplel',13,'QASDK/Switch2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Switch2']],...
            'ForeGround',2,...
              'Threshold','eps',...
           'position',[305,149,335,181])

add_block('built-in/Memory',[sys,'/',['Multiplel',13,'QASDK/Memory2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Memory2']],...
            'orientation',2,...
             'ForeGround',2,...
              'position',[300,205,340,235])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Sum1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Sum1']],...
             'inputs','+-',...
               'position',[440,33,460,62])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Sum4']])
set_param([sys,'/',['Multiplel',13,'QASDK/Sum4']],...
               'position',[630,58,650,87])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/out_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/out_1']],...
         'position',[845,80,865,100])

add_block('built-in/Saturation',[sys,'/',['Multiplel',13,'QASDK/Saturation']])
set_param([sys,'/',['Multiplel',13,'QASDK/Saturation']],...
           'Lower Limit','0',...
           'Upper Limit','N-1',...
         'position',[790,78,820,102])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Sum3']])
set_param([sys,'/',['Multiplel',13,'QASDK/Sum3']],...
              'inputs','+-',...
               'position',[740,73,760,102])


%     Subsystem  ['Multiplel',13,'QASDK/2-D Table'].

new_system([sys,'/',['Multiplel',13,'QASDK/2-D Table']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],'Location',[436,148,718,302])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/2-D Table/y0']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table/y0']],...
           'Port','2',...
          'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/2-D Table/table out']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table/table out']],...
              'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/2-D Table/x0']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table/x0']],...
            'position',[20,25,40,45])

add_block('built-in/S-Function',[sys,'/',['Multiplel',13,'QASDK/2-D Table/S-function']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table/S-function']],...
          'function name','sftable2',...
          'parameters','xindex, yindex, table',...
                'position',[140,52,190,78])

add_block('built-in/Mux',[sys,'/',['Multiplel',13,'QASDK/2-D Table/Mux']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table/Mux']],...
             'inputs','2',...
                'position',[90,46,120,79])
add_line([sys,'/',['Multiplel',13,'QASDK/2-D Table']],[45,90;65,90;65,70;85,70])
add_line([sys,'/',['Multiplel',13,'QASDK/2-D Table']],[195,65;210,65])
add_line([sys,'/',['Multiplel',13,'QASDK/2-D Table']],[45,35;65,35;65,55;85,55])
add_line([sys,'/',['Multiplel',13,'QASDK/2-D Table']],[125,65;135,65])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
                'Mask Display','plot(-10,-10,110,110,[90,50,10],[90,40,30],[90,50,10],[50,26,20],[90,50,10],[22,13,10])',...
            'Mask Type','2-D Table Lookup')
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
               'Mask Dialogue','Two Dimensional Table Lookup\nThe first input corresponds to X Index and the second input corresponds to the Y Index|X Index|Y Index|Table')
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
         'Mask Translate','xindex=@1; yindex=@2; table=@3; sftab2chk(xindex,yindex,table);')
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
           'Mask Help','This block returns a linearly interpolated intersection from the table using the X index (which corresponds to the rows of the table) and the Y index (which corresponds to the columns of the table).  Extrapolation is used.')
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
         'Mask Entries','x\/y\/tab\/')


%     Finished composite block ['Multiplel',13,'QASDK/2-D Table'].

set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
               'position',[675,68,705,92])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Shift key2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Shift key2']],...
              'position',[540,114,565,136])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Sum5']])
set_param([sys,'/',['Multiplel',13,'QASDK/Sum5']],...
             'position',[630,153,650,182])
add_line([sys,'/',['Multiplel',13,'QASDK']],[40,45;135,45])
add_line([sys,'/',['Multiplel',13,'QASDK']],[535,175;550,175])
add_line([sys,'/',['Multiplel',13,'QASDK']],[475,175;495,175])
add_line([sys,'/',['Multiplel',13,'QASDK']],[415,225;420,225;420,180;445,180])
add_line([sys,'/',['Multiplel',13,'QASDK']],[340,165;355,165;345,220])
add_line([sys,'/',['Multiplel',13,'QASDK']],[355,165;445,165])
add_line([sys,'/',['Multiplel',13,'QASDK']],[190,190;260,190;260,165;300,165])
add_line([sys,'/',['Multiplel',13,'QASDK']],[295,220;290,220;300,175])
add_line([sys,'/',['Multiplel',13,'QASDK']],[45,190;120,190])
add_line([sys,'/',['Multiplel',13,'QASDK']],[290,95;285,95;295,50])
add_line([sys,'/',['Multiplel',13,'QASDK']],[335,40;350,40;340,95])
add_line([sys,'/',['Multiplel',13,'QASDK']],[350,40;435,40])
add_line([sys,'/',['Multiplel',13,'QASDK']],[410,100;415,100;415,55;435,55])
add_line([sys,'/',['Multiplel',13,'QASDK']],[465,50;490,50])
add_line([sys,'/',['Multiplel',13,'QASDK']],[530,50;545,50])
add_line([sys,'/',['Multiplel',13,'QASDK']],[220,30;295,30])
add_line([sys,'/',['Multiplel',13,'QASDK']],[220,55;250,55;250,155;300,155])
add_line([sys,'/',['Multiplel',13,'QASDK']],[260,165;260,40;295,40])
add_line([sys,'/',['Multiplel',13,'QASDK']],[825,90;840,90])
add_line([sys,'/',['Multiplel',13,'QASDK']],[710,80;735,80])
add_line([sys,'/',['Multiplel',13,'QASDK']],[765,90;785,90])
add_line([sys,'/',['Multiplel',13,'QASDK']],[570,125;720,125;720,95;735,95])
add_line([sys,'/',['Multiplel',13,'QASDK']],[610,50;610,65;625,65])
add_line([sys,'/',['Multiplel',13,'QASDK']],[615,175;625,175])
add_line([sys,'/',['Multiplel',13,'QASDK']],[655,170;660,170;670,85])
add_line([sys,'/',['Multiplel',13,'QASDK']],[610,125;610,160;625,160])
add_line([sys,'/',['Multiplel',13,'QASDK']],[610,125;610,80;625,80])
add_line([sys,'/',['Multiplel',13,'QASDK']],[655,75;670,75])
set_param([sys,'/',['Multiplel',13,'QASDK']],...
           'Mask Display','MQASK\ndemodu',...
              'Mask Type','MASK Demodulation')
set_param([sys,'/',['Multiplel',13,'QASDK']],...
                'Mask Dialogue','M-ary Amplitude Shift Keying Demodulation:|M-ary number:|Carrier Frequency:|Carrier signal maximum amplitude:|Trigger signal threshold:|Inital phase:')
set_param([sys,'/',['Multiplel',13,'QASDK']],...
          'Mask Translate','N=@1;Fc=@2;Ac=@3;thld=@4;Ph=@5;[num,den]=cheby1(2,.1,Fc*pi/6,''s'');sftx=[1 -1 3 -3 5 -5 7 -7 9 -9 11 -11 13 -13 15 -15];sftx=sftx(1:2*ceil(sqrt(N)/2));sfty=sftx;if N==8,sfty=sfty(1:2);end;sftx=sftx/max(sftx)*Ac;sfty=sfty/max(sfty)*Ac;tab=qaskdeco(length(sftx),length(sfty),''fetch'');x=[1:length(sftx)];y=[1:length(sfty)];')
set_param([sys,'/',['Multiplel',13,'QASDK']],...
         'Mask Help','This block demodulates a MQASK modulated signal. The first input port is for the received signal, which is MQASK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Multiplel',13,'QASDK']],...
          'Mask Entries','N\/Fc\/1\/.2\/0\/')


%     Finished composite block ['Multiplel',13,'QASDK'].

set_param([sys,'/',['Multiplel',13,'QASDK']],...
             'ForeGround',2,...
              'position',[365,125,435,165])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
             'position',[610,50,640,100])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
            'position',[690,68,710,97])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
            'function name','sfuny',...
             'parameters','ax, color,dt',...
         'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
            'position',[65,55,85,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
              'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
                'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
              'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Graph'],...
              'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Graph'],...
           'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
         'Mask Entries','.5\/-1.1\/N-.8\/''y-/r--/g-./c:/m:/g-./w-/r:''\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
                'position',[750,66,780,104])


%     Subsystem  ['Transmitting',13,'error-counter'].

new_system([sys,'/',['Transmitting',13,'error-counter']])
set_param([sys,'/',['Transmitting',13,'error-counter']],'Location',[67,468,602,636])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/in_2']])
set_param([sys,'/',['Transmitting',13,'error-counter/in_2']],...
           'Port','2',...
          'position',[80,40,100,60])

add_block('built-in/Sum',[sys,'/',['Transmitting',13,'error-counter/Sum']])
set_param([sys,'/',['Transmitting',13,'error-counter/Sum']],...
            'inputs','+-',...
               'position',[140,35,160,55])

add_block('built-in/Abs',[sys,'/',['Transmitting',13,'error-counter/Abs']])
set_param([sys,'/',['Transmitting',13,'error-counter/Abs']],...
           'position',[195,33,225,57])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Relational',13,'Operator']])
set_param([sys,'/',['Transmitting',13,'error-counter/Relational',13,'Operator']],...
         'Operator','>',...
              'position',[270,38,300,62])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter/Constant']])
set_param([sys,'/',['Transmitting',13,'error-counter/Constant']],...
            'Value','tol',...
               'position',[195,80,215,100])


%     Subsystem  ['Transmitting',13,'error-counter/Counter'].

new_system([sys,'/',['Transmitting',13,'error-counter/Counter']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter']],'Location',[378,106,972,431])


%     Subsystem  ['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/out_1']],...
             'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
                'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/one1']],...
              'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Memory1']],...
          'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/in_1']],...
               'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
             'position',[135,18,165,42])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],[300,35;335,35])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],...
          'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],...
              'Mask Translate','thld=@1;')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],...
              'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],...
              'Mask Entries','thld\/')


%     Finished composite block ['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector1']],...
            'ForeGround',4,...
              'position',[375,53,435,87])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/Counter/in_3']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/in_3']],...
              'Port','3',...
          'position',[315,60,335,80])

add_block('built-in/Memory',[sys,'/',['Transmitting',13,'error-counter/Counter/Memory3']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Memory3']],...
                'orientation',2,...
             'ForeGround',3,...
              'position',[400,205,440,235])

add_block('built-in/Switch',[sys,'/',['Transmitting',13,'error-counter/Counter/Switch3']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Switch3']],...
              'ForeGround',3,...
              'Threshold','eps',...
           'position',[470,139,495,171])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter/Counter/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/out_1']],...
         'position',[550,145,570,165])


%     Subsystem  ['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
          'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/in_1']],...
          'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Memory1']],...
              'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/one1']],...
               'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
           'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
           'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector/out_1']],...
              'position',[340,25,360,45])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],...
           'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],...
               'Mask Translate','thld=@1;')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],...
               'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],...
               'Mask Entries','thld\/')


%     Finished composite block ['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Rising edge',13,'detector']],...
              'ForeGround',4,...
              'position',[80,148,140,182])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/Counter/in_2']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/in_2']],...
             'Port','2',...
          'position',[15,155,35,175])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/Counter/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/in_1']],...
              'position',[15,50,35,70])

add_block('built-in/Switch',[sys,'/',['Transmitting',13,'error-counter/Counter/Switch2']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Switch2']],...
          'ForeGround',3,...
              'Threshold','eps',...
           'position',[345,149,370,181])

add_block('built-in/Sum',[sys,'/',['Transmitting',13,'error-counter/Counter/Sum']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Sum']],...
         'ForeGround',3,...
              'position',[295,100,315,120])

add_block('built-in/Relational Operator',[sys,'/',['Transmitting',13,'error-counter/Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Relational',13,'Operator1']],...
             'ForeGround',2,...
              'Operator','>',...
              'position',[225,53,255,77])

add_block('built-in/Constant',[sys,'/',['Transmitting',13,'error-counter/Counter/Constant']])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter/Constant']],...
            'ForeGround',3,...
              'Value','thld',...
              'position',[105,100,135,120])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[500,155;545,155])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[520,155;520,220;445,220])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[375,165;465,165])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[340,70;370,70])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[40,165;75,165])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[40,60;220,60])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[320,110;330,110;340,155])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[395,220;275,220;275,175;340,175])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[140,110;190,110;190,70;220,70])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[260,65;275,65;275,105;290,105])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[145,165;340,165])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[275,175;275,115;290,115])
add_line([sys,'/',['Transmitting',13,'error-counter/Counter']],[440,70;450,70;450,155;465,155])
set_param([sys,'/',['Transmitting',13,'error-counter/Counter']],...
                'Mask Display','Number\nCounter',...
            'Mask Type','Number Counter',...
                'Mask Dialogue','Number counter:|Threshold:',...
                'Mask Translate','thld=@1;')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter']],...
         'Mask Help','If the signal at the first port is larger than the given threshold at the time of the clock raising edge, the counter increases one. The clock signl is provided at the second port. The raising edge of the third port clears the counter, which enforces the counter to be zero regardless the signal in port one and two.')
set_param([sys,'/',['Transmitting',13,'error-counter/Counter']],...
          'Mask Entries','.2\/')


%     Finished composite block ['Transmitting',13,'error-counter/Counter'].

set_param([sys,'/',['Transmitting',13,'error-counter/Counter']],...
            'position',[365,43,425,87])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/in_3']])
set_param([sys,'/',['Transmitting',13,'error-counter/in_3']],...
              'Port','3',...
          'position',[260,100,280,120])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/in_4']])
set_param([sys,'/',['Transmitting',13,'error-counter/in_4']],...
            'Port','4',...
          'position',[300,125,320,145])

add_block('built-in/Outport',[sys,'/',['Transmitting',13,'error-counter/out_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/out_1']],...
         'position',[475,55,495,75])

add_block('built-in/Inport',[sys,'/',['Transmitting',13,'error-counter/in_1']])
set_param([sys,'/',['Transmitting',13,'error-counter/in_1']],...
              'position',[40,15,60,35])
add_line([sys,'/',['Transmitting',13,'error-counter']],[430,65;470,65])
add_line([sys,'/',['Transmitting',13,'error-counter']],[325,135;335,135;335,80;360,80])
add_line([sys,'/',['Transmitting',13,'error-counter']],[285,110;315,110;315,65;360,65])
add_line([sys,'/',['Transmitting',13,'error-counter']],[305,50;360,50])
add_line([sys,'/',['Transmitting',13,'error-counter']],[220,90;235,90;235,55;265,55])
add_line([sys,'/',['Transmitting',13,'error-counter']],[230,45;265,45])
add_line([sys,'/',['Transmitting',13,'error-counter']],[165,45;190,45])
add_line([sys,'/',['Transmitting',13,'error-counter']],[105,50;135,50])
add_line([sys,'/',['Transmitting',13,'error-counter']],[65,25;110,25;110,40;135,40])
set_param([sys,'/',['Transmitting',13,'error-counter']],...
          'Mask Display','Error\ncounter',...
             'Mask Type','Error Counter',...
         'Mask Dialogue','Transmission error counter:|Threshold:|Tolerance:',...
         'Mask Translate','thld=@1;tol=@2;')
set_param([sys,'/',['Transmitting',13,'error-counter']],...
          'Mask Help','This block counts the errors digital transmitting. If the difference between the first two ports is larger than the threshold, the counter increases one at the clock raising edge. The clock signal is provided from port three. Port four is used to reset the count to be zero.')
set_param([sys,'/',['Transmitting',13,'error-counter']],...
            'Mask Entries','0.2\/eps\/')


%     Finished composite block ['Transmitting',13,'error-counter'].

set_param([sys,'/',['Transmitting',13,'error-counter']],...
              'ForeGround',7,...
              'position',[505,129,565,171])


%     Subsystem  'Hold and delay1'.

new_system([sys,'/','Hold and delay1'])
set_param([sys,'/','Hold and delay1'],'Location',[380,124,840,274])

add_block('built-in/Inport',[sys,'/','Hold and delay1/in_2'])
set_param([sys,'/','Hold and delay1/in_2'],...
           'Port','2',...
          'position',[45,45,65,65])

add_block('built-in/Inport',[sys,'/','Hold and delay1/in_1'])
set_param([sys,'/','Hold and delay1/in_1'],...
            'position',[15,25,35,45])


%     Subsystem  ['Hold and delay1/Clock triggered',13,'hold buffer'].

new_system([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],'Location',[229,493,559,639])

add_block('built-in/Outport',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/out_1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/out_1']],...
             'position',[290,35,310,55])

add_block('built-in/Switch',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Switch']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Switch']],...
                'Threshold','eps',...
           'position',[210,29,240,61])

add_block('built-in/Inport',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/in_1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/in_1']],...
            'position',[35,25,55,45])


%     Subsystem  ['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector'].

new_system([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator']],...
         'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/in_1']],...
                'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Memory1']],...
            'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/one1']],...
             'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator2']],...
         'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector/out_1']],...
            'position',[340,25,360,45])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
          'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
              'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
              'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
              'Mask Entries','thld\/')


%     Finished composite block ['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector'].

set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
            'position',[80,58,140,102])

add_block('built-in/Inport',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/in_2']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/in_2']],...
            'Port','2',...
          'position',[35,70,55,90])

add_block('built-in/Memory',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Memory']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer/Memory']],...
          'orientation',2,...
             'position',[200,85,240,115])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],[245,45;260,45;260,100;245,100])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],[145,80;155,80;155,45;205,45])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],[195,100;185,100;185,55;205,55])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],[60,35;205,35])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],[245,45;285,45])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],[60,80;75,80])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],...
             'Mask Display','Hold\nBuffer',...
               'Mask Type','Hold Buffer',...
           'Mask Dialogue','Clock triggered hold buffer:|Threshold for clock signal:')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],...
                'Mask Help','The first input port is for signal. The second input port is for clocks pulse. The rising edge of the clock signal locks the signal from the first port and outputs the value until next clock pulse rising edge.')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],...
            'Mask Entries','.2\/')


%     Finished composite block ['Hold and delay1/Clock triggered',13,'hold buffer'].

set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer']],...
          'position',[130,23,190,67])


%     Subsystem  ['Hold and delay1/Clock triggered',13,'hold buffer1'].

new_system([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],'Location',[229,493,559,628])

add_block('built-in/Switch',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Switch']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Switch']],...
             'ForeGround',5,...
              'Threshold','eps',...
           'position',[210,29,240,61])

add_block('built-in/Memory',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Memory']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Memory']],...
              'orientation',2,...
             'position',[200,80,240,110])


%     Subsystem  ['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector'].

new_system([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/out_1']],...
           'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator1']],...
               'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator2']],...
              'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/one1']],...
            'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Memory1']],...
                'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/in_1']],...
             'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator']],...
           'position',[135,18,165,42])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
         'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
             'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
             'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
             'Mask Entries','thld\/')


%     Finished composite block ['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector'].

set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
          'position',[80,48,140,92])

add_block('built-in/Outport',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/out_1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/out_1']],...
                'position',[290,35,310,55])

add_block('built-in/Inport',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/in_2']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/in_2']],...
          'Port','2',...
          'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/in_1']])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1/in_1']],...
            'position',[40,25,60,45])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],[40,70;75,70])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],[245,45;285,45])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],[65,35;205,35])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],[195,95;185,95;185,55;205,55])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],[145,70;155,70;155,45;205,45])
add_line([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],[245,45;260,45;260,95;245,95])
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],...
             'Mask Display','Hold\nBuffer',...
               'Mask Type','Hold Buffer',...
           'Mask Dialogue','Clock triggered hold buffer:|Threshold for clock signal:')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],...
                'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],...
               'Mask Help','The first input port is for signal. The second input port is for clocks pulse. The rising edge of the clock signal locks the signal from the first port and outputs the value until next clock pulse rising edge.')
set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],...
           'Mask Entries','.2\/')


%     Finished composite block ['Hold and delay1/Clock triggered',13,'hold buffer1'].

set_param([sys,'/',['Hold and delay1/Clock triggered',13,'hold buffer1']],...
                'position',[295,33,355,77])

add_block('built-in/Outport',[sys,'/','Hold and delay1/out_1'])
set_param([sys,'/','Hold and delay1/out_1'],...
               'position',[390,45,410,65])

add_block('built-in/Memory',[sys,'/','Hold and delay1/Memory1'])
set_param([sys,'/','Hold and delay1/Memory1'],...
            'position',[220,30,260,60])
add_line([sys,'/','Hold and delay1'],[265,45;290,45])
add_line([sys,'/','Hold and delay1'],[195,45;215,45])
add_line([sys,'/','Hold and delay1'],[40,35;125,35])
add_line([sys,'/','Hold and delay1'],[360,55;385,55])
add_line([sys,'/','Hold and delay1'],[70,55;125,55])
add_line([sys,'/','Hold and delay1'],[85,55;85,105;270,105;270,65;290,65])


%     Finished composite block 'Hold and delay1'.

set_param([sys,'/','Hold and delay1'],...
          'ForeGround',3,...
              'position',[495,219,550,261])

add_block('built-in/Note',[sys,'/',['Change MATLAB workspace variable for different parameters:',13,'N -- M-ary number (default 16)     ',13,'T -- Clock sample time (defualt .1)  ',13,'Fc -- Carrier frequency (default 100)']])
set_param([sys,'/',['Change MATLAB workspace variable for different parameters:',13,'N -- M-ary number (default 16)     ',13,'T -- Clock sample time (defualt .1)  ',13,'Fc -- Carrier frequency (default 100)']],...
              'position',[470,345,475,350])

add_block('built-in/Note',[sys,'/',['The curve color in the graphical scope matches the color of the',13,'blocks in the block diagram                                                   ']])
set_param([sys,'/',['The curve color in the graphical scope matches the color of the',13,'blocks in the block diagram                                                   ']],...
                'position',[475,315,480,320])

add_block('built-in/Constant',[sys,'/',['Additive vector',13,'to seperat the plot']])
set_param([sys,'/',['Additive vector',13,'to seperat the plot']],...
          'Value','[0 .1 .2 0]',...
               'position',[600,199,665,221])


%     Subsystem  'Additive Noise'.

new_system([sys,'/','Additive Noise'])
set_param([sys,'/','Additive Noise'],'Location',[54,341,339,470])

add_block('built-in/White Noise',[sys,'/','Additive Noise/White Noise'])
set_param([sys,'/','Additive Noise/White Noise'],...
              'Seed','seed',...
               'position',[25,40,45,60])

add_block('built-in/Zero-Order Hold',[sys,'/',['Additive Noise/Zero-Order',13,'Hold']])
set_param([sys,'/',['Additive Noise/Zero-Order',13,'Hold']],...
         'Sample time','Ts',...
          'position',[85,34,120,66])

add_block('built-in/Gain',[sys,'/','Additive Noise/Gain'])
set_param([sys,'/','Additive Noise/Gain'],...
               'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
             'position',[155,31,195,69])

add_block('built-in/Outport',[sys,'/','Additive Noise/Out_1'])
set_param([sys,'/','Additive Noise/Out_1'],...
         'position',[230,40,250,60])
add_line([sys,'/','Additive Noise'],[125,50;150,50])
add_line([sys,'/','Additive Noise'],[200,50;225,50])
add_line([sys,'/','Additive Noise'],[50,50;80,50])
set_param([sys,'/','Additive Noise'],...
           'Mask Display','plot(t(:),r2(:))',...
           'Mask Type','Continuous White Noise.')
set_param([sys,'/','Additive Noise'],...
          'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/','Additive Noise'],...
           'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/','Additive Noise'],...
                'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/','Additive Noise'],...
           'Mask Entries','.0001\/0.005\/[23341]\/')


%     Finished composite block 'Additive Noise'.

set_param([sys,'/','Additive Noise'],...
               'BackGround',3,...
              'position',[175,297,220,333])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[85,525,838,667])

add_block('built-in/Note',[sys,'/','Subsystem1/This test file is to test digital amplitude shift-keying//phase shift-keying modulation//demodulation blocks.'])
set_param([sys,'/','Subsystem1/This test file is to test digital amplitude shift-keying//phase shift-keying modulation//demodulation blocks.'],...
             'position',[325,25,330,30])

add_block('built-in/Note',[sys,'/','Subsystem1/Red signal is the M-ary Quadrature ASK//PSK modulated//demodulated result. It should match the yellow signal.'])
set_param([sys,'/','Subsystem1/Red signal is the M-ary Quadrature ASK//PSK modulated//demodulated result. It should match the yellow signal.'],...
              'ForeGround',2,...
              'position',[355,75,360,80])

add_block('built-in/Note',[sys,'/',['Subsystem1/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']])
set_param([sys,'/',['Subsystem1/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']],...
              'ForeGround',5)
set_param([sys,'/',['Subsystem1/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']],...
            'position',[330,45,335,50])

add_block('built-in/Note',[sys,'/','Subsystem1/Green signal is the result of error counting. It records all error occured in the transmitting.'])
set_param([sys,'/','Subsystem1/Green signal is the result of error counting. It records all error occured in the transmitting.'],...
                'ForeGround',3,...
              'position',[285,100,290,105])
set_param([sys,'/','Subsystem1'],...
               'Mask Display','Plot\nsignal set')
set_param([sys,'/','Subsystem1'],...
          'Mask Dialogue','eval(''[x,y]=qaskenco([1:N],N); plot(x,y,''''*'''');axis(''''equal'''');axis(''''off'''');z=axis*1.1;hold on; plot(z(1:2),[0 0],''''w'''');plot([0,0],z(3:4),''''w'''');hold off'');')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
         'hide name',0,...
               'Drop Shadow',4,...
             'position',[160,370,225,406])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[72,442,922,623])

add_block('built-in/Note',[sys,'/',['Subsystem/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']])
set_param([sys,'/',['Subsystem/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']],...
            'ForeGround',5)
set_param([sys,'/',['Subsystem/Yellow signal is the inputed digital messagel to be modulated. The message is i=1,2,...N. where N could',13,'be defined in the workspace. It is suggested to bethe result of power of 2 although it is not limited so.']],...
             'position',[350,45,355,50])

add_block('built-in/Note',[sys,'/','Subsystem/This test file is to test digital quadrature amplitude shift-keying modulation//demodulation blocks.'])
set_param([sys,'/','Subsystem/This test file is to test digital quadrature amplitude shift-keying modulation//demodulation blocks.'],...
                'position',[325,25,330,30])

add_block('built-in/Note',[sys,'/',['Subsystem/Red signal is the M-ary Quadrature amplitude shift-keying modulated//demodulated result. It should match',13,'the yellow signal.']])
set_param([sys,'/',['Subsystem/Red signal is the M-ary Quadrature amplitude shift-keying modulated//demodulated result. It should match',13,'the yellow signal.']],...
              'ForeGround',2,...
              'position',[355,75,360,80])

add_block('built-in/Note',[sys,'/',['Subsystem/Green signal is a test without carrier modulation//demodulation. It contains encoding//decoding only. It should',13,' match the yellow signal.']])
set_param([sys,'/',['Subsystem/Green signal is a test without carrier modulation//demodulation. It contains encoding//decoding only. It should',13,' match the yellow signal.']],...
                'ForeGround',3,...
              'position',[360,105,365,110])

add_block('built-in/Note',[sys,'/','Subsystem/Cyan signal is the result of error counting. It records number of errors occured in the transmitting.'])
set_param([sys,'/','Subsystem/Cyan signal is the result of error counting. It records number of errors occured in the transmitting.'],...
            'ForeGround',7,...
              'position',[325,135,330,140])
set_param([sys,'/','Subsystem'],...
                'Mask Display','?')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
               'hide name',0,...
               'Drop Shadow',4,...
             'position',[65,365,95,401])


%     Subsystem  'Hold and delay'.

new_system([sys,'/','Hold and delay'])
set_param([sys,'/','Hold and delay'],'Location',[249,532,709,682])

add_block('built-in/Memory',[sys,'/','Hold and delay/Memory1'])
set_param([sys,'/','Hold and delay/Memory1'],...
            'position',[220,30,260,60])

add_block('built-in/Outport',[sys,'/','Hold and delay/out_1'])
set_param([sys,'/','Hold and delay/out_1'],...
         'position',[390,45,410,65])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer1'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],'Location',[229,493,559,628])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_1']],...
              'position',[40,25,60,45])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/in_2']],...
              'Port','2',...
          'position',[15,60,35,80])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/out_1']],...
           'position',[290,35,310,55])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator']],...
               'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/in_1']],...
                'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Memory1']],...
            'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/one1']],...
             'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator2']],...
         'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector/out_1']],...
            'position',[340,25,360,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
          'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
              'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
              'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
              'Mask Entries','thld\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Rising edge',13,'detector']],...
            'position',[80,48,140,92])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Memory']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Memory']],...
         'orientation',2,...
             'position',[200,80,240,110])

add_block('built-in/Switch',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Switch']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1/Switch']],...
               'ForeGround',5,...
              'Threshold','eps',...
           'position',[210,29,240,61])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[245,45;260,45;260,95;245,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[145,70;155,70;155,45;205,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[195,95;185,95;185,55;205,55])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[65,35;205,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[245,45;285,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],[40,70;75,70])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
          'Mask Display','Hold\nBuffer',...
               'Mask Type','Hold Buffer',...
           'Mask Dialogue','Clock triggered hold buffer:|Threshold for clock signal:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
                'Mask Help','The first input port is for signal. The second input port is for clocks pulse. The rising edge of the clock signal locks the signal from the first port and outputs the value until next clock pulse rising edge.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
            'Mask Entries','.2\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer1'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer1']],...
          'position',[295,33,355,77])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],'Location',[229,493,559,639])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Memory']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Memory']],...
               'orientation',2,...
             'position',[200,85,240,115])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_2']],...
             'Port','2',...
          'position',[35,70,55,90])


%     Subsystem  ['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector'].

new_system([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/out_1']],...
                'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator1']],...
           'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator2']],...
          'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/one1']],...
                'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Memory1']],...
            'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/in_1']],...
         'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector/Relational',13,'Operator']],...
               'position',[135,18,165,42])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
           'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
               'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
               'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
               'Mask Entries','thld\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Rising edge',13,'detector']],...
              'position',[80,58,140,102])

add_block('built-in/Inport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/in_1']],...
              'position',[35,25,55,45])

add_block('built-in/Switch',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Switch']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/Switch']],...
            'Threshold','eps',...
           'position',[210,29,240,61])

add_block('built-in/Outport',[sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/out_1']])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer/out_1']],...
           'position',[290,35,310,55])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[60,80;75,80])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[245,45;285,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[60,35;205,35])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[195,100;185,100;185,55;205,55])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[145,80;155,80;155,45;205,45])
add_line([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],[245,45;260,45;260,100;245,100])
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
             'Mask Display','Hold\nBuffer',...
               'Mask Type','Hold Buffer',...
           'Mask Dialogue','Clock triggered hold buffer:|Threshold for clock signal:')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
          'Mask Translate','thld=@1;')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
         'Mask Help','The first input port is for signal. The second input port is for clocks pulse. The rising edge of the clock signal locks the signal from the first port and outputs the value until next clock pulse rising edge.')
set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
             'Mask Entries','.2\/')


%     Finished composite block ['Hold and delay/Clock triggered',13,'hold buffer'].

set_param([sys,'/',['Hold and delay/Clock triggered',13,'hold buffer']],...
            'position',[130,23,190,67])

add_block('built-in/Inport',[sys,'/','Hold and delay/in_1'])
set_param([sys,'/','Hold and delay/in_1'],...
            'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/','Hold and delay/in_2'])
set_param([sys,'/','Hold and delay/in_2'],...
              'Port','2',...
          'position',[45,45,65,65])
add_line([sys,'/','Hold and delay'],[70,55;125,55])
add_line([sys,'/','Hold and delay'],[85,55;85,105;270,105;270,65;290,65])
add_line([sys,'/','Hold and delay'],[360,55;385,55])
add_line([sys,'/','Hold and delay'],[40,35;125,35])
add_line([sys,'/','Hold and delay'],[195,45;215,45])
add_line([sys,'/','Hold and delay'],[265,45;290,45])
set_param([sys,'/','Hold and delay'],...
            'Mask Display','Hold\nand delay',...
            'Mask Type','Hold and delay',...
                'Mask Dialogue','Hold and delay:|Threshold of clock pulse:|Inital output:',...
          'Mask Translate','thr=@1;ini=@2;')
set_param([sys,'/','Hold and delay'],...
              'Mask Help','This block hold a value until the next rising edge of clock. The output delays a period of clock time..',...
               'Mask Entries','0.2\/0\/')


%     Finished composite block 'Hold and delay'.

set_param([sys,'/','Hold and delay'],...
              'ForeGround',5,...
              'position',[200,39,260,81])
add_line(sys,[115,50;195,50])
add_line(sys,[250,130;290,130])
add_line(sys,[320,135;360,135])
add_line(sys,[225,315;265,315;265,140;290,140])
add_line(sys,[105,285;330,285;330,155;360,155])
add_line(sys,[155,285;155,140;180,140])
add_line(sys,[155,140;155,70;195,70])
add_line(sys,[125,50;125,120;180,120])
add_line(sys,[250,230;365,230])
add_line(sys,[125,120;125,210;180,210])
add_line(sys,[155,230;180,230])
add_line(sys,[330,245;365,245])
add_line(sys,[265,60;605,60])
add_line(sys,[445,230;490,230])
add_line(sys,[440,145;470,145;470,70;605,70])
add_line(sys,[555,240;575,240;575,80;605,80])
add_line(sys,[645,75;685,75])
add_line(sys,[715,85;745,85])
add_line(sys,[670,210;675,210;685,90])
add_line(sys,[330,285;460,285;460,250;490,250])
add_line(sys,[485,60;485,135;500,135])
add_line(sys,[470,145;500,145])
add_line(sys,[460,250;460,155;500,155])
add_line(sys,[570,150;580,150;580,90;605,90])
add_line(sys,[250,210;305,210;305,215;365,215])

drawnow

% Return any arguments.
if (nargin | nargout)
      % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
else
 drawnow % Flash up the model and execute load callback
end
