function [ret,x0,str,ts,xts]=tstrand(t,x,u,flag);
%TSTRAND	is the M-file description of the SIMULINK system named TSTRAND.
%	The block-diagram can be displayed by typing: TSTRAND.
%
%	SYS=TSTRAND(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTRAND to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTRAND with a FLAG of zero:
%	[SIZES]=TSTRAND([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[409,370,909,670])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Uniform',13,'noise'].

new_system([sys,'/',['Uniform',13,'noise']])
set_param([sys,'/',['Uniform',13,'noise']],'Location',[420,594,637,734])

add_block('built-in/Outport',[sys,'/',['Uniform',13,'noise/out_1']])
set_param([sys,'/',['Uniform',13,'noise/out_1']],...
		'position',[165,65,185,85])

add_block('built-in/S-Function',[sys,'/',['Uniform',13,'noise/Uniform',13,'noise']])
set_param([sys,'/',['Uniform',13,'noise/Uniform',13,'noise']],...
		'function name','surandom',...
		'parameters','seed,up,low',...
		'position',[65,55,135,95])
add_line([sys,'/',['Uniform',13,'noise']],[140,75;160,75])
set_param([sys,'/',['Uniform',13,'noise']],...
		'Mask Display','Uniform\nnoise',...
		'Mask Type','Uniform distribution noise.',...
		'Mask Dialogue','Uniform distribution noise.|Low bound of the output:|Upper bound of the output:|Seed:')
set_param([sys,'/',['Uniform',13,'noise']],...
		'Mask Translate','seed=@3;up=@2;low=@1;')
set_param([sys,'/',['Uniform',13,'noise']],...
		'Mask Help','The output of this block is uniformly distributed between the low and up boundaries. The output size is the same as the vector size for seed.',...
		'Mask Entries','0\/1\/1234\/')


%     Finished composite block ['Uniform',13,'noise'].

set_param([sys,'/',['Uniform',13,'noise']],...
		'position',[55,4,130,46])


%     Subsystem  ['Gaussian',13,'noise'].

new_system([sys,'/',['Gaussian',13,'noise']])
set_param([sys,'/',['Gaussian',13,'noise']],'Location',[371,386,719,591])

add_block('built-in/State-Space',[sys,'/',['Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Gaussian',13,'noise']],...
		'Mask Entries','0\/1\/4321\/')


%     Finished composite block ['Gaussian',13,'noise'].

set_param([sys,'/',['Gaussian',13,'noise']],...
		'position',[60,75,135,115])


%     Subsystem  ['Random-integer',13,'generator1'].

new_system([sys,'/',['Random-integer',13,'generator1']])
set_param([sys,'/',['Random-integer',13,'generator1']],'Location',[98,518,454,687])

add_block('built-in/S-Function',[sys,'/',['Random-integer',13,'generator1/Uniform',13,'number']])
set_param([sys,'/',['Random-integer',13,'generator1/Uniform',13,'number']],...
		'function name','srandint',...
		'parameters','seed,mul',...
		'position',[65,45,135,85])

add_block('built-in/Outport',[sys,'/',['Random-integer',13,'generator1/out_1']])
set_param([sys,'/',['Random-integer',13,'generator1/out_1']],...
		'position',[165,55,185,75])
add_line([sys,'/',['Random-integer',13,'generator1']],[140,65;160,65])
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Display','Random\nNumber',...
		'Mask Type','Random number generator.')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Dialogue','Randomly generate integers in the range of [0,1,...,N-1]. N is the M-ary number defined below:|M-ary number:|Seed(s):',...
		'Mask Translate','seed=@2;mul=@1;')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Help','This block generate integer number 0 to M-1, where M is a integer. The probability of the apperance for each number is equal.',...
		'Mask Entries','8\/1\/')


%     Finished composite block ['Random-integer',13,'generator1'].

set_param([sys,'/',['Random-integer',13,'generator1']],...
		'position',[60,143,135,187])


%     Subsystem  ['Poisson',13,'noise'].

new_system([sys,'/',['Poisson',13,'noise']])
set_param([sys,'/',['Poisson',13,'noise']],'Location',[391,74,676,237])

add_block('built-in/Outport',[sys,'/',['Poisson',13,'noise/out_1']])
set_param([sys,'/',['Poisson',13,'noise/out_1']],...
		'position',[165,65,185,85])

add_block('built-in/S-Function',[sys,'/',['Poisson',13,'noise/Poisson distribution',13,'number']])
set_param([sys,'/',['Poisson',13,'noise/Poisson distribution',13,'number']],...
		'function name','srandpoi',...
		'parameters','seed,lambda',...
		'position',[65,55,135,95])
add_line([sys,'/',['Poisson',13,'noise']],[140,75;160,75])
set_param([sys,'/',['Poisson',13,'noise']],...
		'Mask Display','Poison\nrand int',...
		'Mask Type','Poisson distribution noise.',...
		'Mask Dialogue','Poisson distribution number generator.|Lambda:|Seed:')
set_param([sys,'/',['Poisson',13,'noise']],...
		'Mask Translate','seed=@2;lambda=@1;')
set_param([sys,'/',['Poisson',13,'noise']],...
		'Mask Help','The output of this block is poisson distributed integers. The output size is the same as the vector size for seed. Please use function disttool to see the distribution of the outputof this block.')
set_param([sys,'/',['Poisson',13,'noise']],...
		'Mask Entries','.1\/1243\/')


%     Finished composite block ['Poisson',13,'noise'].

set_param([sys,'/',['Poisson',13,'noise']],...
		'position',[55,219,130,261])


%     Subsystem  'Error-Meter'.

new_system([sys,'/','Error-Meter'])
set_param([sys,'/','Error-Meter'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error-Meter/in_2'])
set_param([sys,'/','Error-Meter/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error-Meter/in_1'])
set_param([sys,'/','Error-Meter/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error-Meter/Mux'])
set_param([sys,'/','Error-Meter/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error-Meter/S-function'])
set_param([sys,'/','Error-Meter/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error-Meter'],[40,70;60,70])
add_line([sys,'/','Error-Meter'],[40,55;60,55])
add_line([sys,'/','Error-Meter'],[105,65;125,65])
set_param([sys,'/','Error-Meter'],...
		'Mask Display','Error Rate\nMeter',...
		'Mask Type','Symbol/Bit Error Counter.')
set_param([sys,'/','Error-Meter'],...
		'Mask Dialogue','Compare 2nd port input to scalar 1st port input. Compute the error rate.|Bit per symbol:|Number of digit on display:|Delay between input (1st port) and output (2nd port):|Sampling time (second):')
set_param([sys,'/','Error-Meter'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error-Meter'],...
		'Mask Help','The signal from the first port should be always be a scalar. The 2nd port input signal can be a vector with a same time delay to the input signal.',...
		'Mask Entries','3\/16\/td\/td\/')


%     Finished composite block 'Error-Meter'.

set_param([sys,'/','Error-Meter'],...
		'position',[345,83,420,127])


%     Subsystem  'Mean&std'.

new_system([sys,'/','Mean&std'])
set_param([sys,'/','Mean&std'],'Location',[16,148,871,412])

add_block('built-in/Inport',[sys,'/','Mean&std/Actual'])
set_param([sys,'/','Mean&std/Actual'],...
		'position',[25,35,45,55])

add_block('built-in/Digital Clock',[sys,'/','Mean&std/Digital Clock'])
set_param([sys,'/','Mean&std/Digital Clock'],...
		'Sample time','Ts',...
		'position',[45,80,80,110])

add_block('built-in/Fcn',[sys,'/','Mean&std/Fcn2'])
set_param([sys,'/','Mean&std/Fcn2'],...
		'Expr','u[1]/Ts +1',...
		'position',[105,83,165,107])

add_block('built-in/Unit Delay',[sys,'/','Mean&std/Unit Delay1'])
set_param([sys,'/','Mean&std/Unit Delay1'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[350,87,400,103])

add_block('built-in/Outport',[sys,'/','Mean&std/mean value'])
set_param([sys,'/','Mean&std/mean value'],...
		'position',[545,45,565,65])

add_block('built-in/Mux',[sys,'/','Mean&std/Mux1'])
set_param([sys,'/','Mean&std/Mux1'],...
		'inputs','3',...
		'position',[235,39,265,71])

add_block('built-in/Fcn',[sys,'/','Mean&std/Fcn3'])
set_param([sys,'/','Mean&std/Fcn3'],...
		'Expr','(u[3]*(u[2]-1) + u[1])/u[2]',...
		'position',[290,41,465,69])

add_block('built-in/Mux',[sys,'/','Mean&std/Mux'])
set_param([sys,'/','Mean&std/Mux'],...
		'inputs','3',...
		'position',[235,134,265,166])

add_block('built-in/Unit Delay',[sys,'/','Mean&std/Unit Delay'])
set_param([sys,'/','Mean&std/Unit Delay'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[345,192,395,208])

add_block('built-in/Fcn',[sys,'/','Mean&std/Fcn'])
set_param([sys,'/','Mean&std/Fcn'],...
		'Expr','(u[3]*(u[2]-1) + u[1]*u[1])/u[2]',...
		'position',[290,136,465,164])

add_block('built-in/Sum',[sys,'/','Mean&std/Sum'])
set_param([sys,'/','Mean&std/Sum'],...
		'inputs','-+',...
		'position',[645,135,665,155])

add_block('built-in/Outport',[sys,'/',['Mean&std/Mean',13,'Squared',13,'Error1']])
set_param([sys,'/',['Mean&std/Mean',13,'Squared',13,'Error1']],...
		'Port','2',...
		'position',[790,135,810,155])

add_block('built-in/Fcn',[sys,'/','Mean&std/Fcn1'])
set_param([sys,'/','Mean&std/Fcn1'],...
		'Expr','sqrt(u[1])',...
		'position',[690,132,755,158])

add_block('built-in/Mux',[sys,'/','Mean&std/Mux2'])
set_param([sys,'/','Mean&std/Mux2'],...
		'inputs','2',...
		'position',[515,101,545,134])

add_block('built-in/Fcn',[sys,'/','Mean&std/Fcn4'])
set_param([sys,'/','Mean&std/Fcn4'],...
		'Expr','u[1]*u[1]',...
		'position',[555,107,620,133])
add_line([sys,'/','Mean&std'],[85,95;100,95])
add_line([sys,'/','Mean&std'],[340,200;220,200;230,160])
add_line([sys,'/','Mean&std'],[170,95;190,95;190,150;230,150])
add_line([sys,'/','Mean&std'],[270,150;285,150])
add_line([sys,'/','Mean&std'],[270,55;285,55])
add_line([sys,'/','Mean&std'],[470,55;540,55])
add_line([sys,'/','Mean&std'],[760,145;785,145])
add_line([sys,'/','Mean&std'],[50,45;210,45;230,45])
add_line([sys,'/','Mean&std'],[190,95;190,55;230,55])
add_line([sys,'/','Mean&std'],[495,55;495,95;405,95])
add_line([sys,'/','Mean&std'],[345,95;210,95;210,65;230,65])
add_line([sys,'/','Mean&std'],[200,45;200,140;230,140])
add_line([sys,'/','Mean&std'],[470,150;480,150;480,200;400,200])
add_line([sys,'/','Mean&std'],[670,145;685,145])
add_line([sys,'/','Mean&std'],[480,150;640,150])
add_line([sys,'/','Mean&std'],[625,120;625,140;640,140])
add_line([sys,'/','Mean&std'],[495,95;495,110;510,110])
add_line([sys,'/','Mean&std'],[190,125;500,125;510,125])
add_line([sys,'/','Mean&std'],[550,120;550,120])
set_param([sys,'/','Mean&std'],...
		'Mask Display','Mean\n& std',...
		'Mask Type','Mean Squared Error',...
		'Mask Dialogue','Calculates the mean squared error of the two inputs sampling at the delay time.|Delay time:')
set_param([sys,'/','Mean&std'],...
		'Mask Translate','Ts=@1;',...
		'Mask Help','For the inputs x and xHat and delay time T, the output, e, at the n''th time step will be\ne[nT] = sqrt( sum( (x-xHat)^2 )/n ).',...
		'Mask Entries','td\/')


%     Finished composite block 'Mean&std'.

set_param([sys,'/','Mean&std'],...
		'position',[245,83,300,127])


%     Subsystem  'Mean&var'.

new_system([sys,'/','Mean&var'])
set_param([sys,'/','Mean&var'],'Location',[16,148,774,399])

add_block('built-in/Outport',[sys,'/',['Mean&var/Mean',13,'Squared',13,'Error1']])
set_param([sys,'/',['Mean&var/Mean',13,'Squared',13,'Error1']],...
		'Port','2',...
		'position',[700,135,720,155])

add_block('built-in/Fcn',[sys,'/','Mean&var/Fcn4'])
set_param([sys,'/','Mean&var/Fcn4'],...
		'Expr','u[1]*u[1]',...
		'position',[555,107,620,133])

add_block('built-in/Mux',[sys,'/','Mean&var/Mux2'])
set_param([sys,'/','Mean&var/Mux2'],...
		'inputs','2',...
		'position',[515,101,545,134])

add_block('built-in/Sum',[sys,'/','Mean&var/Sum'])
set_param([sys,'/','Mean&var/Sum'],...
		'inputs','-+',...
		'position',[645,135,665,155])

add_block('built-in/Fcn',[sys,'/','Mean&var/Fcn'])
set_param([sys,'/','Mean&var/Fcn'],...
		'Expr','(u[3]*(u[2]-1) + u[1]*u[1])/u[2]',...
		'position',[290,136,465,164])

add_block('built-in/Unit Delay',[sys,'/','Mean&var/Unit Delay'])
set_param([sys,'/','Mean&var/Unit Delay'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[345,192,395,208])

add_block('built-in/Mux',[sys,'/','Mean&var/Mux'])
set_param([sys,'/','Mean&var/Mux'],...
		'inputs','3',...
		'position',[235,134,265,166])

add_block('built-in/Fcn',[sys,'/','Mean&var/Fcn3'])
set_param([sys,'/','Mean&var/Fcn3'],...
		'Expr','(u[3]*(u[2]-1) + u[1])/u[2]',...
		'position',[290,41,465,69])

add_block('built-in/Mux',[sys,'/','Mean&var/Mux1'])
set_param([sys,'/','Mean&var/Mux1'],...
		'inputs','3',...
		'position',[235,39,265,71])

add_block('built-in/Outport',[sys,'/','Mean&var/mean value'])
set_param([sys,'/','Mean&var/mean value'],...
		'position',[545,45,565,65])

add_block('built-in/Unit Delay',[sys,'/','Mean&var/Unit Delay1'])
set_param([sys,'/','Mean&var/Unit Delay1'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[350,87,400,103])

add_block('built-in/Fcn',[sys,'/','Mean&var/Fcn2'])
set_param([sys,'/','Mean&var/Fcn2'],...
		'Expr','u[1]/Ts +1',...
		'position',[105,83,165,107])

add_block('built-in/Digital Clock',[sys,'/','Mean&var/Digital Clock'])
set_param([sys,'/','Mean&var/Digital Clock'],...
		'Sample time','Ts',...
		'position',[45,80,80,110])

add_block('built-in/Inport',[sys,'/','Mean&var/Actual'])
set_param([sys,'/','Mean&var/Actual'],...
		'position',[25,35,45,55])
add_line([sys,'/','Mean&var'],[670,145;695,145])
add_line([sys,'/','Mean&var'],[550,120;550,120])
add_line([sys,'/','Mean&var'],[170,95;190,95;190,150;230,150])
add_line([sys,'/','Mean&var'],[190,125;510,125])
add_line([sys,'/','Mean&var'],[470,55;540,55])
add_line([sys,'/','Mean&var'],[495,55;495,95;405,95])
add_line([sys,'/','Mean&var'],[495,95;495,110;510,110])
add_line([sys,'/','Mean&var'],[625,120;625,140;640,140])
add_line([sys,'/','Mean&var'],[470,150;480,150;480,200;400,200])
add_line([sys,'/','Mean&var'],[480,150;640,150])
add_line([sys,'/','Mean&var'],[50,45;230,45])
add_line([sys,'/','Mean&var'],[200,45;200,140;230,140])
add_line([sys,'/','Mean&var'],[345,95;210,95;210,65;230,65])
add_line([sys,'/','Mean&var'],[190,95;190,55;230,55])
add_line([sys,'/','Mean&var'],[270,55;285,55])
add_line([sys,'/','Mean&var'],[270,150;285,150])
add_line([sys,'/','Mean&var'],[340,200;220,200;230,160])
add_line([sys,'/','Mean&var'],[85,95;100,95])
set_param([sys,'/','Mean&var'],...
		'Mask Display','Mean\n& var',...
		'Mask Type','Mean & Variant',...
		'Mask Dialogue','Calculates the mean squared error of the two inputs sampling at the delay time.|Delay time:')
set_param([sys,'/','Mean&var'],...
		'Mask Translate','Ts=@1;',...
		'Mask Help','For the inputs x and xHat and delay time T, the output, e, at the n''th time step will be\ne[nT] = sqrt( sum( (x-xHat)^2 )/n ).',...
		'Mask Entries','td\/')


%     Finished composite block 'Mean&var'.

set_param([sys,'/','Mean&var'],...
		'position',[175,160,245,200])
add_line(sys,[305,95;340,95])
add_line(sys,[305,115;340,115])
add_line(sys,[135,240;185,240;185,105;240,105])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
