function [ret,x0,str,ts,xts]=tstrcos2(t,x,u,flag);
%TSTRCOS2	is the M-file description of the SIMULINK system named TSTRCOS2.
%	The block-diagram can be displayed by typing: TSTRCOS2.
%
%	SYS=TSTRCOS2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTRCOS2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTRCOS2 with a FLAG of zero:
%	[SIZES]=TSTRCOS2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,53,565,363])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '12')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Memory Impulse'.

new_system([sys,'/','Memory Impulse'])
set_param([sys,'/','Memory Impulse'],'Location',[413,205,811,430])

add_block('built-in/Inport',[sys,'/','Memory Impulse/in_2'])
set_param([sys,'/','Memory Impulse/in_2'],...
		'Port','2',...
		'position',[25,30,45,50])


%     Subsystem  ['Memory Impulse/discrete',13,'Rising edge',13,'detector'].

new_system([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']])
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],'Location',[419,521,808,713])

add_block('built-in/Unit Delay',[sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']])
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']],...
		'Sample time','ts',...
		'position',[120,87,170,103])

add_block('built-in/Outport',[sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']])
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Inport',[sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],[45,25;45,95;115,95])
add_line([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],[175,95;195,95])
add_line([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:|Sampling time:')
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;ts=@2;')
set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thr\/ts\/')


%     Finished composite block ['Memory Impulse/discrete',13,'Rising edge',13,'detector'].

set_param([sys,'/',['Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'position',[65,26,120,54])

add_block('built-in/Switch',[sys,'/','Memory Impulse/Switch'])
set_param([sys,'/','Memory Impulse/Switch'],...
		'Threshold','.5',...
		'position',[295,124,320,156])

add_block('built-in/Constant',[sys,'/','Memory Impulse/Constant'])
set_param([sys,'/','Memory Impulse/Constant'],...
		'Value','x',...
		'position',[210,155,230,175])

add_block('built-in/Outport',[sys,'/','Memory Impulse/out_1'])
set_param([sys,'/','Memory Impulse/out_1'],...
		'position',[355,130,375,150])

add_block('built-in/Product',[sys,'/','Memory Impulse/Product'])
set_param([sys,'/','Memory Impulse/Product'],...
		'position',[155,90,180,110])

add_block('built-in/Zero-Order Hold',[sys,'/',['Memory Impulse/Zero-Order',13,'Hold']])
set_param([sys,'/',['Memory Impulse/Zero-Order',13,'Hold']],...
		'Sample time','ts',...
		'position',[205,84,240,116])

add_block('built-in/Inport',[sys,'/','Memory Impulse/in_1'])
set_param([sys,'/','Memory Impulse/in_1'],...
		'position',[35,185,55,205])
add_line([sys,'/','Memory Impulse'],[50,40;60,40])
add_line([sys,'/','Memory Impulse'],[125,40;130,40;130,95;150,95])
add_line([sys,'/','Memory Impulse'],[235,165;250,165;250,140;290,140])
add_line([sys,'/','Memory Impulse'],[325,140;350,140])
add_line([sys,'/','Memory Impulse'],[60,195;280,195;290,150])
add_line([sys,'/','Memory Impulse'],[95,195;95,105;150,105])
add_line([sys,'/','Memory Impulse'],[185,100;200,100])
add_line([sys,'/','Memory Impulse'],[245,100;260,100;260,130;290,130])
set_param([sys,'/','Memory Impulse'],...
		'Mask Display','Sinc',...
		'Mask Type','Impulse',...
		'Mask Dialogue','1/sinc filter:|Holding time:|Threshold for clock pulse: ',...
		'Mask Translate','ts=@1;thr=@2;x=thr>0;')
set_param([sys,'/','Memory Impulse'],...
		'Mask Help','When the threshold is greater than zero, this block outputs an impulse signal, which begins at the raising edge of the second input and lasts the holding time. The impulse holds a constant amplitude, which equals the amplitude of the first input at the begining of the impulse. A clock raising edge will trigger next impulse. When the threshold is less or equal to zero, this block faithfully outputs the first input.')
set_param([sys,'/','Memory Impulse'],...
		'Mask Entries','.1\/.2\/')


%     Finished composite block 'Memory Impulse'.

set_param([sys,'/','Memory Impulse'],...
		'hide name',0,...
		'position',[195,105,265,145])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[405,100,440,135])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'Vgain','1.200000',...
		'Hgain','12.000000',...
		'Vmax','2.400000',...
		'Hmax','24.000000',...
		'Window',[0,404,322,747])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[465,107,485,133])


%     Subsystem  ['Raised cosine',13,'filter2'].

new_system([sys,'/',['Raised cosine',13,'filter2']])
set_param([sys,'/',['Raised cosine',13,'filter2']],'Location',[131,545,589,761])


%     Subsystem  ['Raised cosine',13,'filter2/Memory Impulse'].

new_system([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],'Location',[541,520,939,745])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/in_1']],...
		'position',[35,185,55,205])

add_block('built-in/Zero-Order Hold',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/Zero-Order',13,'Hold']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/Zero-Order',13,'Hold']],...
		'Sample time','ts',...
		'position',[205,84,240,116])

add_block('built-in/Product',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/Product']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/Product']],...
		'position',[155,90,180,110])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/out_1']],...
		'position',[355,130,375,150])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/Constant']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/Constant']],...
		'Value','x',...
		'position',[210,155,230,175])

add_block('built-in/Switch',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/Switch']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/Switch']],...
		'Threshold','.5',...
		'position',[295,124,320,156])


%     Subsystem  ['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

new_system([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],'Location',[419,521,808,713])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Unit Delay',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']],...
		'Sample time','ts',...
		'position',[120,87,170,103])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[175,95;195,95])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[45,25;45,95;115,95])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Dialogue','Rising edge detection:|Threshold:|Sampling time:',...
		'Mask Translate','thld=@1;ts=@2;')
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Entries','thr\/ts\/')


%     Finished composite block ['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'position',[65,26,120,54])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter2/Memory Impulse/in_2']])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse/in_2']],...
		'Port','2',...
		'position',[25,30,45,50])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],[245,100;260,100;260,130;290,130])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],[185,100;200,100])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],[60,195;280,195;290,150])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],[95,195;95,105;150,105])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],[325,140;350,140])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],[235,165;250,165;250,140;290,140])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],[125,40;130,40;130,95;150,95])
add_line([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],[50,40;60,40])
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],...
		'Mask Display','1/sinc',...
		'Mask Type','Impulse',...
		'Mask Dialogue','1/sinc filter:|Holding time:|Threshold for clock pulse: ')
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],...
		'Mask Translate','ts=@1;thr=@2;x=thr>0;')
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],...
		'Mask Help','When the threshold is greater than zero, this block outputs an impulse signal, which begins at the raising edge of the second input and lasts the holding time. The impulse holds a constant amplitude, which equals the amplitude of the first input at the begining of the impulse. A clock raising edge will trigger next impulse. When the threshold is less or equal to zero, this block faithfully outputs the first input.')
set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],...
		'Mask Entries','ts\/x\/')


%     Finished composite block ['Raised cosine',13,'filter2/Memory Impulse'].

set_param([sys,'/',['Raised cosine',13,'filter2/Memory Impulse']],...
		'position',[155,30,225,70])

add_block('built-in/Filter',[sys,'/',['Raised cosine',13,'filter2/Filter']])
set_param([sys,'/',['Raised cosine',13,'filter2/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,31,310,69])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter2/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter2/out_1']],...
		'position',[330,40,350,60])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter2/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter2/in_1']],...
		'position',[35,30,55,50])


%     Subsystem  ['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','td\/1\/off\/')


%     Finished composite block ['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Raised cosine',13,'filter2/Pulses deivide',13,'same sample time1']],...
		'position',[35,71,95,109])
add_line([sys,'/',['Raised cosine',13,'filter2']],[100,90;115,90;115,60;150,60])
add_line([sys,'/',['Raised cosine',13,'filter2']],[230,50;250,50])
add_line([sys,'/',['Raised cosine',13,'filter2']],[60,40;150,40])
add_line([sys,'/',['Raised cosine',13,'filter2']],[315,50;325,50])
set_param([sys,'/',['Raised cosine',13,'filter2']],...
		'Mask Display','R-C\nfilter',...
		'Mask Type','R-C filter')
set_param([sys,'/',['Raised cosine',13,'filter2']],...
		'Mask Dialogue','Design a raised cosine filter and use it to filter the input signal.|Symbol interval (sec):|Computation sampling time (sec):|Filter rolloff factor:|Delay step (integer to multiply symbol interval):|Filter type (FIR or IIR) / (Normal or Sqrt):|With or without sinc filter (1 or 0, suggest 1):')
set_param([sys,'/',['Raised cosine',13,'filter2']],...
		'Mask Translate','td=@1;if length(td)>1,off=td(2);td=td(1);else,off=0;end;ts=@2;R=@3;delay=@4;fil=@5;[num,den]=rcosine(1/td(1),1/ts(1),fil,R,delay);x=@6/2;')
set_param([sys,'/',['Raised cosine',13,'filter2']],...
		'Mask Help','This block designs a raised cosine filter using the specified parameter. The filter is used to filter the input signal. You can optionally use the sinc filter in the filtering computation.')
set_param([sys,'/',['Raised cosine',13,'filter2']],...
		'Mask Entries','1\/.1\/.5\/6\/''FIR''\/1\/')


%     Finished composite block ['Raised cosine',13,'filter2'].

set_param([sys,'/',['Raised cosine',13,'filter2']],...
		'hide name',0,...
		'position',[235,48,315,92])


%     Subsystem  ['Raised cosine',13,'filter3'].

new_system([sys,'/',['Raised cosine',13,'filter3']])
set_param([sys,'/',['Raised cosine',13,'filter3']],'Location',[131,545,589,761])


%     Subsystem  ['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','td\/1\/off\/')


%     Finished composite block ['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Raised cosine',13,'filter3/Pulses deivide',13,'same sample time1']],...
		'position',[35,71,95,109])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter3/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter3/in_1']],...
		'position',[35,30,55,50])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter3/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter3/out_1']],...
		'position',[330,40,350,60])

add_block('built-in/Filter',[sys,'/',['Raised cosine',13,'filter3/Filter']])
set_param([sys,'/',['Raised cosine',13,'filter3/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,31,310,69])


%     Subsystem  ['Raised cosine',13,'filter3/Memory Impulse'].

new_system([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],'Location',[541,520,939,745])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/in_2']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/in_2']],...
		'Port','2',...
		'position',[25,30,45,50])


%     Subsystem  ['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

new_system([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],'Location',[419,521,808,713])

add_block('built-in/Unit Delay',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']],...
		'Sample time','ts',...
		'position',[120,87,170,103])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[45,25;45,95;115,95])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[175,95;195,95])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Dialogue','Rising edge detection:|Threshold:|Sampling time:',...
		'Mask Translate','thld=@1;ts=@2;')
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Entries','thr\/ts\/')


%     Finished composite block ['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'position',[65,26,120,54])

add_block('built-in/Switch',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/Switch']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/Switch']],...
		'Threshold','.5',...
		'position',[295,124,320,156])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/Constant']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/Constant']],...
		'Value','x',...
		'position',[210,155,230,175])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/out_1']],...
		'position',[355,130,375,150])

add_block('built-in/Product',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/Product']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/Product']],...
		'position',[155,90,180,110])

add_block('built-in/Zero-Order Hold',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/Zero-Order',13,'Hold']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/Zero-Order',13,'Hold']],...
		'Sample time','ts',...
		'position',[205,84,240,116])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter3/Memory Impulse/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse/in_1']],...
		'position',[35,185,55,205])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],[50,40;60,40])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],[125,40;130,40;130,95;150,95])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],[235,165;250,165;250,140;290,140])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],[325,140;350,140])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],[60,195;280,195;290,150])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],[95,195;95,105;150,105])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],[185,100;200,100])
add_line([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],[245,100;260,100;260,130;290,130])
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],...
		'Mask Display','1/sinc',...
		'Mask Type','Impulse',...
		'Mask Dialogue','1/sinc filter:|Holding time:|Threshold for clock pulse: ')
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],...
		'Mask Translate','ts=@1;thr=@2;x=thr>0;')
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],...
		'Mask Help','When the threshold is greater than zero, this block outputs an impulse signal, which begins at the raising edge of the second input and lasts the holding time. The impulse holds a constant amplitude, which equals the amplitude of the first input at the begining of the impulse. A clock raising edge will trigger next impulse. When the threshold is less or equal to zero, this block faithfully outputs the first input.')
set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],...
		'Mask Entries','ts\/x\/')


%     Finished composite block ['Raised cosine',13,'filter3/Memory Impulse'].

set_param([sys,'/',['Raised cosine',13,'filter3/Memory Impulse']],...
		'position',[155,30,225,70])
add_line([sys,'/',['Raised cosine',13,'filter3']],[315,50;325,50])
add_line([sys,'/',['Raised cosine',13,'filter3']],[60,40;150,40])
add_line([sys,'/',['Raised cosine',13,'filter3']],[230,50;250,50])
add_line([sys,'/',['Raised cosine',13,'filter3']],[100,90;115,90;115,60;150,60])
set_param([sys,'/',['Raised cosine',13,'filter3']],...
		'Mask Display','R-C\nfilter',...
		'Mask Type','R-C filter')
set_param([sys,'/',['Raised cosine',13,'filter3']],...
		'Mask Dialogue','Design a raised cosine filter and use it to filter the input signal.|Symbol interval (sec):|Computation sampling time (sec):|Filter rolloff factor:|Delay step (integer to multiply symbol interval):|Filter type (FIR or IIR) / (Normal or Sqrt):|With or without sinc filter (1 or 0, suggest 1):')
set_param([sys,'/',['Raised cosine',13,'filter3']],...
		'Mask Translate','td=@1;if length(td)>1,off=td(2);td=td(1);else,off=0;end;ts=@2;R=@3;delay=@4;fil=@5;[num,den]=rcosine(1/td(1),1/ts(1),fil,R,delay);x=@6/2;')
set_param([sys,'/',['Raised cosine',13,'filter3']],...
		'Mask Help','This block designs a raised cosine filter using the specified parameter. The filter is used to filter the input signal. You can optionally use the sinc filter in the filtering computation.')
set_param([sys,'/',['Raised cosine',13,'filter3']],...
		'Mask Entries','1\/.1\/.5\/6\/''FIR''\/0\/')


%     Finished composite block ['Raised cosine',13,'filter3'].

set_param([sys,'/',['Raised cosine',13,'filter3']],...
		'hide name',0,...
		'position',[290,103,370,147])


%     Subsystem  ['Raised cosine',13,'filter4'].

new_system([sys,'/',['Raised cosine',13,'filter4']])
set_param([sys,'/',['Raised cosine',13,'filter4']],'Location',[131,545,589,761])


%     Subsystem  ['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','td\/1\/off\/')


%     Finished composite block ['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Raised cosine',13,'filter4/Pulses deivide',13,'same sample time1']],...
		'position',[35,71,95,109])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter4/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter4/in_1']],...
		'position',[35,30,55,50])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter4/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter4/out_1']],...
		'position',[330,40,350,60])

add_block('built-in/Filter',[sys,'/',['Raised cosine',13,'filter4/Filter']])
set_param([sys,'/',['Raised cosine',13,'filter4/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,31,310,69])


%     Subsystem  ['Raised cosine',13,'filter4/Memory Impulse'].

new_system([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],'Location',[541,520,939,745])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/in_2']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/in_2']],...
		'Port','2',...
		'position',[25,30,45,50])


%     Subsystem  ['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

new_system([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],'Location',[419,521,808,713])

add_block('built-in/Unit Delay',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']],...
		'Sample time','ts',...
		'position',[120,87,170,103])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[45,25;45,95;115,95])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[175,95;195,95])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Dialogue','Rising edge detection:|Threshold:|Sampling time:',...
		'Mask Translate','thld=@1;ts=@2;')
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Entries','thr\/ts\/')


%     Finished composite block ['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'position',[65,26,120,54])

add_block('built-in/Switch',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/Switch']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/Switch']],...
		'Threshold','.5',...
		'position',[295,124,320,156])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/Constant']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/Constant']],...
		'Value','x',...
		'position',[210,155,230,175])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/out_1']],...
		'position',[355,130,375,150])

add_block('built-in/Product',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/Product']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/Product']],...
		'position',[155,90,180,110])

add_block('built-in/Zero-Order Hold',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/Zero-Order',13,'Hold']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/Zero-Order',13,'Hold']],...
		'Sample time','ts',...
		'position',[205,84,240,116])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter4/Memory Impulse/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse/in_1']],...
		'position',[35,185,55,205])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],[50,40;60,40])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],[125,40;130,40;130,95;150,95])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],[235,165;250,165;250,140;290,140])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],[325,140;350,140])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],[60,195;280,195;290,150])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],[95,195;95,105;150,105])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],[185,100;200,100])
add_line([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],[245,100;260,100;260,130;290,130])
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],...
		'Mask Display','1/sinc',...
		'Mask Type','Impulse',...
		'Mask Dialogue','1/sinc filter:|Holding time:|Threshold for clock pulse: ')
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],...
		'Mask Translate','ts=@1;thr=@2;x=thr>0;')
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],...
		'Mask Help','When the threshold is greater than zero, this block outputs an impulse signal, which begins at the raising edge of the second input and lasts the holding time. The impulse holds a constant amplitude, which equals the amplitude of the first input at the begining of the impulse. A clock raising edge will trigger next impulse. When the threshold is less or equal to zero, this block faithfully outputs the first input.')
set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],...
		'Mask Entries','ts\/x\/')


%     Finished composite block ['Raised cosine',13,'filter4/Memory Impulse'].

set_param([sys,'/',['Raised cosine',13,'filter4/Memory Impulse']],...
		'position',[155,30,225,70])
add_line([sys,'/',['Raised cosine',13,'filter4']],[315,50;325,50])
add_line([sys,'/',['Raised cosine',13,'filter4']],[60,40;150,40])
add_line([sys,'/',['Raised cosine',13,'filter4']],[230,50;250,50])
add_line([sys,'/',['Raised cosine',13,'filter4']],[100,90;115,90;115,60;150,60])
set_param([sys,'/',['Raised cosine',13,'filter4']],...
		'Mask Display','R-C\nfilter',...
		'Mask Type','R-C filter')
set_param([sys,'/',['Raised cosine',13,'filter4']],...
		'Mask Dialogue','Design a raised cosine filter and use it to filter the input signal.|Symbol interval (sec):|Computation sampling time (sec):|Filter rolloff factor:|Delay step (integer to multiply symbol interval):|Filter type (FIR or IIR) / (Normal or Sqrt):|With or without sinc filter (1 or 0, suggest 1):')
set_param([sys,'/',['Raised cosine',13,'filter4']],...
		'Mask Translate','td=@1;if length(td)>1,off=td(2);td=td(1);else,off=0;end;ts=@2;R=@3;delay=@4;fil=@5;[num,den]=rcosine(1/td(1),1/ts(1),fil,R,delay);x=@6/2;')
set_param([sys,'/',['Raised cosine',13,'filter4']],...
		'Mask Help','This block designs a raised cosine filter using the specified parameter. The filter is used to filter the input signal. You can optionally use the sinc filter in the filtering computation.')
set_param([sys,'/',['Raised cosine',13,'filter4']],...
		'Mask Entries','1\/.1\/.5\/3\/''FIR/Sqrt''\/1\/')


%     Finished composite block ['Raised cosine',13,'filter4'].

set_param([sys,'/',['Raised cosine',13,'filter4']],...
		'hide name',0,...
		'position',[185,163,265,207])


%     Subsystem  ['Raised cosine',13,'filter5'].

new_system([sys,'/',['Raised cosine',13,'filter5']])
set_param([sys,'/',['Raised cosine',13,'filter5']],'Location',[131,545,589,761])


%     Subsystem  ['Raised cosine',13,'filter5/Memory Impulse'].

new_system([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],'Location',[541,520,939,745])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/in_1']],...
		'position',[35,185,55,205])

add_block('built-in/Zero-Order Hold',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/Zero-Order',13,'Hold']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/Zero-Order',13,'Hold']],...
		'Sample time','ts',...
		'position',[205,84,240,116])

add_block('built-in/Product',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/Product']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/Product']],...
		'position',[155,90,180,110])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/out_1']],...
		'position',[355,130,375,150])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/Constant']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/Constant']],...
		'Value','x',...
		'position',[210,155,230,175])

add_block('built-in/Switch',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/Switch']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/Switch']],...
		'Threshold','.5',...
		'position',[295,124,320,156])


%     Subsystem  ['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

new_system([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],'Location',[419,521,808,713])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Unit Delay',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']],...
		'Sample time','ts',...
		'position',[120,87,170,103])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[175,95;195,95])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[45,25;45,95;115,95])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Dialogue','Rising edge detection:|Threshold:|Sampling time:',...
		'Mask Translate','thld=@1;ts=@2;')
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Entries','thr\/ts\/')


%     Finished composite block ['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'position',[65,26,120,54])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter5/Memory Impulse/in_2']])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse/in_2']],...
		'Port','2',...
		'position',[25,30,45,50])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],[245,100;260,100;260,130;290,130])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],[185,100;200,100])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],[60,195;280,195;290,150])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],[95,195;95,105;150,105])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],[325,140;350,140])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],[235,165;250,165;250,140;290,140])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],[125,40;130,40;130,95;150,95])
add_line([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],[50,40;60,40])
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],...
		'Mask Display','1/sinc',...
		'Mask Type','Impulse',...
		'Mask Dialogue','1/sinc filter:|Holding time:|Threshold for clock pulse: ')
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],...
		'Mask Translate','ts=@1;thr=@2;x=thr>0;')
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],...
		'Mask Help','When the threshold is greater than zero, this block outputs an impulse signal, which begins at the raising edge of the second input and lasts the holding time. The impulse holds a constant amplitude, which equals the amplitude of the first input at the begining of the impulse. A clock raising edge will trigger next impulse. When the threshold is less or equal to zero, this block faithfully outputs the first input.')
set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],...
		'Mask Entries','ts\/x\/')


%     Finished composite block ['Raised cosine',13,'filter5/Memory Impulse'].

set_param([sys,'/',['Raised cosine',13,'filter5/Memory Impulse']],...
		'position',[155,30,225,70])

add_block('built-in/Filter',[sys,'/',['Raised cosine',13,'filter5/Filter']])
set_param([sys,'/',['Raised cosine',13,'filter5/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,31,310,69])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter5/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter5/out_1']],...
		'position',[330,40,350,60])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter5/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter5/in_1']],...
		'position',[35,30,55,50])


%     Subsystem  ['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','td\/1\/off\/')


%     Finished composite block ['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Raised cosine',13,'filter5/Pulses deivide',13,'same sample time1']],...
		'position',[35,71,95,109])
add_line([sys,'/',['Raised cosine',13,'filter5']],[100,90;115,90;115,60;150,60])
add_line([sys,'/',['Raised cosine',13,'filter5']],[230,50;250,50])
add_line([sys,'/',['Raised cosine',13,'filter5']],[60,40;150,40])
add_line([sys,'/',['Raised cosine',13,'filter5']],[315,50;325,50])
set_param([sys,'/',['Raised cosine',13,'filter5']],...
		'Mask Display','R-C\nfilter',...
		'Mask Type','R-C filter')
set_param([sys,'/',['Raised cosine',13,'filter5']],...
		'Mask Dialogue','Design a raised cosine filter and use it to filter the input signal.|Symbol interval (sec):|Computation sampling time (sec):|Filter rolloff factor:|Delay step (integer to multiply symbol interval):|Filter type (FIR or IIR) / (Normal or Sqrt):|With or without sinc filter (1 or 0, suggest 1):')
set_param([sys,'/',['Raised cosine',13,'filter5']],...
		'Mask Translate','td=@1;if length(td)>1,off=td(2);td=td(1);else,off=0;end;ts=@2;R=@3;delay=@4;fil=@5;[num,den]=rcosine(1/td(1),1/ts(1),fil,R,delay);x=@6/2;')
set_param([sys,'/',['Raised cosine',13,'filter5']],...
		'Mask Help','This block designs a raised cosine filter using the specified parameter. The filter is used to filter the input signal. You can optionally use the sinc filter in the filtering computation.')
set_param([sys,'/',['Raised cosine',13,'filter5']],...
		'Mask Entries','1\/.1\/.5\/3\/''FIR/Sqrt''\/0\/')


%     Finished composite block ['Raised cosine',13,'filter5'].

set_param([sys,'/',['Raised cosine',13,'filter5']],...
		'hide name',0,...
		'position',[295,163,375,207])


%     Subsystem  ['Raised cosine',13,'filter6'].

new_system([sys,'/',['Raised cosine',13,'filter6']])
set_param([sys,'/',['Raised cosine',13,'filter6']],'Location',[131,545,589,761])


%     Subsystem  ['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','td\/1\/off\/')


%     Finished composite block ['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Raised cosine',13,'filter6/Pulses deivide',13,'same sample time1']],...
		'position',[35,71,95,109])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter6/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter6/in_1']],...
		'position',[35,30,55,50])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter6/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter6/out_1']],...
		'position',[330,40,350,60])

add_block('built-in/Filter',[sys,'/',['Raised cosine',13,'filter6/Filter']])
set_param([sys,'/',['Raised cosine',13,'filter6/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,31,310,69])


%     Subsystem  ['Raised cosine',13,'filter6/Memory Impulse'].

new_system([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],'Location',[541,520,939,745])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/in_2']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/in_2']],...
		'Port','2',...
		'position',[25,30,45,50])


%     Subsystem  ['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

new_system([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],'Location',[419,521,808,713])

add_block('built-in/Unit Delay',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/Unit Delay']],...
		'Sample time','ts',...
		'position',[120,87,170,103])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[45,25;45,95;115,95])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[175,95;195,95])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Dialogue','Rising edge detection:|Threshold:|Sampling time:',...
		'Mask Translate','thld=@1;ts=@2;')
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'Mask Entries','thr\/ts\/')


%     Finished composite block ['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector'].

set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/discrete',13,'Rising edge',13,'detector']],...
		'position',[65,26,120,54])

add_block('built-in/Switch',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/Switch']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/Switch']],...
		'Threshold','.5',...
		'position',[295,124,320,156])

add_block('built-in/Constant',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/Constant']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/Constant']],...
		'Value','x',...
		'position',[210,155,230,175])

add_block('built-in/Outport',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/out_1']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/out_1']],...
		'position',[355,130,375,150])

add_block('built-in/Product',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/Product']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/Product']],...
		'position',[155,90,180,110])

add_block('built-in/Zero-Order Hold',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/Zero-Order',13,'Hold']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/Zero-Order',13,'Hold']],...
		'Sample time','ts',...
		'position',[205,84,240,116])

add_block('built-in/Inport',[sys,'/',['Raised cosine',13,'filter6/Memory Impulse/in_1']])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse/in_1']],...
		'position',[35,185,55,205])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],[50,40;60,40])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],[125,40;130,40;130,95;150,95])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],[235,165;250,165;250,140;290,140])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],[325,140;350,140])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],[60,195;280,195;290,150])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],[95,195;95,105;150,105])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],[185,100;200,100])
add_line([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],[245,100;260,100;260,130;290,130])
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],...
		'Mask Display','1/sinc',...
		'Mask Type','Impulse',...
		'Mask Dialogue','1/sinc filter:|Holding time:|Threshold for clock pulse: ')
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],...
		'Mask Translate','ts=@1;thr=@2;x=thr>0;')
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],...
		'Mask Help','When the threshold is greater than zero, this block outputs an impulse signal, which begins at the raising edge of the second input and lasts the holding time. The impulse holds a constant amplitude, which equals the amplitude of the first input at the begining of the impulse. A clock raising edge will trigger next impulse. When the threshold is less or equal to zero, this block faithfully outputs the first input.')
set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],...
		'Mask Entries','ts\/x\/')


%     Finished composite block ['Raised cosine',13,'filter6/Memory Impulse'].

set_param([sys,'/',['Raised cosine',13,'filter6/Memory Impulse']],...
		'position',[155,30,225,70])
add_line([sys,'/',['Raised cosine',13,'filter6']],[315,50;325,50])
add_line([sys,'/',['Raised cosine',13,'filter6']],[60,40;150,40])
add_line([sys,'/',['Raised cosine',13,'filter6']],[230,50;250,50])
add_line([sys,'/',['Raised cosine',13,'filter6']],[100,90;115,90;115,60;150,60])
set_param([sys,'/',['Raised cosine',13,'filter6']],...
		'Mask Display','R-C\nfilter',...
		'Mask Type','R-C filter')
set_param([sys,'/',['Raised cosine',13,'filter6']],...
		'Mask Dialogue','Design a raised cosine filter and use it to filter the input signal.|Symbol interval (sec):|Computation sampling time (sec):|Filter rolloff factor:|Delay step (integer to multiply symbol interval):|Filter type (FIR or IIR) / (Normal or Sqrt):|With or without sinc filter (1 or 0, suggest 1):')
set_param([sys,'/',['Raised cosine',13,'filter6']],...
		'Mask Translate','td=@1;if length(td)>1,off=td(2);td=td(1);else,off=0;end;ts=@2;R=@3;delay=@4;fil=@5;[num,den]=rcosine(1/td(1),1/ts(1),fil,R,delay);x=@6/2;')
set_param([sys,'/',['Raised cosine',13,'filter6']],...
		'Mask Help','This block designs a raised cosine filter using the specified parameter. The filter is used to filter the input signal. You can optionally use the sinc filter in the filtering computation.')
set_param([sys,'/',['Raised cosine',13,'filter6']],...
		'Mask Entries','1\/.1\/.5\/6\/''FIR''\/0\/')


%     Finished composite block ['Raised cosine',13,'filter6'].

set_param([sys,'/',['Raised cosine',13,'filter6']],...
		'hide name',0,...
		'position',[235,218,315,262])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'Vgain','10.000000',...
		'Hgain','12.000000',...
		'Vmax','20.000000',...
		'Hmax','24.000000',...
		'Window',[633,416,955,753])
open_system([sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'position',[460,227,480,253])

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'Vgain','1.200000',...
		'Hgain','12.000000',...
		'Vmax','2.400000',...
		'Hmax','24.000000',...
		'Window',[314,409,636,753])
open_system([sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'position',[465,172,485,198])


%     Subsystem  ['FFT',13,'Scope'].

new_system([sys,'/',['FFT',13,'Scope']])
set_param([sys,'/',['FFT',13,'Scope']],'Location',[276,440,798,541])


%     Subsystem  ['FFT',13,'Scope/Buffer'].

new_system([sys,'/',['FFT',13,'Scope/Buffer']])
set_param([sys,'/',['FFT',13,'Scope/Buffer']],'Location',[486,410,806,564])

add_block('built-in/Zero-Order Hold',[sys,'/',['FFT',13,'Scope/Buffer/Zero-Order',13,'Hold']])
set_param([sys,'/',['FFT',13,'Scope/Buffer/Zero-Order',13,'Hold']],...
		'Sample time','sampleTime(1,:)',...
		'position',[60,39,95,71])

add_block('built-in/S-Function',[sys,'/',['FFT',13,'Scope/Buffer/Buffer']])
set_param([sys,'/',['FFT',13,'Scope/Buffer/Buffer']],...
		'function name','sbuffer',...
		'parameters','bufSize,bufOverlap,sampleTime',...
		'position',[120,34,195,76])

add_block('built-in/Inport',[sys,'/',['FFT',13,'Scope/Buffer/in_1']])
set_param([sys,'/',['FFT',13,'Scope/Buffer/in_1']],...
		'position',[10,45,30,65])

add_block('built-in/Outport',[sys,'/',['FFT',13,'Scope/Buffer/Outport']])
set_param([sys,'/',['FFT',13,'Scope/Buffer/Outport']],...
		'position',[285,45,305,65])

add_block('built-in/S-Function',[sys,'/',['FFT',13,'Scope/Buffer/ZOH']])
set_param([sys,'/',['FFT',13,'Scope/Buffer/ZOH']],...
		'function name','szoh',...
		'parameters','sampleTime(2,:)',...
		'position',[220,43,260,67])
add_line([sys,'/',['FFT',13,'Scope/Buffer']],[200,55;215,55])
add_line([sys,'/',['FFT',13,'Scope/Buffer']],[265,55;280,55])
add_line([sys,'/',['FFT',13,'Scope/Buffer']],[35,55;55,55])
add_line([sys,'/',['FFT',13,'Scope/Buffer']],[100,55;115,55])
set_param([sys,'/',['FFT',13,'Scope/Buffer']],...
		'Mask Display','plot(0,0,100,100,[12 28 28 32 28 28],[92 92 94 92 90 92],[32 36 36 40 36 36],[92 92 94 92 90 92],[24 24 28],[92 92 92],[40 44 44 48 44 44],[92 92 94 92 90 92],[52 48 52 52 56 52 52],[92 92 92 94 92 90 92],[56 64 64 57 64 71],[92 92 69 76 69 76],[48 80 80 48 48],[64 64 12 12 64],[56 72],[56 56],[56 72],[48 48],[56 72],[40 40],[56 72],[32 32],[56 72],[24 24])')
set_param([sys,'/',['FFT',13,'Scope/Buffer']],...
		'Mask Type','Buffer',...
		'Mask Dialogue','Buffer input data.|Buffer size:|Buffer overlap:|Sample time:')
set_param([sys,'/',['FFT',13,'Scope/Buffer']],...
		'Mask Translate','bufSize=@1;bufOverlap=@2;sampleTime=dspbufst( @3, @1-@2, @1 - 1);')
set_param([sys,'/',['FFT',13,'Scope/Buffer']],...
		'Mask Help','Accumulates samples (at a sampling interval of Sample time) of the real scalar input into a buffer of length Buffer size. Outputs the content of the buffer in a real vector. Updates the buffer every (Buffer size - Buffer overlap) samples, outputting a frame of the input which overlaps the previous frame by Buffer overlap samples.  Buffer overlap may be zero or negative.')
set_param([sys,'/',['FFT',13,'Scope/Buffer']],...
		'Mask Entries','bufsize\/olap\/ts\/')


%     Finished composite block ['FFT',13,'Scope/Buffer'].

set_param([sys,'/',['FFT',13,'Scope/Buffer']],...
		'position',[75,24,115,56])


%     Subsystem  ['FFT',13,'Scope/FFT',13,'R -> C'].

new_system([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']])
set_param([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']],'Location',[561,290,960,446])

add_block('built-in/Inport',[sys,'/',['FFT',13,'Scope/FFT',13,'R -> C/in_1']])
set_param([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C/in_1']],...
		'position',[40,75,60,95])

add_block('built-in/Mux',[sys,'/',['FFT',13,'Scope/FFT',13,'R -> C/Mux']])
set_param([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C/Mux']],...
		'inputs','2',...
		'position',[155,76,185,109])

add_block('built-in/S-Function',[sys,'/',['FFT',13,'Scope/FFT',13,'R -> C/FFT(u)']])
set_param([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C/FFT(u)']],...
		'function name','srfft',...
		'parameters','sample_time',...
		'position',[225,82,280,108])

add_block('built-in/Outport',[sys,'/',['FFT',13,'Scope/FFT',13,'R -> C/out_1']])
set_param([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C/out_1']],...
		'position',[310,85,330,105])
add_line([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']],[285,95;305,95])
add_line([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']],[65,85;100,85;100,100;150,100])
add_line([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']],[100,85;150,85])
add_line([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']],[190,95;220,95])
set_param([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']],...
		'Mask Display','plot(0,0,100,100,x,y);  FFT ',...
		'Mask Type','FFT',...
		'Mask Dialogue','Compute FFT of real vector.|Sample time (use -1 to inherit sample time):')
set_param([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']],...
		'Mask Translate','sample_time=@1; [x,y]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']],...
		'Mask Help','Computes the discrete Fourier transform of the real input vector. Sampling and FFT computation occur at each Sample time. The length of the input vector must be a power of two. The output is complex.')
set_param([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']],...
		'Mask Entries','-1\/')


%     Finished composite block ['FFT',13,'Scope/FFT',13,'R -> C'].

set_param([sys,'/',['FFT',13,'Scope/FFT',13,'R -> C']],...
		'position',[235,24,275,56])

add_block('built-in/S-Function',[sys,'/',['FFT',13,'Scope/Buffer Scope']])
set_param([sys,'/',['FFT',13,'Scope/Buffer Scope']],...
		'function name','sbufscop',...
		'parameters','1/ts,1,figpos,nan,rads',...
		'Mask Display','',...
		'position',[410,25,475,55])

add_block('built-in/Inport',[sys,'/',['FFT',13,'Scope/u']])
set_param([sys,'/',['FFT',13,'Scope/u']],...
		'position',[5,30,25,50])

add_block('built-in/S-Function',[sys,'/',['FFT',13,'Scope/Zero Pad']])
set_param([sys,'/',['FFT',13,'Scope/Zero Pad']],...
		'function name','szeropad',...
		'parameters','N')
set_param([sys,'/',['FFT',13,'Scope/Zero Pad']],...
		'Mask Display','plot(0,0,100,100,[51 44 44 51],[92 92 8 8],[73 80 80 73],[92 92 8 8],[56 68],[80 80],[56 68],[72 72],[56 68],[64 64],[56 68],[56 56],[56 68],[48 48],[56 68],[40 40],[64 60 56 55 56 60 64 68 69 68 64],[32 32 28 22 16 12 12 16 22 28 32],[24 24 40 36 40 36],[52 24 24 28 24 20])')
set_param([sys,'/',['FFT',13,'Scope/Zero Pad']],...
		'Mask Type','Zero Pad',...
		'Mask Dialogue','Pad vector with zeros to specified length.|Vector length:',...
		'Mask Translate','N=@1;')
set_param([sys,'/',['FFT',13,'Scope/Zero Pad']],...
		'Mask Help','Increases the length of its input vector to length "Vector length" by appending zeros to the vector. If the Vector length is smaller than the input vector length, the Zero Pad block discards elements at the end of the input vector.')
set_param([sys,'/',['FFT',13,'Scope/Zero Pad']],...
		'Mask Entries','2.^nextpow2(fftlength)\/',...
		'position',[155,24,195,56])


%     Subsystem  ['FFT',13,'Scope/Magnitude'].

new_system([sys,'/',['FFT',13,'Scope/Magnitude']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude']],'Location',[30,216,487,404])

add_block('built-in/Note',[sys,'/',['FFT',13,'Scope/Magnitude/I']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/I']],...
		'position',[240,105,245,110])

add_block('built-in/S-Function',[sys,'/',['FFT',13,'Scope/Magnitude/Sqrt']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Sqrt']],...
		'function name','selmath1',...
		'parameters','''sqrt''',...
		'Mask Display','plot(x*.9+5,y*.9+5,0,0,100,100,[87,65,62,58,54],[50,50,15,30,30])',...
		'Mask Type','Square Root')
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Sqrt']],...
		'Mask Dialogue','Square root of vector elements.',...
		'Mask Translate','[x,y]=fplot(''10*sqrt(x)'',[0 100],''-'',1e-2);')
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Sqrt']],...
		'Mask Help','Computes the square root of the input vector:\ny=sqrt(u)\nThe output is undefined if the input is negative.',...
		'position',[345,78,375,102])


%     Subsystem  ['FFT',13,'Scope/Magnitude/Square'].

new_system([sys,'/',['FFT',13,'Scope/Magnitude/Square']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Square']],'Location',[98,193,374,369])

add_block('built-in/Product',[sys,'/',['FFT',13,'Scope/Magnitude/Square/Product']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Square/Product']],...
		'position',[150,73,180,97])

add_block('built-in/Outport',[sys,'/',['FFT',13,'Scope/Magnitude/Square/out_1']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Square/out_1']],...
		'position',[210,75,230,95])

add_block('built-in/Inport',[sys,'/',['FFT',13,'Scope/Magnitude/Square/in_1']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Square/in_1']],...
		'position',[65,70,85,90])
add_line([sys,'/',['FFT',13,'Scope/Magnitude/Square']],[185,85;205,85])
add_line([sys,'/',['FFT',13,'Scope/Magnitude/Square']],[90,80;145,80])
add_line([sys,'/',['FFT',13,'Scope/Magnitude/Square']],[100,80;100,90;145,90])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Square']],...
		'Mask Display','plot(x,y); ',...
		'Mask Type','Square',...
		'Mask Dialogue','Square of vector elements.',...
		'Mask Translate','[x,y]=fplot(''x.^2'',[-2 2],''-'',1e-2);')
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Square']],...
		'Mask Help','Computes the square of the input vector:\ny=u.^2')


%     Finished composite block ['FFT',13,'Scope/Magnitude/Square'].

set_param([sys,'/',['FFT',13,'Scope/Magnitude/Square']],...
		'position',[85,78,115,102])

add_block('built-in/Demux',[sys,'/',['FFT',13,'Scope/Magnitude/Split']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Split']],...
		'outputs','2',...
		'Mask Display','plot(0,0,100,100,x,y,x1,y1)',...
		'Mask Type','Complex to Real/Imag',...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Split']],...
		'Mask Translate','o=get_param(gcb,''orientation''); [x,y]=cmplxicn(0,50,o); [x1,y1]=joinicon(o+2); ')
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Split']],...
		'Mask Help','The Decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Split']],...
		'position',[160,78,190,102])

add_block('built-in/Sum',[sys,'/',['FFT',13,'Scope/Magnitude/R^2+I^2']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/R^2+I^2']],...
		'position',[275,64,300,111])

add_block('built-in/Outport',[sys,'/',['FFT',13,'Scope/Magnitude/Magnitude']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/Magnitude']],...
		'position',[410,80,430,100])

add_block('built-in/Inport',[sys,'/',['FFT',13,'Scope/Magnitude/in_1']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/in_1']],...
		'position',[15,80,35,100])

add_block('built-in/Note',[sys,'/',['FFT',13,'Scope/Magnitude/R']])
set_param([sys,'/',['FFT',13,'Scope/Magnitude/R']],...
		'position',[245,55,250,60])
add_line([sys,'/',['FFT',13,'Scope/Magnitude']],[40,90;80,90])
add_line([sys,'/',['FFT',13,'Scope/Magnitude']],[380,90;405,90])
add_line([sys,'/',['FFT',13,'Scope/Magnitude']],[120,90;155,90])
add_line([sys,'/',['FFT',13,'Scope/Magnitude']],[195,85;225,85;225,75;270,75])
add_line([sys,'/',['FFT',13,'Scope/Magnitude']],[195,95;225,95;225,100;270,100])
add_line([sys,'/',['FFT',13,'Scope/Magnitude']],[305,90;340,90])
set_param([sys,'/',['FFT',13,'Scope/Magnitude']],...
		'Mask Display','plot(0,0,100,100,[30,30],[10,90],[90,12],[30,30],[73,80,30],[51,70,30],[64,80],[70,70],[76,83,64],[51,73,73],[78,33,30,77],[65,30,34,70],x,y)',...
		'Mask Type','Magnitude')
set_param([sys,'/',['FFT',13,'Scope/Magnitude']],...
		'Mask Dialogue','Magnitude of complex vector.',...
		'Mask Translate','[x,y]=cmplxicn(0,50,get_param(gcb,''orientation'')); ')
set_param([sys,'/',['FFT',13,'Scope/Magnitude']],...
		'Mask Help','Computes the magnitude of the complex input vector:\ny=sqrt(u*conj(u))\nThe output is a real vector.')


%     Finished composite block ['FFT',13,'Scope/Magnitude'].

set_param([sys,'/',['FFT',13,'Scope/Magnitude']],...
		'position',[330,28,360,52])
add_line([sys,'/',['FFT',13,'Scope']],[200,40;230,40])
add_line([sys,'/',['FFT',13,'Scope']],[280,40;325,40])
add_line([sys,'/',['FFT',13,'Scope']],[30,40;70,40])
add_line([sys,'/',['FFT',13,'Scope']],[120,40;150,40])
add_line([sys,'/',['FFT',13,'Scope']],[365,40;405,40])
set_param([sys,'/',['FFT',13,'Scope']],...
		'Mask Display','plot(0,0,100,100,[8 8 92 92 8],[92 40 40 92 92],[16 16 84],[88 48 48],[24 24],[76 48],[32 32 32],[65 48 48],[40 40],[79 48],[48 48],[60 48],[56 56],[58 48],[64 64],[64 48],[72 72 72],[56 49 48],[80 80 80 80],[49 49 48 48],[38 32 32 36 32 32],[33 33 27 27 27 20],[51 44 44 48 44 44 44],[33 33 27 27 27 27 20],[64 60 56 60 60],[33 33 33 33 20])')
set_param([sys,'/',['FFT',13,'Scope']],...
		'Mask Type','FFT Scope')
set_param([sys,'/',['FFT',13,'Scope']],...
		'Mask Dialogue','FFT scope for real input.|Buffer size:|Buffer overlap:|Sample time:|FFT length (must be a power of two):|Units (0 - Hz, 1 - Rads/sec):|Figure position (in pixels):')
set_param([sys,'/',['FFT',13,'Scope']],...
		'Mask Translate','bufsize=@1;olap=@2;ts=@3;fftlength=@4;rads=@5;figpos=@6;')
set_param([sys,'/',['FFT',13,'Scope']],...
		'Mask Help','Successively accumulates Buffer size (real, scalar) signal values at a sampling rate of Sample time, overlapping successive buffers by Buffer overlap samples. Takes the FFT of length "FFT length" of each buffer and displays its magnitude in a figure.')
set_param([sys,'/',['FFT',13,'Scope']],...
		'Mask Entries','64\/32\/0.1\/128\/0\/get(0,''DefaultFigurePosition'')\/')


%     Finished composite block ['FFT',13,'Scope'].

set_param([sys,'/',['FFT',13,'Scope']],...
		'hide name',0,...
		'position',[460,48,495,92])

add_block('built-in/Note',[sys,'/','The FFT Scope is a block in the DSP Blockset.'])
set_param([sys,'/','The FFT Scope is a block in the DSP Blockset.'],...
		'position',[260,270,265,275])


%     Subsystem  ['Sampled read with',13,'synchronized pulse'].

new_system([sys,'/',['Sampled read with',13,'synchronized pulse']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],'Location',[355,527,737,674])

add_block('built-in/S-Function',[sys,'/',['Sampled read with',13,'synchronized pulse/Message source']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Message source']],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/out_2']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/out_2']],...
		'Port','2',...
		'position',[195,115,215,135])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/out_1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read with',13,'synchronized pulse/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[115,75;175,75])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[135,75;135,125;190,125])
add_line([sys,'/',['Sampled read with',13,'synchronized pulse']],[260,75;290,75])
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Dialogue','Read from a workspace variable at sample time.|Variable (column_number=block_output_length):|Data output sample time (sec):|Repeat flag (1: repeat read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);[v,w]=trigicon(1,75,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reaches the end of the variable (eof), the block will cyclically output from the first row of the variable or output zeros based on the repeat flag entree. The second output is the synchronization pulse, which outputs a spike when the data is refreshed.')
set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'Mask Entries','[1;0]\/1\/0\/0\/')


%     Finished composite block ['Sampled read with',13,'synchronized pulse'].

set_param([sys,'/',['Sampled read with',13,'synchronized pulse']],...
		'hide name',0,...
		'position',[35,58,115,102])
add_line(sys,[120,70;230,70])
add_line(sys,[320,240;455,240])
add_line(sys,[160,70;160,240;230,240])
add_line(sys,[270,185;290,185])
add_line(sys,[120,90;145,90;145,135;190,135])
add_line(sys,[270,125;285,125])
add_line(sys,[445,120;460,120])
add_line(sys,[320,70;380,70;455,70])
add_line(sys,[375,125;400,125])
add_line(sys,[160,115;190,115])
add_line(sys,[380,185;460,185])
add_line(sys,[160,185;180,185])
add_line(sys,[380,70;380,110;400,110])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
