function [ret,x0,str,ts,xts]=tstricia(t,x,u,flag);
%TSTRICIA	is the M-file description of the SIMULINK system named TSTRICIA.
%	The block-diagram can be displayed by typing: TSTRICIA.
%
%	SYS=TSTRICIA(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTRICIA to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTRICIA with a FLAG of zero:
%	[SIZES]=TSTRICIA([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[42,399,522,694])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Mean and var1'.

new_system([sys,'/','Mean and var1'])
set_param([sys,'/','Mean and var1'],'Location',[16,148,774,399])

add_block('built-in/Inport',[sys,'/','Mean and var1/Actual'])
set_param([sys,'/','Mean and var1/Actual'],...
		'position',[25,35,45,55])

add_block('built-in/Digital Clock',[sys,'/','Mean and var1/Digital Clock'])
set_param([sys,'/','Mean and var1/Digital Clock'],...
		'Sample time','Ts',...
		'position',[45,80,80,110])

add_block('built-in/Fcn',[sys,'/','Mean and var1/Fcn2'])
set_param([sys,'/','Mean and var1/Fcn2'],...
		'Expr','u[1]/Ts +1',...
		'position',[105,83,165,107])

add_block('built-in/Unit Delay',[sys,'/','Mean and var1/Unit Delay1'])
set_param([sys,'/','Mean and var1/Unit Delay1'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[350,87,400,103])

add_block('built-in/Outport',[sys,'/','Mean and var1/mean value'])
set_param([sys,'/','Mean and var1/mean value'],...
		'position',[545,45,565,65])

add_block('built-in/Mux',[sys,'/','Mean and var1/Mux1'])
set_param([sys,'/','Mean and var1/Mux1'],...
		'inputs','3',...
		'position',[235,39,265,71])

add_block('built-in/Fcn',[sys,'/','Mean and var1/Fcn3'])
set_param([sys,'/','Mean and var1/Fcn3'],...
		'Expr','(u[3]*(u[2]-1) + u[1])/u[2]',...
		'position',[290,41,465,69])

add_block('built-in/Mux',[sys,'/','Mean and var1/Mux'])
set_param([sys,'/','Mean and var1/Mux'],...
		'inputs','3',...
		'position',[235,134,265,166])

add_block('built-in/Unit Delay',[sys,'/','Mean and var1/Unit Delay'])
set_param([sys,'/','Mean and var1/Unit Delay'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[345,192,395,208])

add_block('built-in/Fcn',[sys,'/','Mean and var1/Fcn'])
set_param([sys,'/','Mean and var1/Fcn'],...
		'Expr','(u[3]*(u[2]-1) + u[1]*u[1])/u[2]',...
		'position',[290,136,465,164])

add_block('built-in/Sum',[sys,'/','Mean and var1/Sum'])
set_param([sys,'/','Mean and var1/Sum'],...
		'inputs','-+',...
		'position',[645,135,665,155])

add_block('built-in/Mux',[sys,'/','Mean and var1/Mux2'])
set_param([sys,'/','Mean and var1/Mux2'],...
		'inputs','2',...
		'position',[515,101,545,134])

add_block('built-in/Fcn',[sys,'/','Mean and var1/Fcn4'])
set_param([sys,'/','Mean and var1/Fcn4'],...
		'Expr','u[1]*u[1]',...
		'position',[555,107,620,133])

add_block('built-in/Outport',[sys,'/',['Mean and var1/Mean',13,'Squared',13,'Error1']])
set_param([sys,'/',['Mean and var1/Mean',13,'Squared',13,'Error1']],...
		'Port','2',...
		'position',[700,135,720,155])
add_line([sys,'/','Mean and var1'],[85,95;100,95])
add_line([sys,'/','Mean and var1'],[340,200;220,200;230,160])
add_line([sys,'/','Mean and var1'],[270,150;285,150])
add_line([sys,'/','Mean and var1'],[270,55;285,55])
add_line([sys,'/','Mean and var1'],[170,95;190,95;190,150;230,150])
add_line([sys,'/','Mean and var1'],[190,95;190,55;230,55])
add_line([sys,'/','Mean and var1'],[345,95;210,95;210,65;230,65])
add_line([sys,'/','Mean and var1'],[50,45;230,45])
add_line([sys,'/','Mean and var1'],[200,45;200,140;230,140])
add_line([sys,'/','Mean and var1'],[470,150;480,150;480,200;400,200])
add_line([sys,'/','Mean and var1'],[480,150;640,150])
add_line([sys,'/','Mean and var1'],[625,120;625,140;640,140])
add_line([sys,'/','Mean and var1'],[470,55;540,55])
add_line([sys,'/','Mean and var1'],[495,55;495,95;405,95])
add_line([sys,'/','Mean and var1'],[495,95;495,110;510,110])
add_line([sys,'/','Mean and var1'],[190,125;510,125])
add_line([sys,'/','Mean and var1'],[550,120;550,120])
add_line([sys,'/','Mean and var1'],[670,145;695,145])
set_param([sys,'/','Mean and var1'],...
		'Mask Display','Mean\n& var',...
		'Mask Type','Running mean and var',...
		'Mask Dialogue','Output the running mean to 1st outport\nand running variant to 2nd outport.|Sample time (sec):')
set_param([sys,'/','Mean and var1'],...
		'Mask Translate','Ts=@1;',...
		'Mask Help','This block updates the running mean and variant value at sampling time point. The mean and var values are outputted into 1st and 2nd outports respectively.')
set_param([sys,'/','Mean and var1'],...
		'Mask Entries','.1\/')


%     Finished composite block 'Mean and var1'.

set_param([sys,'/','Mean and var1'],...
		'hide name',0,...
		'position',[215,33,295,77])

add_block('built-in/Product',[sys,'/','Product1'])
set_param([sys,'/','Product1'],...
		'hide name',0,...
		'position',[160,43,190,67])


%     Subsystem  ['Rician noise',13,'generator'].

new_system([sys,'/',['Rician noise',13,'generator']])
set_param([sys,'/',['Rician noise',13,'generator']],'Location',[445,114,914,317])


%     Subsystem  ['Rician noise',13,'generator/Gaussian',13,'noise'].

new_system([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],'Location',[582,754,930,959])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/',...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],...
		'Mask Entries','m\/s\/seed\/')


%     Finished composite block ['Rician noise',13,'generator/Gaussian',13,'noise'].

set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise']],...
		'position',[45,40,120,80])

add_block('built-in/Product',[sys,'/',['Rician noise',13,'generator/Product']])
set_param([sys,'/',['Rician noise',13,'generator/Product']],...
		'position',[160,48,190,72])

add_block('built-in/Product',[sys,'/',['Rician noise',13,'generator/Product1']])
set_param([sys,'/',['Rician noise',13,'generator/Product1']],...
		'position',[165,118,195,142])


%     Subsystem  ['Rician noise',13,'generator/Gaussian',13,'noise1'].

new_system([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],'Location',[582,754,930,959])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Constant']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Sum']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/out_1']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/',...
		'position',[210,81,235,109])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],[240,95;290,95])
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],...
		'Mask Entries','0\/s\/seed+max(seed)\/')


%     Finished composite block ['Rician noise',13,'generator/Gaussian',13,'noise1'].

set_param([sys,'/',['Rician noise',13,'generator/Gaussian',13,'noise1']],...
		'position',[45,110,120,150])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator/Sum']])
set_param([sys,'/',['Rician noise',13,'generator/Sum']],...
		'position',[245,55,265,75])

add_block('built-in/S-Function',[sys,'/',['Rician noise',13,'generator/Array',13,'function']])
set_param([sys,'/',['Rician noise',13,'generator/Array',13,'function']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['Rician noise',13,'generator/Array',13,'function']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10,sgn.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['Rician noise',13,'generator/Array',13,'function']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sqrt''\/',...
		'position',[295,43,370,87])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator/out_1']])
set_param([sys,'/',['Rician noise',13,'generator/out_1']],...
		'position',[410,55,430,75])
add_line([sys,'/',['Rician noise',13,'generator']],[125,60;135,60;135,55;155,55])
add_line([sys,'/',['Rician noise',13,'generator']],[135,60;135,65;155,65])
add_line([sys,'/',['Rician noise',13,'generator']],[195,60;240,60])
add_line([sys,'/',['Rician noise',13,'generator']],[125,130;135,130;135,125;160,125])
add_line([sys,'/',['Rician noise',13,'generator']],[135,130;135,135;160,135])
add_line([sys,'/',['Rician noise',13,'generator']],[200,130;210,130;210,70;240,70])
add_line([sys,'/',['Rician noise',13,'generator']],[270,65;290,65])
add_line([sys,'/',['Rician noise',13,'generator']],[375,65;405,65])
set_param([sys,'/',['Rician noise',13,'generator']],...
		'Mask Display','plot(0,0,100,100,x,y);Rician (K)',...
		'Mask Type','Rician noise generator')
set_param([sys,'/',['Rician noise',13,'generator']],...
		'Mask Dialogue','Generate Rician distributed noise.\nThe output vector size of this block is the same as the vector size of the seed.|Rician K-factor:|sigma:|Seed:')
set_param([sys,'/',['Rician noise',13,'generator']],...
		'Mask Translate','K=@1;s=@2;seed=@3;m=sqrt(2*K(:)).*s;[x,y]=srcsicon(3);')
set_param([sys,'/',['Rician noise',13,'generator']],...
		'Mask Help','The Rician noise is composed with two independant Gaussian noises. These two Gaussain noises have a same std, sigma. Their mean values are m1 and m2 respectively. The Rician K-factor=(m1^2+m2^2)/2/sigma^2. The output vector size of this block is the same as the vector size of the seed.')
set_param([sys,'/',['Rician noise',13,'generator']],...
		'Mask Entries','2\/1\/12345\/')


%     Finished composite block ['Rician noise',13,'generator'].

set_param([sys,'/',['Rician noise',13,'generator']],...
		'hide name',0,...
		'position',[30,33,110,77])

add_block('built-in/Constant',[sys,'/','Expected value'])
set_param([sys,'/','Expected value'],...
		'Value','[6 20]',...
		'position',[230,134,275,156])


%     Subsystem  ['Rician noise',13,'generator2'].

new_system([sys,'/',['Rician noise',13,'generator2']])
set_param([sys,'/',['Rician noise',13,'generator2']],'Location',[535,122,1004,325])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator2/out_1']])
set_param([sys,'/',['Rician noise',13,'generator2/out_1']],...
		'position',[410,55,430,75])

add_block('built-in/S-Function',[sys,'/',['Rician noise',13,'generator2/Array',13,'function']])
set_param([sys,'/',['Rician noise',13,'generator2/Array',13,'function']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['Rician noise',13,'generator2/Array',13,'function']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10,sgn.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['Rician noise',13,'generator2/Array',13,'function']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sqrt''\/',...
		'position',[295,43,370,87])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator2/Sum']])
set_param([sys,'/',['Rician noise',13,'generator2/Sum']],...
		'position',[245,55,265,75])


%     Subsystem  ['Rician noise',13,'generator2/Gaussian',13,'noise1'].

new_system([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],'Location',[582,754,930,959])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Matrix',13,'Gain']],...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/out_1']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Sum']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Constant']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],[240,95;290,95])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],...
		'Mask Entries','m2\/s\/seed+max(seed)\/')


%     Finished composite block ['Rician noise',13,'generator2/Gaussian',13,'noise1'].

set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise1']],...
		'position',[45,110,120,150])

add_block('built-in/Product',[sys,'/',['Rician noise',13,'generator2/Product1']])
set_param([sys,'/',['Rician noise',13,'generator2/Product1']],...
		'position',[165,118,195,142])

add_block('built-in/Product',[sys,'/',['Rician noise',13,'generator2/Product']])
set_param([sys,'/',['Rician noise',13,'generator2/Product']],...
		'position',[160,48,190,72])


%     Subsystem  ['Rician noise',13,'generator2/Gaussian',13,'noise'].

new_system([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],'Location',[582,754,930,959])

add_block('built-in/White Noise',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/',...
		'position',[210,81,235,109])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],[240,95;290,95])
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],...
		'Mask Entries','m1\/s\/seed\/')


%     Finished composite block ['Rician noise',13,'generator2/Gaussian',13,'noise'].

set_param([sys,'/',['Rician noise',13,'generator2/Gaussian',13,'noise']],...
		'position',[45,40,120,80])
add_line([sys,'/',['Rician noise',13,'generator2']],[375,65;405,65])
add_line([sys,'/',['Rician noise',13,'generator2']],[270,65;290,65])
add_line([sys,'/',['Rician noise',13,'generator2']],[200,130;210,130;210,70;240,70])
add_line([sys,'/',['Rician noise',13,'generator2']],[125,130;135,130;135,125;160,125])
add_line([sys,'/',['Rician noise',13,'generator2']],[135,130;135,135;160,135])
add_line([sys,'/',['Rician noise',13,'generator2']],[195,60;240,60])
add_line([sys,'/',['Rician noise',13,'generator2']],[125,60;135,60;135,55;155,55])
add_line([sys,'/',['Rician noise',13,'generator2']],[135,60;135,65;155,65])
set_param([sys,'/',['Rician noise',13,'generator2']],...
		'Mask Display','plot(0,0,100,100,x,y);Rician (m)',...
		'Mask Type','Rician noise generator')
set_param([sys,'/',['Rician noise',13,'generator2']],...
		'Mask Dialogue','Generate Rician distributed noise.\nThe output vector size of this block is the same as the vector size of the seed.|In-phase component m:|Quadrature component m:|sigma:|Seed:')
set_param([sys,'/',['Rician noise',13,'generator2']],...
		'Mask Translate','m1=@1;m2=@2;s=@3;seed=@4;[x,y]=srcsicon(3);')
set_param([sys,'/',['Rician noise',13,'generator2']],...
		'Mask Help','The Rician noise is composed with two independant Gaussian noises. These two Gaussain noises have a same std, sigma. Their mean values are m1 and m2 respectively.  The output vector size of this block is the same as the vector size of the seed.')
set_param([sys,'/',['Rician noise',13,'generator2']],...
		'Mask Entries','sqrt(2)\/sqrt(2)\/1\/5621231\/')


%     Finished composite block ['Rician noise',13,'generator2'].

set_param([sys,'/',['Rician noise',13,'generator2']],...
		'hide name',0,...
		'position',[30,83,110,127])

add_block('built-in/Product',[sys,'/','Product'])
set_param([sys,'/','Product'],...
		'hide name',0,...
		'position',[160,93,190,117])


%     Subsystem  'Mean and var'.

new_system([sys,'/','Mean and var'])
set_param([sys,'/','Mean and var'],'Location',[16,148,774,399])

add_block('built-in/Outport',[sys,'/',['Mean and var/Mean',13,'Squared',13,'Error1']])
set_param([sys,'/',['Mean and var/Mean',13,'Squared',13,'Error1']],...
		'Port','2',...
		'position',[700,135,720,155])

add_block('built-in/Fcn',[sys,'/','Mean and var/Fcn4'])
set_param([sys,'/','Mean and var/Fcn4'],...
		'Expr','u[1]*u[1]',...
		'position',[555,107,620,133])

add_block('built-in/Mux',[sys,'/','Mean and var/Mux2'])
set_param([sys,'/','Mean and var/Mux2'],...
		'inputs','2',...
		'position',[515,101,545,134])

add_block('built-in/Sum',[sys,'/','Mean and var/Sum'])
set_param([sys,'/','Mean and var/Sum'],...
		'inputs','-+',...
		'position',[645,135,665,155])

add_block('built-in/Fcn',[sys,'/','Mean and var/Fcn'])
set_param([sys,'/','Mean and var/Fcn'],...
		'Expr','(u[3]*(u[2]-1) + u[1]*u[1])/u[2]',...
		'position',[290,136,465,164])

add_block('built-in/Unit Delay',[sys,'/','Mean and var/Unit Delay'])
set_param([sys,'/','Mean and var/Unit Delay'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[345,192,395,208])

add_block('built-in/Mux',[sys,'/','Mean and var/Mux'])
set_param([sys,'/','Mean and var/Mux'],...
		'inputs','3',...
		'position',[235,134,265,166])

add_block('built-in/Fcn',[sys,'/','Mean and var/Fcn3'])
set_param([sys,'/','Mean and var/Fcn3'],...
		'Expr','(u[3]*(u[2]-1) + u[1])/u[2]',...
		'position',[290,41,465,69])

add_block('built-in/Mux',[sys,'/','Mean and var/Mux1'])
set_param([sys,'/','Mean and var/Mux1'],...
		'inputs','3',...
		'position',[235,39,265,71])

add_block('built-in/Outport',[sys,'/','Mean and var/mean value'])
set_param([sys,'/','Mean and var/mean value'],...
		'position',[545,45,565,65])

add_block('built-in/Unit Delay',[sys,'/','Mean and var/Unit Delay1'])
set_param([sys,'/','Mean and var/Unit Delay1'],...
		'orientation',2,...
		'Sample time','Ts',...
		'position',[350,87,400,103])

add_block('built-in/Fcn',[sys,'/','Mean and var/Fcn2'])
set_param([sys,'/','Mean and var/Fcn2'],...
		'Expr','u[1]/Ts +1',...
		'position',[105,83,165,107])

add_block('built-in/Digital Clock',[sys,'/','Mean and var/Digital Clock'])
set_param([sys,'/','Mean and var/Digital Clock'],...
		'Sample time','Ts',...
		'position',[45,80,80,110])

add_block('built-in/Inport',[sys,'/','Mean and var/Actual'])
set_param([sys,'/','Mean and var/Actual'],...
		'position',[25,35,45,55])
add_line([sys,'/','Mean and var'],[670,145;695,145])
add_line([sys,'/','Mean and var'],[550,120;550,120])
add_line([sys,'/','Mean and var'],[170,95;190,95;190,150;230,150])
add_line([sys,'/','Mean and var'],[190,125;510,125])
add_line([sys,'/','Mean and var'],[470,55;540,55])
add_line([sys,'/','Mean and var'],[495,55;495,95;405,95])
add_line([sys,'/','Mean and var'],[495,95;495,110;510,110])
add_line([sys,'/','Mean and var'],[625,120;625,140;640,140])
add_line([sys,'/','Mean and var'],[470,150;480,150;480,200;400,200])
add_line([sys,'/','Mean and var'],[480,150;640,150])
add_line([sys,'/','Mean and var'],[50,45;230,45])
add_line([sys,'/','Mean and var'],[200,45;200,140;230,140])
add_line([sys,'/','Mean and var'],[345,95;210,95;210,65;230,65])
add_line([sys,'/','Mean and var'],[190,95;190,55;230,55])
add_line([sys,'/','Mean and var'],[270,55;285,55])
add_line([sys,'/','Mean and var'],[270,150;285,150])
add_line([sys,'/','Mean and var'],[340,200;220,200;230,160])
add_line([sys,'/','Mean and var'],[85,95;100,95])
set_param([sys,'/','Mean and var'],...
		'Mask Display','Mean\n& var',...
		'Mask Type','Running mean and var',...
		'Mask Dialogue','Output the running mean to 1st outport\nand running variant to 2nd outport.|Sample time (sec):')
set_param([sys,'/','Mean and var'],...
		'Mask Translate','Ts=@1;',...
		'Mask Help','This block updates the running mean and variant value at sampling time point. The mean and var values are outputted into 1st and 2nd outports respectively.')
set_param([sys,'/','Mean and var'],...
		'Mask Entries','.1\/')


%     Finished composite block 'Mean and var'.

set_param([sys,'/','Mean and var'],...
		'hide name',0,...
		'position',[215,83,295,127])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','5',...
		'position',[340,30,375,140])

add_block('built-in/Note',[sys,'/',['The mean value of the sqaure of the Rician noise output is 2+2K     ',13,'and the variance of the square of the Rician noise output is 2(2+4K)']])
set_param([sys,'/',['The mean value of the sqaure of the Rician noise output is 2+2K     ',13,'and the variance of the square of the Rician noise output is 2(2+4K)']],...
		'position',[235,220,240,225])

add_block('built-in/Note',[sys,'/',['Assume the the sigma value is 1, the means for in-phase and      ',13,'quadrature are mI and mQ. The K-factor K=(mI^2+mQ^2)//2, then,']])
set_param([sys,'/',['Assume the the sigma value is 1, the means for in-phase and      ',13,'quadrature are mI and mQ. The K-factor K=(mI^2+mQ^2)//2, then,']],...
		'position',[230,185,235,190])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type:|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sample time:')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','20\/-.2\/30\/''y-/g--/y:/g:/y-./g-./m*/ro/b+''\/.1\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'hide name',0,...
		'position',[415,66,445,104])
add_line(sys,[380,85;410,85])
add_line(sys,[115,105;130,105;130,100;155,100])
add_line(sys,[195,105;210,105])
add_line(sys,[130,105;130,110;155,110])
add_line(sys,[195,55;210,55])
add_line(sys,[115,55;130,55;130,60;155,60])
add_line(sys,[130,55;130,50;155,50])
add_line(sys,[300,45;335,45])
add_line(sys,[300,65;335,65])
add_line(sys,[300,95;310,95;310,85;335,85])
add_line(sys,[300,115;315,115;315,105;335,105])
add_line(sys,[280,145;300,145;300,125;335,125])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
