function [ret,x0,str,ts,xts]=tstrsbin(t,x,u,flag);
%TSTRSBIN     is the M-file description of the SIMULINK system named TSTRSBIN.
%       The block-diagram can be displayed by typing: TSTRSBIN.
%
%       SYS=TSTRSBIN(T,X,U,FLAG) returns depending on FLAG certain
%     system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes TSTRSBIN to return state derivatives, FLAG=2
%     discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling TSTRSBIN with a FLAG of zero:
%  [SIZES]=TSTRSBIN([],[],[],0),  returns a vector, SIZES, which
%  contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs
%              SIZES(5) number of roots (currently unsupported)
%               SIZES(6) direct feedthrough flag
%               SIZES(7) number of sample times
%
%       For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[137,230,951,530])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','N_rs_demo=7;K_rs_demo=5;M_rs_demo=3;');

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
           'BackGround',7,...
              'inputs','+',...
                'position',[385,160,405,180])


%     Subsystem  ['Random-integer',13,'generator'].

new_system([sys,'/',['Random-integer',13,'generator']])
set_param([sys,'/',['Random-integer',13,'generator']],'Location',[373,639,729,808])

add_block('built-in/Constant',[sys,'/',['Random-integer',13,'generator/Constant']])
set_param([sys,'/',['Random-integer',13,'generator/Constant']],...
         'Value','x',...
         'position',[65,105,95,125])

add_block('built-in/State-Space',[sys,'/',['Random-integer',13,'generator/Matrix',13,'Gain']])
set_param([sys,'/',['Random-integer',13,'generator/Matrix',13,'Gain']],...
             'A','[]',...
            'B','[]',...
            'C','[]',...
            'D','K',...
             'Mask Display','K',...
          'Mask Type','Matrix Gain',...
           'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Random-integer',13,'generator/Matrix',13,'Gain']],...
          'Mask Translate','K = @1;',...
          'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
            'Mask Entries','ones(1,N-1)\/')
set_param([sys,'/',['Random-integer',13,'generator/Matrix',13,'Gain']],...
               'position',[230,35,275,65])

add_block('built-in/Outport',[sys,'/',['Random-integer',13,'generator/out_1']])
set_param([sys,'/',['Random-integer',13,'generator/out_1']],...
               'position',[310,40,330,60])

add_block('built-in/Relational Operator',[sys,'/',['Random-integer',13,'generator/Relational',13,'Operator']])
set_param([sys,'/',['Random-integer',13,'generator/Relational',13,'Operator']],...
             'position',[155,38,185,62])

add_block('built-in/Signal Generator',[sys,'/',['Random-integer',13,'generator/Uniform',13,'noise gen.']])
set_param([sys,'/',['Random-integer',13,'generator/Uniform',13,'noise gen.']],...
          'Peak','1.000000',...
           'Peak Range','5.000000',...
             'Freq','1234.000000',...
                'Freq Range','6170.000000',...
          'Wave','Rnd',...
                'Units','Rads')
set_param([sys,'/',['Random-integer',13,'generator/Uniform',13,'noise gen.']],...
                'position',[35,28,80,62])
add_line([sys,'/',['Random-integer',13,'generator']],[85,45;150,45])
add_line([sys,'/',['Random-integer',13,'generator']],[100,115;115,115;115,55;150,55])
add_line([sys,'/',['Random-integer',13,'generator']],[190,50;225,50])
add_line([sys,'/',['Random-integer',13,'generator']],[280,50;305,50])
set_param([sys,'/',['Random-integer',13,'generator']],...
           'Mask Display','Random\nNumber',...
             'Mask Type','Random number generator.')
set_param([sys,'/',['Random-integer',13,'generator']],...
                'Mask Dialogue','Randomly generate integers in the range of [0,1,...,N-1]. N is the M-ary number defined below:|M-ary number:',...
                'Mask Translate','N=@1;x=[(2-N)/N:2/N:(N-2)/N];')
set_param([sys,'/',['Random-integer',13,'generator']],...
              'Mask Help','This block generate integer number 0 to M-1, where M is a integer. The probability of the apperance for each number is not guaranteed to be the same.')
set_param([sys,'/',['Random-integer',13,'generator']],...
           'Mask Entries','2^(K_rs_demo*M_rs_demo)\/')


%     Finished composite block ['Random-integer',13,'generator'].

set_param([sys,'/',['Random-integer',13,'generator']],...
           'BackGround',5,...
              'position',[25,35,85,75])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
               'inputs','2',...
                'position',[665,145,700,180])


%     Subsystem  ['Graph',13,'err'].

new_system([sys,'/',['Graph',13,'err']])
set_param([sys,'/',['Graph',13,'err']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Graph',13,'err/x']])
set_param([sys,'/',['Graph',13,'err/x']],...
               'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Graph',13,'err/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph',13,'err/S-function',13,'M-file which plots',13,'lines',13,'']],...
                'function name','sfuny',...
             'parameters','ax, color,dt',...
         'position',[130,55,180,75])
add_line([sys,'/',['Graph',13,'err']],[90,65;125,65])
set_param([sys,'/',['Graph',13,'err']],...
              'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
                'Mask Type','Graph scope.')
set_param([sys,'/',['Graph',13,'err']],...
           'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Graph',13,'err']],...
           'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Graph',13,'err']],...
                'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Graph',13,'err']],...
              'Mask Entries','10\/-1.2\/.2+floor((N_rs_demo-K_rs_demo)/2)\/''mx/c+/m-/w-/b+''\/')


%     Finished composite block ['Graph',13,'err'].

set_param([sys,'/',['Graph',13,'err']],...
         'position',[755,146,785,184])

add_block('built-in/Note',[sys,'/','In this demo, you may chooset the variable code word length N, message length K, and M.'])
set_param([sys,'/','In this demo, you may chooset the variable code word length N, message length K, and M.'],...
            'position',[315,220,320,225])

add_block('built-in/Note',[sys,'/','The default set of this demo is N = N_rs_demo=7; K =K_rs_demo= 5; M =M_rs_demo = 3. One burst error-correction.'])
set_param([sys,'/','The default set of this demo is N = N_rs_demo=7; K =K_rs_demo= 5; M =M_rs_demo = 3. One burst error-correction.'],...
            'position',[390,240,395,245])


%     Subsystem  ['Binary vector',13,'noise generator'].

new_system([sys,'/',['Binary vector',13,'noise generator']])
set_param([sys,'/',['Binary vector',13,'noise generator']],'Location',[334,411,752,588])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'noise generator/S-function']])
set_param([sys,'/',['Binary vector',13,'noise generator/S-function']],...
          'function name','simrdbit',...
          'parameters','n, prob, seed',...
                'position',[90,35,140,55])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'noise generator/Inport']])
set_param([sys,'/',['Binary vector',13,'noise generator/Inport']],...
             'position',[30,65,50,85])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'noise generator/Switch']])
set_param([sys,'/',['Binary vector',13,'noise generator/Switch']],...
              'Threshold','0.5',...
           'position',[215,59,245,91])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'noise generator/Memory']])
set_param([sys,'/',['Binary vector',13,'noise generator/Memory']],...
            'orientation',2,...
             'x0','zeros(1,n)',...
           'position',[215,110,255,140])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'noise generator/out_1']])
set_param([sys,'/',['Binary vector',13,'noise generator/out_1']],...
           'position',[340,65,360,85])
add_line([sys,'/',['Binary vector',13,'noise generator']],[250,75;335,75])
add_line([sys,'/',['Binary vector',13,'noise generator']],[145,45;175,45;175,65;210,65])
add_line([sys,'/',['Binary vector',13,'noise generator']],[55,75;210,75])
add_line([sys,'/',['Binary vector',13,'noise generator']],[70,75;70,45;85,45])
add_line([sys,'/',['Binary vector',13,'noise generator']],[210,125;175,125;175,85;210,85])
add_line([sys,'/',['Binary vector',13,'noise generator']],[280,75;280,125;260,125])
set_param([sys,'/',['Binary vector',13,'noise generator']],...
         'Mask Display','Random\nB-vector',...
           'Mask Type','Binary vector noise generator.')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
             'Mask Dialogue','Generatea binary vector with at most given number of ones randomly distributed in the vector.|Vector length(can''t be changed during simulation):|Probability of a "one", two "ones",three "ones"...:|Seed:')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
            'Mask Translate','n=@1;prob=@2;seed=@3;')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
         'Mask Help','This block outputs a zero vector with ''1''s randomly distributed in any bit of the vector. The maximum number of ''1''s appears in the vector is same as the length of the vector "probability". The value of ith element of the ''probability'' is the probability of i number of ''1''s in the vector, e.g. [1/4 1/4 1/4] means probability of single, double, three ''1''s or no ''1''s in the vector is 1/4. The block refresh its output whenever the input is no-zero.')
set_param([sys,'/',['Binary vector',13,'noise generator']],...
              'Mask Entries','N_rs_demo*M_rs_demo\/1/2\/12345\/')


%     Finished composite block ['Binary vector',13,'noise generator'].

set_param([sys,'/',['Binary vector',13,'noise generator']],...
         'position',[245,153,300,187])

add_block('built-in/Constant',[sys,'/','Const'])
set_param([sys,'/','Const'],...
            'position',[190,160,210,180])

add_block('built-in/Constant',[sys,'/','Const1'])
set_param([sys,'/','Const1'],...
          'position',[195,65,215,85])


%     Subsystem  ['Binary-vector',13,'R-S encode'].

new_system([sys,'/',['Binary-vector',13,'R-S encode']])
set_param([sys,'/',['Binary-vector',13,'R-S encode']],'Location',[160,111,633,282])

add_block('built-in/Outport',[sys,'/',['Binary-vector',13,'R-S encode/out_1']])
set_param([sys,'/',['Binary-vector',13,'R-S encode/out_1']],...
          'position',[425,60,445,80])

add_block('built-in/Inport',[sys,'/',['Binary-vector',13,'R-S encode/in_2']])
set_param([sys,'/',['Binary-vector',13,'R-S encode/in_2']],...
          'Port','2',...
          'position',[20,110,40,130])

add_block('built-in/Inport',[sys,'/',['Binary-vector',13,'R-S encode/in_1']])
set_param([sys,'/',['Binary-vector',13,'R-S encode/in_1']],...
          'position',[30,25,50,45])

add_block('built-in/Mux',[sys,'/',['Binary-vector',13,'R-S encode/Mux']])
set_param([sys,'/',['Binary-vector',13,'R-S encode/Mux']],...
         'inputs','[k, 1]',...
           'position',[90,51,125,84])

add_block('built-in/S-Function',[sys,'/',['Binary-vector',13,'R-S encode/S-function']])
set_param([sys,'/',['Binary-vector',13,'R-S encode/S-function']],...
           'function name','simrscod',...
          'parameters','n, k, pg,tp,dim',...
              'position',[180,30,245,50])

add_block('built-in/Switch',[sys,'/',['Binary-vector',13,'R-S encode/Switch']])
set_param([sys,'/',['Binary-vector',13,'R-S encode/Switch']],...
              'Threshold','0.5',...
           'position',[305,54,335,86])

add_block('built-in/Memory',[sys,'/',['Binary-vector',13,'R-S encode/Memory']])
set_param([sys,'/',['Binary-vector',13,'R-S encode/Memory']],...
              'orientation',2,...
             'x0','zeros(1,n)',...
           'position',[305,105,345,135])
add_line([sys,'/',['Binary-vector',13,'R-S encode']],[45,120;210,120;210,70;300,70])
add_line([sys,'/',['Binary-vector',13,'R-S encode']],[70,120;70,75;85,75])
add_line([sys,'/',['Binary-vector',13,'R-S encode']],[130,70;160,70;160,40;175,40])
add_line([sys,'/',['Binary-vector',13,'R-S encode']],[55,35;70,35;70,60;85,60])
add_line([sys,'/',['Binary-vector',13,'R-S encode']],[250,40;265,40;265,60;300,60])
add_line([sys,'/',['Binary-vector',13,'R-S encode']],[300,120;265,120;265,80;300,80])
add_line([sys,'/',['Binary-vector',13,'R-S encode']],[340,70;420,70])
add_line([sys,'/',['Binary-vector',13,'R-S encode']],[370,70;370,120;350,120])
set_param([sys,'/',['Binary-vector',13,'R-S encode']],...
               'Mask Display','R-S\nencode',...
                'Mask Type','Reed-Solomon encoding')
set_param([sys,'/',['Binary-vector',13,'R-S encode']],...
           'Mask Dialogue','Code word N, message length K multi-burst-error-correction Reed-Solomon code.|Code length (N=2^M-1. M is a >2 integer):|Message length:')
set_param([sys,'/',['Binary-vector',13,'R-S encode']],...
             'Mask Translate','n=@1;k=@2;if length(k)>1,pg=k;k=n-length(pg)-1;else,pg=rspoly(n,k);end;dim=3;p_dim=7;while p_dim<n,dim=dim+1;p_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);')
set_param([sys,'/',['Binary-vector',13,'R-S encode']],...
         'Mask Help','This block encodes the K-ary Integer message signal from the 1st inport into N-ary Integer code word using Reed-Solomon code. The input/output integers are in the range [0, N]. Code word length N=2^M-1, where M is a integer no less than 3. The message length K<N. The error-correction capability T=floor((N-K)/2). The outport outputs the last encoded vector until the 2nd inport signal is non-zero.')
set_param([sys,'/',['Binary-vector',13,'R-S encode']],...
          'Mask Entries','N_rs_demo\/K_rs_demo\/')


%     Finished composite block ['Binary-vector',13,'R-S encode'].

set_param([sys,'/',['Binary-vector',13,'R-S encode']],...
              'position',[245,45,305,85])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector',13,'converter']])
set_param([sys,'/',['Integer scalar',13,'to vector',13,'converter']],...
          'function name','simde2bi',...
          'parameters','len,p',...
                'Mask Display','Sca to vec\nconverter',...
              'Mask Type','Scalar integer  to vector converter')
set_param([sys,'/',['Integer scalar',13,'to vector',13,'converter']],...
              'Mask Dialogue','Positive decimal interger to binary converter.|Output vector length:|Output element base:',...
         'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector',13,'converter']],...
                'Mask Help','This block converts scaler positive decimal integer input to an arbitrary base integer  vector output with specified vector length and output element base. The first element of the output vector is the lowest binary bit. For example, for a length two binary output, y(1)=0, y(2)=1 means the input is 1; y(0)=1, y(2)=0 means the input is 2.')
set_param([sys,'/',['Integer scalar',13,'to vector',13,'converter']],...
              'Mask Entries','K_rs_demo*M_rs_demo\/2\/',...
           'position',[120,36,180,74])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
               'position',[345,60,365,80])

add_block('built-in/S-Function',[sys,'/',['Modulo',13,'operation']])
set_param([sys,'/',['Modulo',13,'operation']],...
                'function name','arymodu',...
           'parameters','md',...
           'Mask Display','Modulo',...
             'Mask Type','Modulo',...
                'Mask Dialogue','Modulo operation:|Modulo base:',...
            'Mask Translate','md = @1;')
set_param([sys,'/',['Modulo',13,'operation']],...
           'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Modulo',13,'operation']],...
          'Mask Entries','2^M_rs_demo\/',...
              'position',[385,51,445,89])

add_block('built-in/Constant',[sys,'/','Const2'])
set_param([sys,'/','Const2'],...
            'position',[465,80,485,100])


%     Subsystem  ['Binary-vector',13,'R-S decode1'].

new_system([sys,'/',['Binary-vector',13,'R-S decode1']])
set_param([sys,'/',['Binary-vector',13,'R-S decode1']],'Location',[143,192,726,352])

add_block('built-in/Outport',[sys,'/',['Binary-vector',13,'R-S decode1/out_2']])
set_param([sys,'/',['Binary-vector',13,'R-S decode1/out_2']],...
            'Port','2',...
          'position',[495,95,515,115])

add_block('built-in/Outport',[sys,'/',['Binary-vector',13,'R-S decode1/out_1']])
set_param([sys,'/',['Binary-vector',13,'R-S decode1/out_1']],...
            'position',[495,30,515,50])

add_block('built-in/Demux',[sys,'/',['Binary-vector',13,'R-S decode1/Demux']])
set_param([sys,'/',['Binary-vector',13,'R-S decode1/Demux']],...
               'outputs','[k, 1]',...
          'position',[395,40,435,75])

add_block('built-in/Inport',[sys,'/',['Binary-vector',13,'R-S decode1/in_2']])
set_param([sys,'/',['Binary-vector',13,'R-S decode1/in_2']],...
                'Port','2',...
          'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/',['Binary-vector',13,'R-S decode1/in_1']])
set_param([sys,'/',['Binary-vector',13,'R-S decode1/in_1']],...
                'position',[20,15,40,35])

add_block('built-in/Mux',[sys,'/',['Binary-vector',13,'R-S decode1/Mux']])
set_param([sys,'/',['Binary-vector',13,'R-S decode1/Mux']],...
               'inputs','[n, 1]',...
           'position',[80,41,115,74])

add_block('built-in/S-Function',[sys,'/',['Binary-vector',13,'R-S decode1/S-function']])
set_param([sys,'/',['Binary-vector',13,'R-S decode1/S-function']],...
         'function name','simrsdec',...
          'parameters','n, k, tp, dim',...
                'position',[170,20,235,40])

add_block('built-in/Switch',[sys,'/',['Binary-vector',13,'R-S decode1/Switch']])
set_param([sys,'/',['Binary-vector',13,'R-S decode1/Switch']],...
            'Threshold','0.5',...
           'position',[295,44,325,76])

add_block('built-in/Memory',[sys,'/',['Binary-vector',13,'R-S decode1/Memory']])
set_param([sys,'/',['Binary-vector',13,'R-S decode1/Memory']],...
            'orientation',2,...
             'x0','zeros(1,k+1)',...
         'position',[295,95,335,125])
add_line([sys,'/',['Binary-vector',13,'R-S decode1']],[440,65;455,65;455,105;490,105])
add_line([sys,'/',['Binary-vector',13,'R-S decode1']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary-vector',13,'R-S decode1']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary-vector',13,'R-S decode1']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary-vector',13,'R-S decode1']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary-vector',13,'R-S decode1']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary-vector',13,'R-S decode1']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary-vector',13,'R-S decode1']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary-vector',13,'R-S decode1']],[330,60;390,60])
add_line([sys,'/',['Binary-vector',13,'R-S decode1']],[360,60;360,110;340,110])
set_param([sys,'/',['Binary-vector',13,'R-S decode1']],...
             'Mask Display','R-S\ndecode',...
                'Mask Type','Reed-Solomon decode')
set_param([sys,'/',['Binary-vector',13,'R-S decode1']],...
            'Mask Dialogue','Code word length N, message length K, burst error-correction Reed-Solomon decode.|Code word length (N=2^M-1. M is a >2 integer):|Message length K < N:')
set_param([sys,'/',['Binary-vector',13,'R-S decode1']],...
             'Mask Translate','n=@1;k=@2;dim=3;p_d=7;while p_d<n,dim=dim+1;p_d=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);')
set_param([sys,'/',['Binary-vector',13,'R-S decode1']],...
           'Mask Help','This block decodes N-ary integer code word from 1st inport into K-ary integer message sigusing at 1st ouport using Reed-Solomon method. M is an integer no less than 3. The input/output integers are in the range [0,N]. A non-zero second inport signal triggers the block to do decode process. The block outputs the last processed results when second inport signal is zero. The second outport outputs the error detected in the process. A negative output indicates more error than the capability.')
set_param([sys,'/',['Binary-vector',13,'R-S decode1']],...
           'Mask Entries','N_rs_demo\/K_rs_demo\/')


%     Finished composite block ['Binary-vector',13,'R-S decode1'].

set_param([sys,'/',['Binary-vector',13,'R-S decode1']],...
            'position',[505,60,565,100])

add_block('built-in/S-Function',[sys,'/',['Integer vector  ',13,'to scalar',13,'converter']])
set_param([sys,'/',['Integer vector  ',13,'to scalar',13,'converter']],...
             'function name','simbi2de',...
          'parameters','p',...
            'Mask Display','Vec to sca\nconverter',...
              'Mask Type','Vectro to scalar converter')
set_param([sys,'/',['Integer vector  ',13,'to scalar',13,'converter']],...
             'Mask Dialogue','Positive integer vector to scalar decimal integer converter:|Input element base:',...
          'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector  ',13,'to scalar',13,'converter']],...
             'Mask Help','This block converts a binary vector to a scalar decimal integer. The block takes the first element input as the lowest binary bit. For example, if u(1)=1 and u(2)=0, the block outputs y=1; if u(1)=0 and u(2)=1, the block outputs y=2.')
set_param([sys,'/',['Integer vector  ',13,'to scalar',13,'converter']],...
              'Mask Entries','2\/',...
                'position',[610,50,670,90])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
               'inputs','[K_rs_demo, K_rs_demo]',...
           'position',[695,45,730,80])


%     Subsystem  ['Graph',13,'sig v.s. dec'].

new_system([sys,'/',['Graph',13,'sig v.s. dec']])
set_param([sys,'/',['Graph',13,'sig v.s. dec']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph',13,'sig v.s. dec/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph',13,'sig v.s. dec/S-function',13,'M-file which plots',13,'lines',13,'']],...
            'function name','sfuny',...
             'parameters','ax, color,dt',...
         'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Graph',13,'sig v.s. dec/x']])
set_param([sys,'/',['Graph',13,'sig v.s. dec/x']],...
            'position',[65,55,85,75])
add_line([sys,'/',['Graph',13,'sig v.s. dec']],[90,65;125,65])
set_param([sys,'/',['Graph',13,'sig v.s. dec']],...
              'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
                'Mask Type','Graph scope.')
set_param([sys,'/',['Graph',13,'sig v.s. dec']],...
          'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Graph',13,'sig v.s. dec']],...
          'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Graph',13,'sig v.s. dec']],...
               'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Graph',13,'sig v.s. dec']],...
             'Mask Entries','10\/-.2\/.2+2^(M_rs_demo*K_rs_demo)\/''yo/g*/r*/c*/m*''\/')


%     Finished composite block ['Graph',13,'sig v.s. dec'].

set_param([sys,'/',['Graph',13,'sig v.s. dec']],...
               'position',[750,46,780,84])
add_line(sys,[310,65;340,65])
add_line(sys,[370,70;380,70])
add_line(sys,[450,70;500,70])
add_line(sys,[90,55;115,55])
add_line(sys,[735,65;745,65])
add_line(sys,[185,55;240,55])
add_line(sys,[305,170;380,170])
add_line(sys,[215,170;240,170])
add_line(sys,[325,170;325,75;340,75])
add_line(sys,[705,165;750,165])
add_line(sys,[570,90;590,90;590,155;660,155])
add_line(sys,[410,170;660,170])
add_line(sys,[220,75;240,75])
add_line(sys,[490,90;500,90])
add_line(sys,[100,55;100,20;680,20;690,55])
add_line(sys,[675,70;690,70])
add_line(sys,[570,70;605,70])

drawnow

% Return any arguments.
if (nargin | nargout)
        % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
else
 drawnow % Flash up the model and execute load callback
end
