function [ret,x0,str,ts,xts]=tstrsbnv(t,x,u,flag);
%TSTRSBNV	is the M-file description of the SIMULINK system named TSTRSBNV.
%	The block-diagram can be displayed by typing: TSTRSBNV.
%
%	SYS=TSTRSBNV(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTRSBNV to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTRSBNV with a FLAG of zero:
%	[SIZES]=TSTRSBNV([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[39,71,792,341])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '100')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','N_rs_demo=15;K_rs_demo=9;M_rs_demo=4;GWN=.05;');


%     Subsystem  ['Pulses divide',13,'same sample time'].

new_system([sys,'/',['Pulses divide',13,'same sample time']])
set_param([sys,'/',['Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Entries','1\/N_rs_demo*M_rs_demo\/.5/N_rs_demo\/')


%     Finished composite block ['Pulses divide',13,'same sample time'].

set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'hide name',0,...
		'position',[250,138,330,182])


%     Subsystem  ['Binary sequence',13,'RS decode'].

new_system([sys,'/',['Binary sequence',13,'RS decode']])
set_param([sys,'/',['Binary sequence',13,'RS decode']],'Location',[108,572,804,731])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/out_2']],...
		'Port','2',...
		'position',[480,55,500,75])


%     Subsystem  ['Binary sequence',13,'RS decode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','0.1\/')


%     Finished composite block ['Binary sequence',13,'RS decode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary sequence',13,'RS decode/Rising edge',13,'detector']],...
		'ForeGround',2,...
		'position',[280,51,330,79])


%     Subsystem  ['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n k]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'RS decode/Pulses deivide',13,'same sample time']],...
		'position',[15,86,75,124])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Demux']],...
		'outputs','2',...
		'position',[95,85,140,120])


%     Subsystem  ['Binary sequence',13,'RS decode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'RS decode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS decode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[55,80;75,80])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'Mask Entries','[n*m:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'RS decode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'RS decode/Register-shift']],...
		'ForeGround',3,...
		'position',[195,35,250,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/in_1']],...
		'position',[100,35,120,55])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/out_1']],...
		'position',[645,40,665,60])


%     Subsystem  ['Binary sequence',13,'RS decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'Mask Entries','k*m\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'RS decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'RS decode/Triggered',13,'buffer down']],...
		'ForeGround',6,...
		'position',[555,38,615,72])


%     Subsystem  ['Binary sequence',13,'RS decode/Binary vector',13,'RS decode'].

new_system([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],'Location',[143,192,726,352])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/out_2']],...
		'Port','2',...
		'position',[495,95,515,115])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/out_1']],...
		'position',[495,30,515,50])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Demux']],...
		'outputs','[k*dim,1]',...
		'position',[395,40,435,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Mux']],...
		'inputs','2',...
		'position',[80,41,115,74])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/S-function']],...
		'function name','simrsdbv',...
		'parameters','n, k, tp, dim',...
		'position',[170,20,235,40])

add_block('built-in/Switch',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Switch']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Switch']],...
		'Threshold','0.5',...
		'position',[295,44,325,76])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Memory']])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,k*dim+1)',...
		'position',[295,95,335,125])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[440,65;455,65;455,105;490,105])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[330,60;390,60])
add_line([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],[360,60;360,110;340,110])
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);B-RS de',...
		'Mask Type','Binary vector I/O RS decode')
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'Mask Dialogue','Reed-Solomon decode with binary input\nvector length N*M and binary output\nvector length K*M.|Code length N=2^M-1 (M is a >2 integer):|Message length K (< N):')
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'Mask Translate','n=@1;k=@2;dim=3;p_d=7;while p_d<n,dim=dim+1;p_d=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'Mask Help','This block decodes length N*M binary vector input into length K*M binary vector output. The codeword length is N=2^M-1. M>2. The message length is K<N. The block refreshes its decoding output when the enable signal at the second inport has positive value. The second outport outputs the number of errors detected in the process. If the codeword contains more errors than the correction capability, this output is negative.')
set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'Mask Entries','n\/k\/')


%     Finished composite block ['Binary sequence',13,'RS decode/Binary vector',13,'RS decode'].

set_param([sys,'/',['Binary sequence',13,'RS decode/Binary vector',13,'RS decode']],...
		'position',[380,33,460,77])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[465,65;475,65])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[80,105;90,105])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[255,45;375,45])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[145,95;160,95;160,65;190,65])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[125,45;190,45])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[255,65;275,65])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[145,110;525,110;525,65;550,65])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[335,65;360,65;360,105;520,105;520,55;550,55])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[360,65;375,65])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[465,45;550,45])
add_line([sys,'/',['Binary sequence',13,'RS decode']],[620,50;640,50])
set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'Mask Display','plot(0,0,100,100,x,y);B-RS de',...
		'Mask Type','Binary sequence I/O RS decode')
set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'Mask Dialogue','RS decode with codeword length N, message\nlength K.|Code length N=2^M-1 (M is a >2 integer):|Message length K:|Output sample time T_out (sec):')
set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'Mask Translate','n=@1;k=@2;samp=@3;m=3;p_d=7;while p_d<n,m=m+1;p_d=2^m-1;end;[x,y]=codeicon(4);')
set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'Mask Help','This block decodes length N binary codeword into length K binary message. The block uses sequence input/output format. The input sequential sample time is K*T_out/N. The block causes a K*M*T_out delay. The second outport outputs the number of errors detected in the process. If the codeword contains more error than the correction capability, this output is nagative.')
set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'Mask Entries','N_rs_demo\/K_rs_demo\/1/K_rs_demo/M_rs_demo\/')


%     Finished composite block ['Binary sequence',13,'RS decode'].

set_param([sys,'/',['Binary sequence',13,'RS decode']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[400,53,480,97])


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','randint(100*K_rs_demo*M_rs_demo,1)\/1/K_rs_demo/M_rs_demo\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[25,23,105,67])


%     Subsystem  ['Binary sequence',13,'RS encode'].

new_system([sys,'/',['Binary sequence',13,'RS encode']])
set_param([sys,'/',['Binary sequence',13,'RS encode']],'Location',[263,35,887,210])


%     Subsystem  ['Binary sequence',13,'RS encode/Binary vector',13,'RS encode'].

new_system([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],'Location',[160,111,633,282])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Memory']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,n*dim)',...
		'position',[305,105,345,135])

add_block('built-in/Switch',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Switch']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Switch']],...
		'Threshold','0.5',...
		'position',[305,54,335,86])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/S-function']],...
		'function name','simrscbv',...
		'parameters','n, k, pg,tp,dim',...
		'position',[180,30,245,50])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/Mux']],...
		'inputs','2',...
		'position',[90,51,125,84])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/in_1']],...
		'position',[30,25,50,45])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/in_2']],...
		'Port','2',...
		'position',[20,110,40,130])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode/out_1']],...
		'position',[425,60,445,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[340,70;420,70])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[370,70;370,120;350,120])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[300,120;265,120;265,80;300,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[250,40;265,40;265,60;300,60])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[55,35;70,35;70,60;85,60])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[130,70;160,70;160,40;175,40])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[45,120;210,120;210,70;300,70])
add_line([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],[70,120;70,75;85,75])
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Bnr RS en',...
		'Mask Type','Binary vector I/O RS encode')
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'Mask Dialogue','Reed-Solomon encode with binary input\nvector length K*M and binary output vector length N*M.|Code length N=2^M-1 (M is a >2 integer):|Message length K (< N):')
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,pg=k;k=n-length(pg)-1;else,pg=rspoly(n,k);end;dim=3;p_dim=7;while p_dim<n,dim=dim+1;p_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'Mask Help','This block encodes length K*M binary vector input into length N*M binary vector output using Reed-Solomon code. The codeword length is N=2^M-1. M is a integer larger than 2. The message length is K<N. The block refreshes its encoding output when the enable signal at the second inport has positive value.')
set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'Mask Entries','n\/k\/')


%     Finished composite block ['Binary sequence',13,'RS encode/Binary vector',13,'RS encode'].

set_param([sys,'/',['Binary sequence',13,'RS encode/Binary vector',13,'RS encode']],...
		'position',[415,38,495,82])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/in_1']],...
		'position',[115,40,135,60])


%     Subsystem  ['Binary sequence',13,'RS encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'RS encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'Mask Entries','[k*m:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'RS encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'RS encode/Register-shift']],...
		'ForeGround',3,...
		'position',[225,40,280,80])


%     Subsystem  ['Binary sequence',13,'RS encode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','0.1\/')


%     Finished composite block ['Binary sequence',13,'RS encode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary sequence',13,'RS encode/Rising edge',13,'detector']],...
		'ForeGround',2,...
		'position',[315,56,365,84])


%     Subsystem  ['Binary sequence',13,'RS encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'Mask Entries','n*m\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'RS encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'RS encode/Triggered',13,'buffer down']],...
		'ForeGround',6,...
		'position',[540,53,600,87])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'RS encode/out_2']],...
		'Port','2',...
		'position',[645,70,665,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/out_1']],...
		'position',[685,55,705,75])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'RS encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Demux']],...
		'outputs','2',...
		'position',[125,90,170,125])


%     Subsystem  ['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k n]\/[0 0]\/')


%     Finished composite block ['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'RS encode/Pulses deivide',13,'same sample time']],...
		'position',[35,91,95,129])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[605,80;640,80])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[605,65;680,65])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[140,50;220,50])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[285,50;410,50])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[100,110;120,110])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[500,60;535,60])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[285,70;310,70])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[370,70;410,70])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[395,70;395,110;505,110;505,70;535,70])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[175,100;185,100;185,70;220,70])
add_line([sys,'/',['Binary sequence',13,'RS encode']],[175,115;510,115;510,80;535,80])
set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);B-RS en',...
		'Mask Type','Binary sequence I/O RS encode')
set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'Mask Dialogue','RS encode with codeword length N, message\nlength K.|Code length N=2^M-1 (M is a >2 integer):|Message length K:|Input sample time T_in (sec):')
set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'Mask Translate','n=@1;k=@2;samp=@3;m=3;p_m=7;while p_m<n,m=m+1;p_m=2^m-1;end;[x,y]=codeicon(3);[v,w]=trigicon(1,75,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'Mask Help','This block encodes length K binary message into length N binary codeword. The block uses sequential input/output format. The output sequence sample time is K*T_in/N. The block causes a K*M*T_in delay. The second outport outputs a pulse when (K*M)-th message signal is received.')
set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'Mask Entries','N_rs_demo\/K_rs_demo\/1/K_rs_demo/M_rs_demo\/')


%     Finished composite block ['Binary sequence',13,'RS encode'].

set_param([sys,'/',['Binary sequence',13,'RS encode']],...
		'hide name',0,...
		'position',[140,73,220,117])


%     Subsystem  ['adding noise',13,'in the transmit'].

new_system([sys,'/',['adding noise',13,'in the transmit']])
set_param([sys,'/',['adding noise',13,'in the transmit']],'Location',[448,375,1004,566])


%     Subsystem  ['adding noise',13,'in the transmit/Poisson',13,'noise'].

new_system([sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise']])
set_param([sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise']],'Location',[391,74,676,237])

add_block('built-in/S-Function',[sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise/Poisson distribution',13,'number']])
set_param([sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise/Poisson distribution',13,'number']],...
		'function name','srandpoi',...
		'parameters','seed,lambda',...
		'position',[65,55,135,95])

add_block('built-in/Outport',[sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise/out_1']])
set_param([sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise/out_1']],...
		'position',[165,65,185,85])
add_line([sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise']],[140,75;160,75])
set_param([sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise']],...
		'Mask Display','Poison\nrand int',...
		'Mask Type','Poisson distribution noise.',...
		'Mask Dialogue','Poisson distribution number generator.|Lambda:|Seed:')
set_param([sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise']],...
		'Mask Translate','seed=@2;lambda=@1;')
set_param([sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise']],...
		'Mask Help','The output of this block is poisson distributed integers. The output size is the same as the vector size for seed. Please use function disttool to see the distribution of the outputof this block.')
set_param([sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise']],...
		'Mask Entries','.02\/12345\/')


%     Finished composite block ['adding noise',13,'in the transmit/Poisson',13,'noise'].

set_param([sys,'/',['adding noise',13,'in the transmit/Poisson',13,'noise']],...
		'position',[90,104,165,146])

add_block('built-in/Outport',[sys,'/',['adding noise',13,'in the transmit/Error source']])
set_param([sys,'/',['adding noise',13,'in the transmit/Error source']],...
		'Port','2',...
		'position',[445,115,465,135])

add_block('built-in/Outport',[sys,'/',['adding noise',13,'in the transmit/code_word+error']])
set_param([sys,'/',['adding noise',13,'in the transmit/code_word+error']],...
		'position',[435,50,455,70])

add_block('built-in/Inport',[sys,'/',['adding noise',13,'in the transmit/code_word']])
set_param([sys,'/',['adding noise',13,'in the transmit/code_word']],...
		'position',[140,45,160,65])

add_block('built-in/Sum',[sys,'/',['adding noise',13,'in the transmit/Sum']])
set_param([sys,'/',['adding noise',13,'in the transmit/Sum']],...
		'position',[245,50,265,70])

add_block('built-in/S-Function',[sys,'/',['adding noise',13,'in the transmit/Modulus',13,'operation']])
set_param([sys,'/',['adding noise',13,'in the transmit/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['adding noise',13,'in the transmit/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['adding noise',13,'in the transmit/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['adding noise',13,'in the transmit/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[300,41,360,79])
add_line([sys,'/',['adding noise',13,'in the transmit']],[170,125;215,125;215,65;240,65])
add_line([sys,'/',['adding noise',13,'in the transmit']],[215,125;440,125])
add_line([sys,'/',['adding noise',13,'in the transmit']],[365,60;430,60])
add_line([sys,'/',['adding noise',13,'in the transmit']],[165,55;240,55])
add_line([sys,'/',['adding noise',13,'in the transmit']],[270,60;295,60])


%     Finished composite block ['adding noise',13,'in the transmit'].

set_param([sys,'/',['adding noise',13,'in the transmit']],...
		'position',[255,66,315,104])


%     Subsystem  'Error rate'.

new_system([sys,'/','Error rate'])
set_param([sys,'/','Error rate'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate/S-function'])
set_param([sys,'/','Error rate/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate/Mux'])
set_param([sys,'/','Error rate/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate/in_1'])
set_param([sys,'/','Error rate/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate/in_2'])
set_param([sys,'/','Error rate/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate'],[105,65;125,65])
add_line([sys,'/','Error rate'],[40,55;60,55])
add_line([sys,'/','Error rate'],[40,70;60,70])
set_param([sys,'/','Error rate'],...
		'Mask Display','Error Rate\nMeter',...
		'Mask Type','Symbol/Bit Error Counter.')
set_param([sys,'/','Error rate'],...
		'Mask Dialogue','Compare 2nd port input to scalar 1st port input. Compute the error rate.|Bit per symbol:|Number of digit on display:|Delay between input (1st port) and output (2nd port):|Sampling time (second):')
set_param([sys,'/','Error rate'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate'],...
		'Mask Help','The signal from the first port should be always be a scalar. The 2nd port input signal can be a vector with a same time delay to the input signal.')
set_param([sys,'/','Error rate'],...
		'Mask Entries','1\/K_rs_demo\/2\/1/K_rs_demo/M_rs_demo\/')


%     Finished composite block 'Error rate'.

set_param([sys,'/','Error rate'],...
		'hide name',0,...
		'position',[580,33,655,77])


%     Subsystem  'Counter'.

new_system([sys,'/','Counter'])
set_param([sys,'/','Counter'],'Location',[128,50,722,374])


%     Subsystem  ['Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Counter/Rising edge',13,'detector1']],[300,35;335,35])
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Counter/Rising edge',13,'detector1']],...
		'ForeGround',4,...
		'position',[375,53,435,87])

add_block('built-in/Inport',[sys,'/','Counter/in_3'])
set_param([sys,'/','Counter/in_3'],...
		'Port','3',...
		'position',[315,60,335,80])

add_block('built-in/Memory',[sys,'/','Counter/Memory3'])
set_param([sys,'/','Counter/Memory3'],...
		'orientation',2,...
		'ForeGround',3,...
		'position',[400,205,440,235])

add_block('built-in/Switch',[sys,'/','Counter/Switch3'])
set_param([sys,'/','Counter/Switch3'],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[470,139,495,171])

add_block('built-in/Outport',[sys,'/','Counter/out_1'])
set_param([sys,'/','Counter/out_1'],...
		'position',[550,145,570,165])


%     Subsystem  ['Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Counter/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thld\/')


%     Finished composite block ['Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Counter/Rising edge',13,'detector']],...
		'ForeGround',4,...
		'position',[80,148,140,182])

add_block('built-in/Inport',[sys,'/','Counter/in_2'])
set_param([sys,'/','Counter/in_2'],...
		'Port','2',...
		'position',[15,155,35,175])

add_block('built-in/Inport',[sys,'/','Counter/in_1'])
set_param([sys,'/','Counter/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Switch',[sys,'/','Counter/Switch2'])
set_param([sys,'/','Counter/Switch2'],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[345,149,370,181])

add_block('built-in/Sum',[sys,'/','Counter/Sum'])
set_param([sys,'/','Counter/Sum'],...
		'ForeGround',3,...
		'position',[295,100,315,120])

add_block('built-in/Relational Operator',[sys,'/',['Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Counter/Relational',13,'Operator1']],...
		'ForeGround',2,...
		'Operator','>',...
		'position',[225,53,255,77])

add_block('built-in/Constant',[sys,'/','Counter/Constant'])
set_param([sys,'/','Counter/Constant'],...
		'ForeGround',3,...
		'Value','thld',...
		'position',[105,100,135,120])
add_line([sys,'/','Counter'],[500,155;545,155])
add_line([sys,'/','Counter'],[520,155;520,220;445,220])
add_line([sys,'/','Counter'],[375,165;465,165])
add_line([sys,'/','Counter'],[340,70;370,70])
add_line([sys,'/','Counter'],[40,165;75,165])
add_line([sys,'/','Counter'],[40,60;220,60])
add_line([sys,'/','Counter'],[320,110;330,110;340,155])
add_line([sys,'/','Counter'],[140,110;190,110;190,70;220,70])
add_line([sys,'/','Counter'],[260,65;275,65;275,105;290,105])
add_line([sys,'/','Counter'],[145,165;340,165])
add_line([sys,'/','Counter'],[395,220;275,220;275,175;340,175])
add_line([sys,'/','Counter'],[275,175;275,115;290,115])
add_line([sys,'/','Counter'],[440,70;450,70;450,155;465,155])
set_param([sys,'/','Counter'],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Counter',...
		'Mask Type','Resettable number counter')
set_param([sys,'/','Counter'],...
		'Mask Dialogue','If the 1st inport value is larger than the threshold, the counter increases one at the rising edge of the 2nd inport pulse.|Threshold:')
set_param([sys,'/','Counter'],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(0,20,get_param(gcb,''orientation''),2);')
set_param([sys,'/','Counter'],...
		'Mask Help','If the signal at the 1st inport is larger than or equal to the given threshold at the rising edge of the 2nd inport, the counter increases by one. The rising edge of the 3rd port resets the counter to zero.')
set_param([sys,'/','Counter'],...
		'Mask Entries','.6\/')


%     Finished composite block 'Counter'.

set_param([sys,'/','Counter'],...
		'hide name',0,...
		'position',[390,138,470,182])


%     Subsystem  ['K-step',13,'delay'].

new_system([sys,'/',['K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay']],'Location',[12,432,357,702])

add_block('built-in/Digital Clock',[sys,'/',['K-step',13,'delay/Digital Clock']])
set_param([sys,'/',['K-step',13,'delay/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])

add_block('built-in/Inport',[sys,'/',['K-step',13,'delay/in_1']])
set_param([sys,'/',['K-step',13,'delay/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['K-step',13,'delay/out_1']])
set_param([sys,'/',['K-step',13,'delay/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Filter',[sys,'/',['K-step',13,'delay/K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Switch',[sys,'/',['K-step',13,'delay/Switch']])
set_param([sys,'/',['K-step',13,'delay/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant']])
set_param([sys,'/',['K-step',13,'delay/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant1']])
set_param([sys,'/',['K-step',13,'delay/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Relational Operator',[sys,'/',['K-step',13,'delay/Relational',13,'Operator']])
set_param([sys,'/',['K-step',13,'delay/Relational',13,'Operator']],...
		'position',[150,168,180,192])
add_line([sys,'/',['K-step',13,'delay']],[300,130;320,130])
add_line([sys,'/',['K-step',13,'delay']],[45,90;55,90])
add_line([sys,'/',['K-step',13,'delay']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['K-step',13,'delay']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['K-step',13,'delay']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['K-step',13,'delay']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['K-step',13,'delay']],[185,180;220,180;220,130;265,130])
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay',...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Entries','N_rs_demo*M_rs_demo\/1/N_rs_demo/M_rs_demo\/0\/')


%     Finished composite block ['K-step',13,'delay'].

set_param([sys,'/',['K-step',13,'delay']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[500,138,580,182])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[620,136,650,169])


%     Subsystem  ['Placed and',13,'detected errors'].

new_system([sys,'/',['Placed and',13,'detected errors']])
set_param([sys,'/',['Placed and',13,'detected errors']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Placed and',13,'detected errors/x']])
set_param([sys,'/',['Placed and',13,'detected errors/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Placed and',13,'detected errors/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Placed and',13,'detected errors/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Placed and',13,'detected errors']],[90,65;125,65])
set_param([sys,'/',['Placed and',13,'detected errors']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Placed and',13,'detected errors']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Placed and',13,'detected errors']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Placed and',13,'detected errors']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Placed and',13,'detected errors']],...
		'Mask Entries','5\/-1.1\/5\/''r-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Placed and',13,'detected errors'].

set_param([sys,'/',['Placed and',13,'detected errors']],...
		'hide name',0,...
		'position',[685,136,715,174])

add_block('built-in/Note',[sys,'/','This demo shows one burst error R-S code correction.'])
set_param([sys,'/','This demo shows one burst error R-S code correction.'],...
		'position',[190,195,195,200])

add_block('built-in/Note',[sys,'/',['This demo uses the MATLAB workspace variable to set the code world length N_rs_demo=15,',13,'message length K_rs_demo= 9, and bits per symbol M_rs_demo=4.                                  ']])
set_param([sys,'/',['This demo uses the MATLAB workspace variable to set the code world length N_rs_demo=15,',13,'message length K_rs_demo= 9, and bits per symbol M_rs_demo=4.                                  ']],...
		'position',[300,210,305,215])
add_line(sys,[110,45;575,45])
add_line(sys,[110,45;125,45;135,95])
add_line(sys,[320,75;395,75])
add_line(sys,[225,85;250,85])
add_line(sys,[485,65;575,65])
add_line(sys,[585,160;615,160])
add_line(sys,[655,155;680,155])
add_line(sys,[475,160;495,160])
add_line(sys,[335,160;385,160])
add_line(sys,[320,95;345,95;345,145;385,145])
add_line(sys,[485,85;595,85;595,145;615,145])
add_line(sys,[225,105;235,105;235,185;365,185;365,175;385,175])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
