function [ret,x0,str,ts,xts]=tstrscbv(t,x,u,flag);
%TSTRSCBV	is the M-file description of the SIMULINK system named TSTRSCBV.
%	The block-diagram can be displayed by typing: TSTRSCBV.
%
%	SYS=TSTRSCBV(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTRSCBV to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTRSCBV with a FLAG of zero:
%	[SIZES]=TSTRSCBV([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[12,376,916,618])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','N_rs_demo=7;K_rs_demo=5;M_rs_demo=3;');

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'position',[360,60,380,80])


%     Subsystem  ['Binary vector',13,'RS encode'].

new_system([sys,'/',['Binary vector',13,'RS encode']])
set_param([sys,'/',['Binary vector',13,'RS encode']],'Location',[160,111,633,282])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'RS encode/out_1']])
set_param([sys,'/',['Binary vector',13,'RS encode/out_1']],...
		'position',[425,60,445,80])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'RS encode/in_2']])
set_param([sys,'/',['Binary vector',13,'RS encode/in_2']],...
		'Port','2',...
		'position',[20,110,40,130])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'RS encode/in_1']])
set_param([sys,'/',['Binary vector',13,'RS encode/in_1']],...
		'position',[30,25,50,45])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'RS encode/Mux']])
set_param([sys,'/',['Binary vector',13,'RS encode/Mux']],...
		'inputs','2',...
		'position',[90,51,125,84])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'RS encode/S-function']])
set_param([sys,'/',['Binary vector',13,'RS encode/S-function']],...
		'function name','simrscbv',...
		'parameters','n, k, pg,tp,dim',...
		'position',[180,30,245,50])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'RS encode/Switch']])
set_param([sys,'/',['Binary vector',13,'RS encode/Switch']],...
		'Threshold','0.5',...
		'position',[305,54,335,86])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'RS encode/Memory']])
set_param([sys,'/',['Binary vector',13,'RS encode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,n*dim)',...
		'position',[305,105,345,135])
add_line([sys,'/',['Binary vector',13,'RS encode']],[45,120;210,120;210,70;300,70])
add_line([sys,'/',['Binary vector',13,'RS encode']],[70,120;70,75;85,75])
add_line([sys,'/',['Binary vector',13,'RS encode']],[130,70;160,70;160,40;175,40])
add_line([sys,'/',['Binary vector',13,'RS encode']],[55,35;70,35;70,60;85,60])
add_line([sys,'/',['Binary vector',13,'RS encode']],[250,40;265,40;265,60;300,60])
add_line([sys,'/',['Binary vector',13,'RS encode']],[300,120;265,120;265,80;300,80])
add_line([sys,'/',['Binary vector',13,'RS encode']],[340,70;420,70])
add_line([sys,'/',['Binary vector',13,'RS encode']],[370,70;370,120;350,120])
set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);B-RS en',...
		'Mask Type','Binary vector I/O RS encode')
set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'Mask Dialogue','Reed-Solomon encode with binary input\nvector length K*M and binary output\nvector length N*M.|Code length N=2^M-1 (M is a >2 integer):|Message length K (< N):')
set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,pg=k;k=n-length(pg)-1;else,pg=rspoly(n,k);end;dim=3;p_dim=7;while p_dim<n,dim=dim+1;p_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'Mask Help','This block encodes length K*M binary vector input into length N*M binary vector output. The codeword length is N=2^M-1. M is a integer larger than 2. The message length is K<N. The block refreshes its encoding output when the enable signal at the second inport has positive value.')
set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'Mask Entries','N_rs_demo\/K_rs_demo\/')


%     Finished composite block ['Binary vector',13,'RS encode'].

set_param([sys,'/',['Binary vector',13,'RS encode']],...
		'hide name',0,...
		'position',[235,43,315,87])


%     Subsystem  ['Binary vector',13,'RS decode'].

new_system([sys,'/',['Binary vector',13,'RS decode']])
set_param([sys,'/',['Binary vector',13,'RS decode']],'Location',[143,192,726,352])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'RS decode/out_2']])
set_param([sys,'/',['Binary vector',13,'RS decode/out_2']],...
		'Port','2',...
		'position',[495,95,515,115])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'RS decode/out_1']])
set_param([sys,'/',['Binary vector',13,'RS decode/out_1']],...
		'position',[495,30,515,50])

add_block('built-in/Demux',[sys,'/',['Binary vector',13,'RS decode/Demux']])
set_param([sys,'/',['Binary vector',13,'RS decode/Demux']],...
		'outputs','[k*dim,1]',...
		'position',[395,40,435,75])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'RS decode/in_2']])
set_param([sys,'/',['Binary vector',13,'RS decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'RS decode/in_1']])
set_param([sys,'/',['Binary vector',13,'RS decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'RS decode/Mux']])
set_param([sys,'/',['Binary vector',13,'RS decode/Mux']],...
		'inputs','2',...
		'position',[80,41,115,74])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'RS decode/S-function']])
set_param([sys,'/',['Binary vector',13,'RS decode/S-function']],...
		'function name','simrsdbv',...
		'parameters','n, k, tp, dim',...
		'position',[170,20,235,40])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'RS decode/Switch']])
set_param([sys,'/',['Binary vector',13,'RS decode/Switch']],...
		'Threshold','0.5',...
		'position',[295,44,325,76])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'RS decode/Memory']])
set_param([sys,'/',['Binary vector',13,'RS decode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,k*dim+1)',...
		'position',[295,95,335,125])
add_line([sys,'/',['Binary vector',13,'RS decode']],[440,65;455,65;455,105;490,105])
add_line([sys,'/',['Binary vector',13,'RS decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary vector',13,'RS decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary vector',13,'RS decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary vector',13,'RS decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary vector',13,'RS decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary vector',13,'RS decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary vector',13,'RS decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary vector',13,'RS decode']],[330,60;390,60])
add_line([sys,'/',['Binary vector',13,'RS decode']],[360,60;360,110;340,110])
set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);B-RS de',...
		'Mask Type','Binary vector I/O RS decode')
set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'Mask Dialogue','Reed-Solomon decode with binary input\nvector length N*M and binary output\nvector length K*M.|Code length N=2^M-1 (M is a >2 integer):|Message length K (< N):')
set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'Mask Translate','n=@1;k=@2;dim=3;p_d=7;while p_d<n,dim=dim+1;p_d=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'Mask Help','This block decodes length N*M binary vector input into length K*M binary vector output. The codeword length is N=2^M-1. M>2. The message length is K<N. The block refreshes its decoding output when the enable signal at the second inport has positive value. The second outport outputs the number of errors detected in the process. If the codeword contains more errors than the correction capability, this output is negative.')
set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'Mask Entries','N_rs_demo\/K_rs_demo\/')


%     Finished composite block ['Binary vector',13,'RS decode'].

set_param([sys,'/',['Binary vector',13,'RS decode']],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[540,58,620,102])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector']])
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter',...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Entries','K_rs_demo*M_rs_demo\/2\/',...
		'position',[120,33,200,77])


%     Subsystem  ['Random-integer',13,'generator1'].

new_system([sys,'/',['Random-integer',13,'generator1']])
set_param([sys,'/',['Random-integer',13,'generator1']],'Location',[98,518,454,687])

add_block('built-in/S-Function',[sys,'/',['Random-integer',13,'generator1/Uniform',13,'number']])
set_param([sys,'/',['Random-integer',13,'generator1/Uniform',13,'number']],...
		'function name','srandint',...
		'parameters','seed,mul',...
		'position',[65,45,135,85])

add_block('built-in/Outport',[sys,'/',['Random-integer',13,'generator1/out_1']])
set_param([sys,'/',['Random-integer',13,'generator1/out_1']],...
		'position',[165,55,185,75])
add_line([sys,'/',['Random-integer',13,'generator1']],[140,65;160,65])
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Display','plot(0,0,100,100,x,y);Random int',...
		'Mask Type','Random integer generator')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Dialogue','Generate integers randomly distributed in range [0, M-1], where M is the M-ary number.|M-ary number:|Seed:',...
		'Mask Translate','seed=@2;mul=@1;[x,y]=srcsicon(4);')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Help','This block generates an integer number in the range [0 M-1], where M is the M-ary number. The probability of the appearance for each number is equal.')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Entries','2^(K_rs_demo*M_rs_demo)\/[12345]\/')


%     Finished composite block ['Random-integer',13,'generator1'].

set_param([sys,'/',['Random-integer',13,'generator1']],...
		'hide name',0,...
		'position',[10,33,90,77])


%     Subsystem  'Error rate'.

new_system([sys,'/','Error rate'])
set_param([sys,'/','Error rate'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate/S-function'])
set_param([sys,'/','Error rate/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate/Mux'])
set_param([sys,'/','Error rate/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate/in_1'])
set_param([sys,'/','Error rate/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate/in_2'])
set_param([sys,'/','Error rate/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate'],[105,65;125,65])
add_line([sys,'/','Error rate'],[40,55;60,55])
add_line([sys,'/','Error rate'],[40,70;60,70])
set_param([sys,'/','Error rate'],...
		'Mask Display','Error Rate\nMeter',...
		'Mask Type','Symbol/Bit Error Counter.')
set_param([sys,'/','Error rate'],...
		'Mask Dialogue','Compare 2nd port input to scalar 1st port input. Compute the error rate.|Bit per symbol:|Number of digit on display:|Delay between input (1st port) and output (2nd port):|Sampling time (second):')
set_param([sys,'/','Error rate'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate'],...
		'Mask Help','The signal from the first port should be always be a scalar. The 2nd port input signal can be a vector with a same time delay to the input signal.')
set_param([sys,'/','Error rate'],...
		'Mask Entries','K_rs_demo*M_rs_demo\/20\/0\/1\/')


%     Finished composite block 'Error rate'.

set_param([sys,'/','Error rate'],...
		'hide name',0,...
		'position',[755,13,830,57])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar1']])
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Entries','2\/',...
		'position',[640,48,720,92])

add_block('built-in/Constant',[sys,'/','Const2'])
set_param([sys,'/','Const2'],...
		'orientation',3,...
		'hide name',0,...
		'position',[500,120,520,140])


%     Subsystem  ['Binary vector',13,'noise generator1'].

new_system([sys,'/',['Binary vector',13,'noise generator1']])
set_param([sys,'/',['Binary vector',13,'noise generator1']],'Location',[36,445,326,560])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'noise generator1/S-function']])
set_param([sys,'/',['Binary vector',13,'noise generator1/S-function']],...
		'function name','srandbit',...
		'parameters','n, prob, seed',...
		'position',[90,35,140,55])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'noise generator1/out_1']])
set_param([sys,'/',['Binary vector',13,'noise generator1/out_1']],...
		'position',[190,35,210,55])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[145,45;185,45])
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Display','plot(0,0,100,100,x,y);B-vector',...
		'Mask Type','Binary noise generator')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Dialogue','Generate a binary vector with the probability of "1"s in the vector being specified.|Vector length(can''t be changed during simulation):|Probability of a "one", two "ones",three "ones"...:|Seed:')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Translate','n=@1;prob=@2;seed=@3;[x,y]=srcsicon(5);')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Help','This block outputs a zero vector with "1"s randomly distributed the vector. The maximum number of "1"s in the vector is the same as the length of the vector probability. The value of ith element of the probability is the probability of i number of "1"s in the vector, e.g. [1/4 1/4 1/4] means probability of single "1", double "1"s, three "1"s or no "1" in the vector is 1/4.')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Entries','N_rs_demo\/1/2\/12345\/')


%     Finished composite block ['Binary vector',13,'noise generator1'].

set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'hide name',0,...
		'position',[80,98,160,142])


%     Subsystem  ['Triggered',13,'signal switch'].

new_system([sys,'/',['Triggered',13,'signal switch']])
set_param([sys,'/',['Triggered',13,'signal switch']],'Location',[672,516,1052,680])

add_block('built-in/S-Function',[sys,'/',['Triggered',13,'signal switch/S-function']])
set_param([sys,'/',['Triggered',13,'signal switch/S-function']],...
		'function name','stdmamux',...
		'parameters','sw,ke,in,tt',...
		'position',[205,60,275,90])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'signal switch/in_2']])
set_param([sys,'/',['Triggered',13,'signal switch/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/Outport',[sys,'/',['Triggered',13,'signal switch/out_1']])
set_param([sys,'/',['Triggered',13,'signal switch/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Mux',[sys,'/',['Triggered',13,'signal switch/Mux']])
set_param([sys,'/',['Triggered',13,'signal switch/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Inport',[sys,'/',['Triggered',13,'signal switch/in_1']])
set_param([sys,'/',['Triggered',13,'signal switch/in_1']],...
		'position',[65,20,85,40])
add_line([sys,'/',['Triggered',13,'signal switch']],[280,75;315,75])
add_line([sys,'/',['Triggered',13,'signal switch']],[180,75;200,75])
add_line([sys,'/',['Triggered',13,'signal switch']],[85,85;140,85])
add_line([sys,'/',['Triggered',13,'signal switch']],[90,30;120,30;120,65;140,65])
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Display','plot(0,0,100,100,v,w);Vct re-arr',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Dialogue','The rising edge from the 2nd inport\ntriggers the output of this block to follow the rule of the next row in the switch box.|Switch box (column number equals block output length):|Keeping value (flag 0 element in switch box):|Initial value (before the 1st trigger is detected):|Trigger threshold:')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Translate','sw=@1;ke=@2;in=@3;tt=@4;[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Help','When the ith element in the current row of the switch box is j, the ith element in the output vector equals jth input element. When j=0, the output keeps the last output value if keep_value >= 0; it equals ini_val otherwise. The switch box column number must be same as the lengths of output, keep_value, and init_value. The rising edge of the 2nd inport triggers the distribution pattern to follow the next row of the switch box.')
set_param([sys,'/',['Triggered',13,'signal switch']],...
		'Mask Entries','vec2mat([1:N_rs_demo]''*ones(1,M_rs_demo),M_rs_demo*N_rs_demo)\/zeros(1,N_rs_demo*M_rs_demo)\/zeros(1,N_rs_demo*M_rs_demo)\/.1\/')


%     Finished composite block ['Triggered',13,'signal switch'].

set_param([sys,'/',['Triggered',13,'signal switch']],...
		'hide name',0,...
		'position',[245,108,325,152])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'ForeGround',7,...
		'hide name',0,...
		'inputs','+',...
		'position',[435,150,455,170])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[665,135,700,170])


%     Subsystem  ['Compare placed and',13,'detected number of errors'].

new_system([sys,'/',['Compare placed and',13,'detected number of errors']])
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Compare placed and',13,'detected number of errors/x']])
set_param([sys,'/',['Compare placed and',13,'detected number of errors/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Compare placed and',13,'detected number of errors/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Compare placed and',13,'detected number of errors/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Compare placed and',13,'detected number of errors']],[90,65;125,65])
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'Mask Entries','10\/-1.2\/.2+K_rs_demo\/''mx/c+/m-/w-/b+''\/')


%     Finished composite block ['Compare placed and',13,'detected number of errors'].

set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'hide name',0,...
		'position',[750,136,780,174])

add_block('built-in/Constant',[sys,'/','Const1'])
set_param([sys,'/','Const1'],...
		'hide name',0,...
		'position',[185,85,205,105])

add_block('built-in/Constant',[sys,'/','Const3'])
set_param([sys,'/','Const3'],...
		'hide name',0,...
		'position',[200,130,220,150])

add_block('built-in/S-Function',[sys,'/',['Modulo',13,'operation1']])
set_param([sys,'/',['Modulo',13,'operation1']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Modulo',13,'operation1']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Modulo',13,'operation1']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.',...
		'Mask Entries','2\/')
set_param([sys,'/',['Modulo',13,'operation1']],...
		'position',[405,48,485,92])

add_block('built-in/Note',[sys,'/','This demo shows one burst error R-S code correction.'])
set_param([sys,'/','This demo shows one burst error R-S code correction.'],...
		'position',[190,170,195,175])

add_block('built-in/Note',[sys,'/',['This demo uses the MATLAB workspace variable to set the code world length N_rs_demo=7,',13,'message length K_rs_demo= 4, and bits per symbol M_rs_demo=3.                                  ']])
set_param([sys,'/',['This demo uses the MATLAB workspace variable to set the code world length N_rs_demo=7,',13,'message length K_rs_demo= 4, and bits per symbol M_rs_demo=3.                                  ']],...
		'position',[295,190,300,195])
add_line(sys,[320,65;355,65])
add_line(sys,[385,70;400,70])
add_line(sys,[490,70;535,70])
add_line(sys,[95,55;115,55])
add_line(sys,[205,55;230,55])
add_line(sys,[625,90;625,145;660,145])
add_line(sys,[460,160;660,160])
add_line(sys,[510,115;510,90;535,90])
add_line(sys,[625,70;635,70])
add_line(sys,[725,70;735,70;735,45;750,45])
add_line(sys,[705,155;745,155])
add_line(sys,[105,55;105,25;750,25])
add_line(sys,[165,120;240,120])
add_line(sys,[330,130;335,130;335,75;355,75])
add_line(sys,[190,120;190,160;430,160])
add_line(sys,[210,95;215,95;215,75;230,75])
add_line(sys,[225,140;240,140])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
