function [ret,x0,str,ts,xts]=tstrscod(t,x,u,flag);
%TSTRSCOD	is the M-file description of the SIMULINK system named TSTRSCOD.
%	The block-diagram can be displayed by typing: TSTRSCOD.
%
%	SYS=TSTRSCOD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTRSCOD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTRSCOD with a FLAG of zero:
%	[SIZES]=TSTRSCOD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,97,784,341])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','N_rs_demo=7;K_rs_demo=5;M_rs_demo=3;');

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'ForeGround',7,...
		'hide name',0,...
		'inputs','+',...
		'position',[430,135,450,155])

add_block('built-in/S-Function',[sys,'/',['Modulo',13,'operation1']])
set_param([sys,'/',['Modulo',13,'operation1']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Modulo',13,'operation1']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Modulo',13,'operation1']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Modulo',13,'operation1']],...
		'Mask Entries','2^M_rs_demo\/',...
		'position',[390,48,470,92])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector']])
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter',...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Entries','K_rs_demo\/2^M_rs_demo\/',...
		'position',[115,33,195,77])


%     Subsystem  ['Random-integer',13,'generator1'].

new_system([sys,'/',['Random-integer',13,'generator1']])
set_param([sys,'/',['Random-integer',13,'generator1']],'Location',[98,518,454,687])

add_block('built-in/Outport',[sys,'/',['Random-integer',13,'generator1/out_1']])
set_param([sys,'/',['Random-integer',13,'generator1/out_1']],...
		'position',[165,55,185,75])

add_block('built-in/S-Function',[sys,'/',['Random-integer',13,'generator1/Uniform',13,'number']])
set_param([sys,'/',['Random-integer',13,'generator1/Uniform',13,'number']],...
		'function name','srandint',...
		'parameters','seed,mul',...
		'position',[65,45,135,85])
add_line([sys,'/',['Random-integer',13,'generator1']],[140,65;160,65])
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Display','plot(0,0,100,100,x,y);Random int',...
		'Mask Type','Random integer generator')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Dialogue','Generate integers randomly distributed in range [0, M-1], where M is the M-ary number.|M-ary number:|Seed:',...
		'Mask Translate','seed=@2;mul=@1;[x,y]=srcsicon(4);')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Help','This block generates an integer number in the range [0 M-1], where M is the M-ary number. The probability of the appearance for each number is equal.')
set_param([sys,'/',['Random-integer',13,'generator1']],...
		'Mask Entries','2^(K_rs_demo*M_rs_demo)\/[12345]\/')


%     Finished composite block ['Random-integer',13,'generator1'].

set_param([sys,'/',['Random-integer',13,'generator1']],...
		'hide name',0,...
		'position',[10,33,90,77])


%     Subsystem  ['Integer vector',13,'RS encode'].

new_system([sys,'/',['Integer vector',13,'RS encode']])
set_param([sys,'/',['Integer vector',13,'RS encode']],'Location',[315,420,618,590])

add_block('built-in/Outport',[sys,'/',['Integer vector',13,'RS encode/out_1']])
set_param([sys,'/',['Integer vector',13,'RS encode/out_1']],...
		'position',[260,60,280,80])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'RS encode/S-function']])
set_param([sys,'/',['Integer vector',13,'RS encode/S-function']],...
		'function name','simrscod',...
		'parameters','n, k, pg,tp,dim',...
		'position',[155,60,220,80])

add_block('built-in/Mux',[sys,'/',['Integer vector',13,'RS encode/Mux']])
set_param([sys,'/',['Integer vector',13,'RS encode/Mux']],...
		'inputs','2',...
		'position',[90,51,125,84])

add_block('built-in/Inport',[sys,'/',['Integer vector',13,'RS encode/in_1']])
set_param([sys,'/',['Integer vector',13,'RS encode/in_1']],...
		'position',[30,25,50,45])

add_block('built-in/Inport',[sys,'/',['Integer vector',13,'RS encode/in_2']])
set_param([sys,'/',['Integer vector',13,'RS encode/in_2']],...
		'Port','2',...
		'position',[20,110,40,130])
add_line([sys,'/',['Integer vector',13,'RS encode']],[225,70;255,70])
add_line([sys,'/',['Integer vector',13,'RS encode']],[55,35;70,35;70,60;85,60])
add_line([sys,'/',['Integer vector',13,'RS encode']],[130,70;150,70])
add_line([sys,'/',['Integer vector',13,'RS encode']],[45,120;70,120;70,75;85,75])
set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Int RS en',...
		'Mask Type','Integer vector I/O RS encode')
set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'Mask Dialogue','Reed-Solomon encode with integer input\nmessage vector length K and integer\noutput codeword vector length N.|Code length N=2^M-1 (M is a >=3 integer):|Message length K (< N):')
set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'Mask Translate','n=@1;k=@2;if length(k)>1,pg=k;k=n-length(pg)-1;else,pg=rspoly(n,k);end;dim=3;p_dim=7;while p_dim<n,dim=dim+1;p_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'Mask Help','This block encodes length K integer vector message input into length N integer vector codeword output. The input/output integers are in range [0, N-1]. Code word length N=2^M-1, where M is a integer no less than 3. The message length is K<N. The error-correction capability is T=floor((N-K)/2). The block refreshes its decoding output when the enable signal at the second inport has positive value.')
set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'Mask Entries','N_rs_demo\/K_rs_demo\/')


%     Finished composite block ['Integer vector',13,'RS encode'].

set_param([sys,'/',['Integer vector',13,'RS encode']],...
		'hide name',0,...
		'position',[235,43,315,87])


%     Subsystem  ['Binary vector',13,'noise generator1'].

new_system([sys,'/',['Binary vector',13,'noise generator1']])
set_param([sys,'/',['Binary vector',13,'noise generator1']],'Location',[36,445,326,560])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'noise generator1/out_1']])
set_param([sys,'/',['Binary vector',13,'noise generator1/out_1']],...
		'position',[190,35,210,55])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'noise generator1/S-function']])
set_param([sys,'/',['Binary vector',13,'noise generator1/S-function']],...
		'function name','srandbit',...
		'parameters','n, prob, seed',...
		'position',[90,35,140,55])
add_line([sys,'/',['Binary vector',13,'noise generator1']],[145,45;185,45])
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Display','plot(0,0,100,100,x,y);B-vector',...
		'Mask Type','Binary noise generator')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Dialogue','Generate a binary vector with the probability of "1"s in the vector being specified.|Vector length(can''t be changed during simulation):|Probability of a "one", two "ones",three "ones"...:|Seed:')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Translate','n=@1;prob=@2;seed=@3;[x,y]=srcsicon(5);')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Help','This block outputs a zero vector with "1"s randomly distributed the vector. The maximum number of "1"s in the vector is the same as the length of the vector probability. The value of ith element of the probability is the probability of i number of "1"s in the vector, e.g. [1/4 1/4 1/4] means probability of single "1", double "1"s, three "1"s or no "1" in the vector is 1/4.')
set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'Mask Entries','N_rs_demo\/1/2\/12345\/')


%     Finished composite block ['Binary vector',13,'noise generator1'].

set_param([sys,'/',['Binary vector',13,'noise generator1']],...
		'hide name',0,...
		'position',[205,123,285,167])

add_block('built-in/Constant',[sys,'/','Const1'])
set_param([sys,'/','Const1'],...
		'orientation',3,...
		'hide name',0,...
		'position',[200,90,220,110])

add_block('built-in/State-Space',[sys,'/',['Matrix',13,'Gain']])
set_param([sys,'/',['Matrix',13,'Gain']],...
		'orientation',3,...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).')
set_param([sys,'/',['Matrix',13,'Gain']],...
		'Mask Entries','diag(randint(N_rs_demo,1,[1,M_rs_demo]))\/',...
		'position',[315,90,345,120])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'position',[355,60,375,80])

add_block('built-in/Note',[sys,'/','This demo shows one burst error R-S code correction.'])
set_param([sys,'/','This demo shows one burst error R-S code correction.'],...
		'position',[175,170,180,175])

add_block('built-in/Note',[sys,'/',['This demo uses the MATLAB workspace variable to set the code world length N_rs_demo=7,',13,'message length K_rs_demo= 4, and bits per symbol M_rs_demo=3.                                  ']])
set_param([sys,'/',['This demo uses the MATLAB workspace variable to set the code world length N_rs_demo=7,',13,'message length K_rs_demo= 4, and bits per symbol M_rs_demo=3.                                  ']],...
		'position',[280,190,285,195])

add_block('built-in/Constant',[sys,'/','Const2'])
set_param([sys,'/','Const2'],...
		'orientation',3,...
		'hide name',0,...
		'position',[465,105,485,125])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[615,120,650,155])


%     Subsystem  ['Integer vector',13,'RS decode'].

new_system([sys,'/',['Integer vector',13,'RS decode']])
set_param([sys,'/',['Integer vector',13,'RS decode']],'Location',[267,61,656,221])

add_block('built-in/Outport',[sys,'/',['Integer vector',13,'RS decode/out_2']])
set_param([sys,'/',['Integer vector',13,'RS decode/out_2']],...
		'Port','2',...
		'position',[325,100,345,120])

add_block('built-in/Demux',[sys,'/',['Integer vector',13,'RS decode/Demux']])
set_param([sys,'/',['Integer vector',13,'RS decode/Demux']],...
		'outputs','[k, 1]',...
		'position',[260,50,300,85])

add_block('built-in/Mux',[sys,'/',['Integer vector',13,'RS decode/Mux']])
set_param([sys,'/',['Integer vector',13,'RS decode/Mux']],...
		'inputs','2',...
		'position',[80,40,115,75])

add_block('built-in/Inport',[sys,'/',['Integer vector',13,'RS decode/in_2']])
set_param([sys,'/',['Integer vector',13,'RS decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/',['Integer vector',13,'RS decode/in_1']])
set_param([sys,'/',['Integer vector',13,'RS decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'RS decode/S-function']])
set_param([sys,'/',['Integer vector',13,'RS decode/S-function']],...
		'function name','simrsdec',...
		'parameters','n, k, tp, dim',...
		'position',[170,50,235,70])

add_block('built-in/Outport',[sys,'/',['Integer vector',13,'RS decode/out_1']])
set_param([sys,'/',['Integer vector',13,'RS decode/out_1']],...
		'position',[325,50,345,70])
add_line([sys,'/',['Integer vector',13,'RS decode']],[305,75;310,75;320,110])
add_line([sys,'/',['Integer vector',13,'RS decode']],[305,60;320,60])
add_line([sys,'/',['Integer vector',13,'RS decode']],[240,60;240,70;255,70])
add_line([sys,'/',['Integer vector',13,'RS decode']],[35,110;60,110;60,65;75,65])
add_line([sys,'/',['Integer vector',13,'RS decode']],[120,60;165,60])
add_line([sys,'/',['Integer vector',13,'RS decode']],[45,25;60,25;60,50;75,50])
set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Int RS de',...
		'Mask Type','Integer vector I/O RS decode')
set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'Mask Dialogue','Reed-Solomon decode with integer output\ncodeword vector length N and integer\ninput message vector length K.|Code word length N=2^M-1 (M is a >=3 integer):|Message length K (< N):')
set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'Mask Translate','n=@1;k=@2;dim=3;p_d=7;while p_d<n,dim=dim+1;p_d=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'Mask Help','This block decodes length N integer vector codeword input into length K integer vector message output. The input/output integers are in the range [0, N-1]. The block refreshes its decoding output when the enable signal at the second inport has positive value. The second outport outputs the number of errors detected in the process. If the codeword contains more errors than the correction capability, this output is negative.')
set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'Mask Entries','N_rs_demo\/K_rs_demo\/')


%     Finished composite block ['Integer vector',13,'RS decode'].

set_param([sys,'/',['Integer vector',13,'RS decode']],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[500,58,580,102])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar1']])
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Entries','2^M_rs_demo\/',...
		'position',[600,48,680,92])


%     Subsystem  'Error rate2'.

new_system([sys,'/','Error rate2'])
set_param([sys,'/','Error rate2'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate2/S-function'])
set_param([sys,'/','Error rate2/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate2/Mux'])
set_param([sys,'/','Error rate2/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate2/in_1'])
set_param([sys,'/','Error rate2/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate2/in_2'])
set_param([sys,'/','Error rate2/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate2'],[105,65;125,65])
add_line([sys,'/','Error rate2'],[40,55;60,55])
add_line([sys,'/','Error rate2'],[40,70;60,70])
set_param([sys,'/','Error rate2'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate2'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate2'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate2'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate2'],...
		'Mask Entries','M_rs_demo*K_rs_demo\/10\/0\/1\/')


%     Finished composite block 'Error rate2'.

set_param([sys,'/','Error rate2'],...
		'hide name',0,...
		'position',[700,38,780,82])


%     Subsystem  ['Compare placed and',13,'detected number of errors'].

new_system([sys,'/',['Compare placed and',13,'detected number of errors']])
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Compare placed and',13,'detected number of errors/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Compare placed and',13,'detected number of errors/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Compare placed and',13,'detected number of errors/x']])
set_param([sys,'/',['Compare placed and',13,'detected number of errors/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Compare placed and',13,'detected number of errors']],[90,65;125,65])
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'Mask Entries','10\/-1.2\/.2+K_rs_demo\/''mx/c+/m-/w-/b+''\/')


%     Finished composite block ['Compare placed and',13,'detected number of errors'].

set_param([sys,'/',['Compare placed and',13,'detected number of errors']],...
		'hide name',0,...
		'position',[680,121,710,159])
add_line(sys,[320,65;350,65])
add_line(sys,[380,70;385,70])
add_line(sys,[475,70;495,70])
add_line(sys,[95,55;110,55])
add_line(sys,[200,55;230,55])
add_line(sys,[210,85;210,75;230,75])
add_line(sys,[585,70;595,70])
add_line(sys,[685,70;695,70])
add_line(sys,[95,55;95,25;685,25;695,50])
add_line(sys,[330,85;330,75;350,75])
add_line(sys,[655,140;675,140])
add_line(sys,[585,90;590,90;590,130;610,130])
add_line(sys,[455,145;610,145])
add_line(sys,[475,100;475,90;495,90])
add_line(sys,[290,145;425,145])
add_line(sys,[330,145;330,135;330,125])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
