function [ret,x0,str,ts,xts]=tstrssq(t,x,u,flag);
%TSTRSSQ       is the M-file description of the SIMULINK system named TSTRSSQ.
%        The block-diagram can be displayed by typing: TSTRSSQ.
%
%        SYS=TSTRSSQ(T,X,U,FLAG) returns depending on FLAG certain
%      system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes TSTRSSQ to return state derivatives, FLAG=2
%      discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling TSTRSSQ with a FLAG of zero:
%   [SIZES]=TSTRSSQ([],[],[],0),  returns a vector, SIZES, which
%   contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs
%              SIZES(5) number of roots (currently unsupported)
%               SIZES(6) direct feedthrough flag
%               SIZES(7) number of sample times
%
%       For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[62,53,963,404])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','N_rs_demo=15;K_rs_demo=9;M_rs_demo=4;GWN=.05');

add_block('built-in/Note',[sys,'/','In this demo, you may sent the variable code word length N, message length K, and probability of noise..'])
set_param([sys,'/','In this demo, you may sent the variable code word length N, message length K, and probability of noise..'],...
             'position',[395,270,400,275])

add_block('built-in/S-Function',[sys,'/','Message source'])
set_param([sys,'/','Message source'],...
                'BackGround',5,...
              'function name','trigwksp',...
          'parameters','var,thd,cyclFlag',...
             'Mask Display','Triggered\nread',...
            'Mask Type','Read from workspace')
set_param([sys,'/','Message source'],...
              'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).')
set_param([sys,'/','Message source'],...
            'Mask Translate','var=@1;thd=@2;cyclFlag=@3;',...
               'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/','Message source'],...
             'Mask Entries','randint(K_rs_demo*M_rs_demo,1)\/.1\/1\/',...
            'position',[200,100,265,140])


%     Subsystem  'Delay'.

new_system([sys,'/','Delay'])
set_param([sys,'/','Delay'],'Location',[19,610,374,740])

add_block('built-in/Demux',[sys,'/','Delay/Demux'])
set_param([sys,'/','Delay/Demux'],...
             'outputs','[len_rg, 1]',...
             'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/','Delay/S-function'])
set_param([sys,'/','Delay/S-function'],...
              'function name','regshift',...
          'parameters','shft_out, thrhld',...
             'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/','Delay/Mux'])
set_param([sys,'/','Delay/Mux'],...
           'inputs','2',...
                'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/','Delay/out_1'])
set_param([sys,'/','Delay/out_1'],...
            'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/','Delay/out_2'])
set_param([sys,'/','Delay/out_2'],...
           'Port','2',...
          'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/','Delay/in_1'])
set_param([sys,'/','Delay/in_1'],...
              'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/','Delay/in_2'])
set_param([sys,'/','Delay/in_2'],...
                'Port','2',...
          'position',[30,70,50,90])
add_line([sys,'/','Delay'],[120,75;145,75])
add_line([sys,'/','Delay'],[205,75;255,75])
add_line([sys,'/','Delay'],[305,65;325,65])
add_line([sys,'/','Delay'],[305,80;325,80])
add_line([sys,'/','Delay'],[55,65;75,65])
add_line([sys,'/','Delay'],[55,80;75,80])
set_param([sys,'/','Delay'],...
          'Mask Display','Register\nshift',...
            'Mask Type','Register-shift')
set_param([sys,'/','Delay'],...
            'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/','Delay'],...
             'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/','Delay'],...
           'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/','Delay'],...
             'Mask Entries','K_rs_demo*M_rs_demo*2\/.1\/')


%     Finished composite block 'Delay'.

set_param([sys,'/','Delay'],...
             'BackGround',5,...
              'position',[310,35,365,75])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
         'outputs','3',...
               'position',[125,57,165,93])


%     Subsystem  ['Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Pulses deivide',13,'same sample time/S-function1']],...
         'function name','homopuls',...
          'parameters','samp_time, out_divid, offset',...
         'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Pulses deivide',13,'same sample time/Outport']],...
              'position',[160,35,180,55])
add_line([sys,'/',['Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Pulses deivide',13,'same sample time']],...
         'Mask Display','Vector\nPulse',...
              'Mask Type','Pulse generator')
set_param([sys,'/',['Pulses deivide',13,'same sample time']],...
          'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Pulses deivide',13,'same sample time']],...
                'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Pulses deivide',13,'same sample time']],...
                'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Pulses deivide',13,'same sample time']],...
            'Mask Entries','1\/[K_rs_demo*M_rs_demo, N_rs_demo, K_rs_demo]\/[0,0,0]\/')


%     Finished composite block ['Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Pulses deivide',13,'same sample time']],...
             'position',[30,56,90,94])

add_block('built-in/Note',[sys,'/','Recovered message'])
set_param([sys,'/','Recovered message'],...
            'ForeGround',2,...
              'position',[640,90,645,95])

add_block('built-in/Note',[sys,'/','Delayed message source'])
set_param([sys,'/','Delayed message source'],...
                'ForeGround',5,...
              'position',[630,65,635,70])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
             'inputs','3',...
                'position',[775,163,810,217])

add_block('built-in/Note',[sys,'/','Error detected in decoding'])
set_param([sys,'/','Error detected in decoding'],...
              'ForeGround',2,...
              'position',[675,145,680,150])

add_block('built-in/S-Function',[sys,'/',['White Guassian',13,'noise source']])
set_param([sys,'/',['White Guassian',13,'noise source']],...
                'ForeGround',3,...
              'function name','trigwksp',...
          'parameters','var,thd,cyclFlag',...
             'Mask Display','Triggered\nread',...
            'Mask Type','Read from workspace')
set_param([sys,'/',['White Guassian',13,'noise source']],...
          'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).')
set_param([sys,'/',['White Guassian',13,'noise source']],...
                'Mask Translate','var=@1;thd=@2;cyclFlag=@3;',...
               'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/',['White Guassian',13,'noise source']],...
         'Mask Entries','rand(1000,1)<GWN\/.1\/1\/',...
          'position',[245,190,310,230])

add_block('built-in/Note',[sys,'/','Grouping signal'])
set_param([sys,'/','Grouping signal'],...
            'position',[705,170,710,175])

add_block('built-in/Note',[sys,'/','Error placed'])
set_param([sys,'/','Error placed'],...
          'ForeGround',3,...
              'position',[715,190,720,195])


%     Subsystem  ['Binary sequence',13,'R-S encode'].

new_system([sys,'/',['Binary sequence',13,'R-S encode']])
set_param([sys,'/',['Binary sequence',13,'R-S encode']],'Location',[29,353,1012,554])
open_system([sys,'/',['Binary sequence',13,'R-S encode']])

add_block('built-in/Note',[sys,'/',['Binary sequence',13,'R-S encode/Input resources, Clock_pulses']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Input resources, Clock_pulses']],...
               'position',[110,165,115,170])


%     Subsystem  ['Binary sequence',13,'R-S encode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/out_1']],...
            'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/Relational',13,'Operator1']],...
           'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/Relational',13,'Operator2']],...
          'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/one1']],...
                'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/Memory1']],...
            'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/in_1']],...
         'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector/Relational',13,'Operator']],...
               'position',[135,18,165,42])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],...
           'Mask Display','Edge\nDetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],...
               'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','0.1\/')


%     Finished composite block ['Binary sequence',13,'R-S encode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary sequence',13,'R-S encode/Rising edge',13,'detector']],...
               'ForeGround',2,...
              'position',[470,56,520,84])


%     Subsystem  ['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode'].

new_system([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],'Location',[160,111,633,282])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/out_1']],...
             'position',[425,60,445,80])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/in_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/in_2']],...
                'Port','2',...
          'position',[20,110,40,130])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/in_1']],...
                'position',[30,25,50,45])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/Mux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/Mux']],...
               'inputs','[k, 1]',...
           'position',[90,51,125,84])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/S-function']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/S-function']],...
         'function name','simrscod',...
          'parameters','n, k, pg,tp,dim',...
              'position',[180,30,245,50])

add_block('built-in/Switch',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/Switch']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/Switch']],...
            'Threshold','0.5',...
           'position',[305,54,335,86])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/Memory']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode/Memory']],...
            'orientation',2,...
             'x0','zeros(1,n)',...
           'position',[305,105,345,135])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],[45,120;210,120;210,70;300,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],[70,120;70,75;85,75])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],[130,70;160,70;160,40;175,40])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],[55,35;70,35;70,60;85,60])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],[250,40;265,40;265,60;300,60])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],[300,120;265,120;265,80;300,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],[340,70;420,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],[370,70;370,120;350,120])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],...
              'Mask Display','R-S\nencode',...
                'Mask Type','Reed-Solomon encoding')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],...
          'Mask Dialogue','Code word N, message length K multi-burst-error-correction Reed-Solomon code.|Code length (N=2^M-1. M is a >2 integer):|Message length:')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],...
            'Mask Translate','n=@1;k=@2;if length(k)>1,pg=k;k=n-length(pg)-1;else,pg=rspoly(n,k);end;dim=3;p_dim=7;while p_dim<n,dim=dim+1;p_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],...
                'Mask Help','This block encodes the K-ary Integer message signal from the 1st inport into N-ary Integer code word using Reed-Solomon code. The input/output integers are in the range [0, N]. Code word length N=2^M-1, where M is a integer no less than 3. The message length K<N. The error-correction capability T=floor((N-K)/2). The outport outputs the last encoded vector until the 2nd inport signal is non-zero.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],...
         'Mask Entries','n\/k\/')


%     Finished composite block ['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode'].

set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S encode']],...
            'ForeGround',2,...
              'position',[545,40,605,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/out_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/out_1']],...
           'position',[945,60,965,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/out_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/out_2']],...
           'Port','2',...
          'position',[910,30,930,50])


%     Subsystem  ['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1'].

new_system([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/out_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/out_1']],...
            'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/out_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/out_2']],...
           'Port','2',...
          'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/Mux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/Mux']],...
          'inputs','[in_size 1 1]',...
            'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/Demux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/Demux']],...
            'outputs','[out_size 1]',...
            'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/S-function']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/S-function']],...
              'function name','regdown',...
           'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
         'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/in_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/in_1']],...
              'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/in_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/in_2']],...
                'Port','2',...
          'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/in_3']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1/in_3']],...
                'Port','3',...
          'position',[65,85,85,105])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],[240,80;285,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],[90,95;105,95])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],...
             'Mask Display','Triggered\nbuffer dn',...
               'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],...
            'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],...
               'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],...
              'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],...
              'Mask Entries','m\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1'].

set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down1']],...
                'ForeGround',6,...
              'position',[840,58,900,92])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'R-S encode/Integer to binary']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer to binary']],...
                'ForeGround',6,...
              'function name','simde2bi',...
          'parameters','len, p, rev',...
          'Mask Display','Sca to vec\nconverter')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer to binary']],...
            'Mask Type','Scalar integer  to vector converter')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer to binary']],...
         'Mask Dialogue','Positive decimal interger to binary converter.|Output vector length:|Output element base:|Normal ordered (0), or reverse ordered (1):')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer to binary']],...
           'Mask Translate','len=@1;p=@2;rev=@3;')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer to binary']],...
            'Mask Help','This block converts scaler positive decimal integer input to an arbitrary base integer  vector output with specified vector length and output element base. The first element of the output vector is the lowest binary bit. For example, for a length two binary output, y(1)=0, y(2)=1 means the input is 1; y(0)=1, y(2)=0 means the input is 2.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer to binary']],...
         'Mask Entries','m\/2\/0\/',...
          'position',[740,50,805,80])


%     Subsystem  ['Binary sequence',13,'R-S encode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/in_3']],...
            'Port','3',...
          'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/in_2']],...
         'Port','2',...
          'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/in_1']],...
          'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/S-function']],...
          'function name','regdown',...
           'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
         'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/Demux']],...
               'outputs','[out_size 1]',...
            'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/Mux']],...
             'inputs','[in_size 1 1]',...
            'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/out_2']],...
            'Port','2',...
          'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down/out_1']],...
            'position',[390,60,410,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],...
            'Mask Display','Triggered\nbuffer dn',...
               'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],...
             'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],...
                'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],...
               'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],...
               'Mask Entries','n\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary sequence',13,'R-S encode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary sequence',13,'R-S encode/Triggered',13,'buffer down']],...
          'ForeGround',6,...
              'position',[645,53,705,87])

add_block('built-in/Note',[sys,'/',['Binary sequence',13,'R-S encode/Buffer_dn, integer to binary conversion']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Buffer_dn, integer to binary conversion']],...
          'ForeGround',6,...
              'position',[780,5,785,10])

add_block('built-in/Note',[sys,'/',['Binary sequence',13,'R-S encode/Buffer_up, binary to integer conversion']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Buffer_up, binary to integer conversion']],...
           'ForeGround',3,...
              'position',[320,10,325,15])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/in_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/in_1']],...
              'position',[115,40,135,60])


%     Subsystem  ['Binary sequence',13,'R-S encode/Register-shift1'].

new_system([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],'Location',[237,587,592,717])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/in_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/in_2']],...
           'Port','2',...
          'position',[30,70,50,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/in_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/in_1']],...
                'position',[30,55,50,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/out_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/out_2']],...
             'Port','2',...
          'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/out_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/out_1']],...
           'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/Mux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/Mux']],...
           'inputs','2',...
                'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/S-function']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/S-function']],...
               'function name','regshift',...
          'parameters','shft_out, thrhld',...
             'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/Demux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1/Demux']],...
             'outputs','[len_rg, 1]',...
             'position',[260,55,300,90])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],[55,80;75,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],[120,75;145,75])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],...
            'Mask Display','Register\nshift',...
            'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],...
                'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],...
         'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],...
               'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],...
         'Mask Entries','[m:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'R-S encode/Register-shift1'].

set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift1']],...
          'ForeGround',3,...
              'position',[190,40,245,80])


%     Subsystem  ['Binary sequence',13,'R-S encode/Register-shift'].

new_system([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift/Demux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift/Demux']],...
               'outputs','[len_rg, 1]',...
             'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift/S-function']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift/S-function']],...
                'function name','regshift',...
          'parameters','shft_out, thrhld',...
             'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift/Mux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift/Mux']],...
             'inputs','2',...
                'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift/out_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift/out_1']],...
              'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift/out_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift/out_2']],...
             'Port','2',...
          'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift/in_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift/in_1']],...
                'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Register-shift/in_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift/in_2']],...
          'Port','2',...
          'position',[30,70,50,90])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],...
             'Mask Display','Register\nshift',...
            'Mask Type','Register-shift')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],...
         'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],...
          'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],...
                'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],...
          'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Binary sequence',13,'R-S encode/Register-shift'].

set_param([sys,'/',['Binary sequence',13,'R-S encode/Register-shift']],...
            'ForeGround',3,...
              'position',[380,40,435,80])


%     Subsystem  ['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time/S-function1']],...
         'function name','homopuls',...
          'parameters','samp_time, out_divid, offset',...
         'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time/Outport']],...
              'position',[160,35,180,55])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time']],...
         'Mask Display','Vector\nPulse',...
              'Mask Type','Pulse generator')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time']],...
          'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time']],...
                'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time']],...
                'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time']],...
            'Mask Entries','samp*k*m\/[k*m, k, 1, n, n*m]\/[0 0 0 0 0]\/')


%     Finished composite block ['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary sequence',13,'R-S encode/Pulses deivide',13,'same sample time']],...
          'position',[30,106,90,144])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'R-S encode/Demux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Demux']],...
             'outputs','5',...
               'position',[115,108,160,142])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'R-S encode/Binary to integer']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Binary to integer']],...
              'ForeGround',3,...
              'function name','simbi2de',...
          'parameters','p',...
            'Mask Display','Vec to sca\nconverter',...
              'Mask Type','Vectro to scalar converter')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Binary to integer']],...
          'Mask Dialogue','Positive integer vector to scalar decimal integer converter:|Input element base:',...
          'Mask Translate','p=@1;')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Binary to integer']],...
          'Mask Help','This block converts a binary vector to a scalar decimal integer. The block takes the first element input as the lowest binary bit. For example, if u(1)=1 and u(2)=0, the block outputs y=1; if u(1)=0 and u(2)=1, the block outputs y=2.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Binary to integer']],...
           'Mask Entries','2\/',...
                'position',[280,37,345,63])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/out_3']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/out_3']],...
           'Port','3',...
          'position',[905,155,925,175])

add_block('built-in/Note',[sys,'/',['Binary sequence',13,'R-S encode/Decoding process. Because it is computational expensive,',13,'calculate it only it is necessary']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Decoding process. Because it is computational expensive,',13,'calculate it only it is necessary']],...
                'ForeGround',2,...
              'position',[550,135,555,140])


%     Subsystem  ['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode'].

new_system([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],'Location',[143,192,726,352])

add_block('built-in/Memory',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/Memory']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/Memory']],...
          'orientation',2,...
             'x0','zeros(1,k+1)',...
         'position',[295,95,335,125])

add_block('built-in/Switch',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/Switch']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/Switch']],...
           'Threshold','0.5',...
           'position',[295,44,325,76])

add_block('built-in/S-Function',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/S-function']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/S-function']],...
                'function name','simrsdec',...
          'parameters','n, k, tp, dim',...
                'position',[170,20,235,40])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/Mux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/Mux']],...
             'inputs','[n, 1]',...
           'position',[80,41,115,74])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/in_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/in_1']],...
         'position',[20,15,40,35])

add_block('built-in/Inport',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/in_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/in_2']],...
          'Port','2',...
          'position',[10,100,30,120])

add_block('built-in/Demux',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/Demux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/Demux']],...
               'outputs','[k, 1]',...
          'position',[395,40,435,75])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/out_1']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/out_1']],...
             'position',[495,30,515,50])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/out_2']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode/out_2']],...
             'Port','2',...
          'position',[495,95,515,115])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],[330,60;390,60])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],[360,60;360,110;340,110])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],[440,65;455,65;455,105;490,105])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],...
             'Mask Display','R-S\ndecode',...
                'Mask Type','Reed-Solomon decode')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],...
            'Mask Dialogue','Code word length N, message length K, burst error-correction Reed-Solomon decode.|Code word length (N=2^M-1. M is a >2 integer):|Message length K < N:')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],...
             'Mask Translate','n=@1;k=@2;dim=3;p_d=7;while p_d<n,dim=dim+1;p_d=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],...
           'Mask Help','This block decodes N-ary integer code word from 1st inport into K-ary integer message sigusing at 1st ouport using Reed-Solomon method. M is an integer no less than 3. The input/output integers are in the range [0,N]. A non-zero second inport signal triggers the block to do decode process. The block outputs the last processed results when second inport signal is zero. The second outport outputs the error detected in the process. A negative output indicates more error than the capability.')
set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],...
           'Mask Entries','n\/k\/')


%     Finished composite block ['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode'].

set_param([sys,'/',['Binary sequence',13,'R-S encode/Integer-vector',13,'R-S decode']],...
            'ForeGround',2,...
              'position',[645,5,705,45])

add_block('built-in/Outport',[sys,'/',['Binary sequence',13,'R-S encode/out_4']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/out_4']],...
            'Port','4',...
          'position',[660,175,680,195])

add_block('built-in/Mux',[sys,'/',['Binary sequence',13,'R-S encode/Mux']])
set_param([sys,'/',['Binary sequence',13,'R-S encode/Mux']],...
         'inputs','[9,1]',...
            'position',[565,162,600,198])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[525,70;540,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[710,80;720,80;720,40;905,40])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[905,70;940,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[810,65;835,65])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[710,65;735,65])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[140,50;185,50])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[165,115;175,115;185,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[250,50;275,50])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[350,50;375,50])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[440,50;540,50])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[95,125;110,125])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[610,60;640,60])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[165,130;625,130;625,80;640,80])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[165,135;825,135;835,85])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[625,130;820,130;820,75;835,75])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[250,70;265,70;265,85;360,85;360,70;375,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[440,70;465,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[525,70;525,115;615,115;615,70;640,70])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[610,60;620,60;620,15;640,15])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[710,15;820,175;855,175;855,165;900,165])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[525,70;530,70;530,35;640,35])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[520,50;530,50;530,170;560,170])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[545,115;545,190;560,190])
add_line([sys,'/',['Binary sequence',13,'R-S encode']],[605,180;625,180;625,185;655,185])
set_param([sys,'/',['Binary sequence',13,'R-S encode']],...
           'Mask Display','R-S\nencode',...
                'Mask Type','Reed-Solomon encoding')
set_param([sys,'/',['Binary sequence',13,'R-S encode']],...
         'Mask Dialogue','Code word N, message length K multi-burst-error-correction Reed-Solomon code.|Code length (N=2^M-1. M is a >2 integer):|Message length:|Input message sample time:')
set_param([sys,'/',['Binary sequence',13,'R-S encode']],...
                'Mask Translate','n=@1;k=@2;samp=@3;m=3;p_m=7;while p_m<n,m=m+1;p_m=2^m-1;end;')
set_param([sys,'/',['Binary sequence',13,'R-S encode']],...
             'Mask Help','This block encodes the K-ary Integer message signal from the 1st inport into N-ary Integer code word using Reed-Solomon code. The input/output integers are in the range [0, N]. Code word length N=2^M-1, where M is a integer no less than 3. The message length K<N. The error-correction capability T=floor((N-K)/2). The outport outputs the last encoded vector until the 2nd inport signal is non-zero.')
set_param([sys,'/',['Binary sequence',13,'R-S encode']],...
                'Mask Entries','N_rs_demo\/K_rs_demo\/1/K_rs_demo/M_rs_demo\/')


%     Finished composite block ['Binary sequence',13,'R-S encode'].

set_param([sys,'/',['Binary sequence',13,'R-S encode']],...
           'position',[310,100,370,140])

add_block('built-in/Note',[sys,'/','The default set of this demo is N = N_rs_demo=15; K =K_rs_demo= 5; and M=M_rs_demo=4. We have 2^M-1=N..'])
set_param([sys,'/','The default set of this demo is N = N_rs_demo=15; K =K_rs_demo= 5; and M=M_rs_demo=4. We have 2^M-1=N..'],...
            'position',[425,285,430,290])

add_block('built-in/Note',[sys,'/','GWN is used to set the probability of errors in the transmitting.'])
set_param([sys,'/','GWN is used to set the probability of errors in the transmitting.'],...
                'position',[275,305,280,310])


%     Subsystem  ['Binary-sequence',13,'R-S decode'].

new_system([sys,'/',['Binary-sequence',13,'R-S decode']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode']],'Location',[19,534,999,718])
open_system([sys,'/',['Binary-sequence',13,'R-S decode']])

add_block('built-in/Note',[sys,'/',['Binary-sequence',13,'R-S decode/Input resources, Clock_pulses']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Input resources, Clock_pulses']],...
                'position',[105,155,110,160])

add_block('built-in/Note',[sys,'/',['Binary-sequence',13,'R-S decode/Decoding process. Because it is computational expensive,',13,'calculate it only it is necessary']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Decoding process. Because it is computational expensive,',13,'calculate it only it is necessary']],...
                'ForeGround',2,...
              'position',[555,125,560,130])

add_block('built-in/Note',[sys,'/',['Binary-sequence',13,'R-S decode/Buffer_dn, integer to binary conversion']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Buffer_dn, integer to binary conversion']],...
                'ForeGround',6,...
              'position',[755,5,760,10])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/out_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/out_2']],...
            'Port','2',...
          'position',[930,20,950,40])

add_block('built-in/Note',[sys,'/',['Binary-sequence',13,'R-S decode/Buffer_up, binary to integer conversion']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Buffer_up, binary to integer conversion']],...
          'ForeGround',3,...
              'position',[325,5,330,10])


%     Subsystem  ['Binary-sequence',13,'R-S decode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/Relational',13,'Operator']],...
             'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/in_1']],...
          'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/Memory1']],...
              'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/one1']],...
               'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/Relational',13,'Operator2']],...
           'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/Relational',13,'Operator1']],...
           'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector/out_1']],...
              'position',[340,25,360,45])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],...
           'Mask Display','Edge\nDetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],...
               'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','0.1\/')


%     Finished composite block ['Binary-sequence',13,'R-S decode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary-sequence',13,'R-S decode/Rising edge',13,'detector']],...
               'ForeGround',2,...
              'position',[480,51,530,79])


%     Subsystem  ['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1'].

new_system([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/in_3']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/in_3']],...
               'Port','3',...
          'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/in_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/in_2']],...
               'Port','2',...
          'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/in_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/in_1']],...
                'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/S-function']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/S-function']],...
                'function name','regdown',...
           'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
         'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/Demux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/Demux']],...
             'outputs','[out_size 1]',...
            'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/Mux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/Mux']],...
           'inputs','[in_size 1 1]',...
            'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/out_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/out_2']],...
          'Port','2',...
          'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/out_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1/out_1']],...
          'position',[390,60,410,80])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],[90,95;105,95])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],[335,90;350,90])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],[65,80;105,80])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],[335,70;385,70])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],[40,65;105,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],[145,80;180,80])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],[240,80;285,80])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],...
            'Mask Display','Triggered\nbuffer dn',...
               'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],...
            'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],...
               'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],...
              'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],...
              'Mask Entries','m\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1'].

set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down1']],...
                'ForeGround',6,...
              'position',[850,43,910,77])


%     Subsystem  ['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode'].

new_system([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],'Location',[143,192,726,352])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/out_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/out_2']],...
             'Port','2',...
          'position',[495,95,515,115])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/out_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/out_1']],...
            'position',[495,30,515,50])

add_block('built-in/Demux',[sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/Demux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/Demux']],...
               'outputs','[k, 1]',...
          'position',[395,40,435,75])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/in_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/in_2']],...
                'Port','2',...
          'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/in_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/in_1']],...
                'position',[20,15,40,35])

add_block('built-in/Mux',[sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/Mux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/Mux']],...
               'inputs','[n, 1]',...
           'position',[80,41,115,74])

add_block('built-in/S-Function',[sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/S-function']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/S-function']],...
         'function name','simrsdec',...
          'parameters','n, k, tp, dim',...
                'position',[170,20,235,40])

add_block('built-in/Switch',[sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/Switch']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/Switch']],...
            'Threshold','0.5',...
           'position',[295,44,325,76])

add_block('built-in/Memory',[sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/Memory']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode/Memory']],...
            'orientation',2,...
             'x0','zeros(1,k+1)',...
         'position',[295,95,335,125])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],[440,65;455,65;455,105;490,105])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],[330,60;390,60])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],[360,60;360,110;340,110])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],...
             'Mask Display','R-S\ndecode',...
                'Mask Type','Reed-Solomon decode')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],...
            'Mask Dialogue','Code word length N, message length K, burst error-correction Reed-Solomon decode.|Code word length (N=2^M-1. M is a >2 integer):|Message length K < N:')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],...
             'Mask Translate','n=@1;k=@2;dim=3;p_d=7;while p_d<n,dim=dim+1;p_d=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],...
           'Mask Help','This block decodes N-ary integer code word from 1st inport into K-ary integer message sigusing at 1st ouport using Reed-Solomon method. M is an integer no less than 3. The input/output integers are in the range [0,N]. A non-zero second inport signal triggers the block to do decode process. The block outputs the last processed results when second inport signal is zero. The second outport outputs the error detected in the process. A negative output indicates more error than the capability.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],...
           'Mask Entries','n\/k\/')


%     Finished composite block ['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode'].

set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer-vector',13,'R-S decode']],...
            'ForeGround',2,...
              'position',[550,35,610,75])


%     Subsystem  ['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time/Outport']],...
            'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time/S-function1']],...
          'function name','homopuls',...
          'parameters','samp_time, out_divid, offset',...
         'position',[40,31,105,59])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time']],...
          'Mask Display','Vector\nPulse',...
              'Mask Type','Pulse generator')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time']],...
          'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time']],...
                'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time']],...
                'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time']],...
            'Mask Entries','samp*k*m\/[n*m, n, 1 k, k*m]\/[0 0 0 0 0]\/')


%     Finished composite block ['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary-sequence',13,'R-S decode/Pulses deivide',13,'same sample time']],...
           'position',[30,91,90,129])

add_block('built-in/Demux',[sys,'/',['Binary-sequence',13,'R-S decode/Demux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Demux']],...
              'outputs','5',...
               'position',[115,93,160,127])


%     Subsystem  ['Binary-sequence',13,'R-S decode/Register-shift'].

new_system([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/in_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/in_2']],...
               'Port','2',...
          'position',[30,70,50,90])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/in_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/in_1']],...
          'position',[30,55,50,75])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/out_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/out_2']],...
               'Port','2',...
          'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/out_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/out_1']],...
             'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/Mux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/Mux']],...
             'inputs','2',...
                'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/S-function']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/S-function']],...
         'function name','regshift',...
          'parameters','shft_out, thrhld',...
             'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/Demux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift/Demux']],...
               'outputs','[len_rg, 1]',...
             'position',[260,55,300,90])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],[55,80;75,80])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],...
           'Mask Display','Register\nshift',...
            'Mask Type','Register-shift')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],...
         'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],...
          'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],...
                'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],...
          'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Binary-sequence',13,'R-S decode/Register-shift'].

set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift']],...
            'ForeGround',3,...
              'position',[395,35,450,75])

add_block('built-in/S-Function',[sys,'/',['Binary-sequence',13,'R-S decode/Binary to integer']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Binary to integer']],...
                'ForeGround',3,...
              'function name','simbi2de',...
          'parameters','p',...
            'Mask Display','Vec to sca\nconverter',...
              'Mask Type','Vectro to scalar converter')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Binary to integer']],...
          'Mask Dialogue','Positive integer vector to scalar decimal integer converter:|Input element base:',...
          'Mask Translate','p=@1;')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Binary to integer']],...
          'Mask Help','This block converts a binary vector to a scalar decimal integer. The block takes the first element input as the lowest binary bit. For example, if u(1)=1 and u(2)=0, the block outputs y=1; if u(1)=0 and u(2)=1, the block outputs y=2.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Binary to integer']],...
           'Mask Entries','2\/',...
                'position',[295,32,360,58])


%     Subsystem  ['Binary-sequence',13,'R-S decode/Register-shift1'].

new_system([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],'Location',[237,587,592,717])

add_block('built-in/Demux',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/Demux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/Demux']],...
          'outputs','[len_rg, 1]',...
             'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/S-function']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/S-function']],...
              'function name','regshift',...
          'parameters','shft_out, thrhld',...
             'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/Mux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/Mux']],...
           'inputs','2',...
                'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/out_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/out_1']],...
            'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/out_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/out_2']],...
           'Port','2',...
          'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/in_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/in_1']],...
              'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/in_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1/in_2']],...
                'Port','2',...
          'position',[30,70,50,90])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],[120,75;145,75])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],[205,75;255,75])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],[305,65;325,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],[305,80;325,80])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],[55,65;75,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],[55,80;75,80])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],...
              'Mask Display','Register\nshift',...
            'Mask Type','Register-shift')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],...
                'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],...
         'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],...
               'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],...
         'Mask Entries','[m:-1:1]\/.1\/')


%     Finished composite block ['Binary-sequence',13,'R-S decode/Register-shift1'].

set_param([sys,'/',['Binary-sequence',13,'R-S decode/Register-shift1']],...
          'ForeGround',3,...
              'position',[205,35,260,75])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/in_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/in_1']],...
              'position',[130,35,150,55])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/out_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/out_1']],...
           'position',[960,45,980,65])

add_block('built-in/S-Function',[sys,'/',['Binary-sequence',13,'R-S decode/Integer to binary']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer to binary']],...
                'ForeGround',6,...
              'function name','simde2bi',...
          'parameters','len, p, rev',...
          'Mask Display','Sca to vec\nconverter')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer to binary']],...
            'Mask Type','Scalar integer  to vector converter')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer to binary']],...
         'Mask Dialogue','Positive decimal interger to binary converter.|Output vector length:|Output element base:|Normal ordered (0), or reverse ordered (1):')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer to binary']],...
           'Mask Translate','len=@1;p=@2;rev=@3;')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer to binary']],...
            'Mask Help','This block converts scaler positive decimal integer input to an arbitrary base integer  vector output with specified vector length and output element base. The first element of the output vector is the lowest binary bit. For example, for a length two binary output, y(1)=0, y(2)=1 means the input is 1; y(0)=1, y(2)=0 means the input is 2.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Integer to binary']],...
         'Mask Entries','m\/2\/0\/',...
          'position',[750,35,815,65])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/out_3']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/out_3']],...
           'Port','3',...
          'position',[925,145,945,165])


%     Subsystem  ['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/out_1']],...
               'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/out_2']],...
             'Port','2',...
          'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/Mux']],...
            'inputs','[in_size 1 1]',...
            'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/Demux']],...
              'outputs','[out_size 1]',...
            'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/S-function']],...
                'function name','regdown',...
           'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
         'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/in_1']],...
                'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/in_2']],...
          'Port','2',...
          'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down/in_3']],...
          'Port','3',...
          'position',[65,85,85,105])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],...
             'Mask Display','Triggered\nbuffer dn',...
               'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],...
             'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],...
                'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],...
               'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],...
               'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary-sequence',13,'R-S decode/Triggered',13,'buffer down']],...
          'ForeGround',6,...
              'position',[655,38,715,72])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[535,65;545,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[615,65;620,65;620,30;925,30])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[615,45;650,45])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[95,110;110,110])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[455,45;545,45])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[365,45;390,45])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[265,45;290,45])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[165,100;175,100;175,65;200,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[155,45;200,45])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[720,50;745,50])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[820,50;845,50])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[915,55;955,55])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[165,115;635,115;635,65;650,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[635,115;820,115;820,60;845,60])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[165,120;825,120;825,70;845,70])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[265,65;275,65;275,90;375,90;375,65;390,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[455,65;475,65])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[535,65;535,105;630,105;630,55;650,55])
add_line([sys,'/',['Binary-sequence',13,'R-S decode']],[365,45;370,45;370,155;920,155])
set_param([sys,'/',['Binary-sequence',13,'R-S decode']],...
           'Mask Display','R-S\ndecode',...
                'Mask Type','Reed-Solomon decode')
set_param([sys,'/',['Binary-sequence',13,'R-S decode']],...
           'Mask Dialogue','Code word length N, message length K, burst error-correction Reed-Solomon decode.|Code word length (N=2^M-1. M is a >2 integer):|Message length K < N:|Input message sample time:')
set_param([sys,'/',['Binary-sequence',13,'R-S decode']],...
         'Mask Translate','n=@1;k=@2;samp=@3;m=3;p_d=7;while p_d<n,m=m+1;p_d=2^m-1;end;')
set_param([sys,'/',['Binary-sequence',13,'R-S decode']],...
             'Mask Help','This block decodes N-ary integer code word from 1st inport into K-ary integer message sigusing at 1st ouport using Reed-Solomon method. M is an integer no less than 3. The input/output integers are in the range [0,N]. A non-zero second inport signal triggers the block to do decode process. The block outputs the last processed results when second inport signal is zero. The second outport outputs the error detected in the process. A negative output indicates more error than the capability.')
set_param([sys,'/',['Binary-sequence',13,'R-S decode']],...
          'Mask Entries','N_rs_demo\/K_rs_demo\/1/K_rs_demo/M_rs_demo\/')


%     Finished composite block ['Binary-sequence',13,'R-S decode'].

set_param([sys,'/',['Binary-sequence',13,'R-S decode']],...
           'position',[510,100,570,140])


%     Subsystem  ['Graph',13,'comparing true value',13,'and err-correected value'].

new_system([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value']])
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value']],'Location',[186,363,460,556])

add_block('built-in/Inport',[sys,'/',['Graph',13,'comparing true value',13,'and err-correected value/x']])
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value/x']],...
         'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Graph',13,'comparing true value',13,'and err-correected value/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value/S-function',13,'M-file which plots',13,'lines',13,'']],...
          'function name','sfuny',...
             'parameters','ax, color,dt',...
         'position',[130,55,180,75])
add_line([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value']],[90,65;125,65])
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value']],...
                'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])')
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value']],...
          'Mask Type','Graph scope.')
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value']],...
            'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sampled time:')
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value']],...
              'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value']],...
         'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value']],...
               'Mask Entries','1\/-.2\/1.2\/''yo/r+/m-/w-/b+''\/1/M_rs_demo/K_rs_demo/2\/')


%     Finished composite block ['Graph',13,'comparing true value',13,'and err-correected value'].

set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value']],...
          'position',[825,81,855,119])


%     Subsystem  ['adding noise',13,'to the channel'].

new_system([sys,'/',['adding noise',13,'to the channel']])
set_param([sys,'/',['adding noise',13,'to the channel']],'Location',[400,108,703,228])

add_block('built-in/Outport',[sys,'/',['adding noise',13,'to the channel/out_1']])
set_param([sys,'/',['adding noise',13,'to the channel/out_1']],...
          'position',[240,50,260,70])

add_block('built-in/S-Function',[sys,'/',['adding noise',13,'to the channel/Modulus',13,'operation']])
set_param([sys,'/',['adding noise',13,'to the channel/Modulus',13,'operation']],...
            'function name','arymodu',...
           'parameters','md',...
           'Mask Display','Modulo',...
             'Mask Type','Modulo')
set_param([sys,'/',['adding noise',13,'to the channel/Modulus',13,'operation']],...
                'Mask Dialogue','Modulus operation:|Modulus base:',...
          'Mask Translate','md = @1;')
set_param([sys,'/',['adding noise',13,'to the channel/Modulus',13,'operation']],...
         'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['adding noise',13,'to the channel/Modulus',13,'operation']],...
                'Mask Entries','2\/',...
                'position',[150,41,210,79])

add_block('built-in/Sum',[sys,'/',['adding noise',13,'to the channel/Sum']])
set_param([sys,'/',['adding noise',13,'to the channel/Sum']],...
         'position',[100,50,120,70])

add_block('built-in/Inport',[sys,'/',['adding noise',13,'to the channel/in_1']])
set_param([sys,'/',['adding noise',13,'to the channel/in_1']],...
            'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/',['adding noise',13,'to the channel/in_2']])
set_param([sys,'/',['adding noise',13,'to the channel/in_2']],...
              'Port','2',...
          'position',[45,55,65,75])
add_line([sys,'/',['adding noise',13,'to the channel']],[125,60;145,60])
add_line([sys,'/',['adding noise',13,'to the channel']],[40,55;95,55])
add_line([sys,'/',['adding noise',13,'to the channel']],[215,60;235,60])
add_line([sys,'/',['adding noise',13,'to the channel']],[70,65;95,65])


%     Finished composite block ['adding noise',13,'to the channel'].

set_param([sys,'/',['adding noise',13,'to the channel']],...
           'position',[55,256,115,294])


%     Subsystem  'Number of errors'.

new_system([sys,'/','Number of errors'])
set_param([sys,'/','Number of errors'],'Location',[186,363,460,556])

add_block('built-in/S-Function',[sys,'/',['Number of errors/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Number of errors/S-function',13,'M-file which plots',13,'lines',13,'']],...
         'function name','sfuny',...
             'parameters','ax, color,dt',...
         'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Number of errors/x'])
set_param([sys,'/','Number of errors/x'],...
              'position',[65,55,85,75])
add_line([sys,'/','Number of errors'],[90,65;125,65])
set_param([sys,'/','Number of errors'],...
                'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
                'Mask Type','Graph scope.')
set_param([sys,'/','Number of errors'],...
           'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sampled time:')
set_param([sys,'/','Number of errors'],...
             'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/','Number of errors'],...
                'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Number of errors'],...
              'Mask Entries','1\/-.2\/2^4-.8\/''r+/w-/go/b*/yx/m-/c-/''\/1/N_rs_demo\/')


%     Finished composite block 'Number of errors'.

set_param([sys,'/','Number of errors'],...
          'position',[430,241,460,279])


%     Subsystem  ['Graph',13,'comparing true value',13,'and err-correected value1'].

new_system([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1']])
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1']],'Location',[186,363,460,556])

add_block('built-in/S-Function',[sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1/S-function',13,'M-file which plots',13,'lines',13,'']],...
            'function name','sfuny',...
             'parameters','ax, color,dt',...
         'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1/x']])
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1/x']],...
              'position',[65,55,85,75])
add_line([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1']],[90,65;125,65])
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1']],...
                'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])')
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1']],...
         'Mask Type','Graph scope.')
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1']],...
           'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':|Sampled time:')
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1']],...
             'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = @5;')
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1']],...
                'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1']],...
              'Mask Entries','1\/-.2\/2^4-.8\/''yo/r+/m-/w-/b+/cx/y*''\/1/K_rs_demo/2\/')


%     Finished composite block ['Graph',13,'comparing true value',13,'and err-correected value1'].

set_param([sys,'/',['Graph',13,'comparing true value',13,'and err-correected value1']],...
         'position',[510,231,540,269])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
             'inputs','2',...
                'position',[705,82,740,118])
add_line(sys,[575,105;700,110])
add_line(sys,[370,45;425,45;425,90;700,90])
add_line(sys,[745,100;820,100])
add_line(sys,[270,120;305,120])
add_line(sys,[575,120;585,120;585,170;770,170])
add_line(sys,[375,115;385,115;385,190;770,190])
add_line(sys,[315,210;770,210])
add_line(sys,[95,75;120,75])
add_line(sys,[170,65;305,65])
add_line(sys,[170,75;175,75;175,210;240,210])
add_line(sys,[185,65;195,120])
add_line(sys,[280,120;280,45;305,45])
add_line(sys,[375,105;435,105;435,120;505,120])
add_line(sys,[375,125;470,125;470,250;505,250])
add_line(sys,[375,135;410,135;410,260;425,260])

drawnow

% Return any arguments.
if (nargin | nargout)
      % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
else
 drawnow % Flash up the model and execute load callback
end
