function [ret,x0,str,ts,xts]=tsttcm(t,x,u,flag);
%TSTTCM	is the M-file description of the SIMULINK system named TSTTCM.
%	The block-diagram can be displayed by typing: TSTTCM.
%
%	SYS=TSTTCM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTTCM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTTCM with a FLAG of zero:
%	[SIZES]=TSTTCM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[244,194,1004,546])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '103')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Nonreal-time algorithm','None')
set_param(sys,'Nonreal-time max step size','.5')
set_param(sys,'Nonreal-time min step size','.5')
set_param(sys,'Nonreal-time stop time','103')
set_param(sys,'Nonreal-time build command','make_nrt OPTS=-Dinf=1.e100')
set_param(sys,'Nonreal-time save output history','off')
set_param(sys,'Nonreal-time save scope blocks','off')
set_param(sys,'Nonreal-time save time history','off')

add_block('built-in/S-Function',[sys,'/',['Triggered read',13,'from file']])
set_param([sys,'/',['Triggered read',13,'from file']],...
		'hide name',0,...
		'function name','sreadfil',...
		'parameters','filename,datatype,nump,numout,recursive,threshold',...
		'Mask Display','plot(0,0,100,100,x,y,v,w);  Rd file')
set_param([sys,'/',['Triggered read',13,'from file']],...
		'Mask Type','Read from file')
set_param([sys,'/',['Triggered read',13,'from file']],...
		'Mask Dialogue','The rising edge of the signal from the\n2nd port triggers the block to read the next row of the specified file.|File name (string, include extension):|Data type (''ascii'',''float'',''integer''):|Number of trigger pulse between saved data:|Output vector length:|Cyclic control (1: cyclic read, 0: output zeros after eof):|Threshold in detecting trigger signal:')
set_param([sys,'/',['Triggered read',13,'from file']],...
		'Mask Translate','filename=@1;datatype=@2;nump=@3;numout=@4;recursive=@5;threshold=@6;[x,y]=srcsicon(6);[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered read',13,'from file']],...
		'Mask Help','This block reads the data from a file. The output is refreshed at the rising edge of the input pulse. When the end of the file (eof) is reached, you can have the block output all zeros or start from the beginning of the file.')
set_param([sys,'/',['Triggered read',13,'from file']],...
		'Mask Entries','''test1.dat''\/''integer''\/0\/1\/0\/.3\/',...
		'position',[140,33,220,77])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector']])
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter',...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Entries','2\/2\/',...
		'position',[250,33,330,77])

add_block('built-in/Demux',[sys,'/','Demux1'])
set_param([sys,'/','Demux1'],...
		'hide name',0,...
		'outputs','2',...
		'position',[350,35,395,70])


%     Subsystem  ['Binary vector',13,'convol encode'].

new_system([sys,'/',['Binary vector',13,'convol encode']])
set_param([sys,'/',['Binary vector',13,'convol encode']],'Location',[268,346,980,597])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain3']])
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain3']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','D',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain3']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain3']],...
		'position',[250,6,275,34])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain']],...
		'orientation',2,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','A',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','a\/',...
		'position',[240,170,270,200])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol encode/in_1']])
set_param([sys,'/',['Binary vector',13,'convol encode/in_1']],...
		'position',[25,60,45,80])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','B',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain1']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','b\/')
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain1']],...
		'position',[100,56,125,84])

add_block('built-in/Sum',[sys,'/',['Binary vector',13,'convol encode/Sum']])
set_param([sys,'/',['Binary vector',13,'convol encode/Sum']],...
		'position',[155,65,175,85])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation1']],...
		'ForeGround',3,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation1']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation1']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation1']],...
		'Mask Entries','2\/',...
		'position',[345,70,390,100])

add_block('built-in/Sum',[sys,'/',['Binary vector',13,'convol encode/Sum1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Sum1']],...
		'position',[465,70,485,90])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation']])
set_param([sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation']],...
		'ForeGround',3,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'convol encode/Modulo',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[500,65,545,95])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'convol encode/Memory1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Memory1']],...
		'orientation',2,...
		'ForeGround',2,...
		'x0','zeros(1,n)',...
		'position',[610,135,650,165])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'convol encode/Switch1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Switch1']],...
		'Threshold','.1',...
		'position',[610,74,640,106])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convol encode/out_1']])
set_param([sys,'/',['Binary vector',13,'convol encode/out_1']],...
		'position',[690,80,710,100])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain2']])
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain2']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','C',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain2']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','c\/')
set_param([sys,'/',['Binary vector',13,'convol encode/Matrix',13,'Gain2']],...
		'position',[420,71,445,99])


%     Subsystem  ['Binary vector',13,'convol encode/Rising edge',13,'detector'].

new_system([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
		'Mask Entries','thd\/')


%     Finished composite block ['Binary vector',13,'convol encode/Rising edge',13,'detector'].

set_param([sys,'/',['Binary vector',13,'convol encode/Rising edge',13,'detector']],...
		'BackGround',5,...
		'position',[470,172,525,208])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol encode/in_2']])
set_param([sys,'/',['Binary vector',13,'convol encode/in_2']],...
		'Port','2',...
		'position',[420,180,440,200])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'convol encode/Memory']])
set_param([sys,'/',['Binary vector',13,'convol encode/Memory']],...
		'ForeGround',2,...
		'x0','zeros(n_st, 1)',...
		'position',[265,70,305,100])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'convol encode/Switch']])
set_param([sys,'/',['Binary vector',13,'convol encode/Switch']],...
		'Threshold','.1',...
		'position',[215,70,245,100])
add_line([sys,'/',['Binary vector',13,'convol encode']],[235,185;135,185;135,80;150,80])
add_line([sys,'/',['Binary vector',13,'convol encode']],[395,85;405,85;405,185;275,185])
add_line([sys,'/',['Binary vector',13,'convol encode']],[180,75;210,75])
add_line([sys,'/',['Binary vector',13,'convol encode']],[310,85;320,85;320,125;195,125;195,95;210,95])
add_line([sys,'/',['Binary vector',13,'convol encode']],[320,85;340,85])
add_line([sys,'/',['Binary vector',13,'convol encode']],[250,85;260,85])
add_line([sys,'/',['Binary vector',13,'convol encode']],[395,85;415,85])
add_line([sys,'/',['Binary vector',13,'convol encode']],[130,70;150,70])
add_line([sys,'/',['Binary vector',13,'convol encode']],[280,20;450,20;460,75])
add_line([sys,'/',['Binary vector',13,'convol encode']],[450,85;460,85])
add_line([sys,'/',['Binary vector',13,'convol encode']],[605,150;585,150;585,100;605,100])
add_line([sys,'/',['Binary vector',13,'convol encode']],[50,70;95,70])
add_line([sys,'/',['Binary vector',13,'convol encode']],[75,70;75,20;245,20])
add_line([sys,'/',['Binary vector',13,'convol encode']],[490,80;495,80])
add_line([sys,'/',['Binary vector',13,'convol encode']],[550,80;605,80])
add_line([sys,'/',['Binary vector',13,'convol encode']],[645,90;665,90;655,150])
add_line([sys,'/',['Binary vector',13,'convol encode']],[645,90;685,90])
add_line([sys,'/',['Binary vector',13,'convol encode']],[445,190;465,190])
add_line([sys,'/',['Binary vector',13,'convol encode']],[530,190;545,190;545,90;605,90])
add_line([sys,'/',['Binary vector',13,'convol encode']],[545,150;185,150;185,85;210,85])
set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl en',...
		'Mask Type','Vector I/O convolution encode')
set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'Mask Dialogue','Convolution encode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Trigger signal threshold:')
set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'Mask Translate','tf=@1;[a,b,c,d,n,k,n_st,m]=simviter(tf);thd=@2;[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using convolution code. The block refreshes its register memory and output at the rising edge of the second inport pulse. You can also use a SIMULINK block diagram to define the convolution code transfer function.')
set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'Mask Entries','''ungerboe''\/.5\/')


%     Finished composite block ['Binary vector',13,'convol encode'].

set_param([sys,'/',['Binary vector',13,'convol encode']],...
		'hide name',0,...
		'position',[425,48,505,92])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar1']])
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Entries','2\/',...
		'position',[600,43,680,87])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[540,46,575,79])


%     Subsystem  ['QASK',13,'circle-demap'].

new_system([sys,'/',['QASK',13,'circle-demap']])
set_param([sys,'/',['QASK',13,'circle-demap']],'Location',[96,182,645,417])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-demap/real']])
set_param([sys,'/',['QASK',13,'circle-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-demap/imag']])
set_param([sys,'/',['QASK',13,'circle-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'circle-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum1']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum6']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['QASK',13,'circle-demap/Product']])
set_param([sys,'/',['QASK',13,'circle-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['QASK',13,'circle-demap/Product1']])
set_param([sys,'/',['QASK',13,'circle-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['QASK',13,'circle-demap/Sum2']])
set_param([sys,'/',['QASK',13,'circle-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['QASK',13,'circle-demap/Minimum1']])
set_param([sys,'/',['QASK',13,'circle-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-demap/out_1']])
set_param([sys,'/',['QASK',13,'circle-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['QASK',13,'circle-demap/real_pt']])
set_param([sys,'/',['QASK',13,'circle-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['QASK',13,'circle-demap/imag_pt']])
set_param([sys,'/',['QASK',13,'circle-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['QASK',13,'circle-demap']],[70,45;115,45])
add_line([sys,'/',['QASK',13,'circle-demap']],[70,130;115,130])
add_line([sys,'/',['QASK',13,'circle-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['QASK',13,'circle-demap']],[160,45;225,45])
add_line([sys,'/',['QASK',13,'circle-demap']],[160,130;225,130])
add_line([sys,'/',['QASK',13,'circle-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['QASK',13,'circle-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['QASK',13,'circle-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['QASK',13,'circle-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['QASK',13,'circle-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['QASK',13,'circle-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['QASK',13,'circle-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['QASK',13,'circle-demap']],[395,95;410,95])
add_line([sys,'/',['QASK',13,'circle-demap']],[480,95;490,95])
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Display','QASK\nC-demap',...
		'Mask Type','QASK C-demap')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Number of symbols on each circle NIC::|Radii for each circle RIC:|Phase shift on each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y2=imag(y1);y1=real(y1);')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using circle constellation. You can place this block after a QAM demodulation block. The circle constellation is defined in NIC, RIC, and PIC. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero. Use function MODMAP to view the constellation.')
set_param([sys,'/',['QASK',13,'circle-demap']],...
		'Mask Entries','8\/1\/0\/1\/')


%     Finished composite block ['QASK',13,'circle-demap'].

set_param([sys,'/',['QASK',13,'circle-demap']],...
		'hide name',0,...
		'position',[540,128,620,172])


%     Subsystem  ['QADM',13,'baseband'].

new_system([sys,'/',['QADM',13,'baseband']])
set_param([sys,'/',['QADM',13,'baseband']],'Location',[283,122,827,462])

add_block('built-in/Inport',[sys,'/',['QADM',13,'baseband/in_1']])
set_param([sys,'/',['QADM',13,'baseband/in_1']],...
		'position',[55,115,75,135])

add_block('built-in/Constant',[sys,'/',['QADM',13,'baseband/Constant1']])
set_param([sys,'/',['QADM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Sum',[sys,'/',['QADM',13,'baseband/Sum1']])
set_param([sys,'/',['QADM',13,'baseband/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Outport',[sys,'/',['QADM',13,'baseband/out_2']])
set_param([sys,'/',['QADM',13,'baseband/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Filter',[sys,'/',['QADM',13,'baseband/Filter1']])
set_param([sys,'/',['QADM',13,'baseband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product1']])
set_param([sys,'/',['QADM',13,'baseband/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Demux',[sys,'/',['QADM',13,'baseband/Demux']])
set_param([sys,'/',['QADM',13,'baseband/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Constant',[sys,'/',['QADM',13,'baseband/Constant']])
set_param([sys,'/',['QADM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product2']])
set_param([sys,'/',['QADM',13,'baseband/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product3']])
set_param([sys,'/',['QADM',13,'baseband/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Sum',[sys,'/',['QADM',13,'baseband/Sum']])
set_param([sys,'/',['QADM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product']])
set_param([sys,'/',['QADM',13,'baseband/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Filter',[sys,'/',['QADM',13,'baseband/Filter']])
set_param([sys,'/',['QADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Note',[sys,'/',['QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Outport',[sys,'/',['QADM',13,'baseband/out_1']])
set_param([sys,'/',['QADM',13,'baseband/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['QADM',13,'baseband']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['QADM',13,'baseband']],[230,115;230,245;265,245])
add_line([sys,'/',['QADM',13,'baseband']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['QADM',13,'baseband']],[200,255;265,255])
add_line([sys,'/',['QADM',13,'baseband']],[165,130;255,130])
add_line([sys,'/',['QADM',13,'baseband']],[180,130;180,210;265,210])
add_line([sys,'/',['QADM',13,'baseband']],[180,50;255,50])
add_line([sys,'/',['QADM',13,'baseband']],[215,50;215,200;265,200])
add_line([sys,'/',['QADM',13,'baseband']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['QADM',13,'baseband']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['QADM',13,'baseband']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['QADM',13,'baseband']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['QADM',13,'baseband']],[80,125;115,125])
add_line([sys,'/',['QADM',13,'baseband']],[360,80;385,80])
add_line([sys,'/',['QADM',13,'baseband']],[450,80;475,80])
add_line([sys,'/',['QADM',13,'baseband']],[365,230;390,230])
add_line([sys,'/',['QADM',13,'baseband']],[455,230;480,230])
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Entries','1\/1\/0\/.01\/')


%     Finished composite block ['QADM',13,'baseband'].

set_param([sys,'/',['QADM',13,'baseband']],...
		'hide name',0,...
		'position',[440,128,520,172])


%     Subsystem  ['Rayleigh noise',13,'channel'].

new_system([sys,'/',['Rayleigh noise',13,'channel']])
set_param([sys,'/',['Rayleigh noise',13,'channel']],'Location',[496,318,758,464])

add_block('built-in/Inport',[sys,'/',['Rayleigh noise',13,'channel/in_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel/in_1']],...
		'position',[45,10,65,30])


%     Subsystem  ['Rayleigh noise',13,'channel/Gaussian',13,'noise'].

new_system([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']])
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']],'Location',[371,386,719,591])

add_block('built-in/White Noise',[sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/',...
		'position',[210,81,235,109])
add_line([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']],[240,95;290,95])
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['Rayleigh noise',13,'channel/Gaussian',13,'noise'].

set_param([sys,'/',['Rayleigh noise',13,'channel/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise',13,'channel/out_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel/out_1']],...
		'position',[200,55,220,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise',13,'channel/Sum']])
set_param([sys,'/',['Rayleigh noise',13,'channel/Sum']],...
		'position',[150,55,170,75])
add_line([sys,'/',['Rayleigh noise',13,'channel']],[175,65;195,65])
add_line([sys,'/',['Rayleigh noise',13,'channel']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['Rayleigh noise',13,'channel']],[90,70;145,70])
set_param([sys,'/',['Rayleigh noise',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rayl N',...
		'Mask Type','Rayleigh noise channel, fixed parameter')
set_param([sys,'/',['Rayleigh noise',13,'channel']],...
		'Mask Dialogue','Additive Rayleigh noise channel for\nbaseband signal simulation. Input\nand output signals are complex.|Covariance (std^2, scalar)):|Initial seeds (1x2 vector):')
set_param([sys,'/',['Rayleigh noise',13,'channel']],...
		'Mask Translate','m=0;d=@1;s=@2;if length(s)<2,s=[s s+s];end;[x,y]=chanicon;[v,w]=cmplxicn(0,50,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rayleigh noise',13,'channel']],...
		'Mask Help','This block adds Rayleigh noise to the transmit ting signal. The input and output of this block are complex data. The Rayleigh noise is a complex zero mean Gaussian noise. The complex zero mean Gaussian noise is composed of two independant Gaussian noise elements with same variance value.')
set_param([sys,'/',['Rayleigh noise',13,'channel']],...
		'Mask Entries','.01\/[12345 54321]\/')


%     Finished composite block ['Rayleigh noise',13,'channel'].

set_param([sys,'/',['Rayleigh noise',13,'channel']],...
		'hide name',0,...
		'position',[340,128,420,172])


%     Subsystem  ['QAM',13,'baseband'].

new_system([sys,'/',['QAM',13,'baseband']])
set_param([sys,'/',['QAM',13,'baseband']],'Location',[321,500,954,793])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/R1']])
set_param([sys,'/',['QAM',13,'baseband/R1']],...
		'position',[190,15,195,20])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product']])
set_param([sys,'/',['QAM',13,'baseband/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product1']])
set_param([sys,'/',['QAM',13,'baseband/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Sum',[sys,'/',['QAM',13,'baseband/Sum']])
set_param([sys,'/',['QAM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/R_out']])
set_param([sys,'/',['QAM',13,'baseband/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Mux',[sys,'/',['QAM',13,'baseband/RI2C']])
set_param([sys,'/',['QAM',13,'baseband/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex',...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['QAM',13,'baseband/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['QAM',13,'baseband/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Inport',[sys,'/',['QAM',13,'baseband/in_1']])
set_param([sys,'/',['QAM',13,'baseband/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Outport',[sys,'/',['QAM',13,'baseband/out_1']])
set_param([sys,'/',['QAM',13,'baseband/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Constant',[sys,'/',['QAM',13,'baseband/Constant']])
set_param([sys,'/',['QAM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Constant',[sys,'/',['QAM',13,'baseband/Constant1']])
set_param([sys,'/',['QAM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/I1']])
set_param([sys,'/',['QAM',13,'baseband/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Inport',[sys,'/',['QAM',13,'baseband/in_2']])
set_param([sys,'/',['QAM',13,'baseband/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/R2']])
set_param([sys,'/',['QAM',13,'baseband/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/I2']])
set_param([sys,'/',['QAM',13,'baseband/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product3']])
set_param([sys,'/',['QAM',13,'baseband/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product2']])
set_param([sys,'/',['QAM',13,'baseband/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Sum',[sys,'/',['QAM',13,'baseband/Sum1']])
set_param([sys,'/',['QAM',13,'baseband/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/I_out']])
set_param([sys,'/',['QAM',13,'baseband/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])
add_line([sys,'/',['QAM',13,'baseband']],[550,140;580,140])
add_line([sys,'/',['QAM',13,'baseband']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['QAM',13,'baseband']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['QAM',13,'baseband']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['QAM',13,'baseband']],[250,100;250,245;305,245])
add_line([sys,'/',['QAM',13,'baseband']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['QAM',13,'baseband']],[280,175;280,200;305,200])
add_line([sys,'/',['QAM',13,'baseband']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['QAM',13,'baseband']],[270,155;270,235;305,235])
add_line([sys,'/',['QAM',13,'baseband']],[120,40;295,40])
add_line([sys,'/',['QAM',13,'baseband']],[238,40;238,190;305,190])
add_line([sys,'/',['QAM',13,'baseband']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['QAM',13,'baseband']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['QAM',13,'baseband']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['QAM',13,'baseband']],[410,220;425,220;425,150;465,150])
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Entries','0\/')


%     Finished composite block ['QAM',13,'baseband'].

set_param([sys,'/',['QAM',13,'baseband']],...
		'hide name',0,...
		'position',[245,128,325,172])


%     Subsystem  ['QASK',13,'circle-map'].

new_system([sys,'/',['QASK',13,'circle-map']])
set_param([sys,'/',['QASK',13,'circle-map']],'Location',[58,103,403,268])

add_block('built-in/Zero-Order Hold',[sys,'/',['QASK',13,'circle-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['QASK',13,'circle-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])

add_block('built-in/Inport',[sys,'/',['QASK',13,'circle-map/in_1']])
set_param([sys,'/',['QASK',13,'circle-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'circle-map/real part']])
set_param([sys,'/',['QASK',13,'circle-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Look Up Table',[sys,'/',['QASK',13,'circle-map/imag part1']])
set_param([sys,'/',['QASK',13,'circle-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-map/Real']])
set_param([sys,'/',['QASK',13,'circle-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Outport',[sys,'/',['QASK',13,'circle-map/Imag']])
set_param([sys,'/',['QASK',13,'circle-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])
add_line([sys,'/',['QASK',13,'circle-map']],[50,30;75,30])
add_line([sys,'/',['QASK',13,'circle-map']],[120,30;175,30])
add_line([sys,'/',['QASK',13,'circle-map']],[145,30;145,110;170,110])
add_line([sys,'/',['QASK',13,'circle-map']],[220,30;270,30])
add_line([sys,'/',['QASK',13,'circle-map']],[215,110;270,110])
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Display','QASK\nC-map',...
		'Mask Type','QASK C-map')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Dialogue','QASK mapping with circle constellation. The constellation is defined in NIC, RIC and PIC.|Number of symbols in each circle NIC:|Radii in each circle RIC:|Phase shift in each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y1=[y1;y1];y1=y1(:);y2=imag(y1);y1=real(y1);x=[-sum(N) 1:sum(N)-1;1:sum(N)-1 10*sum(N)]-.5;x=x(:);')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The circle constellation is defined in NIC, RIC, and PIC. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/',['QASK',13,'circle-map']],...
		'Mask Entries','8\/1\/0\/1\/')


%     Finished composite block ['QASK',13,'circle-map'].

set_param([sys,'/',['QASK',13,'circle-map']],...
		'hide name',0,...
		'position',[150,128,230,172])


%     Subsystem  ['K-step',13,'delay'].

new_system([sys,'/',['K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay']],'Location',[12,432,357,702])

add_block('built-in/Digital Clock',[sys,'/',['K-step',13,'delay/Digital Clock']])
set_param([sys,'/',['K-step',13,'delay/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])

add_block('built-in/Inport',[sys,'/',['K-step',13,'delay/in_1']])
set_param([sys,'/',['K-step',13,'delay/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['K-step',13,'delay/out_1']])
set_param([sys,'/',['K-step',13,'delay/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Filter',[sys,'/',['K-step',13,'delay/K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Switch',[sys,'/',['K-step',13,'delay/Switch']])
set_param([sys,'/',['K-step',13,'delay/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant']])
set_param([sys,'/',['K-step',13,'delay/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay/Constant1']])
set_param([sys,'/',['K-step',13,'delay/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Relational Operator',[sys,'/',['K-step',13,'delay/Relational',13,'Operator']])
set_param([sys,'/',['K-step',13,'delay/Relational',13,'Operator']],...
		'position',[150,168,180,192])
add_line([sys,'/',['K-step',13,'delay']],[300,130;320,130])
add_line([sys,'/',['K-step',13,'delay']],[45,90;55,90])
add_line([sys,'/',['K-step',13,'delay']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['K-step',13,'delay']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['K-step',13,'delay']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['K-step',13,'delay']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['K-step',13,'delay']],[185,180;220,180;220,130;265,130])
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay',...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['K-step',13,'delay']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.',...
		'Mask Entries','3\/1\/0\/')


%     Finished composite block ['K-step',13,'delay'].

set_param([sys,'/',['K-step',13,'delay']],...
		'hide name',0,...
		'position',[370,198,450,242])


%     Subsystem  ['Pulses divide',13,'same sample time'].

new_system([sys,'/',['Pulses divide',13,'same sample time']])
set_param([sys,'/',['Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Entries','1\/1\/0\/')


%     Finished composite block ['Pulses divide',13,'same sample time'].

set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[20,288,100,332])


%     Subsystem  ['Triggered write',13,'to file'].

new_system([sys,'/',['Triggered write',13,'to file']])
set_param([sys,'/',['Triggered write',13,'to file']],'Location',[105,608,345,754])

add_block('built-in/S-Function',[sys,'/',['Triggered write',13,'to file/S-function']])
set_param([sys,'/',['Triggered write',13,'to file/S-function']],...
		'function name','swritfil',...
		'parameters','filename, datatype, nump, threshold',...
		'position',[135,70,185,90])

add_block('built-in/Mux',[sys,'/',['Triggered write',13,'to file/Mux']])
set_param([sys,'/',['Triggered write',13,'to file/Mux']],...
		'inputs','2',...
		'position',[65,61,100,94])

add_block('built-in/Inport',[sys,'/',['Triggered write',13,'to file/in_1']])
set_param([sys,'/',['Triggered write',13,'to file/in_1']],...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/',['Triggered write',13,'to file/in_2']])
set_param([sys,'/',['Triggered write',13,'to file/in_2']],...
		'Port','2',...
		'position',[15,75,35,95])
add_line([sys,'/',['Triggered write',13,'to file']],[105,80;130,80])
add_line([sys,'/',['Triggered write',13,'to file']],[40,70;60,70])
add_line([sys,'/',['Triggered write',13,'to file']],[40,85;60,85])
set_param([sys,'/',['Triggered write',13,'to file']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Wt file',...
		'Mask Type','Write to file')
set_param([sys,'/',['Triggered write',13,'to file']],...
		'Mask Dialogue','The rising edge of the signal from the\n2nd port triggers the block to write\nanother row into the specified file.|File name (string, include extension):|Data type (''ascii'', ''float'', ''integer''):|Number of trigger pulses between saved data:|Threshold in detecting trigger signal:')
set_param([sys,'/',['Triggered write',13,'to file']],...
		'Mask Translate','filename=@1;datatype=@2;nump=@3;threshold=@4;[x,y]=srcsicon(8);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Triggered write',13,'to file']],...
		'Mask Help','This block writes the data inputted from the first port to the next row of the specified file at the rising edge of the second input trigger pulse. The first pulse triggers to write the first record. You can specify the number of pulses between writting records. When you specify ASCII format, there is no return added between two records.')
set_param([sys,'/',['Triggered write',13,'to file']],...
		'Mask Entries','''test2.dat''\/''integer''\/0\/0.5\/')


%     Finished composite block ['Triggered write',13,'to file'].

set_param([sys,'/',['Triggered write',13,'to file']],...
		'hide name',0,...
		'position',[645,243,725,287])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'hide name',0,...
		'outputs','[1 2]',...
		'position',[280,235,325,270])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector1']])
set_param([sys,'/',['Integer scalar',13,'to vector1']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter',...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Integer scalar',13,'to vector1']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Integer scalar',13,'to vector1']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector1']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Integer scalar',13,'to vector1']],...
		'Mask Entries','3\/2\/',...
		'position',[185,233,265,277])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar']])
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Entries','2\/',...
		'position',[540,233,620,277])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[485,236,520,269])


%     Subsystem  ['K-step',13,'delay1'].

new_system([sys,'/',['K-step',13,'delay1']])
set_param([sys,'/',['K-step',13,'delay1']],'Location',[12,432,357,702])

add_block('built-in/Relational Operator',[sys,'/',['K-step',13,'delay1/Relational',13,'Operator']])
set_param([sys,'/',['K-step',13,'delay1/Relational',13,'Operator']],...
		'position',[150,168,180,192])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay1/Constant1']])
set_param([sys,'/',['K-step',13,'delay1/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Constant',[sys,'/',['K-step',13,'delay1/Constant']])
set_param([sys,'/',['K-step',13,'delay1/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Switch',[sys,'/',['K-step',13,'delay1/Switch']])
set_param([sys,'/',['K-step',13,'delay1/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Filter',[sys,'/',['K-step',13,'delay1/K-step',13,'delay']])
set_param([sys,'/',['K-step',13,'delay1/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Outport',[sys,'/',['K-step',13,'delay1/out_1']])
set_param([sys,'/',['K-step',13,'delay1/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Inport',[sys,'/',['K-step',13,'delay1/in_1']])
set_param([sys,'/',['K-step',13,'delay1/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Digital Clock',[sys,'/',['K-step',13,'delay1/Digital Clock']])
set_param([sys,'/',['K-step',13,'delay1/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])
add_line([sys,'/',['K-step',13,'delay1']],[185,180;220,180;220,130;265,130])
add_line([sys,'/',['K-step',13,'delay1']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['K-step',13,'delay1']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['K-step',13,'delay1']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['K-step',13,'delay1']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['K-step',13,'delay1']],[45,90;55,90])
add_line([sys,'/',['K-step',13,'delay1']],[300,130;320,130])
set_param([sys,'/',['K-step',13,'delay1']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay',...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['K-step',13,'delay1']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['K-step',13,'delay1']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.',...
		'Mask Entries','3*2\/1/2\/0\/')


%     Finished composite block ['K-step',13,'delay1'].

set_param([sys,'/',['K-step',13,'delay1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[475,288,555,332])


%     Subsystem  ['Binary vector',13,'convol decode1'].

new_system([sys,'/',['Binary vector',13,'convol decode1']])
set_param([sys,'/',['Binary vector',13,'convol decode1']],'Location',[719,297,1227,483])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol decode1/in_1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/in_1']],...
		'position',[65,35,85,55])


%     Subsystem  ['Binary vector',13,'convol decode1/Rising edge',13,'detector'].

new_system([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;',...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'Mask Entries','thd\/')


%     Finished composite block ['Binary vector',13,'convol decode1/Rising edge',13,'detector'].

set_param([sys,'/',['Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'position',[75,112,130,148])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'convol decode1/Mux']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Mux']],...
		'inputs','[tf(1,size(tf,2)), 1]',...
		'Mask Display','',...
		'position',[170,36,205,69])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'convol decode1/Modulo',13,'operation1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Modulo',13,'operation1']],...
		'function name','sviterbi',...
		'parameters','tf, leng, tran_prob, plot_flag,v1,v2,v3,v4',...
		'position',[235,40,280,70])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convol decode1/out_2']])
set_param([sys,'/',['Binary vector',13,'convol decode1/out_2']],...
		'Port','2',...
		'position',[445,65,465,85])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'convol decode1/out_1']])
set_param([sys,'/',['Binary vector',13,'convol decode1/out_1']],...
		'position',[405,35,425,55])

add_block('built-in/Demux',[sys,'/',['Binary vector',13,'convol decode1/Demux']])
set_param([sys,'/',['Binary vector',13,'convol decode1/Demux']],...
		'outputs','[tf(2,size(tf,2)), 1]',...
		'position',[305,35,345,70])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'convol decode1/in_2']])
set_param([sys,'/',['Binary vector',13,'convol decode1/in_2']],...
		'Port','2',...
		'position',[30,120,50,140])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[55,130;70,130])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[285,55;300,55])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[350,45;400,45])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[350,60;375,60;375,75;440,75])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[210,55;230,55])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[90,45;165,45])
add_line([sys,'/',['Binary vector',13,'convol decode1']],[135,130;140,130;140,60;165,60])
set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl de',...
		'Mask Type','Vector I/O convolution decode')
set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'Mask Dialogue','Convolution decode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Path memory length (delay=path_length*K*T_out):|Transfer probability (3 row matrix, 0 for hard decision):|Trellis figure plot length (0 for no plot):|Trigger signal threshold:')
set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'Mask Translate','gen=@1;leng=@2;tran_prob=@3;plot_flag=@4;thd=@5;[tf,v2,v3,v4,v5,v6,M,nss]=simviter(gen);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);v1=zeros(7,1);v2=zeros(nss,1);v3=zeros(nss^2*leng,1);v4=zeros(nss,1);tf=simviter(gen);')
set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'Mask Help','This block decodes length N binary vector convolution code codeword into length K binary vector message using Viterbi algorithm. The block refreshes its register memory and decoding output at the rising edge of the second inport pulse. The second outport outputs the metric value for soft decision or the accumulative distance for hard\ndecision.')
set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'Mask Entries','''ungerboe''\/3\/0\/0\/.5\/')


%     Finished composite block ['Binary vector',13,'convol decode1'].

set_param([sys,'/',['Binary vector',13,'convol decode1']],...
		'hide name',0,...
		'position',[370,248,450,292])
add_line(sys,[225,55;245,55])
add_line(sys,[685,65;695,65;695,110;130,110;130,150;145,150])
add_line(sys,[625,150;630,150;630,185;170,185;180,255])
add_line(sys,[235,140;240,140])
add_line(sys,[235,160;240,160])
add_line(sys,[525,140;535,140])
add_line(sys,[525,160;535,160])
add_line(sys,[330,150;335,150])
add_line(sys,[270,255;275,255])
add_line(sys,[335,55;345,55])
add_line(sys,[400,60;420,60])
add_line(sys,[510,70;535,70])
add_line(sys,[400,45;510,45;510,55;535,55])
add_line(sys,[580,65;595,65])
add_line(sys,[425,150;435,150])
add_line(sys,[330,260;365,260])
add_line(sys,[455,260;480,260])
add_line(sys,[330,245;345,245;345,220;365,220])
add_line(sys,[455,220;470,220;480,245])
add_line(sys,[525,255;535,255])
add_line(sys,[625,255;640,255])
add_line(sys,[105,310;120,310;120,80;420,80])
add_line(sys,[120,80;120,55;135,55])
add_line(sys,[120,310;355,310;365,280])
add_line(sys,[355,310;470,310])
add_line(sys,[560,310;625,310;625,275;640,275])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
