function [ret,x0,str,ts,xts]=tsttdma(t,x,u,flag);
%TSTTDMA	is the M-file description of the SIMULINK system named TSTTDMA.
%	The block-diagram can be displayed by typing: TSTTDMA.
%
%	SYS=TSTTDMA(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TSTTDMA to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TSTTDMA with a FLAG of zero:
%	[SIZES]=TSTTDMA([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[23,76,666,320])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[125,83,160,117])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator1']])
set_param([sys,'/',['Signal',13,'generator1']],...
		'ForeGround',4,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','2.000000',...
		'Freq','3.000000',...
		'Freq Range','5.000000',...
		'Wave','Saw',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator1']],...
		'position',[40,83,85,117])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'ForeGround',2,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','2.000000',...
		'Freq','2.000000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator']],...
		'position',[40,18,85,52])


%     Subsystem  ['Digital-TDMA',13,'demux'].

new_system([sys,'/',['Digital-TDMA',13,'demux']])
set_param([sys,'/',['Digital-TDMA',13,'demux']],'Location',[7,777,413,924])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'demux/in_1']])
set_param([sys,'/',['Digital-TDMA',13,'demux/in_1']],...
		'position',[60,20,80,40])


%     Subsystem  ['Digital-TDMA',13,'demux/Register-shift'].

new_system([sys,'/',['Digital-TDMA',13,'demux/Register-shift']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Demux',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/Demux']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/S-function']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/Mux']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/out_1']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/out_2']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/in_1']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'demux/Register-shift/in_2']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],[55,80;75,80])
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'Mask Entries','[N:-1:1]\/.1\/')


%     Finished composite block ['Digital-TDMA',13,'demux/Register-shift'].

set_param([sys,'/',['Digital-TDMA',13,'demux/Register-shift']],...
		'position',[150,18,225,62])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'demux/out_1']])
set_param([sys,'/',['Digital-TDMA',13,'demux/out_1']],...
		'position',[335,20,355,40])


%     Subsystem  ['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'Mask Entries','td\/N\/0\/')


%     Finished composite block ['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Digital-TDMA',13,'demux/Pulses deivide',13,'same sample time']],...
		'position',[35,86,100,124])

add_block('built-in/Zero-Order Hold',[sys,'/',['Digital-TDMA',13,'demux/Zero-Order',13,'Hold']])
set_param([sys,'/',['Digital-TDMA',13,'demux/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[255,14,290,46])
add_line([sys,'/',['Digital-TDMA',13,'demux']],[85,30;145,30])
add_line([sys,'/',['Digital-TDMA',13,'demux']],[105,105;120,105;120,50;145,50])
add_line([sys,'/',['Digital-TDMA',13,'demux']],[230,30;250,30])
add_line([sys,'/',['Digital-TDMA',13,'demux']],[295,30;330,30])
set_param([sys,'/',['Digital-TDMA',13,'demux']],...
		'Mask Display','D-TDMA\ndemux',...
		'Mask Type','Reverse digital TDMA')
set_param([sys,'/',['Digital-TDMA',13,'demux']],...
		'Mask Dialogue','Input a scalar digital signal. Output a vector of a down-sampled digital signal.|Output symbol sample time (sec):|Output vector length:',...
		'Mask Translate','td=@1;N=@2;')
set_param([sys,'/',['Digital-TDMA',13,'demux']],...
		'Mask Help','This block inputs a scalar signal and outputs a down-sampled vector signal. The output sample time is T_out and vector length is N_out. The sample time for the input signal is T_out/N_out. For the input signal, a T_out time period is partitioned into N_out sections evenly in the time domain. Each element in the output vector outputs one of the partitioned sections.')
set_param([sys,'/',['Digital-TDMA',13,'demux']],...
		'Mask Entries','.1\/3\/')


%     Finished composite block ['Digital-TDMA',13,'demux'].

set_param([sys,'/',['Digital-TDMA',13,'demux']],...
		'hide name',0,...
		'position',[315,78,395,122])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'hide name',0,...
		'outputs','3',...
		'position',[430,82,470,118])


%     Subsystem  ['Digital-TDMA',13,'mux'].

new_system([sys,'/',['Digital-TDMA',13,'mux']])
set_param([sys,'/',['Digital-TDMA',13,'mux']],'Location',[7,588,411,722])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'mux/in_1']])
set_param([sys,'/',['Digital-TDMA',13,'mux/in_1']],...
		'position',[115,20,135,40])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'mux/out_1']])
set_param([sys,'/',['Digital-TDMA',13,'mux/out_1']],...
		'position',[310,55,330,75])


%     Subsystem  ['Digital-TDMA',13,'mux/Triggered',13,'buffer down'].

new_system([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'Mask Entries','N\/0\/1\/.1\/0\/')


%     Finished composite block ['Digital-TDMA',13,'mux/Triggered',13,'buffer down'].

set_param([sys,'/',['Digital-TDMA',13,'mux/Triggered',13,'buffer down']],...
		'position',[215,53,275,97])

add_block('built-in/Demux',[sys,'/',['Digital-TDMA',13,'mux/Demux']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Demux']],...
		'outputs','2',...
		'position',[130,65,180,100])


%     Subsystem  ['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'Mask Entries','td\/[1 N]\/[0 0]\/')


%     Finished composite block ['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Digital-TDMA',13,'mux/Pulses deivide',13,'same sample time']],...
		'position',[35,66,100,104])
add_line([sys,'/',['Digital-TDMA',13,'mux']],[185,90;210,90])
add_line([sys,'/',['Digital-TDMA',13,'mux']],[185,75;210,75])
add_line([sys,'/',['Digital-TDMA',13,'mux']],[105,85;125,85])
add_line([sys,'/',['Digital-TDMA',13,'mux']],[280,65;305,65])
add_line([sys,'/',['Digital-TDMA',13,'mux']],[140,30;190,30;190,60;210,60])
set_param([sys,'/',['Digital-TDMA',13,'mux']],...
		'Mask Display','D-TDMA\nmux',...
		'Mask Type','Digital TDMA')
set_param([sys,'/',['Digital-TDMA',13,'mux']],...
		'Mask Dialogue','Input a vector digital signal. Output a scalar up-sampled digital signal.|Input symbol sample time (sec):|Input vector length:',...
		'Mask Translate','td=@1;N=@2;')
set_param([sys,'/',['Digital-TDMA',13,'mux']],...
		'Mask Help','This block inputs a length N_in vector input signal with sample time T_in. The output of this block is a vector with sample time T_in/N_in. For the output signal, a T_in time period is partitioned into N_in even time length sections. Each section contains the value of one element of the input vector. This block takes all elements from the input vector at the start point of the sample time.')
set_param([sys,'/',['Digital-TDMA',13,'mux']],...
		'Mask Entries','.1\/3\/')


%     Finished composite block ['Digital-TDMA',13,'mux'].

set_param([sys,'/',['Digital-TDMA',13,'mux']],...
		'hide name',0,...
		'position',[180,78,260,122])

add_block('built-in/Scope',[sys,'/','multiplex signal'])
set_param([sys,'/','multiplex signal'],...
		'Vgain','1.000000',...
		'Hgain','5.000000',...
		'Vmax','2.000000',...
		'Hmax','10.000000',...
		'Window',[682,52,1004,334])
open_system([sys,'/','multiplex signal'])
set_param([sys,'/','multiplex signal'],...
		'position',[350,127,370,153])

add_block('built-in/Scope',[sys,'/','element 3'])
set_param([sys,'/','element 3'],...
		'Vgain','1.000000',...
		'Hgain','5.000000',...
		'Vmax','2.000000',...
		'Hmax','10.000000',...
		'Window',[666,343,988,625])
open_system([sys,'/','element 3'])
set_param([sys,'/','element 3'],...
		'position',[585,157,605,183])

add_block('built-in/Mux',[sys,'/','Mux3'])
set_param([sys,'/','Mux3'],...
		'hide name',0,...
		'inputs','2',...
		'position',[520,151,555,184])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator2']])
set_param([sys,'/',['Signal',13,'generator2']],...
		'ForeGround',6,...
		'hide name',0,...
		'Peak','1.000000',...
		'Peak Range','2.000000',...
		'Freq','5.000000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'generator2']],...
		'position',[40,158,85,192])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[520,26,555,59])

add_block('built-in/Scope',[sys,'/','element 1'])
set_param([sys,'/','element 1'],...
		'Vgain','1.000000',...
		'Hgain','5.000000',...
		'Vmax','2.000000',...
		'Hmax','10.000000',...
		'Window',[21,344,343,627])
open_system([sys,'/','element 1'])
set_param([sys,'/','element 1'],...
		'position',[585,32,605,58])

add_block('built-in/Scope',[sys,'/','element 2'])
set_param([sys,'/','element 2'],...
		'Vgain','1.000000',...
		'Hgain','5.000000',...
		'Vmax','2.000000',...
		'Hmax','10.000000',...
		'Window',[342,343,664,626])
open_system([sys,'/','element 2'])
set_param([sys,'/','element 2'],...
		'position',[585,82,605,108])

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'hide name',0,...
		'inputs','2',...
		'position',[520,76,555,109])
add_line(sys,[90,100;120,100])
add_line(sys,[165,100;175,100])
add_line(sys,[265,100;310,100])
add_line(sys,[400,100;425,100])
add_line(sys,[560,45;580,45])
add_line(sys,[475,90;480,90;480,50;515,50])
add_line(sys,[90,35;515,35])
add_line(sys,[560,95;580,95])
add_line(sys,[475,100;515,100])
add_line(sys,[100,100;100,70;495,70;495,85;515,85])
add_line(sys,[560,170;580,170])
add_line(sys,[475,110;480,110;480,160;515,160])
add_line(sys,[90,175;515,175])
add_line(sys,[285,100;285,140;345,140])
add_line(sys,[110,35;120,90])
add_line(sys,[110,175;110,110;120,110])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
