function [ret,x0,str,ts,xts]=tutbchsq(t,x,u,flag);
%TUTBCHSQ	is the M-file description of the SIMULINK system named TUTBCHSQ.
%	TUTBCHSQ has a the following characteristics:
%		0 continuous states
%		17 discrete states
%		0 outputs
%		0 inputs
%		does not have direct feedthrough
%		5 sample times
%
%	The block-diagram can be displayed by typing: TUTBCHSQ.
%
%	SYS=TUTBCHSQ(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TUTBCHSQ to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TUTBCHSQ with a FLAG of zero:
%	[SIZES]=TUTBCHSQ([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[-8,81,591,234])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Sampled read'.

new_system([sys,'/','Sampled read'])
set_param([sys,'/','Sampled read'],'Location',[355,528,737,675])

add_block('built-in/S-Function',[sys,'/','Sampled read/Message source'])
set_param([sys,'/','Sampled read/Message source'],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;',...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.')
set_param([sys,'/','Sampled read/Message source'],...
		'Mask Entries','var\/.1\/cyc\/ini\/',...
		'position',[180,53,255,97])

add_block('built-in/Outport',[sys,'/','Sampled read/out_1'])
set_param([sys,'/','Sampled read/out_1'],...
		'position',[295,65,315,85])


%     Subsystem  ['Sampled read/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])
add_line([sys,'/','Sampled read'],[115,75;175,75])
add_line([sys,'/','Sampled read'],[260,75;290,75])
set_param([sys,'/','Sampled read'],...
		'Mask Display','Sampled\nread\nvariable',...
		'Mask Type','Read from variable')
set_param([sys,'/','Sampled read'],...
		'Mask Dialogue','Read from a workspace variable at given interval.|Variable (column_number=block_output_length):|Output symbol interval:|Cyclic read (1) or amend zero (0):|Initial output:')
set_param([sys,'/','Sampled read'],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;')
set_param([sys,'/','Sampled read'],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable row, the block will cyclically output from the first row of the the variable or output zero based on the cyclic read entree.')
set_param([sys,'/','Sampled read'],...
		'Mask Entries','randint(1000,1,2)\/1/5\/1\/0\/')


%     Finished composite block 'Sampled read'.

set_param([sys,'/','Sampled read'],...
		'hide name',0,...
		'position',[25,53,100,97])


%     Subsystem  ['Binary-sequential',13,'BCH encode1'].

new_system([sys,'/',['Binary-sequential',13,'BCH encode1']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1']],'Location',[248,302,892,459])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH encode1/out_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/out_2']],...
		'Port','2',...
		'position',[535,45,555,65])


%     Subsystem  ['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Mux',[sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Demux',[sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/S-Function',[sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],[240,80;285,80])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],[90,95;105,95])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],...
		'Mask Entries','n\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[445,28,505,62])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH encode1/out_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/out_1']],...
		'position',[575,30,595,50])

add_block('built-in/Demux',[sys,'/',['Binary-sequential',13,'BCH encode1/Demux']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Demux']],...
		'outputs','2',...
		'position',[140,80,180,115])


%     Subsystem  ['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[k, n]\/[0 0]\/')


%     Finished composite block ['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[45,81,105,119])


%     Subsystem  ['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode'].

new_system([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/out_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Dialogue','Modulus operation:|Modulus base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/in_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']],[245,45;285,45])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']],[140,45;175,45])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']],[55,45;105,45])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']],...
		'Mask Display','BCH\nencode',...
		'Mask Type','BCH encoding')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']],...
		'Mask Dialogue','Code word N, message length K multi-error-correction BCH code.|Code length (N=2^M-1. M is a >2 integer):|Message length (check BCHPOLY for valid number):')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']],...
		'Mask Translate','n=@1; k=@2; pg = bchpoly(n,k);[h,G]=cyclgen(n,pg); G=G'';')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']],...
		'Mask Help','This block encodes the K-ary binary message signal into N-ary binary code word using BCH code. Use MATLAB command BCHPOLY to view the valid code-word length N and message length K combination.')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']],...
		'Mask Entries','n\/k\/')


%     Finished composite block ['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode'].

set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Binary-vector',13,'BCH encode']],...
		'BackGround',5,...
		'position',[340,15,400,55])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH encode1/in_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/in_1']],...
		'position',[55,25,75,45])


%     Subsystem  ['Binary-sequential',13,'BCH encode1/Register-shift'].

new_system([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],'Location',[237,587,592,717])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/in_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/in_2']],...
		'Port','2',...
		'position',[30,70,50,90])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/in_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/in_1']],...
		'position',[30,55,50,75])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/out_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/out_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Mux',[sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/Mux']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/S-Function',[sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/S-function']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Demux',[sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/Demux']])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],[55,80;75,80])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],[55,65;75,65])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],[120,75;145,75])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],...
		'Mask Entries','[k:-1:1]\/.1\/')


%     Finished composite block ['Binary-sequential',13,'BCH encode1/Register-shift'].

set_param([sys,'/',['Binary-sequential',13,'BCH encode1/Register-shift']],...
		'BackGround',3,...
		'position',[230,26,285,59])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1']],[510,55;530,55])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1']],[510,40;570,40])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1']],[405,35;440,35])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1']],[290,35;335,35])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1']],[80,35;225,35])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1']],[290,50;305,50;305,85;410,85;410,45;440,45])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1']],[110,100;135,100])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1']],[185,90;195,90;195,50;225,50])
add_line([sys,'/',['Binary-sequential',13,'BCH encode1']],[185,105;420,105;420,55;440,55])
set_param([sys,'/',['Binary-sequential',13,'BCH encode1']],...
		'Mask Display','BCH\nencode',...
		'Mask Type','BCH binary sequential encoding')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1']],...
		'Mask Dialogue','Code word N, message length K multi-error-correction BCH code.|Code length (N=2^M-1. M is a >2 integer):|Message length (check BCHPOLY for valid number):|Input sample time:')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1']],...
		'Mask Translate','n=@1; k=@2;samp=@3;')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1']],...
		'Mask Help','This block encodes the K-ary binary message signal into N-ary binary code word using BCH code. Use MATLAB command BCHPOLY to view the valid code-word length N and message length K combination.')
set_param([sys,'/',['Binary-sequential',13,'BCH encode1']],...
		'Mask Entries','15\/5\/1/5\/')


%     Finished composite block ['Binary-sequential',13,'BCH encode1'].

set_param([sys,'/',['Binary-sequential',13,'BCH encode1']],...
		'hide name',0,...
		'position',[145,57,210,93])


%     Subsystem  'Binary Error'.

new_system([sys,'/','Binary Error'])
set_param([sys,'/','Binary Error'],'Location',[154,494,633,699])

add_block('built-in/Outport',[sys,'/','Binary Error/out_2'])
set_param([sys,'/','Binary Error/out_2'],...
		'Port','2',...
		'position',[275,125,295,145])

add_block('built-in/Saturation',[sys,'/','Binary Error/Saturation'])
set_param([sys,'/','Binary Error/Saturation'],...
		'Lower Limit','0',...
		'Upper Limit','M-1',...
		'position',[165,70,190,90])

add_block('built-in/S-Function',[sys,'/',['Binary Error/Modulo',13,'operation']])
set_param([sys,'/',['Binary Error/Modulo',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulo operation:|Modulo base:')
set_param([sys,'/',['Binary Error/Modulo',13,'operation']],...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary Error/Modulo',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary Error/Modulo',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[300,56,360,94])

add_block('built-in/Sum',[sys,'/','Binary Error/Sum'])
set_param([sys,'/','Binary Error/Sum'],...
		'position',[235,65,255,85])

add_block('built-in/Outport',[sys,'/','Binary Error/out_1'])
set_param([sys,'/','Binary Error/out_1'],...
		'position',[390,65,410,85])


%     Subsystem  ['Binary Error/Poisson',13,'noise'].

new_system([sys,'/',['Binary Error/Poisson',13,'noise']])
set_param([sys,'/',['Binary Error/Poisson',13,'noise']],'Location',[391,74,676,237])

add_block('built-in/Outport',[sys,'/',['Binary Error/Poisson',13,'noise/out_1']])
set_param([sys,'/',['Binary Error/Poisson',13,'noise/out_1']],...
		'position',[165,65,185,85])

add_block('built-in/S-Function',[sys,'/',['Binary Error/Poisson',13,'noise/Poisson distribution',13,'number']])
set_param([sys,'/',['Binary Error/Poisson',13,'noise/Poisson distribution',13,'number']],...
		'function name','srandpoi',...
		'parameters','seed,lambda',...
		'position',[65,55,135,95])
add_line([sys,'/',['Binary Error/Poisson',13,'noise']],[140,75;160,75])
set_param([sys,'/',['Binary Error/Poisson',13,'noise']],...
		'Mask Display','Poison\nrand int',...
		'Mask Type','Poisson distribution noise.',...
		'Mask Dialogue','Poisson distribution number generator.|Lambda:|Seed:')
set_param([sys,'/',['Binary Error/Poisson',13,'noise']],...
		'Mask Translate','seed=@2;lambda=@1;')
set_param([sys,'/',['Binary Error/Poisson',13,'noise']],...
		'Mask Help','The output of this block is poisson distributed integers. The output size is the same as the vector size for seed. Please use function disttool to see the distribution of the outputof this block.')
set_param([sys,'/',['Binary Error/Poisson',13,'noise']],...
		'Mask Entries','P\/(randint(1, M)+100)*1000*max(P)\/')


%     Finished composite block ['Binary Error/Poisson',13,'noise'].

set_param([sys,'/',['Binary Error/Poisson',13,'noise']],...
		'position',[40,94,115,136])

add_block('built-in/Inport',[sys,'/','Binary Error/in_1'])
set_param([sys,'/','Binary Error/in_1'],...
		'position',[95,30,115,50])
add_line([sys,'/','Binary Error'],[195,80;230,80])
add_line([sys,'/','Binary Error'],[210,80;210,135;270,135])
add_line([sys,'/','Binary Error'],[260,75;295,75])
add_line([sys,'/','Binary Error'],[120,115;140,115;140,80;160,80])
add_line([sys,'/','Binary Error'],[120,40;210,40;210,70;230,70])
add_line([sys,'/','Binary Error'],[365,75;385,75])
set_param([sys,'/','Binary Error'],...
		'Mask Display','Binary err\nchannel',...
		'Mask Type','Add binary errors')
set_param([sys,'/','Binary Error'],...
		'Mask Dialogue','The error probability can be a scalar or a vector with length the same as the input vector length.|Error probability:|Input vector length:')
set_param([sys,'/','Binary Error'],...
		'Mask Translate','M=@2;P=@1;if length(P)~=M, P=ones(1,M)*P(1); end;')
set_param([sys,'/','Binary Error'],...
		'Mask Help','This block is designed for adding errors into a transmitted binary signals. The error rate for the transmitted signal is provided in the input parameter. The first output port outputs the transmitted signal. The second port outputs the added error signal.')
set_param([sys,'/','Binary Error'],...
		'Mask Entries','0.05\/1\/')


%     Finished composite block 'Binary Error'.

set_param([sys,'/','Binary Error'],...
		'hide name',0,...
		'position',[260,59,330,101])


%     Subsystem  ['Binary-sequential',13,'BCH decode1'].

new_system([sys,'/',['Binary-sequential',13,'BCH decode1']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1']],'Location',[298,166,908,319])

add_block('built-in/Demux',[sys,'/',['Binary-sequential',13,'BCH decode1/Demux']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Demux']],...
		'outputs','2',...
		'position',[110,80,150,115])


%     Subsystem  ['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time'].

new_system([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time/S-function1']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time/Outport']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider):')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time']],...
		'Mask Entries','samp*k\/[n, k]\/[0 0]\/')


%     Finished composite block ['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time'].

set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Pulses deivide',13,'same sample time']],...
		'ForeGround',2,...
		'position',[25,81,85,119])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH decode1/sequential',13,'message-out']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/sequential',13,'message-out']],...
		'position',[560,30,580,50])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH decode1/sequential',13,'code-word-in']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/sequential',13,'code-word-in']],...
		'position',[100,25,120,45])


%     Subsystem  ['Binary-sequential',13,'BCH decode1/Register-shift'].

new_system([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],'Location',[19,610,374,740])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/in_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/in_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/in_1']],...
		'position',[10,55,30,75])

add_block('built-in/Demux',[sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/Demux']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/Demux']],...
		'outputs','[len_rg, 1]',...
		'position',[260,55,300,90])

add_block('built-in/S-Function',[sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/S-function']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/S-function']],...
		'function name','regshift',...
		'parameters','shft_out, thrhld',...
		'position',[150,65,200,85])

add_block('built-in/Mux',[sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/Mux']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/Mux']],...
		'inputs','2',...
		'position',[80,56,115,89])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/out_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/out_1']],...
		'position',[330,55,350,75])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/out_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift/out_2']],...
		'Port','2',...
		'position',[330,70,350,90])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],[120,75;145,75])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],[205,75;255,75])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],[305,65;325,65])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],[305,80;325,80])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],[35,65;75,65])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],[65,80;75,80])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],...
		'Mask Display','Register\nshift',...
		'Mask Type','Register-shift')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],...
		'Mask Dialogue','Store and shift the input from 1st port by raising edge of the pulse from second port.|Vector specify ouput delay length(non-negative integer):|Threshold for the pulse signal from the 2nd port:')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],...
		'Mask Translate','shft_out=@1; thrhld=@2; len_rg=length(@1);')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],...
		'Mask Help','This block store the 1st inport signal at the raising edge of 2nd inport pulse. The 1st outport outputs a vector with its size same as the the size of the 1st entree of this block. The maximum delay is the register size of this block. The second outport output a positive pulse at the begining of entire register refreshment.')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],...
		'Mask Entries','[n:-1:1]\/.1\/')


%     Finished composite block ['Binary-sequential',13,'BCH decode1/Register-shift'].

set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Register-shift']],...
		'BackGround',3,...
		'position',[185,25,240,65])


%     Subsystem  ['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode'].

new_system([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],'Location',[157,499,740,659])

add_block('built-in/Memory',[sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/Memory']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,k+1)',...
		'position',[295,95,335,125])

add_block('built-in/Switch',[sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/Switch']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/Switch']],...
		'Threshold','0.5',...
		'position',[295,44,325,76])

add_block('built-in/S-Function',[sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/S-function']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/S-function']],...
		'function name','simbchdc',...
		'parameters','n, k, t,tp,dim',...
		'position',[170,20,235,40])

add_block('built-in/Mux',[sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/Mux']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/Mux']],...
		'inputs','[n, 1]',...
		'position',[80,41,115,74])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/in_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/in_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Demux',[sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/Demux']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/Demux']],...
		'outputs','[k, 1]',...
		'position',[395,40,435,75])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/out_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/out_1']],...
		'position',[495,30,515,50])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/out_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode/out_2']],...
		'Port','2',...
		'position',[495,95,515,115])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],[330,60;390,60])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],[360,60;360,110;340,110])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],[440,65;455,65;455,105;490,105])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],...
		'Mask Display','BCH\ndecode',...
		'Mask Type','BCH decode')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],...
		'Mask Dialogue','Code word length N, message length K, T error-correction BCH decode.|Code word length (N=2^M-1. M is a >2 integer):|Message length:|Error-correction capability (0 for unknown):')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],...
		'Mask Translate','n=@1;k=@2;t=@3;if t<=0, [x1,x2,x3,x4,t]=bchpoly(n,k);end;dim=3;pow_dim=7;while pow_dim<n,dim=dim+1;pow_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],...
		'Mask Help','This block decodes N-ary binary code word from 1st inport into K-ary message sigusing at 1st ouport using BCH method. Use MATLAB command BCHPLOY to view the valid code word length N, message length K and error-correction capability T. A non-zero second inport signal triggers the block to do decode process. The block outputs the last processed results when second inport signal is zero. The second outport outputs the error detected in the process. A negative output indicates more error than the capability.')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],...
		'Mask Entries','n\/k\/t\/')


%     Finished composite block ['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode'].

set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Binary-vector',13,'BCH decode']],...
		'BackGround',5,...
		'position',[285,25,345,65])


%     Subsystem  ['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down'].

new_system([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],'Location',[306,291,744,461])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/in_3']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/in_3']],...
		'Port','3',...
		'position',[65,85,85,105])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/in_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/in_2']],...
		'Port','2',...
		'position',[40,70,60,90])

add_block('built-in/Inport',[sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/in_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/S-Function',[sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/S-function']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/S-function']],...
		'function name','regdown',...
		'parameters','ini_idx, idx_inc, thrshld, cycl_flag',...
		'position',[185,70,235,90])

add_block('built-in/Demux',[sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/Demux']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/Demux']],...
		'outputs','[out_size 1]',...
		'position',[290,62,330,98])

add_block('built-in/Mux',[sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/Mux']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/Mux']],...
		'inputs','[in_size 1 1]',...
		'position',[110,59,140,101])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/out_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/out_2']],...
		'Port','2',...
		'position',[355,80,375,100])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/out_1']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down/out_1']],...
		'position',[390,60,410,80])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],[90,95;105,95])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],[335,90;350,90])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],[65,80;105,80])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],[335,70;385,70])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],[40,65;105,65])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],[145,80;180,80])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],[240,80;285,80])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],...
		'Mask Display','Triggered\nbuffer dn',...
		'Mask Type','Triggered buffer down.')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],...
		'Mask Dialogue','Triggered buffer down.|Input signal vector size:|Initial index (integer vector):|Increament for each index (integer vector):|Trigger threshold:|When index exceed register size, 1 for cyclic ouput, 0 for zero output:')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],...
		'Mask Translate','in_size=@1; ini_idx=@2; idx_inc=@3; thrshld=@4; cycl_flag=@5; out_size=length(ini_idx);')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],...
		'Mask Help','The register inside this block take the signal vector at the 1st inport by the raising edge of the second inport. The fisrt outport outputs a signal vector at the raising edge of the third inport.')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],...
		'Mask Entries','k\/0\/1\/.1\/0\/')


%     Finished composite block ['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down'].

set_param([sys,'/',['Binary-sequential',13,'BCH decode1/Triggered',13,'buffer down']],...
		'BackGround',3,...
		'position',[445,28,505,72])

add_block('built-in/Outport',[sys,'/',['Binary-sequential',13,'BCH decode1/out_2']])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1/out_2']],...
		'Port','2',...
		'position',[370,45,390,65])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1']],[155,90;160,90;160,55;180,55])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1']],[245,55;280,55])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1']],[260,55;260,100;415,100;415,50;440,50])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1']],[245,35;280,35])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1']],[350,55;365,55])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1']],[350,35;440,35])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1']],[125,35;180,35])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1']],[90,100;105,100])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1']],[510,40;555,40])
add_line([sys,'/',['Binary-sequential',13,'BCH decode1']],[155,105;425,105;425,65;440,65])
set_param([sys,'/',['Binary-sequential',13,'BCH decode1']],...
		'Mask Display','BCH\ndecode',...
		'Mask Type','BCH binary sequencial decode')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1']],...
		'Mask Dialogue','Code word length N, message length K, T error-correction BCH decode.|Code word length (N=2^M-1. M is a >2 integer):|Message length:|Error-correction capability (0 for unknown):|Output sample time:')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1']],...
		'Mask Translate','n=@1;k=@2;t=@3;samp=@4;')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1']],...
		'Mask Help','This block decodes N-ary binary code word from 1st inport into K-ary message sigusing at 1st ouport using BCH method. Use MATLAB command BCHPLOY to view the valid code word length N, message length K and error-correction capability T. A non-zero second inport signal triggers the block to do decode process. The block outputs the last processed results when second inport signal is zero. The second outport outputs the error detected in the process. A negative output indicates more error than the capability.')
set_param([sys,'/',['Binary-sequential',13,'BCH decode1']],...
		'Mask Entries','15\/5\/3\/1/5\/')


%     Finished composite block ['Binary-sequential',13,'BCH decode1'].

set_param([sys,'/',['Binary-sequential',13,'BCH decode1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[385,60,445,100])


%     Subsystem  'Error rate'.

new_system([sys,'/','Error rate'])
set_param([sys,'/','Error rate'],'Location',[255,368,509,510])

add_block('built-in/Inport',[sys,'/','Error rate/in_2'])
set_param([sys,'/','Error rate/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Inport',[sys,'/','Error rate/in_1'])
set_param([sys,'/','Error rate/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Error rate/Mux'])
set_param([sys,'/','Error rate/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/S-Function',[sys,'/','Error rate/S-function'])
set_param([sys,'/','Error rate/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])
add_line([sys,'/','Error rate'],[40,70;60,70])
add_line([sys,'/','Error rate'],[40,55;60,55])
add_line([sys,'/','Error rate'],[105,65;125,65])
set_param([sys,'/','Error rate'],...
		'Mask Display','Error Rate\nMeter',...
		'Mask Type','Symbol/Bit Error Counter.')
set_param([sys,'/','Error rate'],...
		'Mask Dialogue','Compare 2nd port input to scalar 1st port input. Compute the error rate.|Bit per symbol:|Number of digit on display:|Delay between input (1st port) and output (2nd port):|Sampling time (second):')
set_param([sys,'/','Error rate'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate'],...
		'Mask Help','The signal from the first port should be always be a scalar. The 2nd port input signal can be a vector with a same time delay to the input signal.',...
		'Mask Entries','1\/0\/2\/1/5\/')


%     Finished composite block 'Error rate'.

set_param([sys,'/','Error rate'],...
		'hide name',0,...
		'position',[495,58,570,102])
add_line(sys,[335,70;355,70;355,80;380,80])
add_line(sys,[215,65;230,65;230,80;255,80])
add_line(sys,[105,75;140,75])
add_line(sys,[450,70;465,70;465,90;490,90])
add_line(sys,[115,75;115,40;475,40;475,70;490,70])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
