function [ret,x0,str,ts,xts]=tutcdwmo(t,x,u,flag);
%TUTCDWMO	is the M-file description of the SIMULINK system named TUTCDWMO.
%	The block-diagram can be displayed by typing: TUTCDWMO.
%
%	SYS=TUTCDWMO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TUTCDWMO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TUTCDWMO with a FLAG of zero:
%	[SIZES]=TUTCDWMO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[15,69,1006,244])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Sampled read',13,'from wksp'].

new_system([sys,'/',['Sampled read',13,'from wksp']])
set_param([sys,'/',['Sampled read',13,'from wksp']],'Location',[355,528,737,675])


%     Subsystem  ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

new_system([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],'Location',[55,192,283,286])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1/Outport']],...
		'position',[160,35,180,55])
add_line([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],[110,45;155,45])
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Display','Vector\nPulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time ./Divider. |Sample time (scalar, sec):|Divider (integer vector):|Offset (have same dimension as Divider:')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Help','This block generator a vector pulses. The output length is the same as the vector defined in "Divider". The ith element of the output has the sample time Sample_time/Divider(i). All elements in "Divider" must be integers.')
set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'Mask Entries','ts\/1\/off\/')


%     Finished composite block ['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1'].

set_param([sys,'/',['Sampled read',13,'from wksp/Pulses deivide',13,'same sample time1']],...
		'position',[50,56,110,94])

add_block('built-in/Outport',[sys,'/',['Sampled read',13,'from wksp/out_1']])
set_param([sys,'/',['Sampled read',13,'from wksp/out_1']],...
		'position',[295,65,315,85])

add_block('built-in/S-Function',[sys,'/',['Sampled read',13,'from wksp/Message source']])
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'BackGround',5,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','Triggered\nread',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Dialogue','The raising edge of input pulse trigger the block output the next row from the workspace variable.|Read the variable:|Threshold for the input pulse:|Cyclic read variable (1) or amend zeros (0).|Output before first trigger:')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the raising edge of the input pulse.',...
		'Mask Entries','var\/.1\/cyc\/ini\/')
set_param([sys,'/',['Sampled read',13,'from wksp/Message source']],...
		'position',[180,53,255,97])
add_line([sys,'/',['Sampled read',13,'from wksp']],[260,75;290,75])
add_line([sys,'/',['Sampled read',13,'from wksp']],[115,75;175,75])
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Display','plot(0,0,100,100,x,y);Rd wksp',...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Dialogue','Read from a workspace variable at\nsampling time point.|Variable (column_number=block_output_length):|Data output sample time (sec):|Cyclic control (1: cyclic read, 0: output zeros after eof).|Initial output:')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Translate','var=@1;td=@2;ts=td(1);if (length(td)>=2),off=td(2);else off=0;end;cyc=@3;ini=@4;[x,y]=srcsicon(7);')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Help','This block reads from a workspace variable at a given sample time. The column number is the block output vector length. When the simulation reached the end of the variable (eof) row, the block will cyclically output from the first row of the variable or output zeros based on the cyclic control entree.')
set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'Mask Entries','de2bi([0:15, 0:2:15, 1:2:15, randint(1, 60, 16)])\/.01\/1\/0\/')


%     Finished composite block ['Sampled read',13,'from wksp'].

set_param([sys,'/',['Sampled read',13,'from wksp']],...
		'hide name',0,...
		'position',[10,63,90,107])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar1']])
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar1']],...
		'Mask Entries','2\/',...
		'position',[710,13,790,57])


%     Subsystem  ['Binary vector',13,'BCH encode'].

new_system([sys,'/',['Binary vector',13,'BCH encode']])
set_param([sys,'/',['Binary vector',13,'BCH encode']],'Location',[235,592,599,711])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'BCH encode/out_1']])
set_param([sys,'/',['Binary vector',13,'BCH encode/out_1']],...
		'position',[290,35,310,55])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'BCH encode/Modulus',13,'operation']])
set_param([sys,'/',['Binary vector',13,'BCH encode/Modulus',13,'operation']],...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo',...
		'Mask Dialogue','Modulus operation:|Modulus base:')
set_param([sys,'/',['Binary vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Binary vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Help','This block output modulus operation of the input signal with module base as specified in block entry. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Binary vector',13,'BCH encode/Modulus',13,'operation']],...
		'Mask Entries','2\/',...
		'position',[180,26,240,64])

add_block('built-in/State-Space',[sys,'/',['Binary vector',13,'BCH encode/Matrix',13,'Gain']])
set_param([sys,'/',['Binary vector',13,'BCH encode/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Binary vector',13,'BCH encode/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','G\/')
set_param([sys,'/',['Binary vector',13,'BCH encode/Matrix',13,'Gain']],...
		'position',[110,31,135,59])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'BCH encode/in_1']])
set_param([sys,'/',['Binary vector',13,'BCH encode/in_1']],...
		'position',[30,35,50,55])
add_line([sys,'/',['Binary vector',13,'BCH encode']],[245,45;285,45])
add_line([sys,'/',['Binary vector',13,'BCH encode']],[140,45;175,45])
add_line([sys,'/',['Binary vector',13,'BCH encode']],[55,45;105,45])
set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'Mask Display','plot(0,0,100,100,x,y);BCH en',...
		'Mask Type','Vector I/O BCH encode')
set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'Mask Dialogue','BCH encode with input message vector\nlength K and output codeword vector length\nN. (N, K) must be a valid BCH code pair.|Codeword length N (N=2^M-1. M is a >2 integer):|Message length K (check BCHPOLY for valid K):')
set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'Mask Translate','n=@1;k=@2;pg = bchpoly(n,k);[h,G]=cyclgen(n,pg);G=G'';[x,y]=codeicon(1);')
set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using BCH code. Use function BCHPOLY to view the valid N, K, and error-corr ection capability T combination.')
set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'Mask Entries','7\/4\/')


%     Finished composite block ['Binary vector',13,'BCH encode'].

set_param([sys,'/',['Binary vector',13,'BCH encode']],...
		'hide name',0,...
		'position',[105,63,185,107])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar']])
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar']],...
		'Mask Entries','2\/',...
		'position',[200,63,280,107])


%     Subsystem  ['Square-map',13,'QASK mod1'].

new_system([sys,'/',['Square-map',13,'QASK mod1']])
set_param([sys,'/',['Square-map',13,'QASK mod1']],'Location',[623,526,913,666])


%     Subsystem  ['Square-map',13,'QASK mod1/QAM',13,'passband'].

new_system([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],'Location',[302,478,834,743])

add_block('built-in/Fcn',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Fcn']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[230,55,325,85])

add_block('built-in/Fcn',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Fcn1']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[230,105,325,135])

add_block('built-in/Note',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[250,305,255,310])

add_block('built-in/Product',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Product']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Product']],...
		'position',[355,47,380,78])

add_block('built-in/Product',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Product1']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Product1']],...
		'position',[355,112,380,143])

add_block('built-in/Sum',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Sum2']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Sum2']],...
		'position',[430,90,450,110])

add_block('built-in/Outport',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/out_1']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/out_1']],...
		'position',[490,90,510,110])

add_block('built-in/Inport',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/in_1']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/in_1']],...
		'position',[160,30,180,50])

add_block('built-in/Inport',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/in_2']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/in_2']],...
		'Port','2',...
		'position',[160,145,180,165])

add_block('built-in/Gain',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Gain']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[130,76,180,114])

add_block('built-in/Clock',[sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Clock']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband/Clock']],...
		'position',[80,85,100,105])
add_line([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],[455,100;485,100])
add_line([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],[330,70;350,70])
add_line([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],[185,40;335,40;335,55;350,55])
add_line([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],[330,120;350,120])
add_line([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],[185,155;330,155;330,135;350,135])
add_line([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],[385,130;400,130;400,105;425,105])
add_line([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],[105,95;125,95])
add_line([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],[185,95;200,95;200,70;225,70])
add_line([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],[200,95;200,120;225,120])
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);QAM',...
		'Mask Type','Passband DSB-SC QAM')
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],...
		'Mask Dialogue','Modulate the in-phase signal from first input port and quadrature signal from\nthe second port using QAM.|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;Ph=@2;ts=@3;[x,y]=moduicon(1);')
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],...
		'Mask Help','This block modulates the in-phase component inputted from the first port and the quadrature component inputted from the second port by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],...
		'Mask Entries','Fc\/Ph\/ts\/')


%     Finished composite block ['Square-map',13,'QASK mod1/QAM',13,'passband'].

set_param([sys,'/',['Square-map',13,'QASK mod1/QAM',13,'passband']],...
		'ForeGround',4,...
		'position',[165,53,245,97])


%     Subsystem  ['Square-map',13,'QASK mod1/QASK',13,'square-map'].

new_system([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],'Location',[214,372,642,541])

add_block('built-in/Look Up Table',[sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/c-y axis']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/c-y axis']],...
		'Input_Values','z',...
		'Output_Values','y',...
		'position',[245,90,280,120])

add_block('built-in/Outport',[sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/out_2']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/out_2']],...
		'Port','2',...
		'position',[325,95,345,115])

add_block('built-in/Look Up Table',[sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/s-x axis']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/s-x axis']],...
		'Input_Values','z',...
		'Output_Values','x',...
		'position',[245,25,280,55])

add_block('built-in/Outport',[sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/out_1']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/out_1']],...
		'position',[325,30,345,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/Zero-Order',13,'Hold']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[110,24,145,56])

add_block('built-in/Inport',[sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/in_1']])
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map/in_1']],...
		'position',[45,30,65,50])
add_line([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],[70,40;105,40])
add_line([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],[150,40;240,40])
add_line([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],[185,40;185,105;240,105])
add_line([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],[285,105;320,105])
add_line([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],[285,40;320,40])
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],...
		'Mask Display','QASK\nS-map',...
		'Mask Type','QASK S-map')
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],...
		'Mask Dialogue','Use square constellation to map the\ninput digital signal into in-phase and\nquadrature components. M must be\nM=2^K with integer K.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],...
		'Mask Translate','N=@1;Ac=1;td=@2;z=[[1:N];[1:N]];z=z(:);[x,y]=qaskenco(z-1,N);z=z-1.5;z=[z(2:2*N);N-.5];x=x/max(x);y=y/max(y);')
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The M-ary number must be M=2^K with integer K. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. The maximum amplitudes for the outputs are 1.')
set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['Square-map',13,'QASK mod1/QASK',13,'square-map'].

set_param([sys,'/',['Square-map',13,'QASK mod1/QASK',13,'square-map']],...
		'position',[50,53,130,97])

add_block('built-in/Outport',[sys,'/',['Square-map',13,'QASK mod1/out_1']])
set_param([sys,'/',['Square-map',13,'QASK mod1/out_1']],...
		'position',[275,65,295,85])

add_block('built-in/Inport',[sys,'/',['Square-map',13,'QASK mod1/in_1']])
set_param([sys,'/',['Square-map',13,'QASK mod1/in_1']],...
		'position',[5,65,20,85])
add_line([sys,'/',['Square-map',13,'QASK mod1']],[135,65;160,65])
add_line([sys,'/',['Square-map',13,'QASK mod1']],[135,85;160,85])
add_line([sys,'/',['Square-map',13,'QASK mod1']],[250,75;270,75])
add_line([sys,'/',['Square-map',13,'QASK mod1']],[25,75;45,75])
set_param([sys,'/',['Square-map',13,'QASK mod1']],...
		'Mask Display','plot(0,0,100,100,x,y);S-QASK',...
		'Mask Type','Passband S-QASK modulation')
set_param([sys,'/',['Square-map',13,'QASK mod1']],...
		'Mask Dialogue','Modulate the input signal using\nquadrature amplitude shift keying\nmodulation method with square constellation.|M-ary number (input digits in range [0, M-1]):|Symbol interval (sec):|Carrier frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Square-map',13,'QASK mod1']],...
		'Mask Translate','M=@1;td=@2;Fc=@3;Ph=@4;ts=@5;[x,y]=moduicon(5);')
set_param([sys,'/',['Square-map',13,'QASK mod1']],...
		'Mask Help','This block modulates a digital signal using QASK method with square constellation. The inputs are integers in the range [0, M-1], where M is the M-ary number, which is M=2^K. K is an integer. When the symbol interval is a two element vector, the second element is the offset (default 0). ')
set_param([sys,'/',['Square-map',13,'QASK mod1']],...
		'Mask Entries','128\/.01\/1000\/0\/.0002\/')


%     Finished composite block ['Square-map',13,'QASK mod1'].

set_param([sys,'/',['Square-map',13,'QASK mod1']],...
		'hide name',0,...
		'position',[295,63,375,107])


%     Subsystem  ['AWGN',13,'channel'].

new_system([sys,'/',['AWGN',13,'channel']])
set_param([sys,'/',['AWGN',13,'channel']],'Location',[86,493,348,639])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Sum']],...
		'position',[150,55,170,75])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/out_1']])
set_param([sys,'/',['AWGN',13,'channel/out_1']],...
		'position',[200,55,220,75])


%     Subsystem  ['AWGN',13,'channel/Gaussian',13,'noise'].

new_system([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],'Location',[409,168,757,373])

add_block('built-in/State-Space',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])

add_block('built-in/Outport',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/Sum',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Constant',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/White Noise',[sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[240,95;290,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.',...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['AWGN',13,'channel/Gaussian',13,'noise'].

set_param([sys,'/',['AWGN',13,'channel/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Inport',[sys,'/',['AWGN',13,'channel/in_1']])
set_param([sys,'/',['AWGN',13,'channel/in_1']],...
		'position',[45,10,65,30])
add_line([sys,'/',['AWGN',13,'channel']],[90,70;145,70])
add_line([sys,'/',['AWGN',13,'channel']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['AWGN',13,'channel']],[175,65;195,65])
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Display','plot(0,0,100,100,x,y);AWGN',...
		'Mask Type','AWGN channel, fixed parameter')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Dialogue','Additive white Gaussian noise channel\nwith fixed mean and variance.|Mean value:|Variance (std^2):|Initial Seed:')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);[x,y]=chanicon;')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Help','This block adds white Gaussian noise to the input signal. The mean and the variance can be a scalar or vector with the same length as the input signal.')
set_param([sys,'/',['AWGN',13,'channel']],...
		'Mask Entries','0\/.000001\/57468\/')


%     Finished composite block ['AWGN',13,'channel'].

set_param([sys,'/',['AWGN',13,'channel']],...
		'hide name',0,...
		'position',[390,63,470,107])


%     Subsystem  ['Square-map',13,'QASK demod1'].

new_system([sys,'/',['Square-map',13,'QASK demod1']])
set_param([sys,'/',['Square-map',13,'QASK demod1']],'Location',[616,427,966,520])


%     Subsystem  ['Square-map',13,'QASK demod1/QASK',13,'square-demap'].

new_system([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],'Location',[57,374,831,674])

add_block('built-in/Zero-Order Hold',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[135,24,170,56])

add_block('built-in/Inport',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/in_1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/in_1']],...
		'position',[60,30,80,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[135,149,170,181])

add_block('built-in/Inport',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/in_2']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/in_2']],...
		'Port','2',...
		'position',[60,155,80,175])

add_block('built-in/Sum',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Sum5']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Sum5']],...
		'ForeGround',2,...
		'position',[470,153,490,182])


%     Subsystem  ['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table'].

new_system([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],'Location',[436,148,718,302])

add_block('built-in/Inport',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table/y0']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table/y0']],...
		'Port','2',...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table/table out']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table/table out']],...
		'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table/x0']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table/x0']],...
		'position',[20,25,40,45])

add_block('built-in/S-Function',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table/S-function']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table/S-function']],...
		'function name','sftable2',...
		'parameters','xindex, yindex, table',...
		'position',[140,52,190,78])

add_block('built-in/Mux',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table/Mux']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table/Mux']],...
		'inputs','2',...
		'position',[90,46,120,79])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],[45,90;65,90;65,70;85,70])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],[195,65;210,65])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],[45,35;65,35;65,55;85,55])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],[125,65;135,65])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],...
		'Mask Display','plot(-10,-10,110,110,[90,50,10],[90,40,30],[90,50,10],[50,26,20],[90,50,10],[22,13,10])',...
		'Mask Type','2-D Table Lookup')
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],...
		'Mask Dialogue','Two Dimensional Table Lookup\nThe first input corresponds to X Index and the second input corresponds to the Y Index|X Index|Y Index|Table')
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],...
		'Mask Translate','xindex=@1; yindex=@2; table=@3; sftab2chk(xindex,yindex,table);')
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],...
		'Mask Help','This block returns a linearly interpolated intersection from the table using the X index (which corresponds to the rows of the table) and the Y index (which corresponds to the columns of the table).  Extrapolation is used.')
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],...
		'Mask Entries','x\/y\/tab\/')


%     Finished composite block ['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table'].

set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/2-D Table']],...
		'position',[515,68,545,92])

add_block('built-in/Sum',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Sum3']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Sum3']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[580,73,600,102])

add_block('built-in/Saturation',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Saturation']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','N-1',...
		'position',[630,78,660,102])

add_block('built-in/Outport',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/out_1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/out_1']],...
		'position',[685,80,705,100])

add_block('built-in/Sum',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Sum4']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Sum4']],...
		'ForeGround',2,...
		'position',[470,58,490,87])

add_block('built-in/Sum',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Sum1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[280,33,300,62])

add_block('built-in/Sum',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Sum2']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Sum2']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[290,158,310,187])

add_block('built-in/S-Function',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Minimum']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Minimum']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,165,450,185])

add_block('built-in/Constant',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Shift key']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Shift key']],...
		'Value','sfty',...
		'position',[225,214,250,236])

add_block('built-in/S-Function',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Minimum1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,40,445,60])

add_block('built-in/Constant',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Shift key1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Shift key1']],...
		'Value','sftx',...
		'position',[220,89,245,111])

add_block('built-in/Constant',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Shift key2']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Shift key2']],...
		'BackGround',5,...
		'position',[325,114,350,136])

add_block('built-in/Abs',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Abs1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Abs1']],...
		'position',[325,38,355,62])

add_block('built-in/Abs',[sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Abs']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap/Abs']],...
		'position',[325,163,355,187])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[85,40;130,40])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[360,175;380,175])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[315,175;320,175])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[255,225;260,225;260,180;285,180])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[250,100;255,100;255,55;275,55])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[305,50;320,50])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[360,50;380,50])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[665,90;680,90])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[550,80;575,80])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[605,90;625,90])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[450,50;450,65;465,65])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[455,175;465,175])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[495,170;500,170;510,85])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[355,125;560,125;560,95;575,95])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[450,125;450,160;465,160])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[450,125;450,80;465,80])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[495,75;510,75])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[85,165;130,165])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[175,165;285,165])
add_line([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],[175,40;275,40])
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],...
		'Mask Display','QASK\nS-demap',...
		'Mask Type','QASK S-demap')
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|QASK M-ary number (outputs are in range [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],...
		'Mask Translate','N=@1;td=@2;Ac=1;sftx=[1 -1 3 -3 5 -5 7 -7 9 -9 11 -11 13 -13 15 -15];sftx=sftx(1:2*ceil(sqrt(N)/2));sfty=sftx;if N==8,sfty=sfty(1:2);end;sftx=sftx/max(sftx)*Ac;sfty=sfty/max(sfty)*Ac;tab=qaskdeco(length(sftx),length(sfty),''fetch'')+1;x=[1:length(sftx)];y=[1:length(sfty)];')
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using square constellation. You can place this block after a QAM demodulation block. This block assumes the maximum amplitude of the input signals is 1. The output symbols are integers in the range [0, M-1].')
set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['Square-map',13,'QASK demod1/QASK',13,'square-demap'].

set_param([sys,'/',['Square-map',13,'QASK demod1/QASK',13,'square-demap']],...
		'hide name',0,...
		'position',[205,28,285,72])


%     Subsystem  ['Square-map',13,'QASK demod1/QADM',13,'passband'].

new_system([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],'Location',[194,478,738,741])

add_block('built-in/Clock',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Clock']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Clock']],...
		'position',[60,110,80,130])

add_block('built-in/Gain',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Gain']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Gain']],...
		'Gain','Fc',...
		'position',[110,101,160,139])

add_block('built-in/Filter',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Filter1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,166,445,204])

add_block('built-in/Filter',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Filter']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Gain',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Gain1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Gain1']],...
		'Gain','2',...
		'position',[270,118,295,142])

add_block('built-in/Inport',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/in_1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/in_1']],...
		'position',[230,120,250,140])

add_block('built-in/Note',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Fcn',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Fcn']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Fcn']],...
		'Expr','cos(u[1]+Ph)',...
		'position',[205,55,300,85])

add_block('built-in/Fcn',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Fcn1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Fcn1']],...
		'Expr','sin(u[1]+Ph)',...
		'position',[200,175,300,205])

add_block('built-in/Product',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Product']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Product']],...
		'position',[330,62,355,93])

add_block('built-in/Product',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Product1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/Product1']],...
		'position',[330,167,355,198])

add_block('built-in/Outport',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/out_2']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/out_2']],...
		'Port','2',...
		'position',[480,175,500,195])

add_block('built-in/Outport',[sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/out_1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[300,130;305,130;305,175;325,175])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[255,130;265,130])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[165,120;185,120;185,70;200,70])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[185,120;195,190])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[305,70;325,70])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[305,190;325,190])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[360,80;385,80])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[450,80;475,80])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[360,185;385,185])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[450,185;475,185])
add_line([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],[85,120;105,120])
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],...
		'Mask Display','plot(0,0,100,100,x,y);QADM',...
		'Mask Type','Passband DSB-SC QADM')
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],...
		'Mask Dialogue','Demodulate a DSB-SC QAM modulated\nsignal into in-phase and quadrature\ncomponents.|Carrier frequency (Hz):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],...
		'Mask Translate','Fc=@1*2*pi;num=@2;den=@3;Ph=@4;ts=@5;[x,y]=moduicon(2);')
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],...
		'Mask Help','This block demodulates the QM-DSB-SC-AM modulated signal. The first output port outputs the in-phase component and the second port outputs the quadrature component. The demodulation uses a discrete-time lowpass filter that passes the signal message and eliminates the carrier signal. ')
set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],...
		'Mask Entries','Fc\/num\/den\/Ph\/ts\/')


%     Finished composite block ['Square-map',13,'QASK demod1/QADM',13,'passband'].

set_param([sys,'/',['Square-map',13,'QASK demod1/QADM',13,'passband']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[90,28,170,72])

add_block('built-in/Inport',[sys,'/',['Square-map',13,'QASK demod1/in_1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/in_1']],...
		'position',[40,40,60,60])

add_block('built-in/Outport',[sys,'/',['Square-map',13,'QASK demod1/out_1']])
set_param([sys,'/',['Square-map',13,'QASK demod1/out_1']],...
		'position',[320,40,340,60])
add_line([sys,'/',['Square-map',13,'QASK demod1']],[175,40;200,40])
add_line([sys,'/',['Square-map',13,'QASK demod1']],[175,60;200,60])
add_line([sys,'/',['Square-map',13,'QASK demod1']],[290,50;315,50])
add_line([sys,'/',['Square-map',13,'QASK demod1']],[65,50;85,50])
set_param([sys,'/',['Square-map',13,'QASK demod1']],...
		'Mask Display','plot(0,0,100,100,x,y);S-QASK',...
		'Mask Type','Passband S-QASK demodulation')
set_param([sys,'/',['Square-map',13,'QASK demod1']],...
		'Mask Dialogue','Demodulate a QASK modulated signal\nusing square constellation.|M-ary number (output integer in range [0 M-1]):|Symbol interval (sec):|Carrier Frequency (Hz):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Square-map',13,'QASK demod1']],...
		'Mask Translate','M=@1;td=@2;Fc=@3;Ph=@4;ts=@5;[num,den]=butter(5,Fc*2*ts);[x,y]=moduicon(6);')
set_param([sys,'/',['Square-map',13,'QASK demod1']],...
		'Mask Help','This block demodulates a MQASK modulated signal. The output signals are digits in the range [0, M-1]. When the symbol interval is a two-element vector, the second element is the offset (default 0). A default lowpass filter is used in the demodulation, which is [num, den]=butter(5, Fc*2*ts). Ungroup this block to specify the numerator and denominator of the lowpass filter.')
set_param([sys,'/',['Square-map',13,'QASK demod1']],...
		'Mask Entries','128\/.01\/1000\/0\/.0002\/')


%     Finished composite block ['Square-map',13,'QASK demod1'].

set_param([sys,'/',['Square-map',13,'QASK demod1']],...
		'hide name',0,...
		'position',[485,63,565,107])

add_block('built-in/S-Function',[sys,'/',['Integer scalar',13,'to vector']])
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter',...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Integer scalar',13,'to vector']],...
		'Mask Entries','7\/2\/',...
		'position',[580,63,660,107])


%     Subsystem  ['Binary vector',13,'BCH decode'].

new_system([sys,'/',['Binary vector',13,'BCH decode']])
set_param([sys,'/',['Binary vector',13,'BCH decode']],'Location',[157,499,740,659])

add_block('built-in/Memory',[sys,'/',['Binary vector',13,'BCH decode/Memory']])
set_param([sys,'/',['Binary vector',13,'BCH decode/Memory']],...
		'orientation',2,...
		'x0','zeros(1,k+1)',...
		'position',[295,95,335,125])

add_block('built-in/Switch',[sys,'/',['Binary vector',13,'BCH decode/Switch']])
set_param([sys,'/',['Binary vector',13,'BCH decode/Switch']],...
		'Threshold','0.5',...
		'position',[295,44,325,76])

add_block('built-in/S-Function',[sys,'/',['Binary vector',13,'BCH decode/S-function']])
set_param([sys,'/',['Binary vector',13,'BCH decode/S-function']],...
		'function name','simbchdc',...
		'parameters','n, k, t,tp,dim',...
		'position',[170,20,235,40])

add_block('built-in/Mux',[sys,'/',['Binary vector',13,'BCH decode/Mux']])
set_param([sys,'/',['Binary vector',13,'BCH decode/Mux']],...
		'inputs','[n, 1]',...
		'position',[80,41,115,74])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'BCH decode/in_1']])
set_param([sys,'/',['Binary vector',13,'BCH decode/in_1']],...
		'position',[20,15,40,35])

add_block('built-in/Inport',[sys,'/',['Binary vector',13,'BCH decode/in_2']])
set_param([sys,'/',['Binary vector',13,'BCH decode/in_2']],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Demux',[sys,'/',['Binary vector',13,'BCH decode/Demux']])
set_param([sys,'/',['Binary vector',13,'BCH decode/Demux']],...
		'outputs','[k, 1]',...
		'position',[395,40,435,75])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'BCH decode/out_1']])
set_param([sys,'/',['Binary vector',13,'BCH decode/out_1']],...
		'position',[495,30,515,50])

add_block('built-in/Outport',[sys,'/',['Binary vector',13,'BCH decode/out_2']])
set_param([sys,'/',['Binary vector',13,'BCH decode/out_2']],...
		'Port','2',...
		'position',[495,95,515,115])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[330,60;390,60])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[360,60;360,110;340,110])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[290,110;255,110;255,70;290,70])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[240,30;255,30;255,50;290,50])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[45,25;60,25;60,50;75,50])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[120,60;150,60;150,30;165,30])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[35,110;200,110;200,60;290,60])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[60,110;60,65;75,65])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[440,50;455,50;455,40;490,40])
add_line([sys,'/',['Binary vector',13,'BCH decode']],[440,65;455,65;455,105;490,105])
set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);BCH de',...
		'Mask Type','Vector I/O BCH decode')
set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'Mask Dialogue','BCH decode with input codeword vector\nlength N, output message vector length K, and error-correction capability T. (N,K,T) must be a valid BCH code combination.|Codeword length N (N=2^M-1. M is a >2 integer):|Message length K (check BCHPOLY for valid K):|Error-correction capability T (0 for unknown):')
set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'Mask Translate','n=@1;k=@2;t=@3;if t<=0, [x1,x2,x3,x4,t]=bchpoly(n,k);end;dim=3;pow_dim=7;while pow_dim<n,dim=dim+1;pow_dim=2^dim-1;end;tp=gftuple([-1:n-1]'',dim);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''));')
set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'Mask Help','This block decodes length N binary vector codeword input into length K binary vector message output using BCH code. The block refreshes its decoding output when the enable signal at the second inport has positive value. The second outport outputs the number of errors detected in the process. A negative value indicates the block found more error in the codeword than T.')
set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'Mask Entries','7\/4\/1\/')


%     Finished composite block ['Binary vector',13,'BCH decode'].

set_param([sys,'/',['Binary vector',13,'BCH decode']],...
		'hide name',0,...
		'position',[685,73,765,117])

add_block('built-in/S-Function',[sys,'/',['Integer vector',13,'to scalar2']])
set_param([sys,'/',['Integer vector',13,'to scalar2']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Integer vector',13,'to scalar2']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Integer vector',13,'to scalar2']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Integer vector',13,'to scalar2']],...
		'Mask Entries','2\/',...
		'position',[785,63,865,107])


%     Subsystem  'Error rate'.

new_system([sys,'/','Error rate'])
set_param([sys,'/','Error rate'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate/S-function'])
set_param([sys,'/','Error rate/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate/Mux'])
set_param([sys,'/','Error rate/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate/in_1'])
set_param([sys,'/','Error rate/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate/in_2'])
set_param([sys,'/','Error rate/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate'],[105,65;125,65])
add_line([sys,'/','Error rate'],[40,55;60,55])
add_line([sys,'/','Error rate'],[40,70;60,70])
set_param([sys,'/','Error rate'],...
		'Mask Display','Error Rate\nMeter',...
		'Mask Type','Symbol/Bit Error Counter.')
set_param([sys,'/','Error rate'],...
		'Mask Dialogue','Compare 2nd port input to scalar 1st port input. Compute the error rate.|Bit per symbol:|Number of digit on display:|Delay between input (1st port) and output (2nd port):|Sampling time (second):')
set_param([sys,'/','Error rate'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate'],...
		'Mask Help','The signal from the first port should be always be a scalar. The 2nd port input signal can be a vector with a same time delay to the input signal.',...
		'Mask Entries','4\/20\/0.008\/0.01\/')


%     Finished composite block 'Error rate'.

set_param([sys,'/','Error rate'],...
		'hide name',0,...
		'position',[885,23,960,67])


%     Subsystem  ['Rising edge',13,'detector'].

new_system([sys,'/',['Rising edge',13,'detector']])
set_param([sys,'/',['Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Rising edge',13,'detector/one1']])
set_param([sys,'/',['Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Rising edge',13,'detector']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Edge det.',...
		'Mask Type','Edge detection')
set_param([sys,'/',['Rising edge',13,'detector']],...
		'Mask Dialogue','Detect the rising edge of the input\nsignal. Output one when the rising\nedge is detected.|Threshold:')
set_param([sys,'/',['Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rising edge',13,'detector']],...
		'Mask Help','This block outputs one when the input signal reaches a value larger than or equal to the given threshold value at the current time and the value was below the threshold one time step before. Otherwise, the block outputs zero.')
set_param([sys,'/',['Rising edge',13,'detector']],...
		'Mask Entries','0.5\/')


%     Finished composite block ['Rising edge',13,'detector'].

set_param([sys,'/',['Rising edge',13,'detector']],...
		'hide name',0,...
		'position',[580,118,660,162])


%     Subsystem  ['Pulses divide',13,'same sample time'].

new_system([sys,'/',['Pulses divide',13,'same sample time']])
set_param([sys,'/',['Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'Mask Entries','.01\/1\/0\/')


%     Finished composite block ['Pulses divide',13,'same sample time'].

set_param([sys,'/',['Pulses divide',13,'same sample time']],...
		'hide name',0,...
		'position',[485,118,565,162])
add_line(sys,[95,85;100,85])
add_line(sys,[95,85;95,35;705,35])
add_line(sys,[770,85;780,85])
add_line(sys,[795,35;880,35])
add_line(sys,[870,85;870,85;870,55;880,55])
add_line(sys,[475,85;480,85])
add_line(sys,[665,85;680,85])
add_line(sys,[190,85;195,85])
add_line(sys,[285,85;290,85])
add_line(sys,[380,85;385,85])
add_line(sys,[570,85;575,85])
add_line(sys,[570,140;575,140])
add_line(sys,[665,140;670,140;680,105])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
