function [ret,x0,str,ts,xts]=tutmodce(t,x,u,flag);
%TUTMODCE	is the M-file description of the SIMULINK system named TUTMODCE.
%	The block-diagram can be displayed by typing: TUTMODCE.
%
%	SYS=TUTMODCE(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TUTMODCE to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TUTMODCE with a FLAG of zero:
%	[SIZES]=TUTMODCE([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[364,65,848,595])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '1')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ts=.01;[num,den]=butter(2,100/pi/2*ts);');

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','3.000000',...
		'Freq Range','6.000000',...
		'Wave','Sin',...
		'Units','Rads',...
		'position',[30,43,75,77])

add_block('built-in/Outport',[sys,'/','Outport3'])
set_param([sys,'/','Outport3'],...
		'ForeGround',4,...
		'Port','4',...
		'position',[365,185,385,205])

add_block('built-in/Outport',[sys,'/','Outport2'])
set_param([sys,'/','Outport2'],...
		'ForeGround',3,...
		'Port','3',...
		'position',[365,125,385,145])

add_block('built-in/Outport',[sys,'/','Outport1'])
set_param([sys,'/','Outport1'],...
		'ForeGround',2,...
		'Port','2',...
		'position',[360,50,380,70])

add_block('built-in/Outport',[sys,'/','Outport'])
set_param([sys,'/','Outport'],...
		'position',[140,5,160,25])

add_block('built-in/Outport',[sys,'/','Outport4'])
set_param([sys,'/','Outport4'],...
		'ForeGround',7,...
		'Port','5',...
		'position',[360,255,380,275])

add_block('built-in/Note',[sys,'/','Default in this simulations: ts=0.01; [num,den]=butter(2,Fc*2*ts);'])
set_param([sys,'/','Default in this simulations: ts=0.01; [num,den]=butter(2,Fc*2*ts);'],...
		'position',[255,535,260,540])

add_block('built-in/Outport',[sys,'/','Outport8'])
set_param([sys,'/','Outport8'],...
		'Port','9',...
		'position',[165,485,185,505])

add_block('built-in/Outport',[sys,'/','Outport6'])
set_param([sys,'/','Outport6'],...
		'ForeGround',5,...
		'Port','7',...
		'position',[400,420,420,440])

add_block('built-in/Outport',[sys,'/','Outport7'])
set_param([sys,'/','Outport7'],...
		'ForeGround',5,...
		'Port','8',...
		'position',[350,440,370,460])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator1']])
set_param([sys,'/',['Signal',13,'generator1']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','6.000000',...
		'Freq Range','6.000000',...
		'Wave','Saw',...
		'Units','Rads',...
		'position',[15,433,60,467])

add_block('built-in/Outport',[sys,'/','Outport5'])
set_param([sys,'/','Outport5'],...
		'ForeGround',6,...
		'Port','6',...
		'position',[360,325,380,345])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'ForeGround',6,...
		'outputs','2',...
		'position',[330,368,385,397])

add_block('built-in/Outport',[sys,'/','Outport9'])
set_param([sys,'/','Outport9'],...
		'ForeGround',6,...
		'Port','10',...
		'position',[415,380,435,400])


%     Subsystem  ['DSB AM',13,'baseband'].

new_system([sys,'/',['DSB AM',13,'baseband']])
set_param([sys,'/',['DSB AM',13,'baseband']],'Location',[212,430,575,573])

add_block('built-in/Outport',[sys,'/',['DSB AM',13,'baseband/out_1']])
set_param([sys,'/',['DSB AM',13,'baseband/out_1']],...
		'position',[320,50,340,70])

add_block('built-in/Product',[sys,'/',['DSB AM',13,'baseband/Product']])
set_param([sys,'/',['DSB AM',13,'baseband/Product']],...
		'position',[255,42,280,73])

add_block('built-in/Inport',[sys,'/',['DSB AM',13,'baseband/in_1']])
set_param([sys,'/',['DSB AM',13,'baseband/in_1']],...
		'position',[115,15,135,35])

add_block('built-in/Mux',[sys,'/',['DSB AM',13,'baseband/Mux']])
set_param([sys,'/',['DSB AM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[170,66,205,99])

add_block('built-in/Constant',[sys,'/',['DSB AM',13,'baseband/Constant1']])
set_param([sys,'/',['DSB AM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[90,90,110,110])

add_block('built-in/Constant',[sys,'/',['DSB AM',13,'baseband/Constant']])
set_param([sys,'/',['DSB AM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[40,65,60,85])
add_line([sys,'/',['DSB AM',13,'baseband']],[65,75;165,75])
add_line([sys,'/',['DSB AM',13,'baseband']],[115,100;130,100;130,90;165,90])
add_line([sys,'/',['DSB AM',13,'baseband']],[140,25;185,25;185,50;250,50])
add_line([sys,'/',['DSB AM',13,'baseband']],[285,60;315,60])
add_line([sys,'/',['DSB AM',13,'baseband']],[210,85;230,85;230,65;250,65])
set_param([sys,'/',['DSB AM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);DSB AM',...
		'Mask Type','DSB-SC AM CE',...
		'Mask Dialogue','Output the complex envelope of a\nDSB-SC AM modulated signal.|Initial Phase (rad):')
set_param([sys,'/',['DSB AM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);pi2=2*pi;[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['DSB AM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the double-sideband suppressed-carrier amplitude modulated signal. The output is a complex signal.',...
		'Mask Entries','0\/')


%     Finished composite block ['DSB AM',13,'baseband'].

set_param([sys,'/',['DSB AM',13,'baseband']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[125,38,205,82])


%     Subsystem  ['DSB-ADM',13,'baseband'].

new_system([sys,'/',['DSB-ADM',13,'baseband']])
set_param([sys,'/',['DSB-ADM',13,'baseband']],'Location',[306,370,856,591])

add_block('built-in/Filter',[sys,'/',['DSB-ADM',13,'baseband/Filter2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Filter2']],...
		'orientation',2,...
		'hide name',0,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'Mask Display','Lowpass\nfilter',...
		'position',[265,100,325,140])

add_block('built-in/Filter',[sys,'/',['DSB-ADM',13,'baseband/Filter']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Filter']],...
		'hide name',0,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'Mask Display','Lowpass\nfilter',...
		'position',[215,26,270,64])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Product1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Product1']],...
		'orientation',2,...
		'hide name',0,...
		'position',[345,110,380,130])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/out_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/out_1']],...
		'position',[440,35,460,55])


%     Subsystem  ['DSB-ADM',13,'baseband/FM CE//VCO'].

new_system([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],'Location',[493,551,1106,698])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/in_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/in_1']],...
		'position',[35,25,55,45])

add_block('built-in/Gain',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[80,21,120,49])

add_block('built-in/Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/cos']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/cos']],...
		'Expr','cos(u)',...
		'position',[270,21,325,49])

add_block('built-in/Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/sin']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/sin']],...
		'Expr','sin(u)',...
		'position',[270,81,325,109])

add_block('built-in/Mux',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Mux']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Mux']],...
		'inputs','2',...
		'position',[355,26,390,59])

add_block('built-in/Gain',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity1']],...
		'Gain','Ac',...
		'position',[420,31,460,59])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/out_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/out_1']],...
		'position',[490,35,510,55])


%     Subsystem  ['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator'].

new_system([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])

add_block('built-in/Unit Delay',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/module']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[410,40;440,40])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[140,35;190,35])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Entries','pi2\/0\/ts\/')


%     Finished composite block ['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator'].

set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'position',[135,16,195,54])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sum']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Sum']],...
		'position',[220,30,240,50])

add_block('built-in/Constant',[sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Constant']])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO/Constant']],...
		'Value','Ph',...
		'position',[160,100,180,120])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[60,35;75,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[125,35;130,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[465,45;485,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[330,35;350,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[395,45;415,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[330,95;335,95;335,50;350,50])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[200,35;215,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[245,40;245,35;265,35])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[185,110;200,110;200,45;215,45])
add_line([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],[245,40;250,40;250,95;265,95])
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Display','FM\ncmplx env',...
		'Mask Type','FM with cmplx env out')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Dialogue','Frequency modulation with complex envelop output:|Amplitude constant:|Modulation sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Translate','Ac=@1;Kc=@2*2*pi;Ph=@3;pi2=2*pi;ts=@4;')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Help','The FM block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Entries','1\/1\/Ph\/ts\/')


%     Finished composite block ['DSB-ADM',13,'baseband/FM CE//VCO'].

set_param([sys,'/',['DSB-ADM',13,'baseband/FM CE//VCO']],...
		'orientation',2,...
		'hide name',0,...
		'position',[155,100,235,140])

add_block('built-in/Filter',[sys,'/',['DSB-ADM',13,'baseband/Filter1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Filter1']],...
		'hide name',0,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'Mask Display','Lowpass\nfilter',...
		'position',[190,156,245,194])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/in_1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/in_1']],...
		'orientation',2,...
		'position',[150,55,170,75])


%     Subsystem  ['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

new_system([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],'Location',[153,39,836,415])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']],...
		'Port','2',...
		'position',[25,205,45,225])

add_block('built-in/Demux',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'position',[80,194,155,236])

add_block('built-in/Inport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']],...
		'position',[35,90,55,110])

add_block('built-in/Demux',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'position',[85,79,160,121])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']],...
		'position',[55,0,60,5])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']],...
		'position',[450,286,455,291])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']],...
		'position',[450,95,455,100])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']],...
		'position',[380,280,400,300])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']],...
		'position',[305,298,335,322])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']],...
		'position',[305,253,335,277])

add_block('built-in/Sum',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']],...
		'inputs','+-',...
		'position',[380,110,400,130])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']],...
		'position',[305,143,335,167])

add_block('built-in/Product',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']],...
		'position',[305,83,335,107])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']],...
		'position',[190,185,195,190])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']],...
		'position',[195,65,200,70])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']],...
		'position',[198,108,203,113])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']],...
		'Port','2',...
		'position',[485,280,505,300])

add_block('built-in/Outport',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']],...
		'position',[495,110,515,130])

add_block('built-in/Note',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']],...
		'position',[170,225,175,230])

add_block('built-in/Gain',[sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']],...
		'Gain','-1',...
		'position',[190,210,230,240])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,310;350,310;350,295;375,295])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,265;350,265;350,285;375,285])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,110;250,110;250,150;300,150])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[255,150;255,315;300,315])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,205;275,205;275,100;300,100])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[275,205;275,305;300,305])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,90;300,90])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[243,90;243,260;300,260])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,155;350,155;350,125;375,125])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,95;350,95;350,115;375,115])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[50,215;75,215])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[60,100;80,100])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,290;480,290])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,120;490,120])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,225;185,225])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[235,225;260,225;260,160;300,160])
add_line([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[260,225;260,270;300,270])
set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],...
		'Mask Display','Complex\nmultiply')


%     Finished composite block ['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

set_param([sys,'/',['DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],...
		'orientation',2,...
		'hide name',0,...
		'position',[40,90,115,130])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[275,45;435,45])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[400,45;400,115;385,115])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[145,65;130,65;120,100])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[35,100;15,100;15,45;210,45])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[35,120;15,120;15,175;185,175])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[250,175;400,175;400,125;385,125])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[340,120;330,120])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[260,120;240,120])
add_line([sys,'/',['DSB-ADM',13,'baseband']],[150,120;120,120])
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);DSB ADM',...
		'Mask Type','DSB-SC ADM CE')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nDSB-SC AM modulated signal.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;pi2=pi*2;ts=@4;[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block requires you to specify a lowpass filter that eliminates the carrier frequency and keeps the message signal. This block takes a complex signal.')
set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'Mask Entries','num\/den\/0\/ts\/')


%     Finished composite block ['DSB-ADM',13,'baseband'].

set_param([sys,'/',['DSB-ADM',13,'baseband']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[235,38,315,82])


%     Subsystem  ['AM with carrier',13,'baseband'].

new_system([sys,'/',['AM with carrier',13,'baseband']])
set_param([sys,'/',['AM with carrier',13,'baseband']],'Location',[239,534,593,656])

add_block('built-in/Inport',[sys,'/',['AM with carrier',13,'baseband/in_1']])
set_param([sys,'/',['AM with carrier',13,'baseband/in_1']],...
		'position',[50,30,70,50])

add_block('built-in/Note',[sys,'/',['AM with carrier',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp76']])
set_param([sys,'/',['AM with carrier',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp76']],...
		'position',[180,155,185,160])

add_block('built-in/Sum',[sys,'/',['AM with carrier',13,'baseband/Sum']])
set_param([sys,'/',['AM with carrier',13,'baseband/Sum']],...
		'position',[125,35,145,55])

add_block('built-in/Outport',[sys,'/',['AM with carrier',13,'baseband/out_1']])
set_param([sys,'/',['AM with carrier',13,'baseband/out_1']],...
		'position',[280,35,300,55])

add_block('built-in/Constant',[sys,'/',['AM with carrier',13,'baseband/Constant']])
set_param([sys,'/',['AM with carrier',13,'baseband/Constant']],...
		'Value','Offset',...
		'position',[35,80,85,100])


%     Subsystem  ['AM with carrier',13,'baseband/DSB AM CE'].

new_system([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],'Location',[212,430,575,573])

add_block('built-in/Outport',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/out_1']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/out_1']],...
		'position',[320,50,340,70])

add_block('built-in/Product',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Product']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Product']],...
		'position',[255,42,280,73])

add_block('built-in/Inport',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/in_1']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/in_1']],...
		'position',[115,15,135,35])

add_block('built-in/Mux',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Mux']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Mux']],...
		'inputs','2',...
		'position',[170,66,205,99])

add_block('built-in/Constant',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Constant1']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Constant1']],...
		'Value','x2',...
		'position',[90,90,110,110])

add_block('built-in/Constant',[sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Constant']])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE/Constant']],...
		'Value','x1',...
		'position',[40,65,60,85])
add_line([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],[65,75;165,75])
add_line([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],[115,100;130,100;130,90;165,90])
add_line([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],[140,25;185,25;185,50;250,50])
add_line([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],[285,60;315,60])
add_line([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],[210,85;230,85;230,65;250,65])
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],...
		'Mask Display','DSB AM\ncmplx env',...
		'Mask Type','DSB-SC AM complex envelop')
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],...
		'Mask Dialogue','Double-sideband suppressed-carrier amplitude modulation complex envelop.|Initial Phase (rad):',...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);pi2=2*pi;')
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],...
		'Mask Help','The Double-Sideband-Supressed-Carrier Amplitude Modulation causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. This block outputs the complex envelop of the modulation, which is a complex number.')
set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],...
		'Mask Entries','Ph\/')


%     Finished composite block ['AM with carrier',13,'baseband/DSB AM CE'].

set_param([sys,'/',['AM with carrier',13,'baseband/DSB AM CE']],...
		'position',[180,25,255,65])
add_line([sys,'/',['AM with carrier',13,'baseband']],[90,90;100,90;100,50;120,50])
add_line([sys,'/',['AM with carrier',13,'baseband']],[260,45;275,45])
add_line([sys,'/',['AM with carrier',13,'baseband']],[75,40;120,40])
add_line([sys,'/',['AM with carrier',13,'baseband']],[150,45;175,45])
set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);AM w TC',...
		'Mask Type','AM CE with TC')
set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'Mask Dialogue','Output complex envelope of an AM with\ntransport carrier modulated signal.|Input signal offset:|Initial phase (rad):')
set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'Mask Translate','Offset=@1;Ph=@2;[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'Mask Help','This block causes the amplitude of the sinusoid carrier to depend on the message signal. An offset is added to the input signal before modulation. The output of this block is a complex signal. This modulation technique is not efficient.')
set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'Mask Entries','1\/0\/')


%     Finished composite block ['AM with carrier',13,'baseband'].

set_param([sys,'/',['AM with carrier',13,'baseband']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[130,113,210,157])


%     Subsystem  ['ADM with carrier',13,'baseband'].

new_system([sys,'/',['ADM with carrier',13,'baseband']])
set_param([sys,'/',['ADM with carrier',13,'baseband']],'Location',[468,490,803,640])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/out_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/out_1']],...
		'position',[290,30,310,50])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'baseband/Sum']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[240,30,260,50])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/in_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/in_1']],...
		'position',[40,25,60,45])

add_block('built-in/Constant',[sys,'/',['ADM with carrier',13,'baseband/Constant']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Constant']],...
		'Value','Offset',...
		'position',[150,100,190,120])


%     Subsystem  ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE'].

new_system([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],'Location',[103,111,653,332])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[260,156,315,194])


%     Subsystem  ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO'].

new_system([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],'Location',[114,165,727,312])


%     Subsystem  ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator'].

new_system([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/module']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Unit Delay',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],[410,40;440,40])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Entries','pi2\/0\/ts\/')


%     Finished composite block ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator'].

set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Dis module',13,'integrator']],...
		'position',[155,16,215,54])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/out_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/out_1']],...
		'position',[490,35,510,55])

add_block('built-in/Gain',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Sensitivity1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Sensitivity1']],...
		'Gain','Ac',...
		'position',[420,31,460,59])

add_block('built-in/Mux',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Mux']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Mux']],...
		'inputs','2',...
		'position',[355,26,390,59])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/sin']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/sin']],...
		'Expr','sin(u)',...
		'position',[270,81,325,109])

add_block('built-in/Fcn',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/cos']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/cos']],...
		'Expr','cos(u)',...
		'position',[270,21,325,49])

add_block('built-in/Gain',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Sensitivity']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[80,21,120,49])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/in_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO/in_1']],...
		'position',[35,25,55,45])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[330,95;335,95;335,50;350,50])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[395,45;415,45])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[330,35;350,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[465,45;485,45])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[220,35;265,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[240,35;240,95;265,95])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[125,35;150,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],[60,35;75,35])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'Mask Display','FM\ncmplx env',...
		'Mask Type','FM with cmplx env out')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'Mask Dialogue','Frequency modulation with complex envelop output:|Amplitude constant:|Modulation sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'Mask Translate','Ac=@1;Kc=@2*2*pi;Ph=@3;pi2=2*pi;ts=@4;')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'Mask Help','The FM block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'Mask Entries','1\/1\/0\/ts\/')


%     Finished composite block ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO'].

set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/FM CE//VCO']],...
		'orientation',2,...
		'position',[205,80,285,120])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/in_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/in_1']],...
		'orientation',2,...
		'position',[165,70,185,90])


%     Subsystem  ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

new_system([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],'Location',[297,318,980,694])

add_block('built-in/Gain',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']],...
		'Gain','-1',...
		'position',[190,210,230,240])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']],...
		'position',[170,225,175,230])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']],...
		'position',[495,110,515,130])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']],...
		'Port','2',...
		'position',[485,280,505,300])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']],...
		'position',[198,108,203,113])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']],...
		'position',[195,65,200,70])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']],...
		'position',[190,185,195,190])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']],...
		'position',[305,83,335,107])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']],...
		'position',[305,143,335,167])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']],...
		'inputs','+-',...
		'position',[380,110,400,130])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']],...
		'position',[305,253,335,277])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']],...
		'position',[305,298,335,322])

add_block('built-in/Sum',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']],...
		'position',[380,280,400,300])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']],...
		'position',[450,95,455,100])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']],...
		'position',[450,286,455,291])

add_block('built-in/Note',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']],...
		'position',[55,0,60,5])

add_block('built-in/Demux',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'position',[85,79,160,121])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']],...
		'position',[35,90,55,110])

add_block('built-in/Demux',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'position',[80,194,155,236])

add_block('built-in/Inport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']],...
		'Port','2',...
		'position',[25,205,45,225])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[235,225;260,225;260,160;300,160])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[260,225;260,270;300,270])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,225;185,225])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,120;490,120])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,290;480,290])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[60,100;80,100])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[50,215;75,215])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,95;350,95;350,115;375,115])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,155;350,155;350,125;375,125])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,90;300,90])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[243,90;243,260;300,260])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,205;275,205;275,100;300,100])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[275,205;275,305;300,305])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,110;250,110;250,150;300,150])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[255,150;255,315;300,315])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,265;350,265;350,285;375,285])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,310;350,310;350,295;375,295])


%     Finished composite block ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Cmplx-in',13,'Re//Im-out',13,'Multiply']],...
		'orientation',2,...
		'position',[50,70,125,110])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[270,6,325,44])

add_block('built-in/Filter',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter2']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[310,80,370,120])

add_block('built-in/Product',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Product1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/Product1']],...
		'orientation',2,...
		'position',[400,90,435,110])

add_block('built-in/Outport',[sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/out_1']])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE/out_1']],...
		'position',[495,15,515,35])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[200,100;130,100])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[305,100;290,100])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[395,100;375,100])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[320,175;455,175;455,105;440,105])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[45,100;25,100;25,175;255,175])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[45,80;30,80;30,25;265,25])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[160,80;130,80])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[330,25;490,25])
add_line([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],[455,25;455,95;440,95])
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'Mask Display','Costas PL\nDSB ADM',...
		'Mask Type','DSB-SC ADM')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'Mask Dialogue','Double-sideband suppressed-carrier amplitude demodulation:|Low-pass filter numerator:|Low-pass filter denominator:|Initial phase:|Sample time:')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;pi2=pi*2;ts=@4;')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'Mask Help','The DSB SC ADM demodulates a DSB-SC-AM signal using Costas Phase-Locked Loop method. The result of this ADM is phase sensitive. This block requires user to specify a lowpass filter which could filter the carrier freency and keep the message signal. Please refer Signal Processing Toolbox for design of the filters. ')
set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE'].

set_param([sys,'/',['ADM with carrier',13,'baseband/Costas DSB-ADM',13,'CE']],...
		'ForeGround',2,...
		'position',[100,15,175,55])
add_line([sys,'/',['ADM with carrier',13,'baseband']],[265,40;285,40])
add_line([sys,'/',['ADM with carrier',13,'baseband']],[180,35;235,35])
add_line([sys,'/',['ADM with carrier',13,'baseband']],[65,35;95,35])
add_line([sys,'/',['ADM with carrier',13,'baseband']],[195,110;210,110;215,45;235,45])
set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);ADM w TC',...
		'Mask Type','ADM with TC CE')
set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of an\nAM with TC modulated signal.|Output signal offset:|Lowpass filter numerator:|Lowpass filter denominator:|Initial Phase (rad):|Sample time (ts):')
set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'Mask Translate','Offset=@1;num=@2;den=@3;Ph=@4;ts=@5;[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of an AM with transport carrier modulated signal. This block requires you to specify a lowpass filter, which eliminates the carrier frequency and keeps the message signal. This block takes a complex signal.')
set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'Mask Entries','1\/num\/den\/0\/ts\/')


%     Finished composite block ['ADM with carrier',13,'baseband'].

set_param([sys,'/',['ADM with carrier',13,'baseband']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[240,113,320,157])


%     Subsystem  ['FDM',13,'baseband'].

new_system([sys,'/',['FDM',13,'baseband']])
set_param([sys,'/',['FDM',13,'baseband']],'Location',[240,174,805,409])


%     Subsystem  ['FDM',13,'baseband/M//P 2 C'].

new_system([sys,'/',['FDM',13,'baseband/M//P 2 C']])
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C']],'Location',[103,336,548,644])

add_block('built-in/Mux',[sys,'/',['FDM',13,'baseband/M//P 2 C/Mux']])
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/Mux']],...
		'inputs','2',...
		'position',[225,111,270,149])

add_block('built-in/S-Function',[sys,'/',['FDM',13,'baseband/M//P 2 C/Array',13,'function1']])
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/Array',13,'function1']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/Array',13,'function1']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10,sgn.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/Array',13,'function1']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''sin''\/',...
		'position',[85,149,140,181])

add_block('built-in/S-Function',[sys,'/',['FDM',13,'baseband/M//P 2 C/Array',13,'function']])
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/Array',13,'function']],...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nFcn',...
		'Mask Type','Array function')
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/Array',13,'function']],...
		'Mask Dialogue','Multi-input/multi-output functions, such as sin, cos, tan,exp,asin, acos,ln,log10,sgn.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/Array',13,'function']],...
		'Mask Help','The vector length of the output is the same as the input.',...
		'Mask Entries','''cos''\/',...
		'position',[85,74,145,106])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband/M//P 2 C/in_2']])
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/in_2']],...
		'Port','2',...
		'position',[15,155,35,175])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband/M//P 2 C/in_1']])
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/in_1']],...
		'position',[235,50,255,70])

add_block('built-in/Product',[sys,'/',['FDM',13,'baseband/M//P 2 C/Product']])
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/Product']],...
		'position',[320,107,345,138])

add_block('built-in/Outport',[sys,'/',['FDM',13,'baseband/M//P 2 C/out_1']])
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C/out_1']],...
		'position',[380,115,400,135])
add_line([sys,'/',['FDM',13,'baseband/M//P 2 C']],[150,90;170,90;170,120;220,120])
add_line([sys,'/',['FDM',13,'baseband/M//P 2 C']],[145,165;170,165;170,140;220,140])
add_line([sys,'/',['FDM',13,'baseband/M//P 2 C']],[40,165;80,165])
add_line([sys,'/',['FDM',13,'baseband/M//P 2 C']],[55,165;55,90;80,90])
add_line([sys,'/',['FDM',13,'baseband/M//P 2 C']],[275,130;315,130])
add_line([sys,'/',['FDM',13,'baseband/M//P 2 C']],[350,125;375,125])
add_line([sys,'/',['FDM',13,'baseband/M//P 2 C']],[260,60;280,60;280,115;315,115])
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C']],...
		'Mask Display','Mag/Phase\nto Cmplx',...
		'Mask Type','Mag/Phase to Complex number',...
		'Mask Dialogue','Convert Magnitude/Phase information to complex number.')
set_param([sys,'/',['FDM',13,'baseband/M//P 2 C']],...
		'Mask Help','This block conver Magnitude/Phase to complex number which is real/imag two part.')


%     Finished composite block ['FDM',13,'baseband/M//P 2 C'].

set_param([sys,'/',['FDM',13,'baseband/M//P 2 C']],...
		'orientation',2,...
		'position',[115,135,205,175])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband/in_1']])
set_param([sys,'/',['FDM',13,'baseband/in_1']],...
		'position',[45,25,65,45])

add_block('built-in/Sum',[sys,'/',['FDM',13,'baseband/Sum']])
set_param([sys,'/',['FDM',13,'baseband/Sum']],...
		'orientation',2,...
		'position',[245,155,265,175])

add_block('built-in/Constant',[sys,'/',['FDM',13,'baseband/Constant']])
set_param([sys,'/',['FDM',13,'baseband/Constant']],...
		'orientation',2,...
		'position',[290,85,320,105])


%     Subsystem  ['FDM',13,'baseband/Multiply and',13,'take imag'].

new_system([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']])
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],'Location',[317,81,820,296])

add_block('built-in/Outport',[sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/I_out_']])
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/I_out_']],...
		'position',[450,105,470,125])

add_block('built-in/Sum',[sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Sum1']])
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Sum1']],...
		'position',[390,105,410,125])

add_block('built-in/Product',[sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Product2']])
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Product2']],...
		'position',[220,108,250,132])

add_block('built-in/Product',[sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Product3']])
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Product3']],...
		'position',[310,63,340,87])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Complex',13,'input 2']])
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Complex',13,'input 2']],...
		'Port','2',...
		'position',[30,150,50,170])

add_block('built-in/Demux',[sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Split1']])
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Split1']],...
		'position',[85,139,160,181])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Complex',13,'input 1']])
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Complex',13,'input 1']],...
		'position',[40,35,60,55])

add_block('built-in/Demux',[sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Split']])
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag/Split']],...
		'position',[90,24,165,66])
add_line([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],[415,115;445,115])
add_line([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],[65,45;85,45])
add_line([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],[55,160;80,160])
add_line([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],[170,35;248,35;248,70;305,70])
add_line([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],[165,170;290,170;290,80;305,80])
add_line([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],[170,55;185,55;185,115;215,115])
add_line([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],[165,150;180,150;180,125;215,125])
add_line([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],[345,75;360,75;360,110;385,110])
add_line([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],[255,120;385,120])


%     Finished composite block ['FDM',13,'baseband/Multiply and',13,'take imag'].

set_param([sys,'/',['FDM',13,'baseband/Multiply and',13,'take imag']],...
		'position',[125,24,200,66])

add_block('built-in/Filter',[sys,'/',['FDM',13,'baseband/Filter']])
set_param([sys,'/',['FDM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,26,310,64])

add_block('built-in/Constant',[sys,'/',['FDM',13,'baseband/Constant1']])
set_param([sys,'/',['FDM',13,'baseband/Constant1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[405,205,435,225])


%     Subsystem  ['FDM',13,'baseband/Dis module',13,'integrator'].

new_system([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']])
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],'Location',[18,602,524,728])

add_block('built-in/Sum',[sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Fcn',[sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/module']])
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,350,61])

add_block('built-in/Inport',[sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[75,16,135,54])

add_block('built-in/Unit Delay',[sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[370,35,420,55])

add_block('built-in/Outport',[sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator/out_1']],...
		'position',[460,35,480,55])
add_line([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],[220,40;230,45])
add_line([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],[40,35;70,35])
add_line([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],[355,45;365,45])
add_line([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],[425,45;435,45;435,95;175,95;175,45;190,45])
add_line([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],[425,45;455,45])
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],...
		'Mask Entries','pi2\/0\/ts\/')


%     Finished composite block ['FDM',13,'baseband/Dis module',13,'integrator'].

set_param([sys,'/',['FDM',13,'baseband/Dis module',13,'integrator']],...
		'orientation',2,...
		'position',[315,140,375,180])

add_block('built-in/Gain',[sys,'/',['FDM',13,'baseband/Sensitivity']])
set_param([sys,'/',['FDM',13,'baseband/Sensitivity']],...
		'orientation',1,...
		'Gain','-pi2',...
		'position',[390,90,430,120])

add_block('built-in/Outport',[sys,'/',['FDM',13,'baseband/out_1']])
set_param([sys,'/',['FDM',13,'baseband/out_1']],...
		'position',[445,10,465,30])
add_line([sys,'/',['FDM',13,'baseband']],[400,215;295,215;295,170;270,170])
add_line([sys,'/',['FDM',13,'baseband']],[410,125;410,160;380,160])
add_line([sys,'/',['FDM',13,'baseband']],[70,35;120,35])
add_line([sys,'/',['FDM',13,'baseband']],[285,95;255,95;255,145;210,145])
add_line([sys,'/',['FDM',13,'baseband']],[240,165;210,165])
add_line([sys,'/',['FDM',13,'baseband']],[310,160;270,160])
add_line([sys,'/',['FDM',13,'baseband']],[110,155;85,155;85,55;120,55])
add_line([sys,'/',['FDM',13,'baseband']],[205,45;250,45])
add_line([sys,'/',['FDM',13,'baseband']],[315,45;325,45;325,20;440,20])
add_line([sys,'/',['FDM',13,'baseband']],[315,45;410,45;410,85])
set_param([sys,'/',['FDM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);FDM',...
		'Mask Type','FDM CE using PLL')
set_param([sys,'/',['FDM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nFM signal.|VCO initial phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['FDM',13,'baseband']],...
		'Mask Translate','Ph=@1;num=@2;den=@3;ts=@4;pi2=2*pi;[x,y]=moduicon(4);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['FDM',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a frequency modulated signal. The filter to be specified by the users is a lowpass filter which passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['FDM',13,'baseband']],...
		'Mask Entries','0\/num\/den\/ts\/')


%     Finished composite block ['FDM',13,'baseband'].

set_param([sys,'/',['FDM',13,'baseband']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[235,173,315,217])


%     Subsystem  ['FM',13,'baseband'].

new_system([sys,'/',['FM',13,'baseband']])
set_param([sys,'/',['FM',13,'baseband']],'Location',[55,571,668,718])

add_block('built-in/Constant',[sys,'/',['FM',13,'baseband/Constant']])
set_param([sys,'/',['FM',13,'baseband/Constant']],...
		'Value','Ph',...
		'position',[180,90,205,110])

add_block('built-in/Sum',[sys,'/',['FM',13,'baseband/Sum']])
set_param([sys,'/',['FM',13,'baseband/Sum']],...
		'position',[265,30,285,50])

add_block('built-in/Inport',[sys,'/',['FM',13,'baseband/in_1']])
set_param([sys,'/',['FM',13,'baseband/in_1']],...
		'position',[35,25,55,45])

add_block('built-in/Fcn',[sys,'/',['FM',13,'baseband/cos']])
set_param([sys,'/',['FM',13,'baseband/cos']],...
		'Expr','cos(u)',...
		'position',[330,26,385,54])

add_block('built-in/Fcn',[sys,'/',['FM',13,'baseband/sin']])
set_param([sys,'/',['FM',13,'baseband/sin']],...
		'Expr','sin(u)',...
		'position',[330,86,385,114])

add_block('built-in/Mux',[sys,'/',['FM',13,'baseband/Mux']])
set_param([sys,'/',['FM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[415,31,450,64])

add_block('built-in/Outport',[sys,'/',['FM',13,'baseband/out_1']])
set_param([sys,'/',['FM',13,'baseband/out_1']],...
		'position',[550,40,570,60])

add_block('built-in/S-Function',[sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']])
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/pi2\/',...
		'position',[155,14,215,56])

add_block('built-in/Gain',[sys,'/',['FM',13,'baseband/Sensitivity']])
set_param([sys,'/',['FM',13,'baseband/Sensitivity']],...
		'Gain','pi2',...
		'position',[80,20,120,50])
add_line([sys,'/',['FM',13,'baseband']],[290,40;325,40])
add_line([sys,'/',['FM',13,'baseband']],[300,40;300,100;325,100])
add_line([sys,'/',['FM',13,'baseband']],[210,100;250,100;260,45])
add_line([sys,'/',['FM',13,'baseband']],[220,35;260,35])
add_line([sys,'/',['FM',13,'baseband']],[390,40;410,40])
add_line([sys,'/',['FM',13,'baseband']],[455,50;545,50])
add_line([sys,'/',['FM',13,'baseband']],[390,100;395,100;395,55;410,55])
add_line([sys,'/',['FM',13,'baseband']],[60,35;75,35])
add_line([sys,'/',['FM',13,'baseband']],[125,35;150,35])
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);FM',...
		'Mask Type','FM CE')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of the FM signal.|Initial phase (rad):|Sample time (second):|Symbol interval (for digital mod, use Inf for analog mod):')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Translate','Kc=2*pi;Ph=@1;pi2=2*pi;ts=@2;td=@3;if isinf(td),td=inf;end;[x,y]=moduicon(3);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the frequency modulated signal. The output is a complex signal. This block resets the phase at the very beginning of the symbol interval. For continuous-time simulation, the symbol interval can be set as infinity.')
set_param([sys,'/',['FM',13,'baseband']],...
		'Mask Entries','0\/ts\/Inf\/')


%     Finished composite block ['FM',13,'baseband'].

set_param([sys,'/',['FM',13,'baseband']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[125,173,205,217])


%     Subsystem  ['PDM',13,'baseband'].

new_system([sys,'/',['PDM',13,'baseband']])
set_param([sys,'/',['PDM',13,'baseband']],'Location',[166,496,871,735])


%     Subsystem  ['PDM',13,'baseband/M//P 2 C'].

new_system([sys,'/',['PDM',13,'baseband/M//P 2 C']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C']],'Location',[87,375,532,683])

add_block('built-in/Mux',[sys,'/',['PDM',13,'baseband/M//P 2 C/Mux']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/Mux']],...
		'inputs','2',...
		'position',[225,111,270,149])

add_block('built-in/Product',[sys,'/',['PDM',13,'baseband/M//P 2 C/Product']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/Product']],...
		'position',[320,107,345,138])

add_block('built-in/Outport',[sys,'/',['PDM',13,'baseband/M//P 2 C/out_1']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/out_1']],...
		'position',[380,115,400,135])

add_block('built-in/Fcn',[sys,'/',['PDM',13,'baseband/M//P 2 C/sin']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/sin']],...
		'position',[75,127,150,153])

add_block('built-in/Fcn',[sys,'/',['PDM',13,'baseband/M//P 2 C/cos']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/cos']],...
		'Expr','cos(u[1])',...
		'position',[80,52,155,78])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/M//P 2 C/in_2']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/in_2']],...
		'Port','2',...
		'position',[15,130,35,150])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/M//P 2 C/in_1']])
set_param([sys,'/',['PDM',13,'baseband/M//P 2 C/in_1']],...
		'position',[215,70,235,90])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[160,65;170,65;170,120;220,120])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[155,140;220,140])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[275,130;315,130])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[350,125;375,125])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[240,80;280,80;280,115;315,115])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[40,140;70,140])
add_line([sys,'/',['PDM',13,'baseband/M//P 2 C']],[50,140;50,65;75,65])


%     Finished composite block ['PDM',13,'baseband/M//P 2 C'].

set_param([sys,'/',['PDM',13,'baseband/M//P 2 C']],...
		'orientation',2,...
		'position',[115,135,205,175])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/in_1']])
set_param([sys,'/',['PDM',13,'baseband/in_1']],...
		'position',[45,25,65,45])

add_block('built-in/Sum',[sys,'/',['PDM',13,'baseband/Sum']])
set_param([sys,'/',['PDM',13,'baseband/Sum']],...
		'orientation',2,...
		'position',[245,155,265,175])

add_block('built-in/Constant',[sys,'/',['PDM',13,'baseband/Constant']])
set_param([sys,'/',['PDM',13,'baseband/Constant']],...
		'orientation',2,...
		'position',[290,85,320,105])


%     Subsystem  ['PDM',13,'baseband/Multiply &',13,'take imag'].

new_system([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],'Location',[317,81,820,296])

add_block('built-in/Outport',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/I_out_']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/I_out_']],...
		'position',[450,105,470,125])

add_block('built-in/Sum',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Sum1']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Sum1']],...
		'position',[390,105,410,125])

add_block('built-in/Product',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Product2']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Product2']],...
		'position',[220,108,250,132])

add_block('built-in/Product',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Product3']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Product3']],...
		'position',[310,63,340,87])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Complex',13,'input 2']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Complex',13,'input 2']],...
		'Port','2',...
		'position',[30,150,50,170])

add_block('built-in/Demux',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split1']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split1']],...
		'position',[85,139,160,181])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Complex',13,'input 1']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Complex',13,'input 1']],...
		'position',[40,35,60,55])

add_block('built-in/Demux',[sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split']])
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag/Split']],...
		'position',[90,24,165,66])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[415,115;445,115])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[65,45;85,45])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[55,160;80,160])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[170,35;248,35;248,70;305,70])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[165,170;290,170;290,80;305,80])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[170,55;185,55;185,115;215,115])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[165,150;180,150;180,125;215,125])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[345,75;360,75;360,110;385,110])
add_line([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],[255,120;385,120])


%     Finished composite block ['PDM',13,'baseband/Multiply &',13,'take imag'].

set_param([sys,'/',['PDM',13,'baseband/Multiply &',13,'take imag']],...
		'position',[125,24,200,66])

add_block('built-in/Filter',[sys,'/',['PDM',13,'baseband/Filter']])
set_param([sys,'/',['PDM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[255,26,310,64])

add_block('built-in/Constant',[sys,'/',['PDM',13,'baseband/Constant1']])
set_param([sys,'/',['PDM',13,'baseband/Constant1']],...
		'orientation',2,...
		'Value','Ph',...
		'position',[340,190,370,210])

add_block('built-in/Gain',[sys,'/',['PDM',13,'baseband/Sensitivity']])
set_param([sys,'/',['PDM',13,'baseband/Sensitivity']],...
		'Gain','-2*pi',...
		'position',[355,30,395,60])


%     Subsystem  ['PDM',13,'baseband/Dis module',13,'integrator1'].

new_system([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],'Location',[48,515,661,644])

add_block('built-in/Outport',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/out_1']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/out_1']],...
		'position',[425,30,445,50])

add_block('built-in/Unit Delay',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Unit Delay']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Inport',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/in_1']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/module']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Sum']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Gain',[sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Gain1']])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1/Gain1']],...
		'Gain','ts(1)',...
		'position',[100,20,130,50])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[400,40;420,40])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[330,40;340,40])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[135,35;190,35])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[40,35;95,35])
add_line([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],[220,40;230,40])
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:',...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],...
		'Mask Entries','100\/0\/ts\/')


%     Finished composite block ['PDM',13,'baseband/Dis module',13,'integrator1'].

set_param([sys,'/',['PDM',13,'baseband/Dis module',13,'integrator1']],...
		'orientation',1,...
		'position',[390,95,450,135])

add_block('built-in/Gain',[sys,'/',['PDM',13,'baseband/Gain1']])
set_param([sys,'/',['PDM',13,'baseband/Gain1']],...
		'Gain','-ts(1)',...
		'position',[465,30,495,60])

add_block('built-in/Sum',[sys,'/',['PDM',13,'baseband/Sum1']])
set_param([sys,'/',['PDM',13,'baseband/Sum1']],...
		'position',[565,40,585,60])

add_block('built-in/Unit Delay',[sys,'/',['PDM',13,'baseband/Unit Delay']])
set_param([sys,'/',['PDM',13,'baseband/Unit Delay']],...
		'orientation',2,...
		'Sample time','ts',...
		'position',[555,80,605,100])

add_block('built-in/Outport',[sys,'/',['PDM',13,'baseband/out_1']])
set_param([sys,'/',['PDM',13,'baseband/out_1']],...
		'position',[660,40,680,60])
add_line([sys,'/',['PDM',13,'baseband']],[420,140;420,160;270,160])
add_line([sys,'/',['PDM',13,'baseband']],[335,200;295,200;295,170;270,170])
add_line([sys,'/',['PDM',13,'baseband']],[70,35;120,35])
add_line([sys,'/',['PDM',13,'baseband']],[285,95;255,95;255,145;210,145])
add_line([sys,'/',['PDM',13,'baseband']],[240,165;210,165])
add_line([sys,'/',['PDM',13,'baseband']],[110,155;85,155;85,55;120,55])
add_line([sys,'/',['PDM',13,'baseband']],[205,45;250,45])
add_line([sys,'/',['PDM',13,'baseband']],[315,45;350,45])
add_line([sys,'/',['PDM',13,'baseband']],[500,45;560,45])
add_line([sys,'/',['PDM',13,'baseband']],[550,90;540,90;540,55;560,55])
add_line([sys,'/',['PDM',13,'baseband']],[590,50;630,50;630,90;610,90])
add_line([sys,'/',['PDM',13,'baseband']],[630,50;655,50])
add_line([sys,'/',['PDM',13,'baseband']],[400,45;460,45])
add_line([sys,'/',['PDM',13,'baseband']],[420,45;420,90])
set_param([sys,'/',['PDM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);PDM',...
		'Mask Type','PLL PDM CE')
set_param([sys,'/',['PDM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nPM modulated signal.|VCO initial phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Sample time (sec):')
set_param([sys,'/',['PDM',13,'baseband']],...
		'Mask Translate','Ph=@1;num=@2;den=@3;ts=@4;pi2=2*pi;[x,y]=moduicon(4);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['PDM',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a PM modulated signal. This block uses a phase-locked loop with a multiplier phase detector.',...
		'Mask Entries','0\/num\/den\/ts\/')


%     Finished composite block ['PDM',13,'baseband'].

set_param([sys,'/',['PDM',13,'baseband']],...
		'ForeGround',7,...
		'hide name',0,...
		'position',[235,243,315,287])


%     Subsystem  ['PM',13,'baseband'].

new_system([sys,'/',['PM',13,'baseband']])
set_param([sys,'/',['PM',13,'baseband']],'Location',[320,489,688,666])

add_block('built-in/Mux',[sys,'/',['PM',13,'baseband/Mux']])
set_param([sys,'/',['PM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[250,51,285,84])

add_block('built-in/Outport',[sys,'/',['PM',13,'baseband/out_1']])
set_param([sys,'/',['PM',13,'baseband/out_1']],...
		'position',[315,60,335,80])

add_block('built-in/Fcn',[sys,'/',['PM',13,'baseband/sin']])
set_param([sys,'/',['PM',13,'baseband/sin']],...
		'Expr','sin(u)',...
		'position',[155,106,210,134])

add_block('built-in/Fcn',[sys,'/',['PM',13,'baseband/cos']])
set_param([sys,'/',['PM',13,'baseband/cos']],...
		'Expr','cos(u)',...
		'position',[155,46,210,74])

add_block('built-in/Inport',[sys,'/',['PM',13,'baseband/in_1']])
set_param([sys,'/',['PM',13,'baseband/in_1']],...
		'position',[35,50,55,70])
add_line([sys,'/',['PM',13,'baseband']],[215,60;245,60])
add_line([sys,'/',['PM',13,'baseband']],[290,70;310,70])
add_line([sys,'/',['PM',13,'baseband']],[215,120;230,120;230,75;245,75])
add_line([sys,'/',['PM',13,'baseband']],[60,60;150,60])
add_line([sys,'/',['PM',13,'baseband']],[130,60;130,120;150,120])
set_param([sys,'/',['PM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);PM',...
		'Mask Type','PM CE',...
		'Mask Dialogue','Output the complex envelope of a PM\nmodulated signal.|Initial phase (rad):')
set_param([sys,'/',['PM',13,'baseband']],...
		'Mask Translate','Ph=@1;pi2=2*pi;[x,y]=moduicon(3);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['PM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the phase modulated signal. The output of this block is a complex signal.',...
		'Mask Entries','0\/')


%     Finished composite block ['PM',13,'baseband'].

set_param([sys,'/',['PM',13,'baseband']],...
		'ForeGround',7,...
		'hide name',0,...
		'position',[125,243,205,287])


%     Subsystem  ['SSB-ADM',13,'baseband'].

new_system([sys,'/',['SSB-ADM',13,'baseband']])
set_param([sys,'/',['SSB-ADM',13,'baseband']],'Location',[283,122,827,380])

add_block('built-in/Outport',[sys,'/',['SSB-ADM',13,'baseband/out_1']])
set_param([sys,'/',['SSB-ADM',13,'baseband/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Note',[sys,'/',['SSB-ADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Filter',[sys,'/',['SSB-ADM',13,'baseband/Filter']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Product',[sys,'/',['SSB-ADM',13,'baseband/Product']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Sum',[sys,'/',['SSB-ADM',13,'baseband/Sum']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Constant',[sys,'/',['SSB-ADM',13,'baseband/Constant']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Demux',[sys,'/',['SSB-ADM',13,'baseband/Demux']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Demux']],...
		'outputs','2',...
		'position',[105,105,160,140])

add_block('built-in/Product',[sys,'/',['SSB-ADM',13,'baseband/Product1']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Inport',[sys,'/',['SSB-ADM',13,'baseband/in_1']])
set_param([sys,'/',['SSB-ADM',13,'baseband/in_1']],...
		'position',[55,115,75,135])

add_block('built-in/Constant',[sys,'/',['SSB-ADM',13,'baseband/Constant1']])
set_param([sys,'/',['SSB-ADM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[150,175,170,195])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[450,80;475,80])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[360,80;385,80])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[80,125;100,125])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[180,50;255,50])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[165,130;255,130])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['SSB-ADM',13,'baseband']],[175,185;210,185;210,140;255,140])
set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);SSB ADM',...
		'Mask Type','SSB-SC ADM CE')
set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nSSB AM modulated signal.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a SSB-SC-AM modulated signal. This block requires you to specify a lowpass filter which eliminates the carrier frequency and keeps the message signal. This block takes a complex signal.')
set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'Mask Entries','num\/den\/0\/ts\/')


%     Finished composite block ['SSB-ADM',13,'baseband'].

set_param([sys,'/',['SSB-ADM',13,'baseband']],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[240,313,320,357])


%     Subsystem  ['SSB-AM',13,'baseband'].

new_system([sys,'/',['SSB-AM',13,'baseband']])
set_param([sys,'/',['SSB-AM',13,'baseband']],'Location',[65,60,522,206])

add_block('built-in/Gain',[sys,'/',['SSB-AM',13,'baseband/Gain']])
set_param([sys,'/',['SSB-AM',13,'baseband/Gain']],...
		'Gain','k',...
		'position',[190,75,210,95])

add_block('built-in/Filter',[sys,'/',['SSB-AM',13,'baseband/Filter']])
set_param([sys,'/',['SSB-AM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[90,66,145,104])

add_block('built-in/Outport',[sys,'/',['SSB-AM',13,'baseband/out_1']])
set_param([sys,'/',['SSB-AM',13,'baseband/out_1']],...
		'position',[395,30,415,50])


%     Subsystem  ['SSB-AM',13,'baseband/QAM CE'].

new_system([sys,'/',['SSB-AM',13,'baseband/QAM CE']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],'Location',[125,397,758,690])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/R1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/R1']],...
		'position',[190,15,195,20])

add_block('built-in/Product',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Product']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Product',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Product1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Sum',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Sum']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/R_out']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Mux',[sys,'/',['SSB-AM',13,'baseband/QAM CE/RI2C']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex',...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Inport',[sys,'/',['SSB-AM',13,'baseband/QAM CE/in_1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Outport',[sys,'/',['SSB-AM',13,'baseband/QAM CE/out_1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Constant',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Constant']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Constant',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Constant1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/I1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Inport',[sys,'/',['SSB-AM',13,'baseband/QAM CE/in_2']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/R2']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/I2']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Product',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Product3']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Product',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Product2']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Sum',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Sum1']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/I_out']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/QAM CE/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[550,140;580,140])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[250,100;250,245;305,245])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[280,175;280,200;305,200])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[270,155;270,235;305,235])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[120,40;295,40])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[238,40;238,190;305,190])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['SSB-AM',13,'baseband/QAM CE']],[410,220;425,220;425,150;465,150])
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'Mask Display','QM DSB\nAM',...
		'Mask Type','Quadrature Multiplexed DSB-SC AM')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'Mask Dialogue','Quadrature multiplexed double-sideband suppressed-carrier amplitude modulation:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'Mask Translate','Ph=@1;ts=@2;x1=cos(Ph);x2=sin(Ph);')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'Mask Help','The Quadratic Multiplexed Double-Sideband-Supressed-Carrier AM block causes the amplitude of the sinusoidal carrier to depend on the input message signal, resulting in amplitude modulation. There are two input signal being modulated at the same time by using two orthogonal sinusoidal carriers.')
set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'Mask Entries','Ph\/ts\/')


%     Finished composite block ['SSB-AM',13,'baseband/QAM CE'].

set_param([sys,'/',['SSB-AM',13,'baseband/QAM CE']],...
		'position',[280,20,360,60])

add_block('built-in/Note',[sys,'/',['SSB-AM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp82']])
set_param([sys,'/',['SSB-AM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp82']],...
		'position',[355,290,360,295])

add_block('built-in/Inport',[sys,'/',['SSB-AM',13,'baseband/in_1']])
set_param([sys,'/',['SSB-AM',13,'baseband/in_1']],...
		'position',[30,20,50,40])
add_line([sys,'/',['SSB-AM',13,'baseband']],[215,85;240,85;240,50;275,50])
add_line([sys,'/',['SSB-AM',13,'baseband']],[150,85;185,85])
add_line([sys,'/',['SSB-AM',13,'baseband']],[55,30;65,30;65,85;85,85])
add_line([sys,'/',['SSB-AM',13,'baseband']],[65,30;275,30])
add_line([sys,'/',['SSB-AM',13,'baseband']],[365,40;390,40])
set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);SSB AM',...
		'Mask Type','SSB-AM CE using Hilbert transform filter.')
set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'Mask Dialogue','Output complex envelope of a SSB AM\nmodulated signal.|Initial Phase (rad):|Bandwidth of the input signal (Hz):|Time delay for Hilbert transform filter (sec):|Sample time (sec):|"upper" sideband or "lower" sideband:')
set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'Mask Translate','Ph=@1;ban=@2;dly=@3;ts=@4;sd=@5;k=-1;if sd(1)==''l'',k=1;end;if ban>1/ts, ban=1/ts-ts;end;[num,den]=hilbiir(ts,dly,ban);pi2=2*pi;pih=pi/2;[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of a SSB AM modulated signal. This block uses the Hilbert transfer filter. Because the Hilbert transform filter is a non-causal filter, you must use a positive time delay in the implementation. The input signal bandwidth is needed in designing the Hilbert transform filter. You can specify the modulation to be an USB or LSB modulation.')
set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'Mask Entries','0\/10\/.1\/ts\/''lower''\/')


%     Finished composite block ['SSB-AM',13,'baseband'].

set_param([sys,'/',['SSB-AM',13,'baseband']],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[130,313,210,357])


%     Subsystem  ['QAM',13,'baseband'].

new_system([sys,'/',['QAM',13,'baseband']])
set_param([sys,'/',['QAM',13,'baseband']],'Location',[321,500,954,793])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/I_out']])
set_param([sys,'/',['QAM',13,'baseband/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Sum',[sys,'/',['QAM',13,'baseband/Sum1']])
set_param([sys,'/',['QAM',13,'baseband/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product2']])
set_param([sys,'/',['QAM',13,'baseband/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product3']])
set_param([sys,'/',['QAM',13,'baseband/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/I2']])
set_param([sys,'/',['QAM',13,'baseband/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/R2']])
set_param([sys,'/',['QAM',13,'baseband/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Inport',[sys,'/',['QAM',13,'baseband/in_2']])
set_param([sys,'/',['QAM',13,'baseband/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/I1']])
set_param([sys,'/',['QAM',13,'baseband/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Constant',[sys,'/',['QAM',13,'baseband/Constant1']])
set_param([sys,'/',['QAM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Constant',[sys,'/',['QAM',13,'baseband/Constant']])
set_param([sys,'/',['QAM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Outport',[sys,'/',['QAM',13,'baseband/out_1']])
set_param([sys,'/',['QAM',13,'baseband/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Inport',[sys,'/',['QAM',13,'baseband/in_1']])
set_param([sys,'/',['QAM',13,'baseband/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Mux',[sys,'/',['QAM',13,'baseband/RI2C']])
set_param([sys,'/',['QAM',13,'baseband/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex',...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['QAM',13,'baseband/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['QAM',13,'baseband/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/R_out']])
set_param([sys,'/',['QAM',13,'baseband/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Sum',[sys,'/',['QAM',13,'baseband/Sum']])
set_param([sys,'/',['QAM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product1']])
set_param([sys,'/',['QAM',13,'baseband/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Product',[sys,'/',['QAM',13,'baseband/Product']])
set_param([sys,'/',['QAM',13,'baseband/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Note',[sys,'/',['QAM',13,'baseband/R1']])
set_param([sys,'/',['QAM',13,'baseband/R1']],...
		'position',[190,15,195,20])
add_line([sys,'/',['QAM',13,'baseband']],[410,220;425,220;425,150;465,150])
add_line([sys,'/',['QAM',13,'baseband']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['QAM',13,'baseband']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['QAM',13,'baseband']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['QAM',13,'baseband']],[120,40;295,40])
add_line([sys,'/',['QAM',13,'baseband']],[238,40;238,190;305,190])
add_line([sys,'/',['QAM',13,'baseband']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['QAM',13,'baseband']],[270,155;270,235;305,235])
add_line([sys,'/',['QAM',13,'baseband']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['QAM',13,'baseband']],[280,175;280,200;305,200])
add_line([sys,'/',['QAM',13,'baseband']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['QAM',13,'baseband']],[250,100;250,245;305,245])
add_line([sys,'/',['QAM',13,'baseband']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['QAM',13,'baseband']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['QAM',13,'baseband']],[550,140;580,140])
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['QAM',13,'baseband']],...
		'Mask Entries','0\/')


%     Finished composite block ['QAM',13,'baseband'].

set_param([sys,'/',['QAM',13,'baseband']],...
		'ForeGround',5,...
		'hide name',0,...
		'position',[125,418,205,462])


%     Subsystem  ['QADM',13,'baseband'].

new_system([sys,'/',['QADM',13,'baseband']])
set_param([sys,'/',['QADM',13,'baseband']],'Location',[283,122,827,462])

add_block('built-in/Outport',[sys,'/',['QADM',13,'baseband/out_1']])
set_param([sys,'/',['QADM',13,'baseband/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Note',[sys,'/',['QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Filter',[sys,'/',['QADM',13,'baseband/Filter']])
set_param([sys,'/',['QADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product']])
set_param([sys,'/',['QADM',13,'baseband/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Sum',[sys,'/',['QADM',13,'baseband/Sum']])
set_param([sys,'/',['QADM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product3']])
set_param([sys,'/',['QADM',13,'baseband/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product2']])
set_param([sys,'/',['QADM',13,'baseband/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Constant',[sys,'/',['QADM',13,'baseband/Constant']])
set_param([sys,'/',['QADM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Demux',[sys,'/',['QADM',13,'baseband/Demux']])
set_param([sys,'/',['QADM',13,'baseband/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Product',[sys,'/',['QADM',13,'baseband/Product1']])
set_param([sys,'/',['QADM',13,'baseband/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Filter',[sys,'/',['QADM',13,'baseband/Filter1']])
set_param([sys,'/',['QADM',13,'baseband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Outport',[sys,'/',['QADM',13,'baseband/out_2']])
set_param([sys,'/',['QADM',13,'baseband/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Sum',[sys,'/',['QADM',13,'baseband/Sum1']])
set_param([sys,'/',['QADM',13,'baseband/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Constant',[sys,'/',['QADM',13,'baseband/Constant1']])
set_param([sys,'/',['QADM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Inport',[sys,'/',['QADM',13,'baseband/in_1']])
set_param([sys,'/',['QADM',13,'baseband/in_1']],...
		'position',[55,115,75,135])
add_line([sys,'/',['QADM',13,'baseband']],[455,230;480,230])
add_line([sys,'/',['QADM',13,'baseband']],[365,230;390,230])
add_line([sys,'/',['QADM',13,'baseband']],[450,80;475,80])
add_line([sys,'/',['QADM',13,'baseband']],[360,80;385,80])
add_line([sys,'/',['QADM',13,'baseband']],[80,125;115,125])
add_line([sys,'/',['QADM',13,'baseband']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['QADM',13,'baseband']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['QADM',13,'baseband']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['QADM',13,'baseband']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['QADM',13,'baseband']],[180,50;255,50])
add_line([sys,'/',['QADM',13,'baseband']],[215,50;215,200;265,200])
add_line([sys,'/',['QADM',13,'baseband']],[165,130;255,130])
add_line([sys,'/',['QADM',13,'baseband']],[180,130;180,210;265,210])
add_line([sys,'/',['QADM',13,'baseband']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['QADM',13,'baseband']],[200,255;265,255])
add_line([sys,'/',['QADM',13,'baseband']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['QADM',13,'baseband']],[230,115;230,245;265,245])
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['QADM',13,'baseband']],...
		'Mask Entries','num\/den\/0\/ts\/')


%     Finished composite block ['QADM',13,'baseband'].

set_param([sys,'/',['QADM',13,'baseband']],...
		'ForeGround',5,...
		'hide name',0,...
		'position',[230,418,310,462])
add_line(sys,[80,60;120,60])
add_line(sys,[100,60;100,195;120,195])
add_line(sys,[100,60;100,15;135,15])
add_line(sys,[320,60;355,60])
add_line(sys,[100,135;125,135])
add_line(sys,[325,135;360,135])
add_line(sys,[320,195;360,195])
add_line(sys,[100,195;100,265;120,265])
add_line(sys,[320,265;355,265])
add_line(sys,[100,265;100,335;125,335])
add_line(sys,[325,335;355,335])
add_line(sys,[65,450;120,450])
add_line(sys,[100,335;100,430;120,430])
add_line(sys,[315,430;395,430])
add_line(sys,[315,450;345,450])
add_line(sys,[85,450;85,495;160,495])
add_line(sys,[390,390;410,390])
add_line(sys,[210,265;230,265])
add_line(sys,[210,195;230,195])
add_line(sys,[215,135;235,135])
add_line(sys,[215,335;235,335])
add_line(sys,[210,440;225,440])
add_line(sys,[210,60;230,60])
add_line(sys,[215,335;225,335;225,385;325,385])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
