%DCMDCW1D Demonstrates continuous wavelet tools in the Wavelet Toolbox. 

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 17:15:01 $

% Demo initialization ====================
if ~exist('DRVShowGUIFlag'), figNumber = 0; end;

echo off
clc;
titre   = 'Continuous Wavelet Transform 1-D';

if wshowdrv('init',figNumber)
        if figNumber==0
                pos    = [380 500 400 500];
                active_fig = figure(...
                    'Name',titre,                   ...
                    'NumberTitle','off',            ...
                    'Unit','Pixels',                ...
                    'Position',pos,                 ...
                    'DefaultAxesFontSize',10,       ...
                    'DefaultTextFontSize',10        ...
                    );
                set(active_fig,'Units','Normalized');
        else
                set(figNumber,'Name',titre);
                wshowdrv('setactfig',figNumber,figNumber);
                democmdm('startshow',figNumber,'cw1d');
                return;
        end
end
if exist('wait_mode')~=1 , wait_mode = 1; end
if figNumber , active_fig = wshowdrv('getactfig',figNumber); end

comment = str2mat( ...
            '% Load original fractal signal.', ...
            ' ', ...
            '        load vonkoch', ...
            '        vonkoch = vonkoch(1:510);', ...
            '        lv = length(vonkoch);' ...
                );
wshowdrv('disp',figNumber,comment); 

% Load original fractal signal.
        load vonkoch
        vonkoch = vonkoch(1:510);
        lv = length(vonkoch);

h1 = subplot(311);
plot(vonkoch,'r');title('Analyzed signal.');
set(gca,'Xlim',[0 510])

if wshowdrv('pause',figNumber,wait_mode), return; end;

comment = str2mat( ...
            '% This example aims to demonstrate the difference between', ...
            '% discrete and continuous wavelet transforms.', ...
            '% Perform discrete wavelet transform at level 5 by sym2.', ...
            '% Levels 1 to 5 correspond to scales 2, 4, 8, 16 and 32.', ...
            ' ', ...
            '        [c,l] = wavedec(vonkoch,5,''sym2'');' ...
                );
wshowdrv('disp',figNumber,comment); 

% This example aims to demonstrate the difference between
% discrete and continuous wavelet transforms.

% Perform discrete wavelet transform at level 5 by sym2. 
% Levels 1 to 5 correspond to scales 2, 4, 8, 16 and 32.
        [c,l] = wavedec(vonkoch,5,'sym2');

if wshowdrv('pause',figNumber,wait_mode), return; end;

comment = str2mat( ...
            '% Expand discrete wavelet coefficients for plot.', ...
            '% Levels 1 to 5 correspond to scales 2, 4, 8, 16 and 32.' ...
                );
wshowdrv('disp',figNumber,comment);

% Expand discrete wavelet coefficients for plot.
% Levels 1 to 5 correspond to scales 2, 4, 8, 16 and 32.
        cfd = zeros(5,lv);
        for k = 1:5
                d = detcoef(c,l,k);
                d = d(:)';
                d = d(ones(1,2^k),:);
                cfd(k,:) = wkeep(d(:)',lv);
        end
        cfd =  cfd(:);
        I = find(abs(cfd)<sqrt(eps));
        cfd(I)=zeros(size(I));
        cfd = reshape(cfd,5,lv);

set(h1,'Xtick',[],'Xticklabels',[]);
h2 = subplot(312);

comment = str2mat( ...
            '% Plot discrete coefficients.', ...
            ' ', ...
            '        colormap(pink(64));', ...
            '        img = image(flipud(wcodemat(cfd,64,''row'')));' ...
                );
wshowdrv('disp',figNumber,comment);

% Plot discrete coefficients.
colormap(pink(64));
img = image(flipud(wcodemat(cfd,64,'row'))); 

        tics = 5:-1:1;
        labs = str2mat('1','2','3','4','5');
        set(get(img,'parent'),                  ...
                'YTicklabelMode','manual',      ...
                'YTick',tics,                   ...
                'YTickLabels',labs,             ...
                'Box','On'                      ...
                );
        title('Discrete Transform, absolute coefficients.')
        ylabel('level')

if wshowdrv('pause',figNumber,wait_mode), return; end;

set(h2,'Xtick',[],'Xticklabels',[]);
h3 = subplot(313);

comment = str2mat( ...
            '% compute coefficients.', ...
            ' ', ...
            '        coefs = cwt(vonkoch,1:32,''sym2'',''plot'');', ...
            '        colormap(pink(64));' ...
                );
wshowdrv('disp',figNumber,comment);

% compute coefficients.
        coefs = cwt(vonkoch,1:32,'sym2','plot');
        colormap(pink(64))

tt = get(h3,'Yticklabels');
[r,c] = size(tt);
yl = setstr(32*ones(r,c));
for k = 1:3:r , yl(k,:) = tt(k,:); end
set(h3,'Yticklabels',yl);


if wshowdrv('pause',figNumber,wait_mode), return; end;

% Reset axes.
delete(findobj(active_fig,'type','axes'));

clear freqbrk;
map = cool(64);

comment = str2mat( ...
            '% Another example.', ...
            ' ', ...
            '        wname   = ''db1'';', ...
            '        scales  = [1:32];', ...
            '        load freqbrk' ...
                );
wshowdrv('disp',figNumber,comment);

% Another example.
        wname   = 'db1';
        scales  = [1:32];
        load freqbrk

signal = freqbrk;
clear freqbrk;
map     = cool(128);
lv      = length(signal);
h1 = subplot(311);
plot(signal,'r');title('Analyzed signal.');
set(gca,'Xlim',[0 lv])

[c,l]   = wavedec(signal,5,wname);
cfd = zeros(5,lv);
for k = 1:5
        d = detcoef(c,l,k);
        d = d(:)';
        d = d(ones(1,2^k),:);
        cfd(k,:) = wkeep(d(:)',lv);
end
cfd =  cfd(:);
I = find(abs(cfd)<sqrt(eps));
cfd(I) = zeros(size(I));
cfd    = reshape(cfd,5,lv);

% Plot discrete coefficients.
set(h1,'Xtick',[],'Xticklabels',[]);
h2 = subplot(312);
colormap(map);
img = image(flipud(wcodemat(cfd,64,'row'))); 
tics = 5:-1:1;
labs = str2mat('1','2','3','4','5');
set(get(img,'parent'),                  ...
        'YTicklabelMode','manual',      ...
        'YTick',tics,                   ...
        'YTickLabels',labs,             ...
        'Box','On'                      ...
                );
title('Discrete Transform, absolute coefficients.')
ylabel('level')

% set next plot parameters.
set(h2,'Xtick',[],'Xticklabels',[]);
h3 = subplot(313);
coefs = cwt(signal,scales,wname,'plot');

tt = get(h3,'Yticklabels');
[r,c] = size(tt);
yl = setstr(32*ones(r,c));
for k = 1:3:r , yl(k,:) = tt(k,:); end
set(h3,'Yticklabels',yl);

colormap(map);

if figNumber==0
        wshowdrv('pause',figNumber,wait_mode);
        delete(active_fig);
end
