% Wavelet Toolbox.
% Version 1.0 12-Mar-96
% Copyright (c) 1995-96 by The Mathworks, Inc.
% $Revision: 1.1 $  $Date: 1996/03/05 21:05:17 $
%
% GUI tools.
%   wavemenu    - Start graphical user interface tools.
%
% Wavelets: General.
%   biorfilt    - Biorthogonal wavelet filter set.
%   dyaddown    - Dyadic downsampling.
%   dyadup      - Dyadic upsampling.
%   intwave     - Integrate wavelet function psi.
%   orthfilt    - Orthogonal wavelet filter set.
%   qmf         - Quadrature mirror filter.
%   wavefun     - Wavelet and scaling functions.
%   wavemngr    - Wavelet manager. 
%   wfilters    - Wavelet filters.
%   wmaxlev     - Maximum wavelet decomposition level.
%
% Wavelet Families.
%   biorwavf    - Biorthogonal spline wavelet filters.
%   coifwavf    - Coiflets wavelet filters.
%   dbaux       - Daubechies wavelet filters computation.
%   dbwavf      - Daubechies wavelet filters.
%   mexihat     - Mexican hat wavelet.
%   meyer       - Meyer wavelet.
%   meyeraux    - Meyer wavelet auxiliary function.
%   morlet      - Morlet wavelet.
%   symwavf     - Symlets wavelet filters.
%
% Continuous Wavelet: 1-D
%   cwt         - Continuous wavelet coefficients 1-D.
%
% Discrete Wavelets: 1-D
%   appcoef     - Extract 1-D approximation coefficients.
%   detcoef     - Extract 1-D detail coefficients.
%   dwt         - Single-level discrete 1-D wavelet transform.
%   dwtper      - Single-level discrete 1-D wavelet transform (periodized).
%   dwtmode     - Discrete wavelet transform extension mode.
%   idwt        - Single-level inverse discrete 1-D wavelet transform.
%   idwtper     - Single-level inverse discrete 1-D wavelet transform (periodized).
%   upcoef      - Direct reconstruction from 1-D wavelet coefficients.
%   upwlev      - Single-level reconstruction of 1-D wavelet decomposition.
%   wavedec     - Multi-level 1-D wavelet decomposition.
%   waverec     - Multi-level 1-D wavelet reconstruction.
%   wrcoef      - Reconstruct single branch from 1-D wavelet coefficients.
%
% Discrete Wavelets: 2-D.
%   appcoef2    - Extract 2-D approximation coefficients.
%   detcoef2    - Extract 2-D detail coefficients.
%   dwt2        - Single-level discrete 2-D wavelet transform.
%   dwtper2     - Single-level discrete 2-D wavelet transform (periodized).
%   dwtmode     - Discrete wavelet transform extension mode.
%   idwt2       - Single-level inverse discrete 2-D wavelet transform.
%   idwtper2    - Single-level inverse discrete 2-D wavelet transform (periodized).
%   upcoef2     - Direct reconstruction from 2-D wavelet coefficients.
%   upwlev2     - Single-level reconstruction of 2-D wavelet decomposition.
%   wavedec2    - Multi-level 2-D wavelet decomposition.
%   waverec2    - Multi-level 2-D wavelet reconstruction.
%   wrcoef2     - Reconstruct single branch from 2-D wavelet coefficients.
%
% Wavelets Packets Algorithms.
%   besttree    - Best tree (wavelet packet).
%   bestlevt    - Best level tree (wavelet packet).
%   entrupd     - Entropy update (wavelet packet).
%   wentropy    - Entropy(wavelet packet).
%   wp2wtree    - Extract wavelet tree from wavelet packet tree.
%   wpcoef      - Wavelet packet coefficients.
%   wpcutree    - Cut wavelet packet tree.
%   wpdec       - Wavelet packet decomposition 1-D.
%   wpdec2      - Wavelet packet decomposition 2-D.
%   wpfun       - Wavelet packet functions.
%   wpjoin      - Recompose wavelet packet.
%   wprcoef     - Reconstruct wavelet packet coefficients.
%   wprec       - Wavelet packet reconstruction 1-D. 
%   wprec2      - Wavelet packet reconstruction 2-D.
%   wpsplt      - Split (decompose) wavelet packet.
%
% De-noising and Compression for Signals and Images.
%   ddencmp     - Default values for de-noising or compression.
%   thselect    - Threshold selection for de-noising.
%   wden        - Automatic 1-D de-noising using wavelets.
%   wdencmp     - De-noising or compression using wavelets.
%   wnoise      - Generate noisy wavelet test data.
%   wnoisest    - Estimate noise of 1-D wavelet coefficients.
%   wpdencmp    - De-noising or compression using wavelet packet.
%   wpthcoef    - Wavelet packet coefficients thresholding.
%   wthcoef     - Wavelet coefficients thresholding 1-D.
%   wthcoef2    - Wavelet coefficients thresholding 2-D.
%   wthresh     - Perform soft or hard thresholding.
%
% Tree Management Utilities.
%   allnodes    - Tree nodes.
%   depo2ind    - Node depth-position to node index.
%   ind2depo    - Node index to node depth-position.
%   isnode      - True for existing node.
%   istnode     - True for terminal nodes.
%   maketree    - Make tree.
%   nodeasc     - Node ascendants.
%   nodedesc    - Node descendants.
%   nodejoin    - Recompose node.
%   nodepar     - Node parent.
%   nodesplt    - Split (decompose) node.
%   ntnode      - Number of terminal nodes.
%   plottree    - Plot tree.
%   tnodes      - Terminal nodes.
%   treedpth    - Tree depth.
%   treeord     - Tree order.
%   wdatamgr    - Manager for data structure.
%   wtreemgr    - Manager for tree structure.
%
% General Utilities.
%   deblankl    - Convert string to lowercase without blanks. 
%   errargn     - Check function arguments number.
%   errargt     - Check function arguments type.
%   num2mstr    - Convert number to string in maximum precision.
%   wcodemat    - Extended pseudocolor matrix scaling.
%   wcommon     - Find common elements.
%   wkeep       - Keep part of a vector or a matrix.
%   wrev        - Flip vector.
%
% Other.
%   instdfft    - Inverse non-standard 1-D fast Fourier transform.
%   nstdfft     - Non-standard 1-D fast Fourier transform.
%
% Wavelets Information.
%   waveinfo    - Information on wavelets.
%
% Demos.
%   wavedemo    - Wavelet toolbox demos.
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Non documented functions used in the toolbox and not user oriented. %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Miscellaneous
%   wavetool    - Warning function (Strang-Nguyen' book refers to wavetool).
%
% Wavelets Information.
%   biorinfo    - Information on biorthogonal spline wavelets.
%   coifinfo    - Information on coiflets.
%   dbinfo      - Information on Daubechies wavelets.
%   haarinfo    - Information on Haar wavelet.
%   infowave    - Information on wavelets.
%   infowsys    - Information on wavelet packets.
%   mexhinfo    - Information on mexican hat wavelet.
%   meyrinfo    - Information on Meyer wavelet.
%   morlinfo    - Information on Morlet wavelet.
%   syminfo     - Information on near symmetric wavelets.
%
% Graphical User Interface: Main Tools.
%   cw1dtool    - Continuous wavelet 1-D tool.
%   dw1dtool    - Discrete wavelet 1-D tool.
%   dw2dtool    - Discrete wavelet 2-D tool.
%   wp1dtool    - Wavelet packets 1-D tool.
%   wp2dtool    - Wavelet packets 2-D tool.
%   wpdtool     - Wavelet packets display tool.
%   wvdtool     - Wavelet display tool.
%
% Graphical User Interface: Wavelets 1-D and 2-D.
%   dw1dcolo    - Discrete wavelet 1-D coloration manager.
%   dw1dcomp    - Discrete wavelet 1-D compression.
%   dw1ddecm    - Discrete wavelet 1-D full decomposition mode.
%   dw1ddeno    - Discrete wavelet 1-D de-noising.
%   dw1ddisp    - Discrete wavelet 1-D display mode options.
%   dw1dfile    - Discrete wavelet 1-D file manager.
%   dw1dhist    - Discrete wavelet 1-D histograms.
%   dw1dmisc    - Discrete wavelet 1-D miscellaneaous utilities.
%   dw1dmngr    - Discrete wavelet 1-D general manager.
%   dw1dscrm    - Discrete wavelet 1-D show and scroll mode manager.
%   dw1dsepm    - Discrete wavelet 1-D separate mode manager.
%   dw1dstat    - Discrete wavelet 1-D statistics.
%   dw1dsupm    - Discrete wavelet 1-D superimpose mode manager.
%   dw1dtrem    - Discrete Wavelet 1-D tree mode manager.
%   dw1dutil    - Discrete wavelet 1-D utilities.
%   dw1dvdrv    - Discrete wavelet 1-D view mode driver.
%   dw1dvmod    - Discrete wavelet 1-D view mode manager.
%   dw2darro    - Discrete wavelet 2-D arrows drawing.
%   dw2dcomp    - Discrete wavelet 2-D compression.
%   dw2ddeno    - Discrete wavelet 2-D de-noising.
%   dw2dhist    - Discrete wavelet 2-D histograms.
%   dw2dimgs    - Discrete wavelet 2-D image selection.
%   dw2dmngr    - Discrete wavelet 2-D general manager.
%   dw2drwcd    - Discrete wavelet 2-D read-write Cdata for image.
%   dw2dstat    - Discrete wavelet 2-D statistics.
%   dw2dutil    - Discrete wavelet 2-D utilities.
%
% Graphical User Interface: Wavelets Packets 1-D and 2-D.
%   wp1dcomp    - Wavelet packets 1-D compression.
%   wp1dcoor    - Wavelet packets 1-D coordinates.
%   wp1ddeno    - Wavelet packets 1-D de-noising.
%   wp1ddraw    - Wavelet packets 1-D drawing manager.
%   wp1dmngr    - Wavelet packets 1-D general manager.
%   wp1dstat    - Wavelet packets 1-D statistics.
%   wp1dutil    - Wavelet packets 1-D utilities.
%   wp2dcomp    - Wavelet packets 2-D compression.
%   wp2dcoor    - Wavelet packets 2-D coordinates.
%   wp2ddeno    - Wavelet packets 2-D de-noising.
%   wp2ddraw    - Wavelet packets 2-D drawing manager.
%   wp2dmngr    - Wavelet packets 2-D general manager.
%   wp2dstat    - Wavelet packets 2-D statistics.
%   wp2dutil    - Wavelet packets 2-D utilities.
%   wpcutree    - Cut wavelet packets tree.
%   wpentmng    - Wavelet packets entropy manager.
%   wpfrqord    - Frequential order for wavelet packets.
%   wpfullsi    - Manage full size for axes.
%   wpmisval    - Miscellaneous values for wavelet packets tools.
%   wpnodlab    - Set the nodes label.
%   wpplotcf    - Plot wavelet packets colored coefficients.
%   wpposaxe    - Axes positions for wavelet packets tool.
%   wpplottr    - Plot wavelet packets tree.
%   wpssnode    - Plot wavelet packets synthesized node.
%   wptreeop    - Operations on wavelet packets tree.
%
% Graphical User Interface: Continuous Wavelets.
%   cw1dcoor    - Continuous wavelet 1-D coordinates.
%   cw1ddraw    - Continuous wavelet 1-D drawing manager.
%   cw1dmngr    - Continuous wavelet 1-D manager.
%   cw1dutil    - Continuous wavelet 1-D utilities.
%
% Graphical User Interface: Utilities.
%   key2info    - Key driven retrieve from tables.
%   thrwda1d    - Thresholds for 1-D Automatic De-noising using Wavelets.
%   wavattrb    - Wavelets properties manager.
%   wcmpscr     - 1-D or 2-D Wavelet compression scores.
%   wimgcode    - Image coding mode.
%   wnumbtn     - Wavelet number (for XX values).
%   wpcmpscr    - 1-D or 2-D Wavelet packets compression scores.
%   wrmcoef     - Reconstruct matrix of single branches from 1-D wavelet coefficients.
%   wscrupd     - Update scores for 1-D manual compression.
%   xynodpos    - Computes graphical position of a node in a tree.
%
% General Graphical Utilities.
%   dlgquest    - Question dialog.
%   getonoff    - Returns a matrix of strings with 'off' or 'on '.
%   mapcolor    - Colormap utilities.
%   mousefrm    - Manage the mouse representation on the screen.
%   txtinaxe    - Right and left texts for axes.
%   wavarrow    - Draw arrows and texts for discrete wavelet 2-D tool.
%   wboxtitl    - Box title for axes.
%   wdstem      - Plot discrete sequence data.
%   wfigcrea    - Utilities for creating figures.
%   wfigtitl    - Titlebar for figures.
%   wfigutil    - Utilities for figures.
%   wfindmen    - Find menu item.
%   whelpfun    - Help function.
%   wlegend     - Legend for compression scores plot.
%   wplothis    - Plots histogram obtained with WGETHIST.
%   wpropimg    - Give image proportions.
%   wshowmsg    - Display error messages.
%   wtxttitl    - Set a text as a super title in an axes.
%   wwaitans    - Wait for an answer to a question.
%   wwaiting    - Wait and Display a message.
%
% Matlab Extended Objects Utilities.
%   dynvtool    - Dynamic visualization tool.
%   extaxe      - Extend axe functionalities.
%   extfig      - Extend figure functionalities.
%   exttxt      - Extend text functionalities.
%   mextglob    - Module of extended objects globals.
%   mngaxe      - Manage axe modifications.
%   mngcoor     - Manage display of coordinates values.
%   mngfig      - Manage figure modifications.
%   mngmbtn     - Manage mouse buttons for the dynamical visualization tool.
%   mngtxt      - Manage text modifications.
%   utsetcol    - Utilities for setting colors.
%   utsetfon    - Utilities for setting fonts.
%   utlwzoom    - Utilities for standard zoom.
%   wselobj     - Object selection utilities.
%   wsetaxe     - Set axe parameters.
%   wsetfig     - Set figure parameters.
%   wsetpri     - Set print parameters.
%   wsettxt     - Set text parameters.
%   wsetxlab    - Plot xlabel.
%   wstdzoom    - Zoom in and out.
%
% General Utilities.
%   defclass    - Definition of classes for matrix codification.
%   findmobj    - True for existing graphic object.
%   nancompl    - Complete with NaN.
%   wgethist    - Build values to plot histogram.
%   wglobals    - Create some globals variables.
%   wimghist    - Compute histograms.
%   wmemtool    - Manage memory tool.
%   wmemutil    - Memory utilities.
%   wnoblank    - Remove blanks in a string.
%   wreadinf    - Read ascii files.
%
% Other Utilities.
%   wdcbm       - Wavelet 1-D deno. and comp. using Birge-Massart strategy.
%   wloasavf    - Script file for saving and loading files in GUI.
%
% Demos.
%
%------------------
% Slide show driver.
%------------------
%   wshowdrv    - A slide show shell for Demos.
%   whelpdem    - Help function for Demos.
%-------------------------
% Command line mode Demos.
%-------------------------
%   democmdm    - Main for command line mode demos.
% 
%   dcmdcasc    - Demo for cascade algorithm.
%   dcmdcomp    - Demo for compression.
%   dcmdcw1d    - Demo for continuous wavelet transform 1-D.
%   dcmddeno    - Demo for de-noising.
%   dcmddw1d    - Demo for discrete wavelet 1-D.
%   dcmddw2d    - Demo for discrete wavelet 2-D.
%   dcmdextm    - Demo for border distortion.
%   dcmdmala    - Demo for Mallat algorithm.
%   dcmdwpck    - Demo for wavelet packets.
%----------------
% GUI mode Demos.
%----------------
%   demoguim    - Main for GUI mode demos.
%
%   dguicw1d    - Demo for continuous wavelet transform 1-D.
%   dguidw1d    - Demo for discrete wavelet 1-D.
%   dguidw2d    - Demo for discrete wavelet 2-D.
%   dguiwp1d    - Demo for wavelet packets 1-D.
%   dguiwp2d    - Demo for wavelet packets 2-D.
%   dguiwp2d    - Demo for wavelet packets 2-D.
%   dguiwpdi    - Demo for wavelet packets display.
%   dguiwvdi    - Demo for wavelets display.
%----------------
% GUI mode Demos.
%----------------
%   demoscen    - Main for Short scenario demos.
%
%   dscedw1d    - Short 1-D scenario.
%
%-----------------
% Demos utilities.
%------------------
%   dmsgfun     - Message function for demos.
%   dguiwait    - Waiting function for demos.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Mat-files used in the toolbox.                                      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Coifman wavelets.
%   coif1       - Coiflet filter order 1.
%   coif2       - Coiflet filter order 2.
%   coif3       - Coiflet filter order 3.
%   coif4       - Coiflet filter order 4.
%   coif5       - Coiflet filter order 5.
%
% Daubechies wavelets.
%   db1         - Daubechies filter order 1.
%   db2         - Daubechies filter order 2.
%   db3         - Daubechies filter order 3.
%   db4         - Daubechies filter order 4.
%   db5         - Daubechies filter order 5.
%   db6         - Daubechies filter order 6.
%   db7         - Daubechies filter order 7.
%   db8         - Daubechies filter order 8.
%   db9         - Daubechies filter order 9.
%   db10        - Daubechies filter order 10.
%
% Haar wavelet.
%   haar        - Haar filter.
%
% Symlets.
%   sym2        - Symlet filter order 2.
%   sym3        - Symlet filter order 3.
%   sym4        - Symlet filter order 4.
%   sym5        - Symlet filter order 5.
%   sym6        - Symlet filter order 6.
%   sym7        - Symlet filter order 7.
%   sym8        - Symlet filter order 8.
%
% Testing signals (DWT or CWT or WP).
%   cnoislop    - Colored noisy slope.
%   freqbrk     - Frequency breakdown.
%   heavysin    - Noisy heavy sine.
%   leleccum    - Electrical consumption.
%   linchirp    - Linear chirp.
%   mfrqbrk     - Many frequency breakdowns
%   mishmash    - MishMash.
%   nearbrk     - Near breakdowns.
%   noisbloc    - Noisy blocks.
%   noisbump    - Noisy bumps.
%   noischir    - Noisy quadratic chirp.
%   noisdopp    - Noisy Doppler.
%   noismima    - Noisy mishmash.
%   noispol     - Noisy polynomial
%   noissin     - Noisy sine.
%   qdchirp     - Quadratic chirp.
%   quachirp    - Quadratic chirp (small length).
%   scddvbrk    - Second derivative breakdown.
%   sinfract    - Fractal signal.
%   sinper8     - Sine of period 8.
%   sumlichr    - Sum of linear chirps.
%   sumsin      - Sum of sines.
%   trsin       - Triangle and sine superposition.
%   vonkoch     - Koch curve.
%   warma       - Arma noise.
%   wcantor     - Cantor curve.
%   whitnois    - White noise.
%   wnoislop    - White noisy slope.
%   wntrsin     - Noisy triangle and sine superposition.
%   wstep       - Step signal.
%
% Testing images (DWT or WP).
%   chess       - Chess pieces                  256 by 256
%   detfingr    - Fingerprint                   301 by 301
%   facets      - Polyedron facets              256 by 256
%   geometry    - Geometry                      128 by 128
%   julia       - Julia set                     296 by 368
%   mandel      - Mandelbrot set                285 by 426
%   noissi2d    - Noisy sinsin                  128 by 128
%   noiswom     - Barbara's face (noisy zoom)   101 by 101
%   sinsin      - sin(8*pi*x)* sin(8*pi*y)      128 by 128
%   tartan      - Tartan                        256 by 256
%   tire        - Tire                          205 by 232
%   wbarb       - Barbara                       256 by 256
%   wifs        - Ifs                           305 by 279
%   woman       - Barbara's face                256 by 256
%   woman2      - Barbara's face                128 by 128
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Other files used in the toolbox.                                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   wavelets.ini - original ascii file containing wavelets info.
%   wavelets.bin - original binary file containing wavelets info.
%   wavelets.asc - ascii file containing wavelets info.
%   wavelets.inf - binary file containing wavelets info.
