function all = allnodes(tree,arg)
%ALLNODES Tree nodes.
%       ALLNODES returns one of two node descriptions:
%       either indices, or depths and positions.
%       Tree nodes are numbered from left to right and
%       from top to bottom. The root index is 0.
%
%       N = ALLNODES(T) returns in column vector N
%       the indices of all nodes of the tree structure T. 
%
%       N = ALLNODES(T,'deppos') returns in matrix N
%       the depths and positions of all the nodes.
%       N(i,1) is the depth and N(i,2) is the position
%       of node i.
%
%       See also MAKETREE.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:05:22 $

%       Uses ERRARGN, WTREEMGR.

% Check arguments.
if errargn('allnodes',nargin,[1:2],nargout,[0:1]), error('*'); end

if nargin==1
        all = wtreemgr('allnodes',tree);
elseif nargin==2
        all = wtreemgr('allnodes',tree,arg);
end
