function cw1ddraw(option,win_cw1dtool,in3,in4)
%CW1DDRAW Continuous wavelet 1D drawing manager.
%       cw1ddraw(option,win_cw1dtool,in3)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:06:16 $

%       Uses ERRARGT, CW1DCOOR, DYNVTOOL, INTWAVE, WCODEMAT, WKEEP
%       WMEMTOOL, WSETXLAB, WWAITING.

% Default values.
%----------------
max_lev_anal     = 12;
min_nbcolors     = 2;
max_nbcolors     = 512;
default_nbcolors = 128;

% MemBloc0 of stored values.
%---------------------------
n_InfoInit      = 'CW1D_InfoInit';
ind_filename    =  1;
ind_pathname    =  2;
nb0_stored      =  2;

% MemBloc1 of stored values.
%---------------------------
n_param_anal    = 'CWAn1d_Par_Anal';
ind_sig_name    =  1;
ind_sig_size    =  2;
ind_wav_name    =  3;
ind_wav_len     =  4;
ind_lev_anal    =  5;
ind_act_option  =  6;
ind_graph_area  =  7;
nb1_stored      =  7;

% MemBloc2 of stored values.
%---------------------------
n_coefs_sca     = 'Coefs_Scales';
ind_coefs       = 1;
ind_scales      = 2;
nb2_stored      = 2;

% Tag property of objects.
%-------------------------
tag_pop_colm    = 'ColM_pop';
tag_pop_scalem  = 'View_Mode';
tag_min_edi     = 'Min_edi';
tag_max_edi     = 'Max_edi';
tag_stp_edi     = 'Stp_edi';
tag_pow_pop     = 'Pow_pop';
tag_msc_edi     = 'MSc_edi';
tag_axesignal   = 'Axe_Signal';
tag_axeimgrec   = 'Axe_Coefs';
tag_axecolmap   = 'Axe_ColMap';

% Local Tag property of objects.
%------------------------------
tag_sig         = 'CW1d_sig';
tag_img         = 'CW1d_cfs';

% Handles of tagged objects.
%---------------------------
axe_handles     = findobj(win_cw1dtool,'Type','axes');
axe_sig         = findobj(axe_handles,'flat','Tag',tag_axesignal);
axe_cfs         = findobj(axe_handles,'flat','Tag',tag_axeimgrec);
axe_col         = findobj(axe_handles,'flat','Tag',tag_axecolmap);

%***********************************%
%** OPTION = 'sig' -  plot signal **%
%***********************************%
if option=='sig'
        axes(axe_sig);
        col_s   = 'r';
        xmin = 1;               xmax = length(in3);
        ymin = min(in3)-eps;    ymax = max(in3)+eps;
        plot(in3,'Color',col_s,'Tag',tag_sig);
        set(axe_sig,'Xlim',[xmin xmax],'Ylim',[ymin ymax],...
                        'XGrid','Off','YGrid','Off','Tag',tag_axesignal);
        title('Analyzed Signal');
        set(axe_cfs,'Xlim',[xmin xmax],'Ylim',[ymin ymax]);

%**********************************************************%
%** OPTION = 'cfs' -  computing and drawing coefficients **%
%**********************************************************%
elseif option=='cfs'

        % Getting  Analysis parameters.
        %------------------------------
        [Signal_Name,Wave_Name,Signal_Size,Level_Anal] = ...
                                wmemtool('rmb',win_cw1dtool,n_param_anal, ...
                                        ind_sig_name,ind_wav_name, ...
                                        ind_sig_size,ind_lev_anal);
        pathname = wmemtool('rmb',win_cw1dtool,n_InfoInit,ind_pathname);

        powmax  = fix(log(Signal_Size)/log(2));
        scamax  = 2^(powmax-1);
        levmax  = min(powmax,max_lev_anal);

        pop_handles     = findobj(win_cw1dtool,'Style','popupmenu');
        edi_handles     = findobj(win_cw1dtool,'Style','edit');
        pop_scalem      = findobj(pop_handles,'tag',tag_pop_scalem);
        pop_colm        = findobj(pop_handles,'tag',tag_pop_colm);
        view_mode       = get(pop_scalem,'Value');
        col_mode        = get(pop_colm,'Value');
        set(pop_colm,'Userdata',col_mode);
        if      view_mode==1
                min_edi = findobj(edi_handles,'Tag',tag_min_edi);
                stp_edi = findobj(edi_handles,'Tag',tag_stp_edi);
                max_edi = findobj(edi_handles,'Tag',tag_max_edi);
                err = 0; 
                mi = str2num(get(min_edi,'String'));
                st = str2num(get(stp_edi,'String'));
                ma = str2num(get(max_edi,'String'));
                if      isempty(st)     , st = 1;       err = 1;
                elseif  st<=0           , st = 1;       err = 1;
                end
                if      isempty(mi)     , mi = 1;       err = 1;
                elseif  mi<sqrt(eps)    , mi = 1;       err = 1;
                end
                if      isempty(ma)     , ma = min(32,scamax);  err = 1;
                elseif  ma>scamax       , ma = min(32,scamax);  err = 1; 
                end
                if ma<mi
                        if      ma<sqrt(eps)    , ma = mi;      err = 1;
                        elseif  mi>scamax       , mi = ma;      err = 1;
                        else
                                tmp = mi; mi = ma; ma = tmp;    err = 1;
                        end
                end

                if err==1
                        set(min_edi,'String',num2str(mi));
                        set(stp_edi,'String',num2str(st));      
                        set(max_edi,'String',num2str(ma));
                        col = get(min_edi,'ForegroundColor');
                        for k=1:10
                                set([min_edi,stp_edi,max_edi],...
                                                'ForegroundColor','r');
                                pause(0.5);
                                set([min_edi,stp_edi,max_edi],...
                                                'ForegroundColor',col); 
                        end
        
                end
                level = [ '[' num2str(mi) ':' num2str(st) ':' num2str(ma) ']'];
                scales  = eval(level);

        elseif  view_mode==2
                pow_pop = findobj(pop_handles,'Tag',tag_pow_pop);
                powmax  = get(pow_pop,'Value');
                scales = 2.^[1:powmax];
                level = '';
                for k=1:powmax , level = [level ' '  int2str(scales(k))]; end

        elseif  view_mode==3
                msc_edi = findobj(edi_handles,'Tag',tag_msc_edi);
                level   = get(msc_edi,'String');
                err     = 0;
                eval('levs = eval(level);','err = 1;');
                if err==1
                        set(msc_edi,'String','Error ...');
                        col = get(msc_edi,'ForegroundColor');
                        set(msc_edi,'ForegroundColor','r');
                        pause(2)
                        set(msc_edi,'String','[ ]');
                        set(msc_edi,'ForegroundColor',col);
                        return  
                end
                levs = levs(:)';
                scales  = levs(find(levs>0));
                scales  = scales(find(scales<=scamax));
                if      length(levs)~=length(scales)    , err = 1;
                elseif  find(levs~=scales)              , err = 1;
                end
                if err==1
                        if ~isempty(scales)
                                level = [num2str(scales(1)) ' .... ' ...
                                        num2str(scales(length(scales)))];
                        end 
                        old_txt = get(msc_edi,'String');
                        set(msc_edi,'String','Warning ...');

                        col = get(msc_edi,'ForegroundColor');
                        for k=1:10
                                set(msc_edi,'ForegroundColor','r');
                                pause(0.75);
                                set(msc_edi,'ForegroundColor',col);     
                        end

                        set(msc_edi,'String',old_txt);
                                
                end
        end

        if isempty(scales) , return;  end;

        filename = Signal_Name;
        LoSaFlag = 'load';  wloasavf;
        if err==1
                msg = ['File ' Signal_Name ' not found!'];      
                errordlg(msg,'Load Signal ERROR','off');
                return
        end
        Signal_Anal = eval(Signal_Name);
        if size(Signal_Anal,1)>1 , Signal_Anal = Signal_Anal'; end

        % Setting Dynamic Visualization tool.
        %------------------------------------
        dynvtool('delbox',win_cw1dtool);
        dynvtool('delline',win_cw1dtool);

        NB_ColorsInPal = default_nbcolors;
        Signal_Size = max(Signal_Size);
        NB_Img = size(scales,2);
        set(axe_cfs,...
                        'Xlim',[1 Signal_Size],         ...
                        'Ylim',[0.5 NB_Img+0.5],        ...
                        'YTicklabelMode','manual',      ...
                        'YTick',[],                     ...
                        'YTickLabels',[],               ...
                        'Box','On',                     ...
                        'XGrid','Off',                  ...
                        'YGrid','Off',                  ...
                        'Nextplot','Replace'            ...
                        );

        % Setting Dynamic Visualization tool.
        %------------------------------------
        dynvtool('attach',win_cw1dtool,                 ...
                        [],[axe_sig axe_cfs],[],[1 0],  ...
                        '','','cw1dcoor',axe_cfs,'r');
        dynvtool('put',win_cw1dtool);

        axes(axe_cfs);
        str_pop = get(pop_colm,'String');
        str_pop = str_pop(col_mode,:);
        str_tit = ['Values of Ca,b Coefficients for a =  ' level ...
                   ' -- Coloration mode : ' str_pop];
        title(str_tit);

        axes(axe_col);
        image([0 1],[0 1],[1:NB_ColorsInPal]);
        set(axe_col,'XTickLabels',[],'YTickLabels',[],...
                'XGrid','Off','YGrid','Off','tag',tag_axecolmap);
        wsetxlab(axe_col,'Scale of colors from MIN to MAX',-10);

        [psi_integ,psi_xval] = intwave(Wave_Name);
        psi_xval = psi_xval-min(psi_xval);
        dxval   = psi_xval(2);
        xmax    = psi_xval(length(psi_xval));
        len     = length(Signal_Anal);
        coefs   = zeros(length(scales),len);

        txt_msg = wwaiting('handle',win_cw1dtool);
        dynvtool('hide',win_cw1dtool);
        drawnow
        ind     = NB_Img;
        for a = scales
                set(txt_msg,'String', ...
                        sprintf('Computing - scale a = %5.3f',a));
                drawnow
                j = [1+floor([0:a*xmax]/(a*dxval))];
                if length(j)==1 , j = [1 1]; end
                f = fliplr(psi_integ(j));
                coefs(ind,:) = -sqrt(a)*wkeep(diff(conv(Signal_Anal,f)),len);
                ind = ind-1;
        end
        wmemtool('wmb',win_cw1dtool,n_coefs_sca,        ...
                                ind_coefs,coefs,ind_scales,scales);
        set(pop_colm,'Userdata',-1);
        cw1ddraw('col',win_cw1dtool,pop_colm,'draw');

        set(txt_msg,'String','');
        dynvtool('show',win_cw1dtool);

%************************************************************%
%** OPTION = 'col' -  changing color mode for coefficients **%
%************************************************************%
elseif option=='col'
        pop_colm = in3;
        img_cfs  = findobj(axe_cfs,'tag',tag_img);
        col_mode = get(pop_colm,'value');
        old_para = get(pop_colm,'userdata');
        if nargin==3
                if isempty(img_cfs) | old_para(1)==0
                        return;
                end             
        end
        if find(col_mode==[1 3 5 7]) , absval = 1; else , absval = 0; end
        if find(col_mode==[1 2 5 6]) , levval = 'row'; else , levval = 'mat'; end
        if find(col_mode==[1 2 3 4]) , view_m = 'gbl'; else , view_m = 'cur'; end
        Signal_Size = wmemtool('rmb',win_cw1dtool,n_param_anal, ...
                                       ind_sig_size);
        if find(col_mode==[5 6 7 8])
                xlim_selbox = dynvtool('getbox',win_cw1dtool); 
                if ~isempty(xlim_selbox)
                        xlim_selbox = [min(xlim_selbox) max(xlim_selbox)];
                else
                        xlim_selbox = get(axe_sig,'XLim');
                end
                xlim1 = max(1,xlim_selbox(1));
                xlim2 = min(Signal_Size,xlim_selbox(2));
        else
                xlim1 = 1;      xlim2 = Signal_Size;
        end
        new_para = [col_mode xlim1 xlim2];
        if length(new_para)==length(old_para)
                if old_para==new_para , return; end
        end
        set(pop_colm,'userdata',new_para);

        % Waiting message.
        %-----------------
        txt_msg = wwaiting('msg',win_cw1dtool,'Wait ... coefficients coloration');


        [coefs,scales] = wmemtool('rmb',win_cw1dtool,n_coefs_sca,...
                                        ind_coefs,ind_scales);
        [row,col] = size(coefs);

        hdl_tit = get(axe_cfs,'title');
        str_tit = get(hdl_tit,'String');
        mm      = findstr(str_tit,'mode');
        str_pop = get(pop_colm,'String');
        str_pop = str_pop(col_mode,:);
        str_tit = [str_tit(1:mm+6) str_pop];

        if strcmp(view_m,'cur')
                if absval==1 , coefs = abs(coefs); end
                if strcmp(levval,'mat')
                        cmin    = min(min(coefs(:,xlim1:xlim2)));
                        cmax    = max(max(coefs(:,xlim1:xlim2)));
                        coefs   = coefs(:);
                        ind     = find(coefs<cmin);
                        coefs(ind) = cmin*ones(size(ind));
                        ind     = find(coefs>cmax);
                        coefs(ind) = cmax*ones(size(ind));
                        coefs    = reshape(coefs,row,col);
                else
                        cmin    = min((coefs(:,xlim1:xlim2))')';
                        cmax    = max((coefs(:,xlim1:xlim2))')';
                        for k=1:length(scales)
                                set(txt_msg,'String', ...
                                        sprintf('Coloration - scale a = %5.3f',scales(k)));
                                drawnow
                                ind     = find(coefs(k,:)<cmin(k));
                                coefs(k,ind) = cmin(k)*ones(1,length(ind));
                                ind     = find(coefs(k,:)>cmax(k));
                                coefs(k,ind) = cmax(k)*ones(1,length(ind));
                        end
                        txt_msg = wwaiting('msg',win_cw1dtool,'Wait ... coefficients coloration');
                        drawnow
                end
        end
        NB_ColorsInPal = default_nbcolors;
        coefs = wcodemat(coefs,NB_ColorsInPal,levval,absval);
        axes(axe_cfs);
        if isempty(img_cfs)
                img_cfs = image('Cdata',coefs,'Userdata',scales,'tag',tag_img);
        else
                set(img_cfs,'Cdata',coefs,'Userdata',scales,'tag',tag_img);
        end
        clear coefs

        len = row;
        nb = ceil(len/20);
        tics = len:-nb:1;
        tmp = scales(1:nb:nb*length(tics));
        labs = num2str(tmp(1));
        for k = 2:length(tmp)
             labs = str2mat(labs,num2str(tmp(k)));
        end
        set(axe_cfs,...
                'YTicklabelMode','manual',      ...
                'YTick',tics,                   ...
                'YTickLabels',labs,             ...
                'Box','On',                     ...
                'XGrid','Off',                  ...
                'YGrid','Off',                  ...
                'Tag',tag_axeimgrec             ...
                );
        title(str_tit);

        % End waiting.
        %---------------
        wwaiting('off',win_cw1dtool);

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('cw1ddraw','Unknown Option','msg');
        error('*');
end
