function out1 = cw1dtool(option,in2)
%CW1DTOOL Continuous wavelet 1D tool.
%       out1 = cw1dtool(option,in2)
%
%       option = 'create' , 'close'

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:06:26 $

global  Def_Btn_Height  Def_Btn_Width   Pop_Min_Width   ...
        X_Spacing       Y_Spacing                       ...
        X_Graph_Ratio   Machine                         ...
        Lst_ColorMap    Def_TxtBkColor  Def_EdiBkColor  ...
        Def_FraBkColor  Def_FraFgColor

% Test inputs.
%-------------
if nargin==0
        option  = 'create'; in2 = [];
elseif nargin==1
        in2 = [];
end
[continu,option,in2] = wfigcrea('test',option,in2);
if ~continu , return; end 

% Default values.
%----------------
max_lev_anal     = 12;
min_nbcolors     = 2;
max_nbcolors     = 512;
default_nbcolors = 128;

% MemBloc0 of stored values.
%---------------------------
n_InfoInit      = 'CW1D_InfoInit';
ind_filename    =  1;
ind_pathname    =  2;
nb0_stored      =  2;

% MemBloc1 of stored values.
%---------------------------
n_param_anal    = 'CWAn1d_Par_Anal';
ind_sig_name    =  1;
ind_sig_size    =  2;
ind_wav_name    =  3;
ind_wav_len     =  4;
ind_lev_anal    =  5;
ind_act_option  =  6;
ind_graph_area  =  7;
nb1_stored      =  7;

% MemBloc2 of stored values.
%---------------------------
n_coefs_sca     = 'Coefs_Scales';
ind_coefs       = 1;
ind_scales      = 2;
nb2_stored      = 2;

% Tag property of objects.
%-------------------------
tag_m_files     = 'Files';
tag_m_savecfs   = 'Save_Cfs';
tag_input_txt   = 'Input_Txt';
tag_input_data  = 'Input_Data';
tag_wav_fams    = 'Wav_Fams';
tag_wav_nums    = 'Wav_Nums';
tag_txt_colm    = 'ColM_txt';
tag_pop_colm    = 'ColM_pop';
tag_pus_anal    = 'Pus_Anal';
tag_txt_sca     = 'Sca_txt';
tag_pop_scalem  = 'View_Mode';
tag_min_txt     = 'Min_txt';
tag_min_edi     = 'Min_edi';
tag_max_txt     = 'Max_txt';
tag_max_edi     = 'Max_edi';
tag_stp_txt     = 'Stp_txt';
tag_stp_edi     = 'Stp_edi';
tag_pow_txt     = 'Pow_txt';
tag_pow_pop     = 'Pow_pop';
tag_msc_txt     = 'MSc_txt';
tag_msc_edi     = 'MSc_edi';
tag_cfs_map     = 'Pop_ColorMap';
tag_sli_nbc     = 'Sli_NBColors';
tag_edi_nbc     = 'Edi_NBColors';
tag_txt_map     = 'Txt_Map';
tag_txt_nbc     = 'Txt_Nbc';
tag_btn_close   = 'Wave_Close';

tag_axesignal   = 'Axe_Signal';
tag_axeimgrec   = 'Axe_Coefs';
tag_axecolmap   = 'Axe_ColMap';

%*****************************************************************%
%** OPTION = 'create' - constructs the initial cw1dtool window  **%
%*****************************************************************%
if strcmp(option,'create')

        % Wavelet 1-D window initialization.
        %-----------------------------------
        win_name = 'Continuous Wavelet 1-D';
        [win_cw1dtool,pos_win,cba_close_menu] = ...
                wfigcrea('create',in2,win_name,'CW1Dtool','',3,'cw1dtool');
        str_numwin = int2str(win_cw1dtool);
        out1       = win_cw1dtool;
        win_units  = 'pixels';

        % Menu construction for current figure.
        %--------------------------------------
        lst_menu  = findobj(win_cw1dtool,'type','uimenu','Parent',win_cw1dtool);
        m_files   = wfindmen(lst_menu,'file');
        set(m_files,'tag',tag_m_files);
        m_loadsig = uimenu(m_files,...
                                'Label','Load Signal ',         ...
                                'Position',1,                   ...
                                'Callback',                     ...
                                ['cw1dmngr(''load_sig'','       ...
                                        str_numwin ');']        ...
                                );
        m_savecfs = uimenu(m_files,...
                                'Label','Save Coefficients ',   ...
                                'Position',2,                   ...
                                'tag',tag_m_savecfs,            ...
                                'Enable','Off',                 ...
                                'Callback',                     ...
                                ['cw1dmngr(''save_cfs'','       ...
                                        str_numwin ');']        ...
                                );
        m_loadtst = uimenu(m_files,...
                                'Label','Demo Analysis ',       ...
                                'Position',3,                   ...
                                'Separator','on'                ...
                                );

        % Submenu of test signals.
        %-------------------------
        k               = 1;
        names(k,:)      = 'Cantor curve                          ';
        files(k,:)      = 'wcantor ';
        waves(k,:)      = 'haar';
        colm(k) = 1;    mini(k) = 1;    step(k) = 1;    maxi(k) = 64;

        k               = k+1;
        names(k,:)      = 'Cantor curve                          ';
        files(k,:)      = 'wcantor ';
        waves(k,:)      = 'meyr';
        colm(k) = 1;    mini(k) = 1;    step(k) = 1;    maxi(k) = 32;

        k               = k+1;
        names(k,:)      = 'Cantor curve (non-abs. cfs)           ';
        files(k,:)      = 'wcantor ';
        waves(k,:)      = 'morl';
        colm(k) = 2;    mini(k) = 1;    step(k) = 1;    maxi(k) = 32;

        k               = k+1;
        names(k,:)      = 'Koch curve                            ';
        files(k,:)      = 'vonkoch ';
        waves(k,:)      = 'sym4';
        colm(k) = 1;    mini(k) = 1;    step(k) = 2;    maxi(k) = 32;


        k               = k+1;
        names(k,:)      = 'Koch curve                            ';
        files(k,:)      = 'vonkoch ';
        waves(k,:)      = 'mexh';
        colm(k) = 1;    mini(k) = 1;    step(k) = 2;    maxi(k) = 32;

        k               = k+1;
        names(k,:)      = 'Koch curve (non-abs. cfs)             ';
        files(k,:)      = 'vonkoch ';
        waves(k,:)      = 'mexh';
        colm(k) = 2;    mini(k) = 1;    step(k) = 2;    maxi(k) = 32;


        k               = k+1;
        names(k,:)      = 'Frequency breakdown                   ';
        files(k,:)      = 'freqbrk ';
        waves(k,:)      = 'sym4';
        colm(k) = 1;    mini(k) = 1;    step(k) = 1;    maxi(k) = 64;


        k               = k+1;
        names(k,:)      = 'Frequency breakdown                   ';
        files(k,:)      = 'freqbrk ';
        waves(k,:)      = 'mexh';
        colm(k) = 1;    mini(k) = 1;    step(k) = 1;    maxi(k) = 32;

        k               = k+1;
        names(k,:)      = 'Frequency breakdown (non-abs. cfs)    ';
        files(k,:)      = 'freqbrk ';
        waves(k,:)      = 'mexh';
        colm(k) = 2;    mini(k) = 1;    step(k) = 1;    maxi(k) = 32;

        k               = k+1;
        names(k,:)      = 'Electrical consumption                ';
        files(k,:)      = 'leleccum';
        waves(k,:)      = 'sym6';
        colm(k) = 1;    mini(k) = 1;    step(k) = 1;    maxi(k) = 32;

        k               = k+1;
        names(k,:)      = 'Noisy sine                            ';
        files(k,:)      = 'noissin ';
        waves(k,:)      = 'db4 ';
        colm(k) = 2;    mini(k) = 1;    step(k) = 1;    maxi(k) = 48;

        beg_call_str = ['cw1dmngr(''demo'',' str_numwin ','''];
        for i=1:size(files,1)

                scales = ['[' num2str(mini(i)) ':' num2str(step(i)) ...
                                ':' num2str(maxi(i)) ']'];
                libel = ['with ' waves(i,:) '   at scales  ' scales ...
                                '  -->  ' names(i,:)];
                action = [beg_call_str files(i,:) ''',''' ...
                        waves(i,:) ''','  ...
                        num2str(mini(i)) ',' num2str(step(i)) ',' ...
                        num2str(maxi(i)) ',' int2str(colm(i)) ');'];
                uimenu(m_loadtst,'Label',libel,'Callback',action);
        end
        drawnow

        % Command frame and Dynamical visualization tool construction.
        %-------------------------------------------------------------
        [frame0,pos_frame0,Pos_Graphic_Area] = ...
                        wfigcrea('frame',win_cw1dtool,'dynv','title');

        % Waiting Frame construction & begin waiting.
        %--------------------------------------------
        wwaiting('create',win_cw1dtool,X_Graph_Ratio,...
                        'Wait ... initialization');

        % Borders and double borders.
        %----------------------------
        dx  = X_Spacing;        dx2 = 2*dx;
        dy  = Y_Spacing;        dy2 = 2*dy;

        % Position property of objects.
        %------------------------------
        x_frame0        = pos_frame0(1);
        cmd_width       = pos_frame0(3);
        y_low           = pos_win(4)-Def_Btn_Height-dy2;
        x_left          = x_frame0+dx2;
        pos_input_txt   = [     x_left                          ,...
                                y_low                           ,...
                                Def_Btn_Width                   ,...
                                Def_Btn_Height                  ];

        pos_input_data  = [     pos_input_txt(1)+pos_input_txt(3)+dx    ,...
                                pos_input_txt(2)                        ,...
                                2*Pop_Min_Width                         ,...
                                Def_Btn_Height                          ];

        pos_wav_txt     = pos_input_txt;
        pos_wav_txt(2)  = pos_input_txt(2)-Def_Btn_Height-dy2;

        pos_wav_fams    = [     pos_wav_txt(1)+pos_wav_txt(3)+dx        ,...
                                pos_wav_txt(2)                          ,...
                                Pop_Min_Width                           ,...
                                Def_Btn_Height                          ];

        pos_wav_nums    = pos_wav_fams;
        pos_wav_nums(1) = pos_wav_fams(1)+pos_wav_fams(3);

        pos_sca_txt     = pos_wav_txt;
        pos_sca_txt(2)  = pos_wav_txt(2)-Def_Btn_Height-dy2;
        pos_sca_txt(3)  = 3*Pop_Min_Width;
        pop_width       = cmd_width-4*dx2;
        if strcmp(Machine(1:3),'PCW')
                pop_height = Def_Btn_Height;
        else
                pop_height = 1.5*Def_Btn_Height;
        end
        x_left          = x_frame0+(cmd_width-pop_width)/2;
        y_low           = pos_sca_txt(2)-pop_height-dy;
        pos_pop_scalem  = [     x_left                                  ,...
                                y_low                                   ,...
                                pop_width                               ,...
                                pop_height                      ];

        y_low           = pos_pop_scalem(2)-Def_Btn_Height-dy2;
        pos_txt_colm    = [     x_frame0+dx2                            ,...
                                y_low                                   ,...
                                1.5*Def_Btn_Width                       ,...
                                Def_Btn_Height                  ];
        y_low           = y_low-pop_height-dy;
        dx              = pop_width/10;
        pos_pop_colm    = [     x_left-dx                               ,...
                                y_low                                   ,...
                                pop_width+2*dx                          ,...
                                pop_height                      ];
        bdx             = (cmd_width-1.5*Def_Btn_Width)/2;
        x_left          = x_frame0+bdx;
        y_low           = y_low-1.5*Def_Btn_Height-4*dy2;
        pos_anal        = [     x_left                                  ,...
                                y_low                                   ,...
                                1.5*Def_Btn_Width                       ,...
                                1.5*Def_Btn_Height                      ];


        push_width      = (cmd_width-3*dx2)/2;
        px              = x_frame0+(cmd_width-7*push_width/4)/2;
        pos_close       = [     px                                      ,...
                                pos_frame0(2)+Def_Btn_Height            ,...
                                7*push_width/4                          ,...
                                1.5*Def_Btn_Height                      ];

        xleft = x_frame0+(cmd_width-2*Def_Btn_Width-dx-Def_Btn_Width/2.4)/2;
        ylow    = 5*Def_Btn_Height;
        pos_txt_map     = [     xleft,          ...
                                ylow,           ...
                                Def_Btn_Width,  ...
                                Def_Btn_Height];
        pos_pop_map     = pos_txt_map;
        pos_pop_map(1)  = pos_pop_map(1)+pos_txt_map(3);
        pos_txt_nbc     = pos_txt_map;
        pos_txt_nbc(2)  = pos_txt_nbc(2)-Def_Btn_Height-dy;
        pos_sli_nbc     = [     pos_txt_nbc(1)+pos_txt_nbc(3),...
                                pos_txt_nbc(2)+dy               ,...
                                Def_Btn_Width                   ,...
                                pos_txt_nbc(4)-2*dy             ...
                                ];
        pos_edi_nbc     = [     pos_sli_nbc(1)+pos_sli_nbc(3)+dx,       ...
                                pos_txt_nbc(2),                         ...
                                Def_Btn_Width/2.4,                      ...
                                Def_Btn_Height                          ...
                                ];

        deltax          = dx2;
        wx              = pos_pop_scalem(3)/2-deltax; 
        pos_min_txt     = [     pos_pop_scalem(1)                       ,...
                                pos_pop_scalem(2)-Def_Btn_Height-dy2    ,...
                                pos_pop_scalem(3)/2+deltax              ,...
                                Def_Btn_Height                  ];
        pos_min_edi     = pos_min_txt;
        pos_min_edi(1)  = pos_min_txt(1)+pos_min_txt(3);
        pos_min_edi(3)  = wx;
        pos_stp_txt     = pos_min_txt;
        pos_stp_txt(2)  = pos_stp_txt(2)-Def_Btn_Height-dy;
        pos_stp_edi     = pos_stp_txt;
        pos_stp_edi(1)  = pos_stp_txt(1)+pos_stp_txt(3);
        pos_stp_edi(3)  = wx;
        pos_max_txt     = pos_stp_txt;
        pos_max_txt(2)  = pos_max_txt(2)-Def_Btn_Height-dy;
        pos_max_edi     = pos_max_txt;
        pos_max_edi(1)  = pos_max_txt(1)+pos_max_txt(3);
        pos_max_edi(3)  = wx;

        pos_pow_txt     = [     pos_pop_scalem(1)                       ,...
                                pos_pop_scalem(2)-Def_Btn_Height-dy2    ,...
                                Def_Btn_Width                           ,...
                                Def_Btn_Height                  ];

        pos_pow_dta     = [     pos_pow_txt(1)+pos_pow_txt(3)+dx        ,...
                                pos_pow_txt(2)                          ,...
                                Pop_Min_Width                           ,...
                                Def_Btn_Height                          ];

        pos_msc_txt     = [     pos_pop_scalem(1)                       ,...
                                pos_pop_scalem(2)-Def_Btn_Height-dy2    ,...
                                pos_pop_scalem(3)                       ,...
                                Def_Btn_Height                  ];
        pos_msc_edi     = pos_msc_txt;
        pos_msc_edi(4)  = 1.5*Def_Btn_Height;
        pos_msc_edi(2)  = pos_msc_txt(2)-1.5*Def_Btn_Height-dy;


        % String property of objects.
        %----------------------------
        str_input_txt   = 'Signal';
        str_input_data  = '';
        str_wav_txt     = 'Wavelet';
        [str_wav_fams,str_wav_nums] = wavattrb('ini','cwt');
        str_sca_txt     = 'Scale Values :';
        str_pop_scalem  = str2mat('Step by Step Mode','Power 2 Mode',...
                                        'Manual Mode');

        str_txt_colm    = 'Coloration Mode :';
        str_pop_colm    = ...
                        str2mat(...
                                'init + by scale + abs',     ...
                                'init + by scale',           ...
                                'init + all scales + abs',   ...
                                'init + all scales',         ...
                                'current + by scale + abs',  ...
                                'current + by scale',        ...
                                'current + all scales + abs',...
                                'current + all scales'       ...
                                );
        str_anal        = 'Analyze';
        str_close       = 'Close';
        str_txt_map     = 'Colormap';
        str_txt_nbc     = 'Nb. Colors';
        str_cfs_map     = Lst_ColorMap;
        str_edi_nbc     = int2str(size(get(win_cw1dtool,'Colormap'),1));

        str_min_txt     = 'Min  ( > 0)';
        str_stp_txt     = 'Step ( > 0 )';
        str_max_txt     = 'Max     ';

        str_pow_txt     = 'Power';
        str_pow_pop     = [int2str(1)];
        for k=2:max_lev_anal , str_pow_pop = str2mat(str_pow_pop,int2str(k));end

        str_msc_txt     = 'Scales : Matlab Vector';

        % Callback property of objects.
        %------------------------------
        action          = '';
        cba_anal        = ['cw1dmngr(''anal'',' str_numwin ');'];
        cba_scalem      = ['cw1dutil(''ch_sm'',' str_numwin ');'];

        % Command part of the window.
        %----------------------------
        figure(win_cw1dtool);
        txt_input_txt           = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_input_txt,       ...
                                        'String',str_input_txt,         ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_input_txt             ...
                                        );
        txt_input_data          = uicontrol(...
                                        'Style','Text',                 ...
                                        'Units',win_units,              ...
                                        'Position',pos_input_data,      ...
                                        'String',str_input_data,        ...
                                        'Backgroundcolor',Def_TxtBkColor,...
                                        'Tag',tag_input_data            ...
                                        );
        txt_wav_txt     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_wav_txt,         ...
                                        'String',str_wav_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_wav_fams    = uicontrol(...
                                        'Style','Popup',        ...
                                        'Unit',win_units,       ...
                                        'Position',pos_wav_fams,...
                                        'String',str_wav_fams,  ...
                                        'Enable','off',         ...
                                        'Tag',tag_wav_fams      ...
                                        );
        pop_wav_nums    = uicontrol(...
                                        'Style','Popup',        ...
                                        'Unit',win_units,       ...
                                        'Position',pos_wav_nums,...
                                        'String',str_wav_nums,  ...
                                        'Visible','off',        ...
                                        'Enable','off',         ...
                                        'Tag',tag_wav_nums      ...
                                        );
        txt_sca_txt     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_sca_txt,         ...
                                        'Visible','Off',                ...
                                        'String',str_sca_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_txt_sca               ...
                                        );
        sca_mode        = 1;
        pop_scalem      = uicontrol(...
                                        'Style','Popup',                ...
                                        'Unit',win_units,               ...
                                        'Position',pos_pop_scalem,      ...
                                        'Visible','Off',                ...
                                        'String',str_pop_scalem,        ...
                                        'Value',sca_mode,               ...
                                        'UserData',0,                   ...
                                        'Enable','off',                 ...
                                        'Callback',cba_scalem,          ...
                                        'Tag',tag_pop_scalem            ...
                                        );

        txt_colm        = uicontrol(...
                                        'Style','Text',                 ...
                                        'Unit',win_units,               ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Position',pos_txt_colm,        ...
                                        'Visible','Off',        ...
                                        'HorizontalAlignment','left',   ...
                                        'String',str_txt_colm,          ...
                                        'Tag',tag_txt_colm              ...
                                        );
        col_mode        = 1;
        pop_colm        = uicontrol(...
                                        'Style','Popup',                ...
                                        'Unit',win_units,               ...
                                        'Position',pos_pop_colm,        ...
                                        'Visible','Off',                ...
                                        'String',str_pop_colm,          ...
                                        'Value',col_mode,               ...
                                        'UserData',0,                   ...
                                        'Enable','off',                 ...
                                        'Tag',tag_pop_colm              ...
                                        );
        pus_anal        = uicontrol(...
                                        'Style','Pushbutton',   ...
                                        'Unit',win_units,       ...
                                        'Position',pos_anal,    ...
                                        'Visible','Off',        ...
                                        'String',str_anal,      ...
                                        'Enable','off',         ...
                                        'Tag',tag_pus_anal,     ...
                                        'Callback',cba_anal,    ...
                                        'Interruptible','yes'   ...
                                        );

        pus_close       = uicontrol(...
                                        'Style','Pushbutton',           ...
                                        'Unit',win_units,               ...
                                        'Position',pos_close,           ...
                                        'String',str_close,             ...
                                        'Interruptible','yes',          ...
                                        'Callback',cba_close_menu,      ...
                                        'Tag',tag_btn_close             ...     
                                        );

        txt_map         = uicontrol(...
                                        'Style','Text',                 ...
                                        'Unit',win_units,               ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Position',pos_txt_map,         ...
                                        'HorizontalAlignment','left',   ...
                                        'String',str_txt_map,           ...
                                        'Tag',tag_txt_map               ...
                                        );
        pop_cfs_map     = uicontrol(...
                                        'Style','Popup',...
                                        'Unit',win_units,...
                                        'Position',pos_pop_map,...
                                        'String',str_cfs_map,...
                                        'Callback',action,...
                                        'Tag',tag_cfs_map...
                                        );

        txt_nbc         = uicontrol(...
                                        'Style','Text',                 ...
                                        'Unit',win_units,               ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Position',pos_txt_nbc,         ...
                                        'HorizontalAlignment','left',   ...
                                        'String',str_txt_nbc,           ...
                                        'Tag',tag_txt_nbc               ...
                                        );
        
        sli_nbc         = uicontrol(...
                                        'Style','Slider',...
                                        'Unit',win_units,...
                                        'Position',pos_sli_nbc,...
                                        'Min',min_nbcolors,...
                                        'Max',max_nbcolors,...
                                        'Value',default_nbcolors,...
                                        'Tag',tag_sli_nbc...
                                        );                              

        edi_nbc         = uicontrol(...
                                        'Style','Edit',                 ...
                                        'Unit',win_units,               ...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'Position',pos_edi_nbc,         ...
                                        'String',str_edi_nbc,           ...
                                        'Callback',action,              ...
                                        'Tag',tag_edi_nbc               ...
                                        );

        %-------------------------- Mode Step by Step --------------------%
        min_txt         = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'Visible','off',                ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_min_txt,         ...
                                        'String',str_min_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_min_txt               ...
                                        );
        min_edi         = uicontrol(...
                                        'Style','edit',                 ...
                                        'Unit',win_units,               ...
                                        'Visible','off',                ...
                                        'HorizontalAlignment','center', ...
                                        'Position',pos_min_edi,         ...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'Tag',tag_min_edi               ...
                                        );

        stp_txt         = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'Visible','off',                ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_stp_txt,         ...
                                        'String',str_stp_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_stp_txt               ...
                                        );
        stp_edi         = uicontrol(...
                                        'Style','edit',                 ...
                                        'Unit',win_units,               ...
                                        'Visible','off',                ...
                                        'HorizontalAlignment','center', ...
                                        'Position',pos_stp_edi,         ...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'Tag',tag_stp_edi               ...
                                        );
        max_txt         = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'Visible','off',                ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_max_txt,         ...
                                        'String',str_max_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_max_txt               ...
                                        );
        max_edi         = uicontrol(...
                                        'Style','edit',                 ...
                                        'Unit',win_units,               ...
                                        'Visible','off',                ...
                                        'HorizontalAlignment','center', ...
                                        'Position',pos_max_edi,         ...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'Tag',tag_max_edi               ...
                                        );

        %--------------------------- Mode Power 2-------------------------%
        txt_pow_txt     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'Visible','off',                ...
                                        'HorizontalAlignment','center', ...
                                        'Position',pos_pow_txt,         ...
                                        'String',str_pow_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor',...
                                        'Tag',tag_pow_txt               ...
                                        );
        pop_pow_dta     = uicontrol(...
                                        'Style','Popup',        ...
                                        'Unit',win_units,       ...
                                        'Visible','off',        ...
                                        'Position',pos_pow_dta,...
                                        'String',str_pow_pop,   ...
                                        'Enable','off',         ...
                                        'Tag',tag_pow_pop       ...
                                        );
        %-------------------------- Mode Manual --------------------------%
        msc_txt         = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'Visible','off',                ...
                                        'HorizontalAlignment','center', ...
                                        'Position',pos_msc_txt,         ...
                                        'String',str_msc_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_msc_txt               ...
                                        );

        msc_edi         = uicontrol(...
                                        'Style','edit',                 ...
                                        'Unit',win_units,               ...
                                        'Visible','off',                ...
                                        'HorizontalAlignment','center', ...
                                        'Position',pos_msc_edi,         ...
                                        'String','[ ]',                 ...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'Tag',tag_msc_edi               ...
                                        );
        %-----------------------------------------------------------------%

        % Callbacks update.
        %------------------
        cba_pop_wav_fams = [    'wavattrb(''gettnum'',' ...
                                num2mstr(pop_wav_fams) ',' ...
                                num2mstr(pop_wav_nums) ');'];
        set(pop_wav_fams,'Callback',cba_pop_wav_fams);

        cba_pop_wav_nums = [    'wnumbtn(1,'            ...
                                num2mstr([pop_wav_fams pop_wav_nums]) ',' ...
                                num2mstr([m_files pus_anal]) ');'];
        set(pop_wav_nums,'Callback',cba_pop_wav_nums);

        str_win_cw1dtool = int2str(win_cw1dtool);
        cba_pop_colm    = [     'cw1ddraw(''col'','     ...
                                str_win_cw1dtool ','            ...
                                num2mstr(pop_colm)  ');'];
        cba_pop_cfs_map = [     'mapcolor(''pal'','     ...
                                str_win_cw1dtool ','            ...
                                num2mstr(pop_cfs_map) ');'];
        cba_edi_nbc = [ 'mapcolor(''nbc'','             ...
                                str_win_cw1dtool ','            ...
                                num2mstr([pop_cfs_map edi_nbc]) ');'];

        cba_sli_nbc = [ 'mapcolor(''nbc'','             ...
                                str_win_cw1dtool ','            ...
                                num2mstr([pop_cfs_map sli_nbc]) ');'];

        set(pop_colm,'Callback',cba_pop_colm);
        set(pop_cfs_map,'Callback',cba_pop_cfs_map);
        set(edi_nbc,'Callback',cba_edi_nbc);
        set(sli_nbc,'Callback',cba_sli_nbc);
        drawnow;

        % Colormap Initial Value.
        %------------------------
        mapcolor('set',win_cw1dtool,'pink',[pop_cfs_map],default_nbcolors);

        %----------------
        pos_win = get(win_cw1dtool,'Position');
        bdx     = 0.05*pos_win(3);
        bdy     = 0.08*pos_win(4);
        bdy0    = 0.04*pos_win(4);
        bdy1    = 0.04*pos_win(4);
        bdy2    = 0.06*pos_win(4);
        %--------------------- Scale of Colors Axes ----------------------%
        h_col   = 0.02*pos_win(4);
        w_col   = Pos_Graphic_Area(3)/3;
        x_col   = Pos_Graphic_Area(1)+w_col;
        y_col   = Pos_Graphic_Area(2)+bdy0;
        pos_ax          = zeros(3,4);
        pos_ax(3,:)     = [x_col , y_col , w_col , h_col];
        %-----------------------------------------------------------------%
        xleft   = Pos_Graphic_Area(1)+bdx;
        width   = Pos_Graphic_Area(3)-2*bdx;
        ylow            = y_col+h_col+bdy1;
        height          = (Pos_Graphic_Area(4)-bdy-bdy0-bdy2-bdy1-h_col)/3;
        pos_ax(2,:)     = [xleft , ylow , width , 2*height];
        ylow = ylow+2*height+bdy;
        pos_ax(1,:)     = [xleft , ylow , width , height];
        figure(win_cw1dtool);
        win_units       = get(win_cw1dtool,'Units');
        ax_hdl(1) =     axes(...
                                'Units',win_units,      ...
                                'Position',pos_ax(1,:), ...
                                'Visible','Off',        ...
                                'DrawMode','Fast',      ...
                                'box','on',             ...
                                'NextPlot','Replace',   ...
                                'Tag',tag_axesignal     ...
                                );
        ax_hdl(2) =     axes(...
                                'Units',win_units,      ...
                                'Position',pos_ax(2,:), ...
                                'Visible','Off',        ...
                                'DrawMode','Fast',      ...
                                'box','on',             ...
                                'NextPlot','Replace',   ...
                                'Tag',tag_axeimgrec     ...
                                );

        ax_hdl(3) =     axes(...
                                'Units',win_units,      ...
                                'Position',pos_ax(3,:), ...
                                'Visible','Off',        ...
                                'DrawMode','Fast',      ...
                                'XTicklabelMode','manual',...
                                'YTicklabelMode','manual',...
                                'XTickLabels',[],       ...
                                'YTickLabels',[],       ...
                                'XTick',[],'YTick',[],  ...
                                'Box','On',             ...
                                'Tag',tag_axecolmap     ...
                                );
        %  Normalization.
        %----------------
        Pos_Graphic_Area = Pos_Graphic_Area./[pos_win(3:4),pos_win(3:4)];
        set(findobj(win_cw1dtool,'units','pixels'),'units','normalized');

        % Memory for stored values.
        %--------------------------
        wmemtool('ini',win_cw1dtool,n_InfoInit,nb0_stored);
        wmemtool('ini',win_cw1dtool,n_param_anal,nb1_stored);
        wmemtool('ini',win_cw1dtool,n_coefs_sca,nb2_stored);
        wmemtool('wmb',win_cw1dtool,n_param_anal, ...
                                        ind_graph_area,Pos_Graphic_Area);

        % End waiting.
        %---------------
        wwaiting('off',win_cw1dtool);

%***********************************************%
%** OPTION = 'close' - close cw1dtool window  **%
%***********************************************%
elseif strcmp(option,'close')
        % in2 = win_cw1dtool
        %--------------------
        called_win = findobj(get(0,'children'),'flat','Userdata',in2);
        close(called_win);

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('cw1dtool','Unknown Option','msg');
        error('*');
end
