function w = dbaux(N,sumw);
%DBAUX Daubechies wavelet filters computation.
%       W = DBAUX(N,SUMW) is the order N Daubechies scaling
%       filter such that SUM(W) = SUMW.
%       Possible values for N are:
%              N = 1, 2, 3, ...
%       Caution : Instability may occur when N is too large.
%
%       W = DBAUX(N) is equivalent to W = DBAUX(N,1).
%       W = DBAUX(N,0) is equivalent to W = DBAUX(N,1).
%
%       See also DBWAVF, WFILTERS.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:06:41 $

%       Uses ERRARGN, DYADUP, WREV.

% Check arguments.
if errargn('dbaux',nargin,[1:2],nargout,[0:1]), error('*'); end

if nargin < 2 , sumw = 1;  end
if sumw == 0 , sumw = 1;  end

% Order n daub scaling filter computation 
% using "Lagrange" filters.
lon = 2*N-1;     
sup = [-N+1:N];
a = zeros(1,N);
for k = 1:N
        nok  = sup(sup ~= k);
        a(k) = prod(0.5-nok)/prod(k-nok);
end
P    = dyadup(a,0);
P    = [wrev(P),1,P]; % "Lagrange a trous" filter such that   
                      % P = conv(wrev(w),w) * 2 if w
                      % denotes the order N daub scaling filter. 
rP    = roots(P);
[s,K] = sort(abs(rP));          rP = rP(K);
[s,K] = sort(abs(rP+1));        rL = rP(K(lon+2:2*lon));
[s,K] = sort(abs(rL));          rL = rL(K);

% rL gives partial root location of w. 
% w have N zeros located at -1. 
w = real(poly([rL(abs(rL)<1);-ones(N,1)]));
w = sumw*(w/sum(w)); 

