function n = depo2ind(order,node)
%DEPO2IND Node depth-position to node index.
%       For a tree of order O, N = DEPO2IND(O,[D P])
%       computes the indices N of the nodes whose
%       depths and positions are encoded within [D,P].
%       The nodes are numbered from left to right and
%       from top to bottom. The root index is 0.
%
%       D, P and N are column vectors.
%          D = depths, 0 <= D <= dmax
%          P = positions at depth D, 0 <= P <= order^D-1
%          N = indices, 0 <= N < ((order^(dmax+1))-1)/(order-1)
%
%       Note: for a column vector X, DEPO2IND(O,X) = X.
%
%       See also IND2DEPO, MAKETREE, WTREEMGR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:07:10 $

%       Uses ERRARGN, ERRARGT.

% Check arguments.
if errargn('depo2ind',nargin,[2],nargout,[0:1]), error('*'); end

[r,c] = size(node);
if c==1
        n = node;
elseif c==2
        n = zeros(r,1);
        K = find(node(:,1)~=0);
        n(K) = (order.^node(K,1)-1)/(order-1) +node(K,2);
else
        errargt('depo2ind','invalid argument value','msg'); error('*');
end
