function d = detcoef(c,l,n)
%DETCOEF Extract 1-D detail coefficients.
%       D = DETCOEF(C,L,N) extracts the detail coefficients
%       at level N from the wavelet decomposition structure [C,L]
%       (see WAVEDEC).
%       Level N must be an integer such that 1 <= N <= length(L)-2.
%
%       D = DETCOEF(C,L) extracts the detail coefficients
%       at last level n = length(L)-2. 
%       
%       See also APPCOEF, WAVEDEC.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:07:16 $

%       Uses ERRARGN, ERRARGT.

% Check arguments.
if errargn('detcoef',nargin,[2:3],nargout,[0:1]), error('*');end
rmax = length(l);
nmax = rmax-2;
if nargin==2 , n = nmax; end
if (n < 1) | (n > nmax) | (n ~= fix(n))
        errargt('detcoef','invalid level value','msg'); error('*');
end

% Extract detail coefficients.
k     = rmax-n;
first = sum(l(1:k-1))+1;
last  = first+l(k)-1;
d     = c(first:last);
