function d = detcoef2(o,c,s,n)
%DETCOEF2 Extract 2-D detail coefficients.
%       D = DETCOEF2(O,C,S,N) extracts from the wavelet
%       decomposition structure [C,S] (see WAVEDEC2),
%       the horizontal, vertical or diagonal detail 
%       coefficients for O = 'h' (or 'v' or 'd',respectively),
%       at level N.
%       Level N must be an integer such that
%       1 <= N <= size(S,1)-2.
%
%       See also APPCOEF2, WAVEDEC2.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:07:21 $

%       Uses ERRARGN, ERRARGT.

% Check arguments.
if errargn('detcoef2',nargin,[4],nargout,[0 1]), error('*'), end
nmax = size(s,1)-2;
if (n<1) | (n>nmax) | (n~=fix(n))
        errargt('detcoef2','invalid level value','msg'); error('*');
end

k     = size(s,1)-n;
first = s(1,1)*s(1,2)+3*sum(s(2:k-1,1).*s(2:k-1,2))+1;
add   = s(k,1)*s(k,2);
o     = lower(o(1));

if     o=='v'
        first = first+add;
elseif o=='d'
        first = first+2*add;
elseif o~='h'
        errargt('detcoef2','invalid argument value','msg'); error('*');
end

last = first+add-1;
d    = reshape(c(first:last),s(k,1),s(k,2));
