function [out1,out2,out3,out4] = dw1dfile(option,win_dw1dtool,in3,in4)
%DW1DFILE Discret wavelet 1D file manager.
%       [out1,out2,out3,out4] = dw1dfile(option,win_dw1dtool,in3,in4)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:08:00 $

% MemBloc0 of stored values.
%---------------------------
n_InfoInit      = 'DW1D_InfoInit';
ind_filename    =  1;
ind_pathname    =  2;
nb0_stored      =  2;

% MemBloc1 of stored values.
%---------------------------
n_param_anal    = 'DWAn1d_Par_Anal';
ind_sig_name    =  1;
ind_sig_size    =  2;
ind_wav_name    =  3;
ind_wav_len     =  4;
ind_lev_anal    =  5;
ind_axe_ref     =  6;
ind_act_option  =  7;
ind_ssig_type   =  8;
nb1_stored      =  8;

% MemBloc2 of stored values.
%---------------------------
n_coefs_longs   = 'Coefs_and_Longs';
ind_coefs       = 1;
ind_longs       = 2;
nb2_stored      = 2;

% MemBloc3 of stored values.
%---------------------------
n_synt_sig      = 'Synt_Sig';
ind_ssig        =  1;
nb3_stored      =  1;

% MemBloc4 of stored values.
%---------------------------
n_miscella      = 'DWAn1d_Miscella';
ind_graph_area  =  1;
ind_view_mode   =  2;
ind_savepath    =  3;
nb4_stored      =  3;

% Figure handle.
%---------------
numfig          = int2str(win_dw1dtool);

epsilon = 0.000001;

%******************************************************%
%** OPTION = 'anal' -  Computing and saving Analysis.**%
%******************************************************%
if strcmp(option,'anal')
        % in3 optional (for 'load_dec' or 'synt' or 'new_anal')
        %------------------------------------------------------
        if      nargin==2
                numopt = 1;
        elseif  strcmp(in3,'new_anal')
                numopt = 2;
        else
                numopt = 3;
        end     

        % Getting  Analysis parameters.
        %------------------------------
        [Signal_Name,Signal_Size,Wave_Name,Level_Anal] =  ...
                wmemtool('rmb',win_dw1dtool,n_param_anal,  ...
                                ind_sig_name,ind_sig_size, ...
                                ind_wav_name,ind_lev_anal  ...
                                );
        pathname = wmemtool('rmb',win_dw1dtool,n_InfoInit,ind_pathname);
        if numopt<3
                if numopt==1   
                        filename = Signal_Name;
                        LoSaFlag = 'load'; wloasavf;
                        Signal_Anal = eval(Signal_Name);
                        if size(Signal_Anal,1)>1
                                Signal_Anal = Signal_Anal';
                        end
                else
                        Signal_Anal = dw1dfile('sig',win_dw1dtool);
                end
                [coefs,longs]   = wavedec(Signal_Anal,Level_Anal,Wave_Name);

                % Writing coefficients.
                %----------------------
                wmemtool('wmb',win_dw1dtool,n_coefs_longs,...
                              ind_coefs,coefs,ind_longs,longs);
        else
                [coefs,longs] = wmemtool('rmb',win_dw1dtool,n_coefs_longs,...
                                                ind_coefs,ind_longs);
        end

        % Cleaning files.
        %----------------
        dw1dfile('del',win_dw1dtool);

        % Test for saving.
        %-----------------
        err = 0;
        sig_rec = 1;
        eval(['save sig_rec.' numfig ' sig_rec -mat'],'err = 1;');

        if err==0

                % Computing and Saving Approximations
                %------------------------------------
                pathname = cd;
                wmemtool('wmb',win_dw1dtool,n_miscella,...
                                ind_savepath,pathname);
                app_rec = wrmcoef('a',coefs,longs,Wave_Name);
                if nargin==2
                        sig_rec = Signal_Anal;
                else
                        sig_rec = app_rec(1,:);
                end
                eval(['save sig_rec.' numfig ' sig_rec -mat']);
                clear sig_rec
                ssig_rec = app_rec(1,:);
                eval(['save ssig_rec.' numfig ' ssig_rec -mat']);
                if nargin==3 , out1 = ssig_rec; end
                wmemtool('wmb',win_dw1dtool,n_synt_sig,ind_ssig,ssig_rec);
                clear ssig_rec
                app_rec = app_rec(2:Level_Anal+1,:);
                eval(['save app_rec.' numfig ' app_rec -mat']);
                clear app_rec

                % Computing and Saving Details
                %-------------------------------
                det_rec = wrmcoef('d',coefs,longs,Wave_Name);
                eval(['save det_rec.' numfig ' det_rec -mat']);
                clear det_rec

                % Computing and Saving Coefficients
                %----------------------------------
                len     = longs(Level_Anal+2);
                cfs_beg = zeros(Level_Anal,len);
                for p = 1:Level_Anal
                        z = detcoef(coefs,longs,p);
                        z = z(ones(1,2^p),:);
                        cfs_beg(p,:) = wkeep(z(:)',len);                
                end
                eval(['save cfs_beg.' numfig ' cfs_beg -mat']);
        else
                out1 = wrcoef('a',coefs,longs,Wave_Name);
                wmemtool('wmb',win_dw1dtool,n_synt_sig,ind_ssig,out1);
        end

%***********************************************************%
%** OPTION = 'comp_ss' -  Computing and saving Synt. Sig. **%
%***********************************************************%
elseif strcmp(option,'comp_ss')
        % Used by return_comp & return_deno
        % in3 = hdl_lin
        %------------------------------------
        ssig_rec = get(in3,'Ydata');
        pathname = wmemtool('rmb',win_dw1dtool,n_miscella,ind_savepath);
        filename = ['ssig_rec.' numfig];
        saveStr  = 'ssig_rec';
        LoSaFlag = 'save'; wloasavf;
        if err
                wmemtool('wmb',win_dw1dtool,n_synt_sig,ind_ssig,ssig_rec);
        end

%************************%
%** OPTION = 'app' - . **%
%************************%
elseif strcmp(option,'app')
        pathname = wmemtool('rmb',win_dw1dtool,n_miscella,ind_savepath);
        filename = ['app_rec.' numfig];
        LoSaFlag = 'load'; wloasavf;
        if err
                [coefs,longs] = wmemtool('rmb',win_dw1dtool,n_coefs_longs,...
                                                ind_coefs,ind_longs);
                Wave_Name     = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_wav_name);
                out1          = wrmcoef('a',coefs,longs,Wave_Name,in3);
        else
                out1 = app_rec(in3,:);
        end
        if nargin<4 , return; end;
        if in4==1
                len_wav = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_wav_len);
                if isempty(len_wav) , len_wav = 10; end
%               mx = len_wav*(2.^in3);
                mx = (2.^(in3+1));
                lx = size(out1,2);
                l3 = length(in3);
                out2 = zeros(1,l3);
                out4 = epsilon*ones(1,l3);
                out3 = -out4;
                for k = 1:l3
                        bord = mx(k);
                        if bord<(lx/2)
                                out2(k) = 1;
                                xmax = lx-bord+1;
                                out3(k) = min(out1(k,bord:xmax))-epsilon;
                                out4(k) = max(out1(k,bord:xmax))+epsilon;
                        end
                end

        elseif in4==2
                out2 = (min(out1'))'-epsilon;
                out3 = (max(out1'))'+epsilon;

        elseif in4==3
                len_wav = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_wav_len);
                if isempty(len_wav), len_wav = 10; end
%               mx      = len_wav*in3;
                mx      = (2.^(in3+1));
                lx      = size(out1,2);
                lx2     = lx/2;
                l3      = length(in3);
                for k = 1:l3
                        bord = mx(k);
                        if bord<(lx/2)
                                xmax = lx-bord+1;
                                out2(k) = min(out1(k,bord:xmax))-epsilon;
                                out3(k) = max(out1(k,bord:xmax))+epsilon;
                        else
                                out2(k) = min(out1(k,:))-epsilon;
                                out3(k) = max(out1(k,:))+epsilon;
                        end
                end

        end

%************************%
%** OPTION = 'det' - . **%
%************************%
elseif strcmp(option,'det')
        pathname = wmemtool('rmb',win_dw1dtool,n_miscella,ind_savepath);
        filename = ['det_rec.' numfig];
        LoSaFlag = 'load'; wloasavf;
        if err
                [coefs,longs]   = wmemtool('rmb',win_dw1dtool,n_coefs_longs,...
                                                ind_coefs,ind_longs);
                Wave_Name       = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_wav_name);
                out1            = wrmcoef('d',coefs,longs,Wave_Name,in3);
        else
                out1 = det_rec(in3,:);
        end
        if nargin<4 , return; end;
        if in4==1
                len_wav = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_wav_len);
                if isempty(len_wav) , len_wav = 10; end

%               mx = len_wav*(2.^in3);
                mx = (2.^(in3+1));

                lx = size(out1,2);
                l3 = length(in3);
                out2 = zeros(1,l3);
                out4 = epsilon*ones(1,l3);
                out3 = -out4;
                for k = 1:l3
                        bord = mx(k);
                        if bord<(lx/2)
                                out2(k) = 1;
                                xmax = lx-bord+1;
                                out3(k) = min(out1(k,bord:xmax))-epsilon;
                                out4(k) = max(out1(k,bord:xmax))+epsilon;
                        end
                end
        elseif in4==2
                out2 = (min(out1'))'-epsilon;
                out3 = (max(out1'))'+epsilon;
        end

%************************%
%** OPTION = 'sig' - . **%
%************************%
elseif strcmp(option,'sig')
        pathname = wmemtool('rmb',win_dw1dtool,n_miscella,ind_savepath);
        filename = ['sig_rec.' numfig];
        LoSaFlag = 'load'; wloasavf;
        if err
                [coefs,longs]   = wmemtool('rmb',win_dw1dtool,n_coefs_longs,...
                                                ind_coefs,ind_longs);
                Wave_Name       = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_wav_name);
                out1            = wrcoef('a',coefs,longs,Wave_Name,0);
        else
                out1 = sig_rec;
        end
        if nargin==3
                out2 = min(out1)-epsilon;
                out3 = max(out1)+epsilon;
        end

%*************************%
%** OPTION = 'ssig' - . **%
%*************************%
elseif strcmp(option,'ssig')
        pathname = wmemtool('rmb',win_dw1dtool,n_miscella,ind_savepath);
        filename = ['ssig_rec.' numfig];
        LoSaFlag = 'load'; wloasavf;
        if err
                out1 =  wmemtool('rmb',win_dw1dtool,n_synt_sig,ind_ssig);
        else
                out1 = ssig_rec;
        end
        if nargin==3
                out2 = min(out1)-epsilon;
                out3 = max(out1)+epsilon;
        end

%************************%
%** OPTION = 'cfs_beg' **%
%************************%
elseif strcmp(option,'cfs_beg')
        pathname = wmemtool('rmb',win_dw1dtool,n_miscella,ind_savepath);
        filename = ['cfs_beg.' numfig];
        LoSaFlag = 'load'; wloasavf;
        if err
                [coefs,longs]   = wmemtool('rmb',win_dw1dtool,n_coefs_longs,...
                                                ind_coefs,ind_longs);
                lev_anal = length(longs)-2;
                len     = longs(lev_anal+2);
                cfs_beg = zeros(lev_anal,len);
                for p = 1:lev_anal
                        z = detcoef(coefs,longs,p);
                        z = z(ones(1,2^p),:);
                        cfs_beg(p,:) = wkeep(z(:)',len);                
                end
        end
        out1 = cfs_beg(in3,:);
        if nargin<4 , return; end;
        if in4==1
                len_wav = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_wav_len);
                if isempty(len_wav) , len_wav = 10; end
%               mx = len_wav*(2.^in3);
                mx = (2.^(in3+1));
                lx = size(out1,2);
                l3 = length(in3);
                out2 = zeros(1,l3);
                out4 = epsilon*ones(1,l3);
                out3 = -out4;
                for k = 1:l3
                        bord = mx(k);
                        if bord<(lx/2)
                                out2(k) = 1;
                                xmax = lx-bord+1;
                                out3(k) = min(out1(k,bord:xmax))-epsilon;
                                out4(k) = max(out1(k,bord:xmax))+epsilon;
                        end
                end
        elseif in4==2
                out2 = (min(out1'))'-epsilon;
                out3 = (max(out1'))'+epsilon;
        end

%************************%
%** OPTION = 'app_cfs' **%
%************************%
elseif strcmp(option,'app_cfs')
        [coefs,longs]   = wmemtool('rmb',win_dw1dtool,n_coefs_longs,...
                                                ind_coefs,ind_longs);
        Wave_Name       = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_wav_name);
        out1            = appcoef(coefs,longs,Wave_Name,in3);
        if nargin<4 , return; end;
        if in4==1
                len_wav = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_wav_len);
                if isempty(len_wav) , len_wav = 10; end
%               bord = len_wav*(2.^(in3-1));
                bord = (2.^(in3+1));
                lx = size(out1,2);
                out2 = 0;
                out3 = -epsilon;
                out4 = epsilon;
                if bord<(lx/2)
                        out2 = 1;
                        xmax = lx-bord+1;
                        out3 = min(out1(bord:xmax))-epsilon;
                        out4 = max(out1(bord:xmax))+epsilon;
                end
        elseif in4==2
                out2 = (min(out1'))'-epsilon;
                out3 = (max(out1'))'+epsilon;
        end

%************************%
%** OPTION = 'det_cfs' **%
%************************%
elseif strcmp(option,'det_cfs')
        [coefs,longs]   = wmemtool('rmb',win_dw1dtool,n_coefs_longs,...
                                                ind_coefs,ind_longs);
        out1            = detcoef(coefs,longs,in3);
        if nargin<4 , return; end;
        if in4==1
                len_wav = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                                        ind_wav_len);
                if isempty(len_wav) , len_wav = 10; end
%               bord = len_wav*(2.^(in3-1));
                bord = (2.^(in3+1));
                lx = size(out1,2);
                out2 = 0;
                out3 = -epsilon;
                out4 = epsilon;
                if bord<(lx/2)
                        out2 = 1;
                        xmax = lx-bord+1;
                        out3 = min(out1(bord:xmax))-epsilon;
                        out4 = max(out1(bord:xmax))+epsilon;
                end
        elseif in4==2
                out2 = (min(out1'))'-epsilon;
                out3 = (max(out1'))'+epsilon;
        end

%************************************%
%** OPTION = 'del' -  Delete files.**%
%************************************%
elseif strcmp(option,'del')
        pathname = wmemtool('rmb',win_dw1dtool,n_miscella,ind_savepath);
        if ~isempty(pathname)
           olddir = cd;
           err = 0;
           eval(['cd(''' pathname ''');'],'err = 1;');
           if err , return; end
           sig_file = ['sig_rec.' numfig];
           if exist(sig_file)==2 , eval(['delete ' sig_file]); end
           ssig_file = ['ssig_rec.' numfig];
           if exist(ssig_file)==2 , eval(['delete ' ssig_file]); end
           app_file = ['app_rec.' numfig];
           if exist(app_file)==2 , eval(['delete ' app_file]); end
           det_file = ['det_rec.' numfig];
           if exist(det_file)==2 , eval(['delete ' det_file]); end
           cfs_file = ['cfs_beg.' numfig];
           if exist(cfs_file)==2 , eval(['delete ' cfs_file]); end
           cd(olddir);
        end
        wmemtool('wmb',win_dw1dtool,n_miscella,ind_savepath,'');

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('dw1dfile','Unknown Option','msg');
        error('*');
end
