function [out1,out2,out3] = dw1dhist(option,in2,in3,in4,in5,in6,in7,in8)
%DW1DHIST Discret wavelet 1D histograms.
%       [out1,out2,out3] = dw1dhist(option,in2,in3,in4,in5,in6,in7,in8)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:08:05 $

%       Uses WMEMTOOL.

global  Def_Btn_Height  Def_Btn_Width   ...
        Pop_Min_Width   X_Graph_Ratio   ...
        X_Spacing       Y_Spacing       ...
        Def_TxtBkColor  Def_EdiBkColor  ...
        Def_FraBkColor  Def_FraFgColor

if nargin==0, option = 'create'; end

% MemBloc1 of stored values.
%---------------------------
n_param_anal    = 'DWAn1d_Par_Anal';
ind_sig_name    =  1;
ind_sig_size    =  2;
ind_wav_name    =  3;
ind_wav_len     =  4;
ind_lev_anal    =  5;
ind_axe_ref     =  6;
ind_act_option  =  7;
ind_ssig_type   =  8;
nb1_stored      =  8;

% MemBloc2 of stored values.
%---------------------------
n_coefs_longs   = 'Coefs_and_Longs';
ind_coefs       = 1;
ind_longs       = 2;
nb2_stored      = 2;

% MemBloc4 of stored values.
%---------------------------
n_miscella      = 'DWAn1d_Miscella';
ind_graph_area  =  1;
ind_view_mode   =  2;
ind_savepath    =  3;
nb4_stored      =  3;

% MemBloc5 of stored values. (Local Bloc)
%----------------------------------------
n_chk_lev_lst   = 'Chk_Lev_Lst';
ind_Chk_App_Lst = 1;
ind_Chk_Det_Lst = 2;
nb5_stored      = 2;

% Tag property of objects.
%-------------------------
tag_cmd_frame   = 'Cmd_Frame';
tag_orig_sig    = 'Orig_sig';
tag_synt_sig    = 'Synt_sig';
tag_app_sig     = 'App_sig';
tag_det_sig     = 'Det_sig';
tag_app_txt     = 'App_Txt';
tag_app_all     = 'App_All';
tag_app_none    = 'App_None';
tag_det_txt     = 'Det_Txt';
tag_det_all     = 'Det_All';
tag_det_none    = 'Det_None';
tag_sel_cfs     = 'Sel_Cfs';
tag_sel_rec     = 'Sel_Rec';
tag_bins_txt    = 'Bins_Txt';
tag_bins_data   = 'Bins_Data';
tag_show_hist   = 'Show_Hist';

%*****************************************************************%
%** OPTION = 'create' - constructs the initial dw1dhist window  **%
%*****************************************************************%
if  strcmp(option,'create')

        % Calling figure.
        %----------------
        win_dw1dtool     = in2;
        str_win_dw1dtool = int2str(win_dw1dtool);

        % Window initialization.
        %----------------------
        win_name = 'Wavelet 1-D  --  Histograms';
        [win_dw1dhist,pos_win,cba_close_menu] = ...
                wfigcrea('create',NaN,win_name,'',win_dw1dtool,...
                        str2mat('-p','-0','-w'),'dw1dhist');
        str_numwin = int2str(win_dw1dhist);
        out1       = win_dw1dhist;
        win_units  = 'pixels';

        % Command frame and Dynamical visualization tool construction.
        %-------------------------------------------------------------
        [frame0,pos_frame0,Pos_Graphic_Area] = ...
                        wfigcrea('frame',win_dw1dhist,'','title');

        % Waiting Frame construction & begin waiting.
        %--------------------------------------------
        wwaiting('create',win_dw1dhist,X_Graph_Ratio,...
                        'Wait ... initialization');

        % Getting global variables from dw1dtool figure memory block.
        %------------------------------------------------------------
        [Sig_Name,Wav_Name,Lev_Anal,Sig_Size,Axe_Ref] = ...
                wmemtool('rmb',win_dw1dtool,n_param_anal,               ...
                        ind_sig_name,ind_wav_name,                      ...
                        ind_lev_anal,ind_sig_size,ind_axe_ref);
        [Wav_Fam,Wav_Num] = wavattrb('fam_num',Wav_Name);

        % General graphical parameters initialization.
        %--------------------------------------------

        % Borders and double borders.
        dx  = X_Spacing;  dx2 = 2*dx;
        dy  = Y_Spacing;  dy2 = 2*dy;

        % X init position and width of frames.
        x_frame0        = pos_frame0(1);
        cmd_width       = pos_frame0(3);
        h_frame0        = pos_frame0(4);

        % Buttons width
        push_width      = (cmd_width-4*dx)/2;
        txt_width       = Def_Btn_Width;
        pop_width       = Pop_Min_Width;

        % Number of cheks lines in apps. and dets. frames
        nb_inline       = 3;
        nb_lines        = max(2,ceil(Lev_Anal/nb_inline))+1;

        % Relative height of buttons.
        Screen_Size = get(0,'ScreenSize');
        if      Screen_Size(4) <= 700
                h_sigs = Def_Btn_Height;
        else
                h_sigs = 3*Def_Btn_Height/2;
        end

        % Parameters initialization.
        %---------------------------
        default_bins    = 30;

        % Position property of objects.
        %------------------------------
        pos_input_txt   = [     x_frame0+dx2                            ,...
                                h_frame0-3*dy-Def_Btn_Height            ,...
                                txt_width                               ,...
                                Def_Btn_Height                          ];
        pos_input_data  = [     pos_input_txt(1)+pos_input_txt(3)+dx    ,...
                                pos_input_txt(2)                        ,...
                                2*pop_width                             ,...
                                Def_Btn_Height                          ];
        pos_wav_txt     = pos_input_txt;
        pos_wav_txt(2)  = pos_input_txt(2)-Def_Btn_Height-dy2;
        pos_wav_fams    = [     pos_wav_txt(1)+pos_wav_txt(3)+dx        ,...
                                pos_wav_txt(2)                          ,...
                                pop_width                               ,...
                                Def_Btn_Height                          ];
        pos_wav_nums    = [     pos_wav_fams(1)+pos_wav_fams(3)+dx/2    ,...
                                pos_wav_fams(2)                         ,...
                                pop_width-dx/2                          ,...
                                Def_Btn_Height                          ];
        pos_lev_txt     = pos_wav_txt;
        pos_lev_txt(2)  = pos_wav_txt(2)-Def_Btn_Height-dy2;
        pos_lev_data    = [     pos_lev_txt(1)+pos_lev_txt(3)+dx        ,...
                                pos_lev_txt(2)                          ,...
                                pop_width                               ,...
                                Def_Btn_Height                          ];

        % Global selection on signals.

        px              = x_frame0+(cmd_width-7*push_width/4)/2;
        pos_orig_sig    = [     px                                      ,...
                                pos_lev_txt(2)-4*h_sigs/3               ,...
                                7*push_width/4                          ,...
                                h_sigs                                  ];
        pos_synt_sig    = [     px                                      ,...
                                pos_orig_sig(2)-4*h_sigs/3              ,...
                                7*push_width/4                          ,...
                                h_sigs                                  ];
        pos_app_sig     = [     px                                      ,...
                                pos_synt_sig(2)-4*h_sigs/3              ,...
                                7*push_width/4                          ,...
                                h_sigs                                  ];
        pos_det_sig     = [     px                                      ,...
                                pos_app_sig(2)-4*h_sigs/3               ,...
                                7*push_width/4                          ,...
                                h_sigs                                  ];

        yclose          = Def_Btn_Height;
        hclose          = 3*Def_Btn_Height/2;
        if Lev_Anal > 9
                yclose  = yclose/2;
                if Screen_Size(4) < 600
                        hclose = Def_Btn_Height;
                end
        end
        pos_close       = [     px                                      ,...
                                pos_frame0(2)+yclose                    ,...
                                7*push_width/4                          ,...
                                hclose                                  ];

        if Lev_Anal > 6
                btn_height = 4*Def_Btn_Height/5;
                if Screen_Size(4)<600
                        chk_height = Def_Btn_Height;
                else
                        chk_height = btn_height;
                end
        else
                btn_height = Def_Btn_Height;
                chk_height = Def_Btn_Height;
        end

        px              = x_frame0+(cmd_width-3*push_width/2)/2;
        pos_app_txt     = [     px                                      ,...
                                pos_det_sig(2)-3*btn_height/2           ,...
                                3*push_width/2                          ,...
                                btn_height                              ];
        nb              = nb_inline+1;
        wx              = (cmd_width-nb*txt_width/2)/(nb+1);
        pos_app_all     = [     x_frame0+wx                             ,...
                                pos_app_txt(2)-6*btn_height/5           ,...
                                txt_width/2                             ,...
                                btn_height                              ];
        pos_app_none    = [     pos_app_all(1)                          ,...
                                pos_app_all(2)-6*btn_height/5           ,...
                                txt_width/2                             ,...
                                btn_height                              ];

        % Inside subframe 2 of subframe 211.

        hx              = nb_lines*(6*btn_height/5);
        pos_det_txt     = [     px                                      ,...
                                pos_app_txt(2)-hx                       ,...
                                3*push_width/2                          ,...
                                btn_height                              ];
        pos_det_all     = [     x_frame0+wx                             ,...
                                pos_det_txt(2)-6*btn_height/5           ,...
                                txt_width/2                             ,...
                                btn_height                              ];
        pos_det_none    = [     pos_det_all(1)                          ,...
                                pos_det_all(2)-6*btn_height/5           ,...
                                txt_width/2                             ,...
                                btn_height                              ];


        px              = x_frame0+(cmd_width-5*push_width/4)/2;
        pos_sel_cfs     = [     px                                      ,...
                                pos_det_txt(2)-hx-btn_height/2          ,...
                                5*push_width/4                          ,...
                                Def_Btn_Height                          ];
        pos_sel_rec     = [     pos_sel_cfs(1)                          ,...
                                pos_sel_cfs(2)-3*Def_Btn_Height/2       ,...
                                5*push_width/4                          ,...
                                Def_Btn_Height                          ];

        px              = x_frame0+(cmd_width-3*pop_width)/2;
        pos_bins_txt    = [     px                                      ,...
                                pos_sel_rec(2)-2*Def_Btn_Height         ,...
                                2*pop_width                             ,...
                                Def_Btn_Height                          ];
        pos_bins_data   = pos_bins_txt;
        pos_bins_data(1)= pos_bins_txt(1)+pos_bins_txt(3)+dx;
        pos_bins_data(3)= pop_width;

        px              = x_frame0+(cmd_width-3*push_width/2)/2;
        hshow           = 2*Def_Btn_Height;
        if Screen_Size(4) < 600 & Lev_Anal > 9 , hshow = Def_Btn_Height; end
        pos_show_hist   = [     px                                      ,...
                                pos_bins_data(2)-Def_Btn_Height-hshow   ,...
                                3*push_width/2                          ,...
                                hshow                   ];

        % String property of objects.
        %----------------------------
        str_input_txt   = 'Signal';
        str_input_data  = Sig_Name;
        str_wav_txt     = 'Wavelet';
        str_wav_fams    = Wav_Fam;
        str_wav_nums    = Wav_Num;
        str_lev_txt     = 'Level';
        str_lev_data    = int2str(Lev_Anal);

        ss_type = wmemtool('rmb',win_dw1dtool,n_param_anal,ind_ssig_type);
        if      ss_type=='ss', str_ss = 'Synthesized signal';
        elseif  ss_type=='ds', str_ss = 'De-noised signal';
        elseif  ss_type=='cs', str_ss = 'Compressed signal';
        end
        str_synt_sig    = str_ss;

        str_orig_sig    = 'Original signal';
        str_app_sig     = 'Approximations';
        str_det_sig     = 'Details';
        str_app_txt     = 'Approximation levels';
        str_app_all     = 'All';
        str_app_none    = 'None';
        str_det_txt     = 'Detail levels';
        str_det_all     = 'All';
        str_det_none    = 'None';
        str_sel_cfs     = 'Coefficients';
        str_sel_rec     = 'Reconstructed';
        str_bins_txt    = 'Number of bins';
        str_bins_data   = int2str(default_bins);
        str_show_hist   = 'Show histograms';
        str_close       = 'Close';

        % Command part construction of the window.
        %-----------------------------------------
        figure(win_dw1dhist)
        txt_input_txt   = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_input_txt,...
                                        'String',str_input_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_input_data  = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_input_data,...
                                        'String',str_input_data,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_wav_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_wav_txt,...
                                        'String',str_wav_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_wav_fams    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_wav_fams,...
                                        'String',str_wav_fams,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        if ~isempty(str_wav_nums)
        txt_wav_nums    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_wav_nums,...
                                        'String',str_wav_nums,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        end
        txt_lev_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_lev_txt,...
                                        'String',str_lev_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_lev_data    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_lev_data,...
                                        'String',str_lev_data,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        drawnow

        chk_orig_sig    = uicontrol(...
                                        'Style','Checkbox',...
                                        'Unit',win_units,...
                                        'Position',pos_orig_sig,...
                                        'String',str_orig_sig,...
                                        'Enable','off',...
                                        'UserData',0,...
                                        'Tag',tag_orig_sig...
                                        );
        chk_synt_sig    = uicontrol(...
                                        'Style','Checkbox',...
                                        'Unit',win_units,...
                                        'Position',pos_synt_sig,...
                                        'String',str_synt_sig,...
                                        'Enable','off',...
                                        'UserData',0,...
                                        'Tag',tag_synt_sig...
                                        );
        chk_app_sig     = uicontrol(...
                                        'Style','Checkbox',...
                                        'Unit',win_units,...
                                        'Position',pos_app_sig,...
                                        'String',str_app_sig,...
                                        'Enable','off',...
                                        'UserData',0,...
                                        'Tag',tag_app_sig...
                                        );
        chk_det_sig     = uicontrol(...
                                        'Style','Checkbox',...
                                        'Unit',win_units,...
                                        'Position',pos_det_sig,...
                                        'String',str_det_sig,...
                                        'Enable','off',...
                                        'UserData',0,...
                                        'Tag',tag_det_sig...
                                        );
        drawnow

        % Approximations checkboxes construction.

        txt_app_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_app_txt,...
                                        'String',str_app_txt,...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Visible','off',...
                                        'Tag',tag_app_txt...
                                        );
        pus_app_all     = uicontrol(...
                                        'Style','PushButton',...
                                        'Unit',win_units,...
                                        'Position',pos_app_all,...
                                        'String',str_app_all,...
                                        'Visible','off',...
                                        'Tag',tag_app_all...
                                        );
        pus_app_none    = uicontrol(...
                                        'Style','PushButton',...
                                        'Unit',win_units,...
                                        'Position',pos_app_none,...
                                        'String',str_app_none,...
                                        'Visible','off',...
                                        'Tag',tag_app_none...
                                        );
        wx              = (cmd_width-nb*txt_width/2)/(nb+1);
        xbtchk0         = x_frame0+txt_width/2+2*wx;
        ybtchk0         = pos_app_txt(2)-6*btn_height/5;
        xbtchk          = xbtchk0;
        ybtchk          = ybtchk0;
        Chk_App_Lst     = zeros(Lev_Anal,1);
        for i=1:Lev_Anal
                pos_app_i = [xbtchk ybtchk txt_width/2 chk_height];
                str_app_i = int2str(i);
                tag_app_i = ['App' int2str(i)];
                chk_app_i = uicontrol(...
                                        'Style','Checkbox',...
                                        'Unit',win_units,...
                                        'Position',pos_app_i,...
                                        'String',str_app_i,...
                                        'Visible','off',...
                                        'Tag',tag_app_i...
                                        );
                Chk_App_Lst(i) = chk_app_i;
                if rem(i,nb_inline)==0
                        xbtchk = xbtchk0;
                        ybtchk = ybtchk-6*btn_height/5;
                else
                        xbtchk = xbtchk+txt_width/2+wx;
                end

        end
        drawnow

        % Details checkboxes construction.

        txt_det_txt      = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_det_txt,...
                                        'String',str_det_txt,...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Visible','off',...
                                        'Tag',tag_det_txt...
                                        );
        pus_det_all     = uicontrol(...
                                        'Style','PushButton',...
                                        'Unit',win_units,...
                                        'Position',pos_det_all,...
                                        'String',str_det_all,...
                                        'Visible','off',...
                                        'Tag',tag_det_all...
                                        );
        pus_det_none    = uicontrol(...
                                        'Style','PushButton',...
                                        'Unit',win_units,...
                                        'Position',pos_det_none,...
                                        'String',str_det_none,...
                                        'Visible','off',...
                                        'Tag',tag_det_none...
                                        );
        ybtchk0         = pos_det_txt(2)-6*btn_height/5;
        xbtchk          = xbtchk0;
        ybtchk          = ybtchk0;
        Chk_Det_Lst     = zeros(Lev_Anal,1);
        for i=1:Lev_Anal
                pos_det_i = [xbtchk ybtchk txt_width/2 chk_height];
                str_det_i = int2str(i);
                tag_det_i = ['Det' int2str(i)];
                chk_det_i = uicontrol(...
                                        'Style','Checkbox',...
                                        'Unit',win_units,...
                                        'Position',pos_det_i,...
                                        'String',str_det_i,...
                                        'Visible','off',...
                                        'Tag',tag_det_i...
                                        );
                Chk_Det_Lst(i) = chk_det_i;
                if rem(i,nb_inline)==0
                        xbtchk = xbtchk0;
                        ybtchk = ybtchk-6*btn_height/5;
                else
                        xbtchk = xbtchk+txt_width/2+wx;
                end

        end
        drawnow

        rad_sel_cfs     = uicontrol(...
                                        'Style','Radiobutton',...
                                        'Unit',win_units,...
                                        'Position',pos_sel_cfs,...
                                        'String',str_sel_cfs,...
                                        'Visible','off',...
                                        'Tag',tag_sel_cfs,...
                                        'Value',0);
        rad_sel_rec     = uicontrol(...
                                        'Style','Radiobutton',...
                                        'Unit',win_units,...
                                        'Position',pos_sel_rec,...
                                        'String',str_sel_rec,...
                                        'Visible','off',...
                                        'Tag',tag_sel_rec,...
                                        'Value',1);
        txt_bins_txt    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_bins_txt,...
                                        'String',str_bins_txt,...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Visible','off',...
                                        'Tag',tag_bins_txt...
                                        );
        edi_bins_data   = uicontrol(...
                                        'Style','Edit',...
                                        'Unit',win_units,...
                                        'Position',pos_bins_data,...
                                        'String',str_bins_data,...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'Visible','off',...
                                        'Tag',tag_bins_data...
                                        );
        pus_show_hist   = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_show_hist,...
                                        'String',str_show_hist,...
                                        'Interruptible','yes',...
                                        'Visible','off',...
                                        'Userdata',[],...
                                        'Tag',tag_show_hist...
                                        );
        pus_close       = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_close,...
                                        'String',str_close,...
                                        'Interruptible','yes'...
                                        );
        drawnow


        % Sets of handles.
        %-----------------
        set1_hdls       = [     txt_app_txt
                                pus_app_all
                                pus_app_none
                                Chk_App_Lst];
        set2_hdls       = [     txt_det_txt
                                pus_det_all
                                pus_det_none
                                Chk_Det_Lst];
        set3_hdls       = [     rad_sel_cfs
                                rad_sel_rec];
        set4_hdls       = [     txt_bins_txt
                                edi_bins_data
                                pus_show_hist
                                pus_close
                                ];

        % Selected box limits.
        %---------------------
        xlim_selbox = dynvtool('getbox',win_dw1dtool); 
        if ~isempty(xlim_selbox)
                xlim_selbox = [min(xlim_selbox) max(xlim_selbox)];
        else
                xlim_selbox = get(Axe_Ref,'XLim');
        end
        xlim_selbox     = round(xlim_selbox);
        xlim1           = xlim_selbox(1);       
        xlim2           = xlim_selbox(2);
        if xlim1<1,             xlim1 = 1;              end
        if xlim2>Sig_Size,      xlim2 = Sig_Size;       end
        if (xlim2<1) | (xlim1>Sig_Size) , return, end
        selbox          = [xlim1 xlim2];

        % Callbacks update.
        %------------------
        str_set1_hdls           = num2mstr(set1_hdls);
        str_set2_hdls           = num2mstr(set2_hdls);
        str_set3_hdls           = num2mstr(set3_hdls);
        str_set4_hdls           = num2mstr(set4_hdls);
        str_group_hdls          = num2mstr([    set1_hdls;...
                                                set2_hdls;...
                                                set3_hdls;...
                                                set4_hdls;...
                                                ]);
        str_chk_orig_sig        = num2mstr(chk_orig_sig);
        str_chk_synt_sig        = num2mstr(chk_synt_sig);
        str_chk_app_sig         = num2mstr(chk_app_sig);
        str_chk_det_sig         = num2mstr(chk_det_sig);
        str_Chk_App_Lst         = num2mstr(Chk_App_Lst);
        str_Chk_Det_Lst         = num2mstr(Chk_Det_Lst);
        str_rad_sel_rec         = num2mstr(rad_sel_rec);
        str_rad_sel_cfs         = num2mstr(rad_sel_cfs);
        str_edi_bins_data       = num2mstr(edi_bins_data);
        str_selbox              = num2mstr(selbox);
        tmp_txt                 =[      str_set1_hdls ',' ...
                                        str_set2_hdls ',' ...
                                        str_set3_hdls ',' ...
                                        str_set4_hdls ',' ...
                                        str_group_hdls];

        cba_orig_sig            = ['dw1dhist(''select'',' ...
                                        str_numwin ',' ...
                                        str_chk_orig_sig ',' ...
                                        tmp_txt ...
                                        ');'];
        cba_synt_sig            = ['dw1dhist(''select'',' ...
                                        str_numwin ',' ...
                                        str_chk_synt_sig ',' ...
                                        tmp_txt ...
                                        ');'];
        cba_app_sig             = ['dw1dhist(''select'',' ...
                                        str_numwin ',' ...
                                        str_chk_app_sig ',' ...
                                        tmp_txt ...
                                        ');'];
        cba_det_sig             = ['dw1dhist(''select'',' ...
                                        str_numwin ',' ...
                                        str_chk_det_sig ',' ...
                                        tmp_txt ...
                                        ');'];
        cba_bins_data           = ['dw1dhist(''update_bins'',' ...
                                        str_numwin ',' ...
                                        str_edi_bins_data ...
                                        ');'];
        cba_app_all             = ['set(' str_Chk_App_Lst ',''Value'',1);'];
        cba_app_none            = ['set(' str_Chk_App_Lst ',''Value'',0);'];
        cba_det_all             = ['set(' str_Chk_Det_Lst ',''Value'',1);'];
        cba_det_none            = ['set(' str_Chk_Det_Lst ',''Value'',0);'];
        cba_sel_rec             = ['set(' str_rad_sel_rec ',''Value'',1);' ...
                                   'set(' str_rad_sel_cfs ',''Value'',0);'];
        cba_sel_cfs             = ['set(' str_rad_sel_cfs ',''Value'',1);' ...
                                   'set(' str_rad_sel_rec ',''Value'',0);'];
        cba_show_hist           = ['dw1dhist(''draw'',' ...
                                        str_numwin ',' ...
                                        str_win_dw1dtool ',' ...
                                        str_selbox ');'];

        set(chk_orig_sig,'Callback',cba_orig_sig);
        set(chk_synt_sig,'Callback',cba_synt_sig);
        set(chk_app_sig,'Callback',cba_app_sig);
        set(chk_det_sig,'Callback',cba_det_sig);
        set(pus_app_all,'Callback',cba_app_all);
        set(pus_app_none,'Callback',cba_app_none);
        set(pus_det_all,'Callback',cba_det_all);
        set(pus_det_none,'Callback',cba_det_none);
        set(rad_sel_rec,'Callback',cba_sel_rec);
        set(rad_sel_cfs,'Callback',cba_sel_cfs);
        set(edi_bins_data,'Callback',cba_bins_data);
        set(pus_show_hist,'Callback',cba_show_hist);
        set(pus_close,'Callback',cba_close_menu);

        % Memory blocks update.
        %----------------------
        wmemtool('def',win_dw1dhist,n_chk_lev_lst,nb5_stored);
        wmemtool('write',win_dw1dhist,n_chk_lev_lst,...
                        ind_Chk_App_Lst,Chk_App_Lst,ind_Chk_Det_Lst,Chk_Det_Lst);

        % Displaying the window title.
        %-----------------------------
        str_nb_val      = [' (' int2str(Sig_Size) ' values)'];
        str_wintitle    = [Sig_Name,str_nb_val,' analyzed at level ',...
                           int2str(Lev_Anal),' with ',Wav_Name];
        str_wintitle    = [str_wintitle '.  Components :   ' ,...
                           int2str(selbox(1)) ' --> ' ...
                           int2str(selbox(2))];
        wfigtitl('string',win_dw1dhist,str_wintitle,'off');

        % Setting units to normalized.
        %-----------------------------
        set(findobj(win_dw1dhist,'Units','pixels'),'Units','normalized');

        % End waiting.
        %-------------
        wwaiting('off',win_dw1dhist);
        set([chk_orig_sig chk_synt_sig chk_app_sig chk_det_sig],'Enable','on');

%***********************************************%
%** OPTION = 'select' - SIGNAL TYPE SELECTION **%
%***********************************************%
elseif  strcmp(option,'select')
        win_dw1dhist    = in2;
        sel_chk_btn     = in3;
        set1_hdls       = in4;
        set2_hdls       = in5;
        set3_hdls       = in6;
        set4_hdls       = in7;
        group_hdls      = in8;

        % Handles of tagged objects.
        %---------------------------
        uic_handles     = findobj(win_dw1dhist,'type','uicontrol');
        chk_handles     = findobj(uic_handles,'Style','checkbox');
        txt_handles     = findobj(uic_handles,'Style','text');
        fra_handles     = findobj(uic_handles,'Style','frame');
        axe_handles     = findobj(win_dw1dhist,'Type','axes');
        chk_orig_sig    = findobj(chk_handles,'Tag',tag_orig_sig);
        chk_synt_sig    = findobj(chk_handles,'Tag',tag_synt_sig);
        chk_app_sig     = findobj(chk_handles,'Tag',tag_app_sig);
        chk_det_sig     = findobj(chk_handles,'Tag',tag_det_sig);
        hdl1            = findobj(fra_handles,'Tag','Dw1dhist_Level');
        hdl2            = findobj(txt_handles,'Tag','Dw1dhist_Sigtype');
        hdl3            = axe_handles;

        % Cleaning the graphical part.
        %-----------------------------
        delete([hdl1; hdl2; hdl3]);

        % Get the current selection.
        %---------------------------
        orig_sig        = (get(chk_orig_sig,'Userdata')~=0);
        synt_sig        = (get(chk_synt_sig,'Userdata')~=0);
        app_sig         = (get(chk_app_sig,'Userdata')~=0);
        det_sig         = (get(chk_det_sig,'Userdata')~=0);

        % Get to the current positions.
        %------------------------------
        pos_det_sig             = get(chk_det_sig,'Position');
        pos_app_txt             = get(set1_hdls(1),'Position');
        pos_app_all             = get(set1_hdls(2),'Position');
        pos_app_none            = get(set1_hdls(3),'Position');
        pos_det_txt             = get(set2_hdls(1),'Position');
        pos_det_all             = get(set2_hdls(2),'Position');
        pos_det_none            = get(set2_hdls(3),'Position');
        pos_sel_cfs             = get(set3_hdls(1),'Position');
        pos_sel_rec             = get(set3_hdls(2),'Position');
        pos_bins_txt            = get(set4_hdls(1),'Position');
        pos_bins_data           = get(set4_hdls(2),'Position');
        pos_show_hist           = get(set4_hdls(3),'Position');
        pos_close               = get(set4_hdls(4),'Position');

        % Redefine heigth of buttons depending on levels.
        %------------------------------------------------
        levels                  = length(set1_hdls)-3;
        nb_inline               = 3;
        nbl                     = max(2,ceil(levels/nb_inline))+1;
        pos_txt_bins            = get(set4_hdls(1),'Position');
        hbtn1                   = pos_txt_bins(4);
        hbtn2                   = hbtn1;
        hbtn3                   = hbtn1;
        if      levels > 6,     hbtn2   = 4*hbtn2/5;    end
        if      levels > 9,     hbtn3   = hbtn2/2;      end

        % Redraw the command part depending on the current selection.
        %------------------------------------------------------------
        if      sel_chk_btn==chk_orig_sig
                if      orig_sig
                        set(chk_orig_sig,'Value',0,'Userdata',0)
                        if      ~(synt_sig | app_sig | det_sig) 
                                set(group_hdls,'Visible','off');
                        end
                else
                        set(chk_orig_sig,'Value',1,'Userdata',1)
                        if      ~(synt_sig | app_sig | det_sig)
                                pos_bins_txt(2) = pos_det_sig(2)-2*hbtn1;
                                pos_bins_data(2)= pos_bins_txt(2);
                                pos_show_hist(2)= pos_bins_data(2)-3*hbtn1;
                                set(set4_hdls(1),'Position',pos_bins_txt);
                                set(set4_hdls(2),'Position',pos_bins_data);
                                set(set4_hdls(3),'Position',pos_show_hist);
                                set(set4_hdls,'Visible','on');
                        end
                end

        elseif  sel_chk_btn==chk_synt_sig
                if      synt_sig
                        set(chk_synt_sig,'Value',0,'Userdata',0)
                        if      ~(orig_sig | app_sig | det_sig) 
                                set(group_hdls,'Visible','off');
                        end
                else
                        set(chk_synt_sig,'Value',1,'Userdata',1)
                        if      ~(orig_sig | app_sig | det_sig)
                                pos_bins_txt(2) = pos_det_sig(2)-2*hbtn1;
                                pos_bins_data(2)= pos_bins_txt(2);
                                pos_show_hist(2)= pos_bins_data(2)-3*hbtn1;
                                set(set4_hdls(1),'Position',pos_bins_txt);
                                set(set4_hdls(2),'Position',pos_bins_data);
                                set(set4_hdls(3),'Position',pos_show_hist);
                                set(set4_hdls,'Visible','on');
                        end
                end

        elseif  sel_chk_btn==chk_app_sig
                set(group_hdls,'Visible','off');
                if      app_sig
                        set(chk_app_sig,'Value',0,'Userdata',0)
                        if      (orig_sig | synt_sig) & ~det_sig
                                pos_bins_txt(2) = pos_det_sig(2)-2*hbtn1;
                                pos_bins_data(2)= pos_bins_txt(2);
                                pos_show_hist(2)= pos_bins_data(2)-3*hbtn1;
                                set(set4_hdls(1),'Position',pos_bins_txt);
                                set(set4_hdls(2),'Position',pos_bins_data);
                                set(set4_hdls(3),'Position',pos_show_hist);
                                set(set4_hdls,'Visible','on');
                        elseif  det_sig
                                pos_det_txt(2)  = pos_det_sig(2)-3*hbtn2/2;
                                pos_det_all(2)  = pos_det_txt(2)-6*hbtn2/5;
                                pos_det_none(2) = pos_det_all(2)-6*hbtn2/5;
                                set(set2_hdls(1),'Position',pos_det_txt);
                                set(set2_hdls(2),'Position',pos_det_all);
                                set(set2_hdls(3),'Position',pos_det_none);
                                pos_chk_det     = zeros(levels,4);
                                for     i=1:levels
                                        j=i+3;
                                        k=ceil(i/nb_inline);
                                        pos_chk_det(j,:) = ...
                                        get(set2_hdls(j),'Position');
                                        pos_chk_det(j,2) = ...
                                        pos_det_txt(2)-k*(6*hbtn2/5);
                                        set(set2_hdls(j),'Position',...
                                        pos_chk_det(j,:));
                                end

                                pos_sel_cfs(2)  = pos_det_txt(2)...
                                                -nbl*(6*hbtn2/5)-hbtn2/2;
                                pos_sel_rec(2)  = pos_sel_cfs(2)-3*hbtn1/2;
                                set(set3_hdls(1),'Position',pos_sel_cfs);
                                set(set3_hdls(2),'Position',pos_sel_rec);

                                pos_bins_txt(2) = pos_sel_rec(2)-hbtn1-hbtn3;
                                pos_bins_data(2)= pos_bins_txt(2);
                                pos_show_hist(2)= pos_bins_data(2)...
                                                -2*hbtn1-hbtn3;
                                set(set4_hdls(1),'Position',pos_bins_txt);
                                set(set4_hdls(2),'Position',pos_bins_data);
                                set(set4_hdls(3),'Position',pos_show_hist);

                                set(set2_hdls,'Visible','on');
                                set(set3_hdls,'Visible','on');
                                set(set4_hdls,'Visible','on');
                        end
                else
                        set(chk_app_sig,'Value',1,'Userdata',1)
                        if      det_sig
                                pos_app_txt(2)  = pos_det_sig(2)-3*hbtn2/2;
                                pos_app_all(2)  = pos_app_txt(2)-6*hbtn2/5;
                                pos_app_none(2) = pos_app_all(2)-6*hbtn2/5;
                                set(set1_hdls(1),'Position',pos_app_txt);
                                set(set1_hdls(2),'Position',pos_app_all);
                                set(set1_hdls(3),'Position',pos_app_none);

                                pos_det_txt(2)  = pos_app_txt(2)...
                                                -nbl*(6*hbtn2/5);
                                pos_det_all(2)  = pos_det_txt(2)-6*hbtn2/5;
                                pos_det_none(2) = pos_det_all(2)-6*hbtn2/5;
                                set(set2_hdls(1),'Position',pos_det_txt);
                                set(set2_hdls(2),'Position',pos_det_all);
                                set(set2_hdls(3),'Position',pos_det_none);
                                pos_chk_det     = zeros(levels,4);
                                for     i=1:levels
                                        j=i+3;
                                        k=ceil(i/nb_inline);
                                        pos_chk_det(j,:) = get(set2_hdls(j),...
                                                                'Position');
                                        pos_chk_det(j,2) = pos_det_txt(2)...
                                                        -k*(6*hbtn2/5);
                                        set(set2_hdls(j),'Position',...
                                        pos_chk_det(j,:));
                                end

                                pos_sel_cfs(2)  = pos_det_txt(2)...
                                                -nbl*(6*hbtn2/5)-hbtn2/2;
                                pos_sel_rec(2)  = pos_sel_cfs(2)-3*hbtn1/2;
                                set(set3_hdls(1),'Position',pos_sel_cfs);
                                set(set3_hdls(2),'Position',pos_sel_rec);

                                pos_bins_txt(2) = pos_sel_rec(2)-hbtn1-hbtn3;
                                pos_bins_data(2)= pos_bins_txt(2);
                                yl              = pos_close(2)+pos_close(4);
                                dy              = pos_bins_data(2)-yl-pos_show_hist(4);
                                pos_show_hist(2)= yl+dy/2;

                                set(set4_hdls(1),'Position',pos_bins_txt);
                                set(set4_hdls(2),'Position',pos_bins_data);
                                set(set4_hdls(3),'Position',pos_show_hist);

                                set(set1_hdls,'Visible','on');
                                set(set2_hdls,'Visible','on');
                                set(set3_hdls,'Visible','on');
                                set(set4_hdls,'Visible','on');
                        else
                                pos_app_txt(2)  = pos_det_sig(2)-3*hbtn2/2;
                                pos_app_all(2)  = pos_app_txt(2)-6*hbtn2/5;
                                pos_app_none(2) = pos_app_all(2)-6*hbtn2/5;
                                set(set1_hdls(1),'Position',pos_app_txt);
                                set(set1_hdls(2),'Position',pos_app_all);
                                set(set1_hdls(3),'Position',pos_app_none);

                                pos_sel_cfs(2)  = pos_app_txt(2)...
                                                -nbl*(6*hbtn2/5)-hbtn2/2;
                                pos_sel_rec(2)  = pos_sel_cfs(2)-3*hbtn1/2;
                                set(set3_hdls(1),'Position',pos_sel_cfs);
                                set(set3_hdls(2),'Position',pos_sel_rec);

                                pos_bins_txt(2) = pos_sel_rec(2)-2*hbtn1;
                                pos_bins_data(2)= pos_bins_txt(2);
                                pos_show_hist(2)= pos_bins_data(2)-3*hbtn1;
                                set(set4_hdls(1),'Position',pos_bins_txt);
                                set(set4_hdls(2),'Position',pos_bins_data);
                                set(set4_hdls(3),'Position',pos_show_hist);

                                set(set1_hdls,'Visible','on');
                                set(set3_hdls,'Visible','on');
                                set(set4_hdls,'Visible','on');


                        end
                end

        elseif  sel_chk_btn==chk_det_sig
                set(group_hdls,'Visible','off');
                if      det_sig
                        set(chk_det_sig,'Value',0,'Userdata',0)
                        if      (orig_sig | synt_sig) & ~app_sig
                                pos_bins_txt(2) = pos_det_sig(2)-2*hbtn1;
                                pos_bins_data(2)= pos_bins_txt(2);
                                pos_show_hist(2)= pos_bins_data(2)-3*hbtn1;
                                set(set4_hdls(1),'Position',pos_bins_txt);
                                set(set4_hdls(2),'Position',pos_bins_data);
                                set(set4_hdls(3),'Position',pos_show_hist);
                                set(set4_hdls,'Visible','on');
                        elseif  app_sig
                                pos_app_txt(2)  = pos_det_sig(2)-3*hbtn2/2;
                                pos_app_all(2)  = pos_app_txt(2)-6*hbtn2/5;
                                pos_app_none(2) = pos_app_all(2)-6*hbtn2/5;
                                set(set1_hdls(1),'Position',pos_app_txt);
                                set(set1_hdls(2),'Position',pos_app_all);
                                set(set1_hdls(3),'Position',pos_app_none);

                                pos_sel_cfs(2)  = pos_app_txt(2)...
                                                -nbl*(6*hbtn2/5)-hbtn2/2;
                                pos_sel_rec(2)  = pos_sel_cfs(2)-3*hbtn1/2;
                                set(set3_hdls(1),'Position',pos_sel_cfs);
                                set(set3_hdls(2),'Position',pos_sel_rec);

                                pos_bins_txt(2) = pos_sel_rec(2)-2*hbtn1;
                                pos_bins_data(2)= pos_bins_txt(2);
                                pos_show_hist(2)= pos_bins_data(2)-3*hbtn1;
                                set(set4_hdls(1),'Position',pos_bins_txt);
                                set(set4_hdls(2),'Position',pos_bins_data);
                                set(set4_hdls(3),'Position',pos_show_hist);

                                set(set1_hdls,'Visible','on');
                                set(set3_hdls,'Visible','on');
                                set(set4_hdls,'Visible','on');
                        end
                else
                        set(chk_det_sig,'Value',1,'Userdata',1)
                        if      app_sig
                                pos_app_txt(2)  = pos_det_sig(2)-3*hbtn2/2;
                                pos_app_all(2)  = pos_app_txt(2)-6*hbtn2/5;
                                pos_app_none(2) = pos_app_all(2)-6*hbtn2/5;
                                set(set1_hdls(1),'Position',pos_app_txt);
                                set(set1_hdls(2),'Position',pos_app_all);
                                set(set1_hdls(3),'Position',pos_app_none);

                                pos_det_txt(2)  = pos_app_txt(2)...
                                                -nbl*(6*hbtn2/5);
                                pos_det_all(2)  = pos_det_txt(2)-6*hbtn2/5;
                                pos_det_none(2) = pos_det_all(2)-6*hbtn2/5;
                                set(set2_hdls(1),'Position',pos_det_txt);
                                set(set2_hdls(2),'Position',pos_det_all);
                                set(set2_hdls(3),'Position',pos_det_none);
                                pos_chk_det     = zeros(levels,4);
                                for     i=1:levels
                                        j=i+3;
                                        k=ceil(i/nb_inline);
                                        pos_chk_det(j,:) = get(set2_hdls(j),...
                                                                'Position');
                                        pos_chk_det(j,2) = pos_det_txt(2)...
                                                        -k*(6*hbtn2/5);
                                        set(set2_hdls(j),'Position',...
                                                        pos_chk_det(j,:));
                                end

                                pos_sel_cfs(2)  = pos_det_txt(2)...
                                                -nbl*(6*hbtn2/5)-hbtn2/2;
                                pos_sel_rec(2)  = pos_sel_cfs(2)-3*hbtn1/2;
                                set(set3_hdls(1),'Position',pos_sel_cfs);
                                set(set3_hdls(2),'Position',pos_sel_rec);

                                pos_bins_txt(2) = pos_sel_rec(2)-hbtn1-hbtn3;
                                pos_bins_data(2)= pos_bins_txt(2);
                                yl              = pos_close(2)+pos_close(4);
                                dy              = pos_bins_data(2)-yl-pos_show_hist(4);                 
                                pos_show_hist(2)= yl+dy/2;
                                set(set4_hdls(1),'Position',pos_bins_txt);
                                set(set4_hdls(2),'Position',pos_bins_data);
                                set(set4_hdls(3),'Position',pos_show_hist);

                                set(set1_hdls,'Visible','on');
                                set(set2_hdls,'Visible','on');
                                set(set3_hdls,'Visible','on');
                                set(set4_hdls,'Visible','on');
                        else
                                pos_det_txt(2)  = pos_det_sig(2)-3*hbtn2/2;
                                pos_det_all(2)  = pos_det_txt(2)-6*hbtn2/5;
                                pos_det_none(2) = pos_det_all(2)-6*hbtn2/5;
                                set(set2_hdls(1),'Position',pos_det_txt);
                                set(set2_hdls(2),'Position',pos_det_all);
                                set(set2_hdls(3),'Position',pos_det_none);
                                pos_chk_det     = zeros(levels,4);
                                for     i=1:levels
                                        j=i+3;
                                        k=ceil(i/nb_inline);
                                        pos_chk_det(j,:) = get(set2_hdls(j),...
                                                                'Position');
                                        pos_chk_det(j,2) = pos_det_txt(2)...
                                                        -k*(6*hbtn2/5);
                                        set(set2_hdls(j),'Position',...
                                                        pos_chk_det(j,:));
                                end

                                pos_sel_cfs(2)  = pos_det_txt(2)...
                                                -nbl*(6*hbtn2/5)-hbtn2/2;
                                pos_sel_rec(2)  = pos_sel_cfs(2)-3*hbtn1/2;
                                set(set3_hdls(1),'Position',pos_sel_cfs);
                                set(set3_hdls(2),'Position',pos_sel_rec);

                                pos_bins_txt(2) = pos_sel_rec(2)-2*hbtn1;
                                pos_bins_data(2)= pos_bins_txt(2);
                                pos_show_hist(2)= pos_bins_data(2)-3*hbtn1;
                                set(set4_hdls(1),'Position',pos_bins_txt);
                                set(set4_hdls(2),'Position',pos_bins_data);
                                set(set4_hdls(3),'Position',pos_show_hist);

                                set(set2_hdls,'Visible','on');
                                set(set3_hdls,'Visible','on');
                                set(set4_hdls,'Visible','on');

                        end
                end
        end

%**********************************************%
%** OPTION = 'draw' - DRAW AXES              **%
%**********************************************%
elseif  strcmp(option,'draw')
        win_dw1dhist    = in2;
        win_dw1dtool    = in3;
        selbox_orig     = in4;

        % Handles of tagged objects.
        %---------------------------
        uic_handles     = findobj(win_dw1dhist,'type','uicontrol');
        chk_handles     = findobj(uic_handles,'Style','checkbox');
        rad_handles     = findobj(uic_handles,'Style','radiobutton');
        pus_handles     = findobj(uic_handles,'Style','pushbutton');
        pus_show_hist   = findobj(pus_handles,...
                                        'Style','pushbutton',...
                                        'Tag',tag_show_hist...
                                        );
        txt_handles     = findobj(uic_handles,'Style','text');
        fra_handles     = findobj(uic_handles,'Style','frame');
        axe_handles     = findobj(win_dw1dhist,'Type','axes');
        hdl1            = findobj(fra_handles,'Tag','Dw1dhist_Level');
        hdl2            = findobj(txt_handles,'Tag','Dw1dhist_Sigtype');
        hdl3            = axe_handles;
        hdl_frame0      = findobj(fra_handles,'Tag',tag_cmd_frame);

        % Handles of tagged objects continuing.
        %-------------------------------------
        chk_orig_sig    = findobj(chk_handles,'Tag',tag_orig_sig);
        chk_synt_sig    = findobj(chk_handles,'Tag',tag_synt_sig);
        chk_app_sig     = findobj(chk_handles,'Tag',tag_app_sig);
        chk_det_sig     = findobj(chk_handles,'Tag',tag_det_sig);
        rad_sel_cfs     = findobj(win_dw1dhist,'Style','radiobutton',...
                                        'Tag',tag_sel_cfs);
        edi_bins_data   = findobj(win_dw1dhist,'Style','edit',...
                                        'Tag',tag_bins_data);

        % Check the bins number.
        %-----------------------
        default_bins    = 30;
        old_params      = get(pus_show_hist,'Userdata');
        if ~isempty(old_params)
                default_bins = old_params(1);
        end
        nb_bins         = str2num(get(edi_bins_data,'String'));
        if isempty(nb_bins)
                nb_bins = default_bins;   
                set(edi_bins_data,'String',int2str(default_bins))
        elseif nb_bins<2
                nb_bins = default_bins;
                set(edi_bins_data,'String',int2str(default_bins))
        end

        % Getting memory blocks.
        %-----------------------
        Lev_Anal        = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                        ind_lev_anal);

        [Chk_App_Lst,Chk_Det_Lst] = wmemtool('read',win_dw1dhist,n_chk_lev_lst,...
                                        ind_Chk_App_Lst,ind_Chk_Det_Lst);

        % Main parameters selection before drawing.
        %------------------------------------------
        sel_cfs         = (get(rad_sel_cfs,'Value')~=0);
        orig_sig        = (get(chk_orig_sig,'Value')~=0);
        synt_sig        = (get(chk_synt_sig,'Value')~=0);
        app_sig         = (get(chk_app_sig,'Value')~=0);
        det_sig         = (get(chk_det_sig,'Value')~=0);

        % Actives apps and dets lists construction.
        %------------------------------------------
        app_lst         = [];
        det_lst         = [];
        if app_sig
                for i=1:Lev_Anal
                        if get(Chk_App_Lst(i),'Value')~=0
                                app_lst = [app_lst i];
                        end
                end
        end
        if det_sig
                for i=1:Lev_Anal
                        if get(Chk_Det_Lst(i),'Value')~=0
                                det_lst = [det_lst i];
                        end
                end
        end

        new_params = [  nb_bins sel_cfs orig_sig synt_sig       ...
                        app_sig det_sig app_lst det_lst         ...
                        ];
        if      isempty(axe_handles)
        elseif  length(new_params)~=length(old_params)
        elseif  new_params==old_params
                return
        end

        % Deseable new selection.
        %-------------------------
        set([chk_handles;pus_handles;rad_handles],'Enable','off');

        % Updating parameters.
        %--------------------- 
        set(pus_show_hist,'Userdata',new_params);

        % Show the status line.
        %----------------------
        wfigtitl('vis',win_dw1dhist,'on');

        % Waiting message.
        %-----------------
        wwaiting('msg',win_dw1dhist,'Wait ... computing');
        drawnow

        % Cleaning the graphical part.
        %-----------------------------
        delete([hdl1; hdl2; hdl3]);
        drawnow;
        
        % Getting memory blocks continuing.
        %----------------------------------
        [Sig_Name,Wav_Name,Sig_Size,Axe_Ref] = ...
                wmemtool('rmb',win_dw1dtool,n_param_anal,               ...
                        ind_sig_name,ind_wav_name,ind_sig_size,ind_axe_ref);
        [coefs,longs]   = wmemtool('rmb',win_dw1dtool,n_coefs_longs,...
                                                ind_coefs,ind_longs);

        % Sort and get length of apps. and dets. lists.
        %----------------------------------------------
        app_lst         = sort(app_lst);
        app_lst_len     = length(app_lst);
        det_lst         = sort(det_lst);
        det_lst_len     = length(det_lst);

        % General graphical parameters initialization.
        %--------------------------------------------
        win_units       = get(win_dw1dtool,'Units');
        btn_heigth      = Def_Btn_Height;
        if ~strcmp(win_units,'pixels')
        [nul,btn_heigth] = wfigutil('prop_size',win_dw1dhist,1,btn_heigth);
        end
        pos_win         = get(win_dw1dtool,'Position');
        bdx             = 0.1*pos_win(3);
        bdy             = 0.05*pos_win(4);
        ecy             = 0.03*pos_win(4);
        pos_graph       = wmemtool('rmb',win_dw1dtool,n_miscella,...
                                        ind_graph_area);
        h_graph         = pos_graph(4);
        w_graph         = pos_graph(3);
        pos_graph(2)    = pos_graph(2)-btn_heigth;
        Screen_Size     = get(0,'ScreenSize');
        if app_lst_len > 9
                if Screen_Size(4)<600
                        fontsize = 12;
                else
                        fontsize = 14;
                end
        else
                if Screen_Size(4)<600
                        fontsize = 14;
                else
                        fontsize = 16;
                end
        end

        % Axes construction.
        %-------------------
        n_axeleft       = app_lst_len;
        n_axeright      = det_lst_len;
        if      orig_sig, n_axeleft = n_axeleft+1; end
        if      synt_sig, n_axeleft = n_axeleft+1; end
        if      n_axeleft*n_axeright~=0
                w_left  = (w_graph-3*bdx)/2;
                x_left  = pos_graph(1)+bdx;
                w_right = w_left;
                x_right = x_left+w_left+bdx+bdx/5;
                w_fra   = 0.01*pos_win(3);
                x_fra   = pos_graph(1)+(w_graph-w_fra)/2;
                y_fra   = pos_graph(2);
                h_fra   = h_graph;
        elseif  n_axeleft~=0
                w_left  = w_graph-2*bdx;
                x_left  = pos_graph(1)+bdx;
        elseif  n_axeright~=0
                w_right = w_graph-2*bdx;
                x_right = pos_graph(1)+bdx;
        end
 
        figure(win_dw1dhist)
       
        % Building axes on the left part.
        %--------------------------------
        if n_axeleft~=0
                h_left = (pos_graph(4)-2*bdy-(n_axeleft-1)*ecy)/n_axeleft;
                y_left = pos_graph(2)+bdy;
                axe_left = zeros(1,n_axeleft);
                pos_left = [x_left y_left w_left h_left];
                for k = 1:n_axeleft
                        axe_left(k) = axes(...
                                        'Unit',win_units,...
                                        'Position',pos_left,...
                                        'Drawmode','fast',...
                                        'Box','On'...
                                        );
                        pos_left(2) = pos_left(2)+pos_left(4)+ecy;
                end
        end

        % Building axes on the right part.
        %---------------------------------
        if n_axeright~=0
                h_right = (pos_graph(4)-2*bdy-(n_axeright-1)*ecy)/n_axeright;
                y_right = pos_graph(2)+bdy;
                axe_right = zeros(1,n_axeright);
                pos_right = [x_right y_right w_right h_right];
                for k = 1:n_axeright
                        axe_right(k) = axes(...
                                        'Unit',win_units,...
                                        'Position',pos_right,...
                                        'Drawmode','fast',...
                                        'Box','On'...
                                        );
                        pos_right(2) = pos_right(2)+pos_right(4)+ecy;
                end
        end

        ind_left        = n_axeleft;
        ind_right       = n_axeright;

        % Definition of the complete selection box.
        %-----------------------------------------
        selbox_orig     = selbox_orig(1):selbox_orig(2);

        % Displaying the signal histogram.
        %---------------------------------
        if orig_sig
                curr_sig        = dw1dfile('sig',win_dw1dtool);
                curr_sig        = curr_sig(selbox_orig);
                curr_color      = dw1dcolo('sig');
                axes(axe_left(ind_left));
                his             = wgethist(curr_sig,nb_bins);
                his(2,:)        = his(2,:)/length(curr_sig);
                wplothis(axe_left(ind_left),his,curr_color);
                set(axe_left(ind_left),'Tag','s');
                set(axe_left(ind_left),'Userdata',curr_sig);
                h = txtinaxe('create','s',axe_left(ind_left),'left',...
                                        'on','bold',fontsize);
                set(h,'Units',win_units);
                ind_left        = ind_left-1;
        end

        % Displaying the synthesized signal histogram.
        %---------------------------------------------
        ss_type = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                        ind_ssig_type);
        if      ss_type=='ss', str_ss = 'synthesized signal';
        elseif  ss_type=='ds', str_ss = 'de_noised signal';
        elseif  ss_type=='cs', str_ss = 'compressed signal';
        end

        if synt_sig
                curr_sig        = dw1dfile('ssig',win_dw1dtool);
                curr_sig        = curr_sig(selbox_orig);
                curr_color      = dw1dcolo('ssig');
                axes(axe_left(ind_left));
                his             = wgethist(curr_sig,nb_bins);
                his(2,:)        = his(2,:)/length(curr_sig);
                wplothis(axe_left(ind_left),his,curr_color);
                set(axe_left(ind_left),'Tag','ss');
                h = txtinaxe('create',ss_type,axe_left(ind_left),'left',...
                                        'on','bold',fontsize);
                set(h,'Units',win_units);
                set(axe_left(ind_left),'Userdata',curr_sig);
                ind_left        = ind_left-1;
        end

        % Displaying the approximations histograms.
        %------------------------------------------
        col_app = dw1dcolo('app',Lev_Anal);
        if app_lst_len~=0 & ~sel_cfs
                rec_apps = dw1dfile('app',win_dw1dtool,1:Lev_Anal);
        end
        for k = app_lst_len:-1:1
                level = app_lst(k);
                ind_coef = 1;
                if sel_cfs
                        curr_sig        = appcoef(coefs,longs,Wav_Name,level);
                        selbox_cfs      = selbox_orig;
                        min_box         = ceil(min(selbox_cfs)/2^level);
                        max_box         = ceil(max(selbox_cfs)/2^level);
                        selbox_cfs      = min_box:max_box;
                        if length(selbox_cfs)>2
                                curr_sig        = curr_sig(selbox_cfs);
                        else
                                f = warndlg(['   Not enough approximation ' ...
                                         'coefficients remaining at level ' ...
                                         int2str(level)],...
                                        'Wavelet 1-D -- Histograms');
                                while f==gcf
                                        pause(1);
                                end
                                ind_coef = 0;
                        end
                else
                        curr_sig = rec_apps(level,:);
                        curr_sig = curr_sig(selbox_orig);
                end
                axes(axe_left(ind_left));
                if ind_coef
                        curr_color      = col_app(level,:);
                        his             = wgethist(curr_sig,nb_bins);
                        his(2,:)        = his(2,:)/length(curr_sig);
                        wplothis(axe_left(ind_left),his,curr_color);
                        set(axe_left(ind_left),'Userdata',curr_sig);
                end
                set(axe_left(ind_left),'Tag',['a' int2str(level)]);
                h = txtinaxe('create',['a' int2str(level)],...
                                        axe_left(ind_left),'left',...
                                        'on','bold',fontsize);
                set(h,'Units',win_units);
                ind_left = ind_left-1;
        end

        % Displaying the details histograms.
        %-----------------------------------
        col_det = dw1dcolo('det',Lev_Anal);
        if det_lst_len~=0 & ~sel_cfs
                rec_dets = dw1dfile('det',win_dw1dtool,1:Lev_Anal);
        end
        for k = det_lst_len:-1:1
                level = det_lst(k);
                ind_coef = 1;
                if sel_cfs
                        curr_sig        = detcoef(coefs,longs,level);
                        selbox_cfs      = selbox_orig;
                        min_box         = ceil(min(selbox_cfs)/2^level);
                        max_box         = ceil(max(selbox_cfs)/2^level);
                        selbox_cfs      = min_box:max_box;
                        if length(selbox_cfs)>2
                                curr_sig        = curr_sig(selbox_cfs);
                        else
                                f = warndlg(['     Not enough detail ' ...
                                         'coefficients remaining at level ' ...
                                         int2str(level)],...
                                        'Wavelet 1-D -- Histograms');
                                while f==gcf
                                        pause(1);
                                end
                                ind_coef = 0;
                        end
                else
                        curr_sig = rec_dets(level,:);
                        curr_sig = curr_sig(selbox_orig);
                end
                axes(axe_right(ind_right));
                if ind_coef
                        curr_color      = col_det(level,:);
                        his             = wgethist(curr_sig,nb_bins);
                        his(2,:)        = his(2,:)/length(curr_sig);
                        wplothis(axe_right(ind_right),his,curr_color);
                        set(axe_right(ind_right),'Userdata',curr_sig);
                end
                set(axe_right(ind_right),'Tag',['d' int2str(level)]);
                h = txtinaxe('create',['d' int2str(level)],...
                                        axe_right(ind_right),'right',...
                                        'on','bold',fontsize);
                set(h,'Units',win_units);
                ind_right = ind_right-1;
        end

        % Vertical separation.
        %---------------------
        if n_axeleft*n_axeright~=0
                uicontrol(...
                        'Parent',win_dw1dhist, ...
                        'Style','frame',...
                        'Unit',win_units,...
                        'Position',[x_fra,y_fra,w_fra,h_fra],...
                        'Visible','On',...
                        'Backgroundcolor',Def_FraBkColor,...
                        'Tag','Dw1dhist_Level'...
                        );
        end

        % Signals type for the status line display.
        %------------------------------------------
        str_sig_type = [];
        if orig_sig
                str_sig_type = [str_sig_type 'original signal - '];
        end
        if synt_sig
                str_sig_type = [str_sig_type str_ss ' - '];
        end

        if (app_sig & ~isempty(app_lst)) | (det_sig & ~isempty(det_lst))
                if ~sel_cfs
                        str_sig_type = [str_sig_type 'reconstructed '];
                end
                if app_sig & ~isempty(app_lst) & det_sig & ~isempty(det_lst)
                        str_sig_type = [str_sig_type ...
                                        'approximations and details'];
                elseif  (app_sig & ~isempty(app_lst)) & (~det_sig | isempty(det_lst))
                        str_sig_type = [str_sig_type 'approximations'];
                elseif  (~app_sig | isempty(app_lst)) & (det_sig & ~isempty(det_lst))
                        str_sig_type = [str_sig_type 'details'];
                end
                if sel_cfs
                        str_sig_type = [str_sig_type ' coefficients'];
                end
        end
        if      ~orig_sig & ~synt_sig           & ...
                (~app_sig | isempty(app_lst))   & ...
                (~det_sig | isempty(det_lst))
                str_sig_type = 'Nothing selected';
        end
        txt_sig_type = uicontrol(...
                                'Parent',win_dw1dhist, ...
                                'Style','text',...
                                'Unit',win_units,...
                                'Position',[0,0,w_graph,btn_heigth],...
                                'Visible','On',...
                                'Backgroundcolor',Def_TxtBkColor,...
                                'String',str_sig_type,...
                                'Tag','Dw1dhist_Sigtype'...
                                );

        % Setting units to normalized.
        %-----------------------------
        set(findobj(win_dw1dhist,'Units','pixels'),'Units','normalized');

        % End waiting.
        %-------------
        wwaiting('off',win_dw1dhist);

        % Enable new selection.
        %-------------------------
        set([chk_handles;pus_handles;rad_handles],'Enable','on');

%**************************************************************%
%** OPTION = 'update_bins' - UPDATE HISTOGRAMS WITH NEW BINS **%
%**************************************************************%
elseif  strcmp(option,'update_bins')
        win_dw1dhist    = in2;
        edi_bins_data   = in3;

        % Handles of tagged objects.
        %---------------------------
        pus_show_hist   = findobj(win_dw1dhist,...
                                        'Style','pushbutton',...
                                        'Tag',tag_show_hist...
                                        );
        axes_hdls       = findobj(win_dw1dhist,'type','axes');
        Sigtype_hdl     = findobj(win_dw1dhist,'Style','text',...
                                          'Tag','Dw1dhist_Sigtype');

        if isempty(axes_hdls) , return; end

        % Check the bins number.
        %-----------------------
        default_bins    = 30;
        old_params      = get(pus_show_hist,'Userdata');
        if ~isempty(old_params)
                default_bins = old_params(1);
        end
        nb_bins         = str2num(get(edi_bins_data,'String'));
        if isempty(nb_bins)
                nb_bins = default_bins;   
                set(edi_bins_data,'String',int2str(default_bins))
        elseif nb_bins<2
                nb_bins = default_bins;
                set(edi_bins_data,'String',int2str(default_bins))
        end
        if default_bins==nb_bins , return; end

        % Waiting message.
        %-----------------
        set(Sigtype_hdl,'Visible','off');
        wwaiting('msg',win_dw1dhist,'Wait ... computing');

        % Updating histograms.
        %---------------------
        old_params(1) = nb_bins;
        set(pus_show_hist,'Userdata',old_params);

        for i=1:length(axes_hdls)
                curr_axe        = axes_hdls(i);
                curr_sig        = get(curr_axe,'Userdata');
                if ~isempty(curr_sig)
                        axes(curr_axe);
                        curr_child = findobj(get(curr_axe,'Children'),'type','patch');
                        axe_col    = get(curr_child,'FaceColor');
                        his        = wgethist(curr_sig,nb_bins);
                        his(2,:)   = his(2,:)/length(curr_sig);
                        wplothis(curr_axe,his,axe_col);
                        curr_txt   = get(curr_axe,'tag');
                        if curr_txt(1)=='d'
                                txtinaxe('create',curr_txt,...
                                                curr_axe,'right');
                        else
                                txtinaxe('create',curr_txt,...
                                                curr_axe,'left');
                        end
                        set(curr_axe,'Userdata',curr_sig)
                end
        end

        % End waiting.
        %-------------
        wwaiting('off',win_dw1dhist);
        set(Sigtype_hdl,'Visible','on');

%****************************************%
%** OPTION = 'demo' -  DEMOS or TESTS  **%
%****************************************%
elseif strcmp(option,'demo')
        win_dw1dhist    = in2;
        chk_handles     = findobj(win_dw1dhist,'Style','checkbox');
        chk_orig_sig    = findobj(chk_handles,'Tag',tag_orig_sig);
        chk_synt_sig    = findobj(chk_handles,'Tag',tag_synt_sig);
        chk_app_sig     = findobj(chk_handles,'Tag',tag_app_sig);
        chk_det_sig     = findobj(chk_handles,'Tag',tag_det_sig);
        pus_show_hist   = findobj(win_dw1dhist,...
                                        'Style','pushbutton',...
                                        'Tag',tag_show_hist...
                                        );
        set(chk_handles,'Value',1);

        eval(get(chk_orig_sig,'Callback'));
        eval(get(chk_synt_sig,'Callback'));
        eval(get(chk_app_sig,'Callback'));
        eval(get(chk_det_sig,'Callback'));
        eval(get(pus_show_hist,'Callback'));

%****************************************%
%** OPTION = 'close' -  CLOSE FIGURE   **%
%****************************************%
elseif  strcmp(option,'close')

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('dw1dhist','Unknown Option','msg');
        error('*');
end

