function [out1,out2,out3,out4,out5,out6,out7] = ...
                  dw1dvmod(option,win_dw1dtool,in3,in4,in5,in6,in7,in8,in9)
%DW1DVMOD Discret wavelet 1D view mode manager.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:09:04 $

%--------------------------------------
% mode 1 : scroll mode          = 'scr'
% mode 2 : decomposition mode   = 'dec'
% mode 3 : separate mode        = 'sep'
% mode 4 : superimposed mode    = 'sup'
% mode 5 : tree mode            = 'tre'
%--------------------------------------

global  Def_Btn_Height Y_Spacing

% MemBloc1 of stored values.
%---------------------------
n_param_anal    = 'DWAn1d_Par_Anal';
ind_sig_name    =  1;
ind_sig_size    =  2;
ind_wav_name    =  3;
ind_wav_len     =  4;
ind_lev_anal    =  5;
ind_axe_ref     =  6;
ind_act_option  =  7;
ind_ssig_type   =  8;
nb1_stored      =  8;

% Default values.
%----------------
max_lev_anal     = 12;
min_nbcolors     = 2;
max_nbcolors     = 128;
default_nbcolors = 128;

% Tag property of objects.
%-------------------------
tag_pop_viewm   = 'View_Mode';
tag_pus_dispopt = 'Pus_Options';
tag_valapp_scr  = 'ValApp_Scr';
tag_txtapp_scr  = 'TxtApp_Scr';
tag_valdet_scr  = 'ValDet_Scr';
tag_txtdet_scr  = 'TxtDet_Scr';
tag_declev      = 'Pop_DecLev';
tag_txtdeclev   = 'Txt_DecLev';
tag_cfs_map     = 'Pop_ColorMap';
tag_sli_nbc     = 'Sli_NBColors';
tag_edi_nbc     = 'Edi_NBColors';
tag_txt_map     = 'Txt_Map';
tag_txt_nbc     = 'Txt_Nbc';

% Handles of tagged objects.
%---------------------------
uic_handles     = findobj(win_dw1dtool,'type','uicontrol');
txt_handles     = findobj(uic_handles,'Style','text');
pop_handles     = findobj(uic_handles,'Style','popupmenu');
pus_handles     = findobj(uic_handles,'Style','pushbutton');
pus_dispopt     = findobj(uic_handles,'tag',tag_pus_dispopt);

% Local MemBloc of stored values.
%---------------------------
ind_scrm_1      =  1;
ind_scrm_2      =  2;
ind_decm_1      =  3;
ind_decm_2      =  4;
ind_sepm_1      =  5;
ind_sepm_2      =  6;
ind_supm_1      =  7;
ind_supm_2      =  8;
ind_trem_1      =  9;
ind_trem_2      = 10;
nb_stored       = 10;

%*****************************************************************%
%** OPTION = 'ini_vm' - Default & Current values for every mode **%
%*****************************************************************%
if strcmp(option,'ini_vm')
        % mode 1 : scroll mode          = 'scr'
        % mode 2 : decomposition mode   = 'dec'
        % mode 3 : separate mode        = 'sep'
        % mode 4 : superimposed mode    = 'sup'
        % mode 5 : tree mode            = 'tre'
        %--------------------------------------
        memB = wmemutil('def',nb_stored);
        scrm = [1 1 1 1 0 1 0 0 1 1];
        memB = wmemutil('set',memB,ind_scrm_1,scrm);
        memB = wmemutil('set',memB,ind_scrm_2,scrm);
        decm = [1 0 1];
        memB = wmemutil('set',memB,ind_decm_1,decm);
        memB = wmemutil('set',memB,ind_decm_2,decm);
        sepm = [1 1 1 1 0 ones(1,max_lev_anal) 1 0 ones(1,max_lev_anal) 1];
        memB = wmemutil('set',memB,ind_sepm_1,sepm);
        memB = wmemutil('set',memB,ind_sepm_2,sepm);
        supm = [1 1 1 1 0 ones(1,max_lev_anal) 0 0 ones(1,max_lev_anal) 1];
        memB = wmemutil('set',memB,ind_supm_1,supm);
        memB = wmemutil('set',memB,ind_supm_2,supm);
        trem = [1 0 1];
        memB = wmemutil('set',memB,ind_trem_1,trem);
        memB = wmemutil('set',memB,ind_trem_2,trem);
        set(pus_dispopt,'Userdata',memB);

%**************************************************%
%** OPTION = 'set_vm' - set View Mode Parameters **%
%**************************************************%
elseif strcmp(option,'set_vm')
        % mode 1 : scroll mode          = 'scr'
        % mode 2 : decomposition mode   = 'dec'
        % mode 3 : separate mode        = 'sep'
        % mode 4 : superimposed mode    = 'sup'
        % mode 5 : tree mode            = 'tre'
        %--------------------------------------
        % in3 = mode
        %-----------------------
        if (in3==3) | (in3==4)
                Level_Anal = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                ind_lev_anal);
                plus = ones(1,max_lev_anal-Level_Anal);
        end
        if      in3==1  
                new_vm  = [in4 in5 in6 in7 in8 in9];
                index   = ind_scrm_2;

        elseif  in3==2
                new_vm  = [in4 in5];
                index   = ind_decm_2;

        elseif  in3==3
                new_vm  = [in4 in5 in6 plus in7 in8 plus in9];
                index   = ind_sepm_2;

        elseif  in3==4
                new_vm  = [in4 in5 in6 plus in7 in8 plus in9];
                index   = ind_supm_2;
        elseif  in3==5
                new_vm  = [in4 in5];
                index   = ind_trem_2;

        end
        memB = get(pus_dispopt,'Userdata');
        old_vm  = wmemutil('get',memB,index);
        if find(new_vm~=old_vm)
                out1 = 1;
                memB = wmemutil('set',memB,index,new_vm);
                set(pus_dispopt,'Userdata',memB);
        else
                out1 = 0;
        end

%**************************************************%
%** OPTION = 'get_vm' - get View Mode Parameters **%
%**************************************************%
elseif strcmp(option,'get_vm')
        % mode 1 : scroll mode          = 'scr'
        % mode 2 : decomposition mode   = 'dec'
        % mode 3 : separate mode        = 'sep'
        % mode 4 : superimposed mode    = 'sup
        % mode 5 : tree mode            = 'tre'
        %--------------------------------------
        % in3 = mode
        % in4 optional
        % if nargin=4 , initial options
        %------------------------------
        if (in3==3) | (in3==4)
                Level_Anal = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                ind_lev_anal);
        end
        memB = get(pus_dispopt,'Userdata');
        if nargin==3 , indplus = 1 ; else , indplus = rem(in4,2); end
        if      in3==1  
                viewm   = wmemutil('get',memB,ind_scrm_1+indplus);
                out1    = viewm(1:3);
                out2    = viewm(4:5);
                out3    = viewm(6);
                out4    = viewm(7:8);
                out5    = viewm(9);
                out6    = viewm(10);

        elseif  in3==2
                viewm   = wmemutil('get',memB,ind_decm_1+indplus);
                out1    = viewm(1:2);
                out2    = viewm(3);

        elseif  in3==3
                viewm   = wmemutil('get',memB,ind_sepm_1+indplus);
                out1    = viewm(1:3);
                out2    = viewm(4:5);
                out3    = viewm(6:max_lev_anal+5);
                out3    = out3(1:Level_Anal);
                out4    = viewm(max_lev_anal+6:max_lev_anal+7);
                out5    = viewm(max_lev_anal+8:2*max_lev_anal+7);
                out5    = out5(1:Level_Anal);
                out6    = viewm(2*max_lev_anal+8);

        elseif  in3==4
                viewm   = wmemutil('get',memB,ind_supm_1+indplus);
                out1    = viewm(1:3);
                out2    = viewm(4:5);
                out3    = viewm(6:max_lev_anal+5);
                out3    = out3(1:Level_Anal);
                out4    = viewm(max_lev_anal+6:max_lev_anal+7);
                out5    = viewm(max_lev_anal+8:2*max_lev_anal+7);
                out5    = out5(1:Level_Anal);
                out6    = viewm(2*max_lev_anal+8);

        elseif  in3==5
                viewm   = wmemutil('get',memB,ind_trem_1+indplus);
                out1    = viewm(1:2);
                out2    = viewm(3);
        end
        
%***********************************************%
%** OPTION = 'ch_vm' - Change Mode  View Mode **%
%***********************************************%
elseif strcmp(option,'ch_vm')
        % in3 = 1 (optional) - clean
        % in3 = 2 (optional) - clean + redraw (return comp & deno)
        %----------------------------------------------------------
        % Handles of tagged objects.
        %---------------------------
        pop_viewm       = findobj(pop_handles,'tag',tag_pop_viewm);
        pop_app_scr     = findobj(pop_handles,'Tag',tag_valapp_scr);
        pop_det_scr     = findobj(pop_handles,'Tag',tag_valdet_scr);
        pop_lev_dec     = findobj(pop_handles,'Tag',tag_declev);
        txt_app_scr     = findobj(txt_handles,'Tag',tag_txtapp_scr);
        txt_det_scr     = findobj(txt_handles,'Tag',tag_txtdet_scr);
        txt_lev_dec     = findobj(txt_handles,'Tag',tag_txtdeclev);
        hdl_col    = zeros(1,5);
        hdl_col(1) = findobj(pop_handles,'tag',tag_cfs_map);
        hdl_col(2) = findobj(uic_handles,'style','slider','tag',tag_sli_nbc);
        hdl_col(3) = findobj(uic_handles,'style','edit','tag',tag_edi_nbc);
        hdl_col(4) = findobj(txt_handles,'Tag',tag_txt_map);
        hdl_col(5) = findobj(txt_handles,'Tag',tag_txt_nbc);
        
        if nargin==2 , in3 = 0; end
        old_mode        = get(pop_viewm,'Userdata');
        new_mode        = get(pop_viewm,'Value');

        %-------------------------------------------------------------%
        %-- pour deno et comp on ne change que le signal synthetise --%
        %-- sinon oter cette partie                                 --%
        %-------------------------------------------------------------%
        if in3==2
                % Begin waiting.
                %---------------
                wwaiting('msg',win_dw1dtool,'Wait ... computing');

                if      new_mode==1
                        fname = 'dw1dscrm';
        
                elseif  new_mode==2
                        val = dw1dvmod('get_vm',win_dw1dtool,new_mode);

                        ss_type = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_ssig_type);
                        if      ss_type=='ss', str_ss = 'Synthesized';
                        elseif  ss_type=='ds', str_ss = 'De-noised';
                        elseif  ss_type=='cs', str_ss = 'Compressed';
                        end
                        set(pus_dispopt, ...
                                'Value',val(2),                         ...
                                'String',['Show ' str_ss ' Sig.']       ...
                                );
                        fname = 'dw1ddecm';

                elseif  new_mode==3
                        fname = 'dw1dsepm';

                elseif  new_mode==4
                        fname = 'dw1dsupm';

                elseif  new_mode==5
                        val = dw1dvmod('get_vm',win_dw1dtool,new_mode);

                        ss_type = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_ssig_type);
                        if      ss_type=='ss', str_ss = 'Synt.';
                        elseif  ss_type=='ds', str_ss = 'De-noised';
                        elseif  ss_type=='cs', str_ss = 'Compressed';
                        end
                        set(pus_dispopt, ...
                                'Value',val(2),                         ...
                                'String',['Show ' str_ss ' Sig.']       ...
                                );
                        fname = 'dw1dtrem';

                end
                feval(fname,'del_ss',win_dw1dtool);
                feval(fname,'view',win_dw1dtool,0);

                % End waiting.
                %---------------
                wwaiting('off',win_dw1dtool);

                return;
        end
        %-------------------------------------------------------------%

        if (old_mode==new_mode) 
                if      in3==0
                        return ;
                elseif  in3==1 | in3==2
                        new_mode  = 1;
                        set(pop_viewm,'Value',new_mode,'Userdata',new_mode);
                        clear_val = 0;
                end
        else
                clear_val = new_mode;
                set(pop_viewm,'Userdata',new_mode);
        end

        % Begin waiting.
        %---------------
        wwaiting('msg',win_dw1dtool,'Wait ... computing');

        % Borders and double borders.
        %----------------------------
        win_units = get(win_dw1dtool,'units');
        deltay  = Def_Btn_Height+4*Y_Spacing;;
        if ~strcmp(win_units,'pixels')
                [dx,deltay] = wfigutil('prop_size',win_dw1dtool,1,deltay);
        end
        pos_pop_viewm   = get(pop_viewm,'Position');

        pos_opt = get(pus_dispopt,'Position');
        if      old_mode==1
                set([   txt_app_scr,txt_det_scr,pop_app_scr,pop_det_scr, ...
                        pus_dispopt],'Visible','off');
                feval('dw1dscrm','clear',win_dw1dtool,clear_val);

        elseif  old_mode==2
                set([txt_lev_dec,pop_lev_dec,pus_dispopt],'Visible','off');
                set(pus_dispopt,'Style','pushbutton');
                feval('dw1ddecm','clear',win_dw1dtool);
                drawnow;

        elseif  old_mode==3
                if (new_mode==1) | (new_mode==2)
                        set(pus_dispopt,'Visible','off');
                end
                feval('dw1dsepm','clear',win_dw1dtool);
                drawnow;

        elseif  old_mode==4
                if (new_mode==1) | (new_mode==2)
                        set(pus_dispopt,'Visible','off');
                end
                feval('dw1dsupm','clear',win_dw1dtool,clear_val);

        elseif  old_mode==5
                set([pus_dispopt],'Visible','off');
                set(pus_dispopt,'Style','pushbutton');
                feval('dw1dtrem','clear',win_dw1dtool);
                drawnow;
        end
        
        if      (new_mode==2) & find(old_mode==[1 3 4 5])
                val = dw1dvmod('get_vm',win_dw1dtool,new_mode);
                ss_type = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_ssig_type);
                if      ss_type=='ss', str_ss = 'Synthesized';
                elseif  ss_type=='ds', str_ss = 'De-noised';
                elseif  ss_type=='cs', str_ss = 'Compressed';
                end

                cba_disp = ['dw1ddecm(''ssig'',' ...
                                int2str(win_dw1dtool) ',' ...
                                num2mstr(pus_dispopt) ');'];
                set(pus_dispopt,...
                                'Style','checkbox',...
                                'Value',val(2),...
                                'String',['Show ' str_ss ' Sig.'],...
                                'Callback',cba_disp);

        elseif  (new_mode==5) & find(old_mode==[1 2 3 4])
                val = dw1dvmod('get_vm',win_dw1dtool,new_mode);
                ss_type = wmemtool('rmb',win_dw1dtool,n_param_anal,...
                                                        ind_ssig_type);
                if      ss_type=='ss', str_ss = 'Synthesized';
                elseif  ss_type=='ds', str_ss = 'De-noised';
                elseif  ss_type=='cs', str_ss = 'Compressed';
                end

                cba_disp = ['dw1dtrem(''ssig'',' ...
                                int2str(win_dw1dtool) ',' ...
                                num2mstr(pus_dispopt) ');'];
                set(pus_dispopt,...
                                'Style','checkbox',...
                                'Value',val(2),...
                                'String',['Show ' str_ss ' Sig.'],...
                                'Callback',cba_disp);

        elseif  (old_mode==2) & find(new_mode==[1 3 4 5])
                cba_disp = ['dw1ddisp(''create'',' int2str(win_dw1dtool) ');'];
                set(pus_dispopt,...
                                'Style','pushbutton',                   ...
                                'String','More Display Options',        ...
                                'Callback',cba_disp);

        elseif  (old_mode==5) & find(new_mode==[1 2 3 4])
                cba_disp = ['dw1ddisp(''create'',' int2str(win_dw1dtool) ');'];
                set(pus_dispopt,...
                                'Style','pushbutton',                   ...
                                'String','More Display Options',        ...
                                'Callback',cba_disp);

        end

        if      new_mode==1
                pos_txt1        = get(txt_app_scr,'Position');
                pos_opt(2)      = pos_txt1(2)-deltay;
                set(pus_dispopt,'Position',pos_opt);
                set([   txt_app_scr,    txt_det_scr,    ...
                        pop_app_scr,    pop_det_scr,    ...
                        pus_dispopt,    hdl_col],       'Visible','on');
                drawnow
                if (clear_val==0) & (in3==1) , return; end
                feval('dw1dscrm','view',win_dw1dtool,old_mode);
        
        elseif  new_mode==2
                pos_txt1        = get(txt_lev_dec,'Position');
                pos_opt(2)      = pos_txt1(2)-deltay;
                set(pus_dispopt,'Position',pos_opt);
                set([txt_lev_dec, pop_lev_dec,pus_dispopt],'Visible','on');
                set([hdl_col],'Visible','off');         
                drawnow
                lev = get(pop_lev_dec,'Value'); 
                feval('dw1ddecm','view',win_dw1dtool,old_mode,lev);

        elseif  new_mode==3
                pos_opt(2) = pos_pop_viewm(2)-deltay;
                set(pus_dispopt,'Position',pos_opt);
                set([pus_dispopt,hdl_col],'Visible','on');
                drawnow
                feval('dw1dsepm','view',win_dw1dtool,old_mode);

        elseif  new_mode==4
                pos_opt(2) = pos_pop_viewm(2)-deltay;
                set(pus_dispopt,'Position',pos_opt);
                set([pus_dispopt,hdl_col],'Visible','on');
                drawnow
                feval('dw1dsupm','view',win_dw1dtool,old_mode);

        elseif  new_mode==5
                pos_txt1        = get(txt_lev_dec,'Position');
                pos_opt(2)      = pos_txt1(2)-deltay;
                set(pus_dispopt,'Position',pos_opt);
                set([pus_dispopt],'Visible','on');
                set([hdl_col],'Visible','off');         
                drawnow
                lev = get(pop_lev_dec,'Value');
                feval('dw1dtrem','view',win_dw1dtool,old_mode,lev);

        end

        % End waiting.
        %---------------
        wwaiting('off',win_dw1dtool);

%*******************************************************%
%** OPTION = 'ss_vm' - set Visibility of synth signal **%
%*******************************************************%
elseif strcmp(option,'ss_vm')
        % mode 1 : scroll mode          = 'scr'
        % mode 2 : decomposition mode   = 'dec'
        % mode 3 : separate mode        = 'sep'
        % mode 4 : superimposed mode    = 'sup'
        % mode 5 : tree mode            = 'tre'
        %-----------------------------------------
        % in3 = view_mode (s)
        % in4 = 0 (invisible) or in4 = 1 (visible)
        % in5 = 0 (invisible) or in5 = 1 (visible)
        %------------------------------------------

        if nargin==4 , in5 = in4; end
        memB = get(pus_dispopt,'Userdata');
        if find(in3==1)
                viewm           = wmemutil('get',memB,ind_scrm_2);
                viewm(5)        = in4;
                viewm(8)        = in5;
                memB            = wmemutil('set',memB,ind_scrm_2,viewm);
        end

        if find(in3==2)
                viewm   = wmemutil('get',memB,ind_decm_2);
                viewm(2)        = in4;
                memB = wmemutil('set',memB,ind_decm_2,viewm);
        end

        if find(in3==3)
                viewm   = wmemutil('get',memB,ind_sepm_2);
                viewm(5)                = in4;
                viewm(max_lev_anal+7)   = in5;
                memB = wmemutil('set',memB,ind_sepm_2,viewm);
        end

        if find(in3==4)
                viewm   = wmemutil('get',memB,ind_supm_2);
                viewm(5)                = in4;
                viewm(max_lev_anal+7)   = in5;
                memB = wmemutil('set',memB,ind_supm_2,viewm);
        end

        if find(in3==5)
                viewm   = wmemutil('get',memB,ind_trem_2);
                viewm(2)        = in4;
                memB = wmemutil('set',memB,ind_trem_2,viewm);
        end

        set(pus_dispopt,'Userdata',memB);

%*************************************************%
%** OPTION = 'ccfs_vm' - get coloration options **%
%*************************************************%
elseif strcmp(option,'ccfs_vm')
        % mode 1 : scroll mode          = 'scr'
        % mode 2 : decomposition mode   = 'dec'
        % mode 3 : separate mode        = 'sep'
        % mode 4 : superimposed mode    = 'sup'
        % mode 5 : tree mode            = 'tre'
        %--------------------------------------
        % in3 = mode
        %------------------------------
        memB = get(pus_dispopt,'Userdata');
        if      in3==1  
                viewm   = wmemutil('get',memB,ind_scrm_2);
                out1    = viewm(10);

        elseif  in3==2
                viewm   = wmemutil('get',memB,ind_decm_2);
                out1    = viewm(3);

        elseif  in3==3
                viewm   = wmemutil('get',memB,ind_sepm_2);
                out1    = viewm(2*max_lev_anal+8);

        elseif  in3==4
                viewm   = wmemutil('get',memB,ind_supm_2);
                out1    = viewm(2*max_lev_anal+8);
        elseif  in3==5
                viewm   = wmemutil('get',memB,ind_tre_2);
                out1    = viewm(3);
        end

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('dw1dvmod','Unknown Option','msg');
        error('*');
end
