function [a,d] = dwtper(x,arg2,arg3)
%DWTPER Single-level discrete 1-D wavelet transform (periodized).
%       [CA,CD] = DWTPER(X,'wname') computes the approximation
%       coefficients vector CA and detail coefficients vector CD,
%       obtained by periodized wavelet decomposition of the 
%       vector X.
%       'wname' is a string containing the wavelet name
%       (see WFILTERS).
%
%       Instead of giving the wavelet name, you can give
%       the filters. When used with three arguments: 
%       [CA,CD] = DWTPER(X,Lo_D,Hi_D),
%       Lo_D is the decomposition low-pass filter and
%       Hi_D is the decomposition high-pass filter.
%
%       If lx = length(X) then
%               length(CA) = length(CD) = CEIL(lx/2).
%
%       See also DWT, IDWTPER.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:10:16 $

%       Uses ERRARGN, DYADDOWN, WFILTERS, WKEEP.

% Check arguments.
if errargn('dwtper',nargin,[2:3],nargout,[0:2]), error('*'), end
if nargin == 2
        [LoF_D,HiF_D,LoF_R,HiF_R] = wfilters(arg2);
else
        LoF_D = arg2;   HiF_D = arg3;
end

% Periodization.
lx = length(x);
lf = length(LoF_D);
if rem(lx,2) , x(lx+1) = x(lx); lx = lx+1; end
if size(x,1)==1
        x = [x(lx-lf+1:lx) x x(1:lf)];
else
        x = [x(lx-lf+1:lx);x;x(1:lf)];
end

% Decomposition.
lp = ceil(lx/2);
a  = wkeep(dyaddown(conv(x,LoF_D)),lp);
d  = wkeep(dyaddown(conv(x,HiF_D)),lp);
