function [a,h,v,d] = dwtper2(x,arg2,arg3)
%DWTPER2  Single-level discrete 2-D wavelet transform (periodized).
%       [CA,CH,CV,CD] = DWTPER2(X,'wname') computes the approximation
%       coefficients matrix CA and details coefficients matrices 
%       CH, CV, CD, obtained by periodized wavelet decomposition 
%       of the input matrix X.
%       'wname' is a string containing the wavelet name
%       (see WFILTERS).
%
%       Instead of giving the wavelet name, you can give
%       the filters. When used with three arguments: 
%       [CA,CH,CV,CD] = DWTPER2(X,Lo_D,Hi_D),
%       Lo_D is the decomposition low-pass filter and
%       Hi_D is the decomposition high-pass filter.
%
%       If sx = size(X) then
%          size(CA) = size(CH) = size(CV) = size(CD) = CEIL(sx/2).
%
%       See also DWT2, IDWTPER2.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:10:21 $

%       Uses DYADDOWN, WKEEP, WFILTERS.

% Check arguments.
if errargn('dwtper2',nargin,[2 3],nargout,[0,1,4]), error('*'), end
if nargin==2
        [LoF_D,HiF_D] = wfilters(arg2,'d');
else
        LoF_D = arg2;   HiF_D = arg3;
end

% Periodization.
sx = size(x);        rx = sx(1);        cx = sx(2);
lf = length(LoF_D);
if rem(cx,2) , x(:,cx+1) = x(:,cx); cx = cx+1; end
x = [x(:,cx-lf+1:cx) x x(:,1:lf)];
if rem(rx,2) , x(rx+1,:) = x(rx,:); rx = rx+1; end
x = [x(rx-lf+1:rx,:);x;x(1:lf,:)];

% Decomposition.
sp = ceil(sx/2);
y = dyaddown(conv2(x,LoF_D),'c');
a = wkeep(dyaddown(conv2(y,LoF_D'),'r'),sp);
h = wkeep(dyaddown(conv2(y,HiF_D'),'r'),sp);

y = dyaddown(conv2(x,HiF_D),'c');
v = wkeep(dyaddown(conv2(y,LoF_D'),'r'),sp);
d = wkeep(dyaddown(conv2(y,HiF_D'),'r'),sp);
