function [out1,out2,out3,out4,out5,out6] = ...
                dynvtool(option,in2,in3,in4,in5,in6,in7,in8,in9,in10,in11,in12)
%DYNVTOOL Dynamic visualization tool.
%       option = 'create'
%       option = 'attach'
%       option = 'delbox'
%       option = 'getbox'
%       option = 'delline'
%       option = 'ini_his'
%       option = 'new_his'
%       option = 'stop'
%       option = 'get'
%       option = 'put'
%       option = 'zoom+'
%       option = 'zoom-'
%       option = 'center'
%       option = 'on'
%       option = 'off'
%       option = 'fcn_w'
%       option = 'write_membuf'
%       option = 'read_membuf'
%       option = 'close'
%
%       option = 'hide'      (for demos)
%       option = 'show'      (for demos)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:10:37 $

%       Uses ERRARGT, DYNVTOOL, FINDMOBJ, MNGCOOR, MNGMBTN,NANCOMPL 
%       Uses NUM2MSTR,WFIGUTIL, WGLOBALS, WMEMUTIL, WMEMTOOL, WCOMMON.

%       Callbacks DYNVTOOL, MNGMBTN.

% Tagged Objects.
%----------------
%       'DynV_Fra_Ini'
%       'DynV_Btn_Xpos'
%       'DynV_Btn_Ypos'
%       'DynV_Btn_HInit'
%       'DynV_Btn_HPrev'
%       'DynV_Btn_HNext'
%
%       'DynV_Sel_Box'
%       'DynV_Line_Hor'
%       'DynV_Line_Ver'
%
%       'DynV_Buf_Histo'
%       'DynV_Handles'
%       'DynV_Buf_Mem'
%       'DynV_Buf_Sel'
%       'DynV_Buf_Tra'
%------------------------------------------------------------------------------
% The handles are stored in "zoom" text. Tagged by :  'DynV_Handles'.
%
% The axes and some other informations are stored in "center" text.
% Tagged by : 'DynV_Buf_Mem'. 
%    DynV_Col_Line  DynV_Axe_Ind  DynV_Axe_Cmd  DynV_Axe_Act  DynV_XY_Const
%
% The translate flag is stored in "center x " edit.
% Tagged by : 'DynV_Buf_Tra'.
%
% The selected axes is stored in "position" text.
% Tagged by : 'DynV_Buf_Sel'. 
%
% The history of transforms are stored in "histo" text. 
% Tagged by :  'DynV_Buf_Histo'. 
%-----------------------------------------------------------------------------

global  Def_Btn_Height  Pop_Min_Width   ...
        Def_EdiBkColor  Def_FraBkColor  ...
        Def_TxtBkColor  Def_ZoomColor

fig     = in2;
if isempty(find(get(0,'Children')==fig)) , return; end

%*********************************%
%** OPTION = 'create' CREATION  **%
%*********************************%
if strcmp(option,'create')
        % Global variables initialization.
        wglobals('ini');

        fig_units = get(fig,'Units');
        xpixl   = 1;
        ypixl   = 1;
        
        if nargin==2 , pos = [0 0 1]; else , pos = [0 0 in3]; end
        lmax = pos(3);
        if (lmax>1) | (lmax<0.5) , lmax = 1; end
        if fig_units(1:3)=='pix'
                pos_f   = get(fig,'Position');
                lmax    = ceil(lmax*pos_f(3));
        else
                [xpixl,ypixl] = wfigutil('prop_size',fig,xpixl,ypixl);
        end

        figure(fig);
        Def_Width       = 3*Pop_Min_Width;

        large   = Def_Width*xpixl;
        lar1    = large/3.6;
        lar2    = large/5.4;
        lar3    = large/2.4;
        lar4    = large/8;
        lar5    = large/3.2;
        lar6    = large/3;
        lar7    = large/2.5;
        lar8    = large/3;
        lar9    = large/7;
        bdx     = large/60;
        bdcadx  = large/40;
        lcad    = lar1+3*lar2+lar3+lar4+lar5+...
                        lar6+lar7+lar8+2*lar9+2*bdcadx+xpixl;

        if abs(lmax-lcad)>sqrt(eps)
                mul = (lmax-2*bdcadx-xpixl-3*lar2-lar4-2*lar9);
                mul = mul/(lar1+lar3+lar5+lar6+lar7+lar8);
                lar1 = lar1*mul;
                lar3 = lar3*mul;
                lar5 = lar5*mul;
                lar6 = lar6*mul;
                lar7 = lar7*mul;
                lar8 = lar8*mul;
                lcad    = lar1+3*lar2+lar3+lar4+lar5+...
                                lar6+lar7+lar8+2*lar9+2*bdcadx+xpixl;
        end

        if fig_units(1:3)=='pix'
                lar1    = floor(lar1);
                lar2    = floor(lar2);
                lar3    = floor(lar3);
                lar4    = floor(lar4);
                lar5    = floor(lar5);
                lar6    = floor(lar6);
                lar8    = floor(lar8);
                lar9    = floor(lar9);
                bdx     = floor(bdx);
                bdcadx  = floor(bdcadx);
                lar7 = lcad-lar1-3*lar2-lar3-lar4-lar5-...
                                lar6-lar8-2*lar9-2*bdcadx-xpixl;
        end


        haut    = Def_Btn_Height*ypixl;
        bdy     = 3*ypixl;
        bdcady  = bdy;
        hcad    = 2*haut+2*bdcady;

        out1    = [pos(1) pos(2) lcad hcad];

        ylow    = pos(2);
        xleft   = pos(1)+bdcadx;

        DynV_Fra_Ini = uicontrol(...
                                'Style','Frame',                ...
                                'Unit',fig_units,               ...
                                'Position',out1,                ...
                                'BackGroundColor',Def_FraBkColor,...
                                'Tag','DynV_Fra_Ini'            ...
                                );

        ylow = pos(2)+hcad-bdcady-haut;

        xl = xleft;
        yh = ylow;
        pos_txtzoom     = [xl+bdx,yh-haut+bdy,lar1-2*bdx,2*haut-2*bdy];
        pos_btngx       = [xl+lar1,yh,lar2,haut];
        pos_btndx       = [xl+lar1,yh-haut,lar2,haut];
        pos_btngy       = [xl+lar1+lar2,yh,lar2,haut];
        pos_btndy       = [xl+lar1+lar2,yh-haut,lar2,haut];
        pos_btngxy      = [xl+lar1+2*lar2,yh,lar2,haut];
        pos_btndxy      = [xl+lar1+2*lar2,yh-haut,lar2,haut];

        xl = xleft+lar1+3*lar2+xpixl;
        yh = ylow;
        pos_txtcent     = [xl+bdx,yh-haut+bdy,lar3-2*bdx,2*haut-2*bdy];

        pos_btncx       = [xl+lar3,yh,lar4,haut];
        pos_btncy       = [xl+lar3,yh-haut,lar4,haut];
        pos_edcentx     = [xl+lar3+lar4+bdx/2,yh+bdy/2,lar5-bdx,haut-bdy];
        pos_edcenty     = [xl+lar3+lar4+bdx/2,yh-haut+bdy/2,lar5-bdx,haut-bdy];

        xl = xleft+lar1+3*lar2+lar3+lar4+lar5+xpixl;
        yh = ylow;
        pos_txtpos      = [xl+bdx,yh-haut+bdy,lar6-2*bdx,2*haut-2*bdy];
        pos_btn_xpos    = [xl+lar6+bdx/2,yh,lar7-bdx,haut-bdy];
        pos_btn_ypos    = [xl+lar6+bdx/2,yh-haut+bdy,lar7-bdx,haut-bdy];

        xl = xleft+lar1+3*lar2+lar3+lar4+lar5+lar6+lar7+xpixl;
        yh = ylow;
        pos_txthis = [xl+bdx,yh-haut+bdy,lar8-2*bdx,2*haut-2*bdy];
        pos_hinit  = [xl+lar8,yh-haut,2*lar9,haut];
        pos_hpwrev  = [xl+lar8,yh,lar9,haut];
        pos_hnext  = [xl+lar8+lar9,yh,lar9,haut];


        txtz            = uicontrol(...
                                'Style','Text',                 ...
                                'Unit',fig_units,               ...
                                'BackGroundColor',Def_TxtBkColor,...
                                'Position',pos_txtzoom,         ...
                                'String','Zoom' ,               ...
                                'Tag','DynV_Handles'            ...
                                );
        action          = ['dynvtool(''zoom+'',' int2str(fig) ',[1 0])'];
        butgx           = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_btngx,           ...
                                'String','X+',                  ...
                                'Callback',action               ...
                                );
        action          = ['dynvtool(''zoom-'',' int2str(fig) ',[1 0])'];
        butdx           = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_btndx,           ...
                                'String','X-',                  ...
                                'Callback',action               ...
                                );
        action          = ['dynvtool(''zoom+'',' int2str(fig) ',[0 1])'];
        butgy           = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_btngy,           ...
                                'String','Y+',                  ...
                                'Callback',action               ...
                                );
        action          = ['dynvtool(''zoom-'',' int2str(fig) ',[0 1])'];
        butdy           = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_btndy,           ...
                                'String','Y-',                  ...
                                'Callback',action               ...
                                );
        action          = ['dynvtool(''zoom+'',' int2str(fig) ',[1 1])'];
        butgxy          = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_btngxy,          ...
                                'String','XY+',                 ...
                                'Callback',action               ...
                                );
        action          = ['dynvtool(''zoom-'',' int2str(fig) ',[1 1])'];
        butdxy          = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_btndxy,          ...
                                'String','XY-',                 ...
                                'Callback',action               ...
                                );
        txtc            = uicontrol(...
                                'Style','Text',                 ...
                                'Unit',fig_units,               ...
                                'BackGroundColor',Def_TxtBkColor,...
                                'Position',pos_txtcent,         ...
                                'String','Center On',           ...
                                'tag','DynV_Buf_Mem'            ...
                                );
        btn_edcentx     = uicontrol(...
                                'Style','Edit',                 ...
                                'Unit',fig_units,               ...
                                'BackGroundColor',Def_EdiBkColor,...
                                'Position',pos_edcentx,         ...
                                'tag','DynV_Buf_Tra'            ...
                                );
        btn_edcenty     = uicontrol(...
                                'Style','Edit',                 ...
                                'Unit',fig_units,               ...
                                'BackGroundColor',Def_EdiBkColor,...
                                'Position',pos_edcenty          ...
                                );
        but_centx       = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_btncx,           ...
                                'String','X',                   ...
                                'Callback',''                   ...
                                );
        but_centy       = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_btncy,           ...
                                'String','Y','Callback',''      ...
                                );
        nums = num2mstr(btn_edcentx);
        action = ['dynvtool(''center'',' int2str(fig) ',' nums ',0);'];
        set(but_centx,'Callback',action);
        nums = num2mstr(btn_edcenty);
        action = ['dynvtool(''center'',' int2str(fig) ',' nums ',1);'];
        set(but_centy,'Callback',action);

        txtpos          = uicontrol(...
                                'Style','Text',                 ...
                                'Unit',fig_units,               ...
                                'BackGroundColor',Def_TxtBkColor,...
                                'Position',pos_txtpos,          ...
                                'String','Position',            ...
                                'tag','DynV_Buf_Sel'            ...
                                );              
        mempos_coor     = wmemutil('add',[],'mngcoor');
        mempos_coor     = wmemutil('add',mempos_coor,'real');
        DynV_Btn_Xpos   = uicontrol(...
                                'Style','Text',                 ...
                                'Unit',fig_units,               ...
                                'BackGroundColor',Def_TxtBkColor,...
                                'Position',pos_btn_xpos,        ...
                                'HorizontalAlignment','left',   ...
                                'UserData',mempos_coor,         ...
                                'Tag','DynV_Btn_Xpos'           ...
                                );
        DynV_Btn_Ypos   = uicontrol(...
                                'Style','Text',                 ...
                                'Unit',fig_units,               ...
                                'BackGroundColor',Def_TxtBkColor,...
                                'Position',pos_btn_ypos,        ...
                                'HorizontalAlignment','left',   ...
                                'UserData',mempos_coor,         ...
                                'Tag','DynV_Btn_Ypos'           ...
                                );

        histo           = uicontrol(...
                                'Style','Text',                 ...
                                'Unit',fig_units,               ...
                                'BackGroundColor',Def_TxtBkColor,...
                                'Position',pos_txthis,          ...
                                'String','History',             ...
                                'Tag','DynV_Buf_Histo'          ...
                                );
                
        action = ['dynvtool(''get'',' int2str(fig) ',0);'];
        DynV_Btn_HInit  = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_hinit,           ...
                                'Enable','Off',                 ...
                                'String','<<-',                 ...
                                'Callback',action,              ...
                                'Tag','DynV_Btn_HInit'          ...
                                );
        action          = ['dynvtool(''get'',' int2str(fig) ',-1);'];
        DynV_Btn_HPrev = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_hpwrev,          ...
                                'Enable','Off',                 ...
                                'String','<-',                  ...
                                'Callback',action,              ...
                                'Tag','DynV_Btn_HPrev'         ...
                                );
        action          = ['dynvtool(''get'',' int2str(fig) ',1);'];
        DynV_Btn_HNext  = uicontrol(...
                                'Style','Pushbutton',           ...
                                'Unit',fig_units,               ...
                                'Position',pos_hnext,           ...
                                'Enable','Off',                 ...
                                'String','->',                  ...
                                'Callback',action,              ...
                                'Tag','DynV_Btn_HNext'          ...
                                );

        DynV_Handles = [... 
                        DynV_Fra_Ini    txtz            ...     
                        butgx           butdx           ... 
                        butgy           butdy           ...
                        butgxy          butdxy          ...
                        txtc                            ...
                        but_centx       but_centy       ...
                        btn_edcentx     btn_edcenty     ...
                        txtpos                          ...
                        DynV_Btn_Xpos   DynV_Btn_Ypos   ...
                        histo                           ...
                        DynV_Btn_HInit                  ...
                        DynV_Btn_HPrev DynV_Btn_HNext  ...
                        ];
        set(txtz,'Userdata',DynV_Handles);

        dynvtool('ini_his',fig,'','');
        drawnow;
        dynvtool('write_membuf',fig,Def_ZoomColor,[],[],[],[0 0]);

%************************************************%
%** OPTION = 'attach' CREATION OU MODIFICATION **%
%************************************************%
elseif strcmp(option,'attach')
        txt_handles     = findobj(fig,'Style','text');
        DynV_Fra_Ini    = findobj(fig,'Style','frame','Tag','DynV_Fra_Ini');    
        DynV_Btn_Xpos   = findobj(txt_handles,'tag','DynV_Btn_Xpos');
        DynV_Btn_Ypos   = findobj(txt_handles,'tag','DynV_Btn_Ypos');

        %-------- tests sur les parametres ---------%
        if nargin<3
                in3 = [];
                in4 = [];
                in5 = [];
                in6 = [0 0];
                in7 = '';       in8 = '';
                in9 = '';       in10 = [];
                if nargin<2, in2 = gcf; end
        end
        g_ind = in3;    g_cmd   = in4;  g_act = in5;    cont_xy = in6;
        fcn_put = in7;  fcn_get = in8;  fcn_wri = in9;
        if isempty(fcn_wri) , fcn_wri='mngcoor'; end
        if nargin<10  , par_wri = []; else , par_wri = in10; end
        if nargin<11 , cbox = Def_ZoomColor; else , cbox = in11; end

        DynV_Axe_Ind    = g_ind;
        DynV_Axe_Cmd    = g_cmd;
        DynV_Axe_Act    = [g_cmd g_act];
        if strcmp(get(DynV_Fra_Ini,'Visible'),'on');
                DynV_Status     = 1;
        else
                DynV_Status     = 0;
        end
        if DynV_Status & (~isempty(DynV_Axe_Ind) | ~isempty(DynV_Axe_Act))
                set(fig,'Interruptible','yes');
                action = ['mngmbtn(''down'',' int2str(fig) ');'];
                set(fig,'WindowButtonDownFcn',action);
        end
        DynV_XY_Const   = cont_xy;
        DynV_Col_Line   = cbox;

        dynvtool('write_membuf',fig,DynV_Col_Line,DynV_Axe_Ind,DynV_Axe_Cmd,...
                                        DynV_Axe_Act,DynV_XY_Const);

        if nargin==12   % flag for ON/OFF
                dynvtool('get',fig,0);
                set(DynV_Btn_Xpos,'String','X = ');
                set(DynV_Btn_Ypos,'String','Y = ');
        else
                dynvtool('ini_his',fig,fcn_put,fcn_get);
        end

        mempos_coor = wmemutil('add',[],fcn_wri);
        mempos_coor = wmemutil('add',mempos_coor,par_wri);
        set(DynV_Btn_Xpos,'UserData',mempos_coor);
        set(DynV_Btn_Ypos,'UserData',mempos_coor);

        %-------------- stockage des parametres de creation --------------%
        if isempty(g_ind) & isempty(g_cmd) , return; end
        params = [];
        params = wmemutil('add',params,g_ind);
        params = wmemutil('add',params,g_cmd);
        params = wmemutil('add',params,g_act);
        params = wmemutil('add',params,cont_xy);
        params = wmemutil('add',params,fcn_put);
        params = wmemutil('add',params,fcn_get);
        params = wmemutil('add',params,fcn_wri);
        params = wmemutil('add',params,par_wri);
        params = wmemutil('add',params,cbox);

        VdynData = get(DynV_Fra_Ini,'UserData');
        nb  = size(VdynData,1);
        if nb~=0
                max_stack = 3;
                ind = [];
                for k=1:nb
                        tmp = VdynData(k,:);
                        tmp1 = tmp(~isnan(tmp));
                        if size(tmp1)==size(params)
                                comp = find(tmp1~=params);
                        else
                                comp = 1;
                        end
                        if isempty(comp)
                                ind = k;
                                notind = find([1:nb]~=ind);
                                VdynData = [tmp;VdynData(notind,:)];
                                break;
                        end
                end
                if isempty(ind)
                        if nb>=max_stack
                                VdynData = VdynData(1:max_stack-1,:);
                        end
                        [l1,l2] = nancompl(params,VdynData);
                        VdynData = [l1;l2];
                        %---- elimination des NaN inutiles ----%
                        fini = find(sum(~isnan(VdynData))>0);
                        VdynData = VdynData(:,fini);
                end
        else
                VdynData = params;
        end
        set(DynV_Fra_Ini,'UserData',VdynData);

%**********************************************************************%
%** OPTION = 'delbox' DESTRUCTION DU RECTANGLE DE ZOOM (indirection) **%
%**********************************************************************%
elseif strcmp(option,'delbox')
        delete(findobj(fig,'Type','line','Tag','DynV_Sel_Box'));

%******************************************************************%
%** OPTION = 'getbox' LECTURE DU RECTANGLE DE ZOOM (indirection) **%
%******************************************************************%
elseif strcmp(option,'getbox')
        [out1,out2] = mngmbtn('getbox',fig);

%*************************************************************%
%** OPTION = 'delline' DESTRUCTION DES LIGNES (indirection) **%
%*************************************************************%
elseif strcmp(option,'delline')
        delete([findobj(fig,'Type','line','Tag','DynV_Line_Hor'),...
                findobj(fig,'Type','line','Tag','DynV_Line_Ver')]);

%********************************************************************%
%** OPTION = 'ini_his' INITIALISATION DE L'HISTORIQUE **%
%********************************************************************%
elseif strcmp(option,'ini_his')
        pus_handles     = findobj(fig,'Style','pushbutton');
        DynV_Btn_HInit  = findobj(pus_handles,'Tag','DynV_Btn_HInit');
        DynV_Btn_HPrev  = findobj(pus_handles,'Tag','DynV_Btn_HPrev');
        DynV_Btn_HNext  = findobj(pus_handles,'Tag','DynV_Btn_HNext');
        txt_handles     = findobj(fig,'Style','text');
        DynV_Buf_Histo  = findobj(txt_handles,'Tag','DynV_Buf_Histo');
        DynV_Btn_Xpos   = findobj(txt_handles,'Tag','DynV_Btn_Xpos');
        DynV_Btn_Ypos   = findobj(txt_handles,'Tag','DynV_Btn_Ypos');
        DynV_Reg_HPtr   = 0;
        set(DynV_Buf_Histo,'Value',DynV_Reg_HPtr,'UserData',[]);
        set(DynV_Btn_HInit,'Enable','Off');
        set(DynV_Btn_HPrev,'Enable','Off');
        set(DynV_Btn_HNext,'Enable','Off');
        if nargin==4
                fcn_put = in3; fcn_get = in4;
                if isempty(fcn_put) , fcn_put='[]'; end
                if isempty(fcn_get) , fcn_get='[]'; end
                set(DynV_Btn_HInit,'UserData',str2mat(fcn_put,fcn_get));
                set(DynV_Btn_HPrev,'UserData','');
                set(DynV_Btn_HNext,'UserData','');
        end
        set(DynV_Btn_Xpos,'String','X = ');
        set(DynV_Btn_Ypos,'String','Y = ');

%**************************************************************%
%** OPTION = 'new_his'      REINITIALISATION DE L'HISTORIQUE **%
%**************************************************************%
elseif strcmp(option,'new_his')
        dynvtool('get',fig,0);
        dynvtool('ini_his',fig);

%**********************************************************%
%** OPTION = 'stop'  REINITIALISATION ET ARRET DU MODULE **%
%**********************************************************%
elseif strcmp(option,'stop')
        dynvtool('get',fig,0);
        dynvtool('ini_his',fig);
        dynvfcn = ['mngmbtn(''down'',' int2str(fig) ');'];
        winfcn  = get(fig,'WindowButtonDownFcn');
        if strcmp(winfcn,dynvfcn)
                set(fig,'WindowButtonDownFcn','');
        end

%*************************************************************%
%** OPTION = 'get' RECUPERATION D'UN ETAT DANS L'HISTORIQUE **%
%*************************************************************%
elseif strcmp(option,'get')
        % in4 (optional) force the reset.
        %--------------------------------
        sens = in3;
        pus_handles     = findobj(fig,'Style','pushbutton');
        DynV_Btn_HInit  = findobj(pus_handles,'Tag','DynV_Btn_HInit');
        DynV_Btn_HPrev  = findobj(pus_handles,'Tag','DynV_Btn_HPrev');
        DynV_Btn_HNext  = findobj(pus_handles,'Tag','DynV_Btn_HNext');
        DynV_Buf_Histo  = findobj(fig,'Style','text','Tag','DynV_Buf_Histo');
        DynV_Reg_HPtr   = get(DynV_Buf_Histo,'value');
        data            = get(DynV_Buf_Histo,'UserData');

        change          = 'non';
        if sens>0
                m = size(data,1);
                if DynV_Reg_HPtr<m
                        DynV_Reg_HPtr = DynV_Reg_HPtr+1;
                        if DynV_Reg_HPtr==m
                                set(DynV_Btn_HNext,'Enable','Off');
                        end
                        set(DynV_Btn_HPrev,'Enable','On');
                        set(DynV_Btn_HInit,'Enable','On');
                        change = 'oui';
                end
        elseif (DynV_Reg_HPtr>1) | (nargin==4)
                if sens==0
                        DynV_Reg_HPtr = 1;
                elseif sens<0
                        DynV_Reg_HPtr = DynV_Reg_HPtr-1;
                end
                set(DynV_Btn_HNext,'Enable','On');
                if DynV_Reg_HPtr==1
                        set(DynV_Btn_HPrev,'Enable','Off');
                        set(DynV_Btn_HInit,'Enable','Off');
                end
                change = 'oui';
        end
        set(DynV_Buf_Histo,'Value',DynV_Reg_HPtr);

        if change=='oui'
                txt_handles     = findobj(fig,'Style','text');
                DynV_Btn_Xpos = findobj(txt_handles,'Tag','DynV_Btn_Xpos');
                DynV_Btn_Ypos = findobj(txt_handles,'Tag','DynV_Btn_Ypos');
                set(DynV_Btn_Xpos,'String','X = ');
                set(DynV_Btn_Ypos,'String','Y = ');
                lin_handles = findobj(fig,'Type','line');
                delete([findobj(lin_handles,'Tag','DynV_Sel_Box')...
                        findobj(lin_handles,'Tag','DynV_Line_Hor'),...
                        findobj(lin_handles,'Tag','DynV_Line_Ver')]);

                if isempty(data) , return; end
                don = data(DynV_Reg_HPtr,:);
                [m p] = size(don);
                if p>1
                        DynV_Buf_Mem    = findobj(fig,'Style','text',...
                                                'Tag','DynV_Buf_Mem');
                        mem_buffer      = get(DynV_Buf_Mem,'Userdata');
                        DynV_Axe_Ind    = wmemutil('get',mem_buffer,2);
                        DynV_Axe_Act    = wmemutil('get',mem_buffer,4);
                        axe_hdls        = [DynV_Axe_Ind DynV_Axe_Act];
                        if don(1)~=0
                                lig = don(1);
                                col = don(2);
                                valeurs  = don(3:lig*col+2);
                                His_don = reshape(valeurs,lig,col);
                                k = 3+lig*col;
                                %------ depilage d'un etat ------%
                                fcns = get(DynV_Btn_HInit,'UserData');
                                feval(fcns(2,:),His_don);
                        else
                                k = 3;
                        end
                        for i = 1:length(axe_hdls)
                                x = [don(k) don(k+1)];
                                y = [don(k+2) don(k+3)];
                                k = k+4;
                                h = axe_hdls(i);
                                if (x~=get(h,'XLim')) | (y~=get(h,'YLim'))
                                        set(h,'XLim',x,'YLim',y);
                                end
                        end
                end
        end

%******************************************************%
%** OPTION = 'put' AJOUT D'UN ETAT DANS L'HISTORIQUE **%
%******************************************************%
elseif strcmp(option,'put')
        pus_handles     = findobj(fig,'Style','pushbutton');
        txt_handles     = findobj(fig,'Style','text');
        DynV_Btn_HInit  = findobj(pus_handles,'Tag','DynV_Btn_HInit');
        DynV_Btn_HPrev  = findobj(pus_handles,'Tag','DynV_Btn_HPrev');
        DynV_Btn_HNext  = findobj(pus_handles,'Tag','DynV_Btn_HNext');
        DynV_Buf_Histo  = findobj(txt_handles,'Tag','DynV_Buf_Histo');
        DynV_Buf_Mem    = findobj(txt_handles,'Tag','DynV_Buf_Mem');
        mem_buffer      = get(DynV_Buf_Mem,'Userdata');
        DynV_Axe_Ind    = wmemutil('get',mem_buffer,2);
        DynV_Axe_Act    = wmemutil('get',mem_buffer,4);
        axe_hdls        = [DynV_Axe_Ind DynV_Axe_Act];

        coor = [];
        for i = 1:length(axe_hdls)
                x = get(axe_hdls(i),'XLim');
                y = get(axe_hdls(i),'YLim');
                coor = [coor x y];
        end
        fcns = get(DynV_Btn_HInit,'UserData');
        %--- empilage de l'etat (fonction utilisateur) ---%
        z1 = eval(fcns(1,:));
        s = size(z1);
        val = z1(:)';
        DynV_Reg_HPtr = get(DynV_Buf_Histo,'Value');
        if DynV_Reg_HPtr~=0
                data = get(DynV_Buf_Histo,'UserData');
                data = data(1:DynV_Reg_HPtr,:);
                [l1,l2] = nancompl(data,[s val coor]);
                data = [l1;l2];
        else
                data = [s val coor];
        end
        [m p] = size(data);
        DynV_Reg_HPtr = m;
        if DynV_Reg_HPtr>1
                set(DynV_Btn_HInit,'Enable','On');
                set(DynV_Btn_HPrev,'Enable','On');
        end
        set(DynV_Buf_Histo,'Value',DynV_Reg_HPtr,'UserData',data);
        set(DynV_Btn_HNext,'Enable','Off');

%********************************************************************%
%** OPTION = 'zoom+' or 'zoom-'   GESTION DES ZOOMS                **%
%********************************************************************%
elseif strcmp(option,'zoom+') | strcmp(option,'zoom-')
        dir = in3;
        DynV_Sel_Box = findobj(fig,'Type','line','Tag','DynV_Sel_Box');

        if isempty(DynV_Sel_Box) , return; end
        pzbx = get(DynV_Sel_Box,'XData');
        pzby = get(DynV_Sel_Box,'YData');
        xmin = min(pzbx);       xmax = max(pzbx);
        ymin = min(pzby);       ymax = max(pzby);
        delete([DynV_Sel_Box, ...
                findobj(fig,'Type','line','Tag','DynV_Line_Hor'),...
                findobj(fig,'Type','line','Tag','DynV_Line_Ver')]);
        if (xmin<xmax) & (ymin<ymax)
                DynV_Buf_Mem    = findobj(fig,'Style','text',...
                                        'Tag','DynV_Buf_Mem');
                DynV_Buf_Sel    = findobj(fig,'Style','text',...
                                        'Tag','DynV_Buf_Sel');
                DynV_Axe_Sel    = get(DynV_Buf_Sel,'Userdata');
                mem_buffer      = get(DynV_Buf_Mem,'Userdata');
                DynV_Axe_Ind    = wmemutil('get',mem_buffer,2);
                if ~isempty(find(DynV_Axe_Sel==DynV_Axe_Ind))
                        DynV_Axe_Act = DynV_Axe_Sel;
                        DynV_XY_Const = [0 0];
                else
                        DynV_Axe_Act    = wmemutil('get',mem_buffer,4);
                        DynV_XY_Const   = wmemutil('get',mem_buffer,5);
                end
                %--- En direction des x ---%
                if dir(1)~=0
                        %-- Agrandir --%
                        if strcmp(option,'zoom+')
                                ux = [xmin xmax];
                        %-- Diminuer --%
                        elseif strcmp(option,'zoom-')
                                xL  = get(DynV_Axe_Sel,'XLim');
                                ux1 = (xL(1)-xmax)*xL(1)+(xmin-xL(1))*xL(2);
                                ux2 = (xmin-xL(2))*xL(2)+(xL(2)-xmax)*xL(1);
                                ux  = [ux1 ux2]/(xmin-xmax);
                        end
                        if DynV_XY_Const(1)~=0
                                set(DynV_Axe_Act,'XLim',ux);
                        else
                                set(DynV_Axe_Sel,'XLim',ux);
                        end
                end
                %--- En direction des y ---%
                if dir(2)~=0
                        %-- Agrandir --%
                        if strcmp(option,'zoom+')
                                uy = [ymin ymax];
                        %-- Diminuer --%
                        elseif strcmp(option,'zoom-')
                                yL  = get(DynV_Axe_Sel,'YLim');
                                uy1 = (yL(1)-ymax)*yL(1)+(ymin-yL(1))*yL(2);
                                uy2 = (ymin-yL(2))*yL(2)+(yL(2)-ymax)*yL(1);
                                uy  = [uy1 uy2]/(ymin-ymax);
                        end
                        if DynV_XY_Const(2)~=0
                                set(DynV_Axe_Act,'YLim',uy);
                        else
                                set(DynV_Axe_Sel,'YLim',uy);
                        end
                end
                dynvtool('put',fig);
        end

%****************************%
%** OPTION = 'center'      **%
%****************************%
elseif strcmp(option,'center')
        btn = in3;      dir = in4;
        DynV_Buf_Mem    = findobj(fig,'Style','text','Tag','DynV_Buf_Mem');
        DynV_Buf_Sel    = findobj(fig,'Style','text','Tag','DynV_Buf_Sel');
        DynV_Axe_Sel    = get(DynV_Buf_Sel,'Userdata');
        mem_buffer      = get(DynV_Buf_Mem,'Userdata');
        if isempty(DynV_Axe_Sel)
                DynV_Axe_Act  = wmemutil('get',mem_buffer,4);
                DynV_XY_Const = wmemutil('get',mem_buffer,5);
		if ~isempty(DynV_Axe_Act)
                    DynV_Axe_Sel  = DynV_Axe_Act(1);
                else
                    return;
                end
        else
                DynV_Axe_Ind    = wmemutil('get',mem_buffer,2);
                if ~isempty(find(DynV_Axe_Sel==DynV_Axe_Ind))
                        DynV_Axe_Act = DynV_Axe_Sel;
                        DynV_XY_Const = [0 0];
                else
                        DynV_Axe_Act    = wmemutil('get',mem_buffer,4);
                        DynV_XY_Const   = wmemutil('get',mem_buffer,5);
                end
        end
        if isempty(DynV_Axe_Act) , set(btn,'String',''); return; end
        lin_handles = findobj(fig,'Type','line');
        delete([findobj(lin_handles,'Tag','DynV_Sel_Box')...
                findobj(lin_handles,'Tag','DynV_Line_Hor'),...
                findobj(lin_handles,'Tag','DynV_Line_Ver')]);
        strval = get(btn,'String');
        [val_centre,count,err] = sscanf(strval,'%f');
        if count==1 & isempty(err)
                if length(DynV_Axe_Act)==1 , seul = 1; else , seul = 0; end
                %--- Centrer par rapport a x ---%
                if dir==0
                        if seul | DynV_XY_Const(1)~=0
                                laxe = DynV_Axe_Act(1);
                        else
                                laxe = DynV_Axe_Sel;
                        end
                        if isempty(laxe) , return; end
                        x = get(laxe,'XLim');
                        la = (x(2)-x(1))/2;
                        xmin = val_centre-la;
                        xmax = val_centre+la;
                        if seul | DynV_XY_Const(1)~=0
                                set(DynV_Axe_Act,'XLim',[xmin xmax]);
                        else
                                set(DynV_Axe_Sel,'XLim',[xmin xmax]);
                        end

                %--- Centrer par rapport a y ---%
                elseif dir==1
                        if seul | DynV_XY_Const(2)~=0
                                laxe = DynV_Axe_Act(1);
                        else
                                laxe = DynV_Axe_Sel;
                        end
                        if isempty(laxe) , return; end
                        y = get(laxe,'YLim');
                        la = (y(2)-y(1))/2;
                        ymin = val_centre-la;
                        ymax = val_centre+la;
                        if seul | DynV_XY_Const(2)~=0
                                set(DynV_Axe_Act,'YLim',[ymin ymax]);
                        else
                                set(DynV_Axe_Sel,'YLim',[ymin ymax]);
                        end
                else
                        return;
                end
                dynvtool('put',fig);
        end
        set(btn,'String','');

%********************************************************************%
%** OPTION = 'on' CONNECTER LE MODULE                              **%
%********************************************************************%
elseif strcmp(option,'on')
        DynV_Fra_Ini = findobj(fig,'Style','frame','Tag','DynV_Fra_Ini');
        VdynData = get(DynV_Fra_Ini,'UserData');
        continu = 0;
        if ~isempty(VdynData)
                params = VdynData(1,:);
                ind = ~isnan(params);
                params = params(ind);
                [g_ind,params]   = wmemutil('get',params);
                [g_cmd,params]   = wmemutil('get',params);
                [g_act,params]   = wmemutil('get',params);
                [cont_xy,params] = wmemutil('get',params);
                [fcn_put,params] = wmemutil('get',params);
                [fcn_get,params] = wmemutil('get',params);
                [fcn_wri,params] = wmemutil('get',params);
                [par_wri,params] = wmemutil('get',params);
                [cbox,params]    = wmemutil('get',params);
                continu = 1;
        end
        dynvaxes = [g_ind g_cmd g_act]; 
        figaxes = findobj(fig,'Type','axes');
        okaxe = wcommon(dynvaxes,figaxes);
        if find(okaxe~= ones(size(dynvaxes))) , continu = 0; end
        if continu==0
                dynvtool('attach',fig);
                return;
                %---------- Old Version ------------%
                errargt('dynvtool',...
                        'Error : attaching Dynamic Vizualisation','msg');
                return;
                %---------- Old Version ------------%
        end
        lin_handles = findobj(fig,'Type','line');
        delete([findobj(lin_handles,'Tag','DynV_Sel_Box')...
                findobj(lin_handles,'Tag','DynV_Line_Hor'),...
                findobj(lin_handles,'Tag','DynV_Line_Ver')]);
        set(DynV_Fra_Ini,'UserData',VdynData);
        dynvtool('attach',fig,g_ind,g_cmd,g_act,cont_xy,...
                fcn_put,fcn_get,fcn_wri,par_wri,cbox,0);

%********************************************************************%
%** OPTION = 'off' DECONNECTER LE MODULE                           **%
%********************************************************************%
elseif strcmp(option,'off')
        dynvfcn = ['mngmbtn(''down'',' int2str(fig) ');'];
        winfcn  = get(fig,'WindowButtonDownFcn');
        if strcmp(winfcn,dynvfcn)
                set(fig,'WindowButtonDownFcn','');
        end
        lin_handles = findobj(fig,'Type','line');
        delete([findobj(lin_handles,'Tag','DynV_Sel_Box')...
                findobj(lin_handles,'Tag','DynV_Line_Hor'),...
                findobj(lin_handles,'Tag','DynV_Line_Ver')]);

%***********************************************************%
%** OPTION = 'fcn_w' CHANGEMENT DE LA FONCTION D'ECRITURE **%
%***********************************************************%
elseif strcmp(option,'fcn_w')
        DynV_Fra_Ini    = findobj(fig,'Style','frame','Tag','DynV_Fra_Ini');
        DynV_Btn_Xpos   = findobj(fig,'Style','text','Tag','DynV_Btn_Xpos');
        DynV_Btn_Ypos   = findobj(fig,'Style','text','Tag','DynV_Btn_Ypos');
        VdynData        = get(DynV_Fra_Ini,'UserData');
        if isempty(VdynData) , return;  end
        params = VdynData(1,:);
        VdynData = VdynData(2:size(VdynData,1),:);
        ind = ~isnan(params);
        params = params(ind);
        if findmobj(fig)
                [g_ind,params]   = wmemutil('get',params);
                [g_cmd,params]   = wmemutil('get',params);
                [g_act,params]   = wmemutil('get',params);
                [cont_xy,params] = wmemutil('get',params);
                [fcn_put,params] = wmemutil('get',params);
                [fcn_get,params] = wmemutil('get',params);
                [fcn_wri,params] = wmemutil('get',params);
                [par_wri,params] = wmemutil('get',params);
                [cbox,params]    = wmemutil('get',params);
        end
        fcn_wri = in3;
        if nargin==4 , par_wri = in4; else , par_wri = []; end 
        if isempty(fcn_wri) , fcn_wri='mngcoor'; end
        mempos_coor = wmemutil('add',[],fcn_wri);
        mempos_coor = wmemutil('add',mempos_coor,par_wri);
        set(DynV_Btn_Xpos,'UserData',mempos_coor);
        set(DynV_Btn_Ypos,'UserData',mempos_coor);
        params = [];
        params = wmemutil('add',params,g_ind);
        params = wmemutil('add',params,g_cmd);
        params = wmemutil('add',params,g_act);
        params = wmemutil('add',params,cont_xy);
        params = wmemutil('add',params,fcn_put);
        params = wmemutil('add',params,fcn_get);
        params = wmemutil('add',params,fcn_wri);
        params = wmemutil('add',params,par_wri);
        params = wmemutil('add',params,cbox);

        if ~isempty(VdynData)
                [l1,l2] = nancompl(params,VdynData);
                VdynData = [l1;l2];
                %---- elimination des NaN inutiles ----%
                ind = find(sum(~isnan(VdynData))>0);
                VdynData = VdynData(:,ind);
        else
                VdynData = params;
        end
        set(DynV_Fra_Ini,'UserData',VdynData);

%*****************************%
%** OPTION = 'write_membuf' **%
%*****************************%
elseif strcmp(option,'write_membuf')
        % DynV_Col_Line DynV_Axe_Cmd
        % DynV_Axe_Act  DynV_XY_Const

        mem_buffer = [];
        mem_buffer = wmemutil('add',mem_buffer,in3);
        mem_buffer = wmemutil('add',mem_buffer,in4);
        mem_buffer = wmemutil('add',mem_buffer,in5);
        mem_buffer = wmemutil('add',mem_buffer,in6);
        mem_buffer = wmemutil('add',mem_buffer,in7);
        DynV_Buf_Mem = findobj(fig,'Style','text','Tag','DynV_Buf_Mem');
        set(DynV_Buf_Mem,'Userdata',mem_buffer);

%*****************************%
%** OPTION = 'read_membuf' **%
%*****************************%
elseif strcmp(option,'read_membuf')
        DynV_Buf_Mem = findobj(fig,'Style','text','Tag','DynV_Buf_Mem');
        mem_buffer = get(DynV_Buf_Mem,'Userdata');
        % DynV_Col_Line
        out1 = wmemutil('get',mem_buffer,1);
        % DynV_Axe_Ind
        out2 = wmemutil('get',mem_buffer,2);
        % DynV_Axe_Cmd
        out3 = wmemutil('get',mem_buffer,3);
        % DynV_Axe_Act
        out4 = wmemutil('get',mem_buffer,4);
        % DynV_XY_Const
        out5 = wmemutil('get',mem_buffer,5);

%********************************************%
%** OPTION = 'close' DESTRUCTION DU MODULE **%
%********************************************%
elseif strcmp(option,'close')
        DynV_Fra_Ini = findobj(fig,'Style','frame','Tag','DynV_Fra_Ini');
        if ~isempty(DynV_Fra_Ini)
                set(DynV_Fra_Ini,'UserData','');
        end
        lin_handles = findobj(fig,'Type','line');
        delete([findobj(lin_handles,'Tag','DynV_Sel_Box')...
                findobj(lin_handles,'Tag','DynV_Line_Hor'),...
                findobj(lin_handles,'Tag','DynV_Line_Ver')]);

%*********************************%
%** OPTION = 'hide' (for demos) **%
%*********************************%
elseif strcmp(option,'hide')
        buffer  = findobj(fig,'style','text','tag','DynV_Handles');
        if ~isempty(buffer)
                dynvfcn = ['mngmbtn(''down'',' int2str(fig) ');'];
                winfcn  = get(fig,'WindowButtonDownFcn');
                if strcmp(winfcn,dynvfcn)
                   set(fig,'WindowButtonDownFcn','');
                end
                lin_handles = findobj(fig,'Type','line');
                delete([findobj(lin_handles,'Tag','DynV_Sel_Box')...
                        findobj(lin_handles,'Tag','DynV_Line_Hor'),...
                        findobj(lin_handles,'Tag','DynV_Line_Ver')]);

                hdls = get(buffer,'Userdata');
                set(hdls,'Visible','off');
        end

%*********************************%
%** OPTION = 'show' (for demos) **%
%*********************************%
elseif strcmp(option,'show')
        buffer  = findobj(fig,'style','text','tag','DynV_Handles');
        if ~isempty(buffer)
                dynvfcn = ['mngmbtn(''down'',' int2str(fig) ');'];
                winfcn  = get(fig,'WindowButtonDownFcn');
                set(fig,'WindowButtonDownFcn',dynvfcn);
                hdls = get(buffer,'Userdata');
                set(hdls,'Visible','on');
        end

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('dynvtool','Unknown Option','msg');
        error('*');
end
