function data = entrupd(tree,data,ent,in4)
%ENTRUPD Entropy update (wavelet packet).
%       NDATA = ENTRUPD(TREE,DATA,ENT) or 
%       NDATA = ENTRUPD(TREE,DATA,ENT,PAR) returns for a
%       given wavelet packet decomposition structure
%       [TREE,DATA] (see MAKETREE), the updated data structure
%       NDATA corresponding to entropy function ENT with
%       optional parameter PAR (see WENTROPY).
%
%       [TREE,NDATA] is the resulting decomposition structure.
%
%       See also WENTROPY, WPDEC, WPDEC2.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:10:43 $

%       Uses ALLNODES, ISTNODE, WDATAMGR, WENTROPY, WPCOEF.

% Check arguments.
if errargn('entrupd',nargin,[3 4],nargout,[0 1]), error('*'), end
if nargin==3 , par = 0; else par = in4; end
if strcmp(lower(ent),'user')
        if ~isstr(par)
                error('*** Invalid function name for user entropy ***');
        end
end

% Keep tree nodes.
nods      = (allnodes(tree))';
ent_nods  = zeros(size(nods));
ento_nods = NaN;
ento_nods = ento_nods(ones(size(nods)));

% Update entropy.
for i = 1:length(nods)
        % read or reconstruct packet coefficients.
        if wtreemgr('istnode',tree,nods(i))
                coefs = wdatamgr('read_cfs',data,tree,nods(i));
        else
                coefs = wpcoef(tree,data,nods(i));
        end
        % compute entropy.
        ent_nods(i) = wentropy(coefs,ent,par);
end

% Update data structure.
data = wdatamgr('write_tp_ent',data,ent,par);
data = wdatamgr('write_ent',data,ent_nods,nods);
data = wdatamgr('write_ento',data,ento_nods,nods);
