function x = idwt(a,d,arg3,arg4,arg5)
%IDWT Single-level inverse discrete 1-D wavelet transform.
%       IDWT performs a single-level 1-D wavelet reconstruction
%       with respect to either a particular wavelet
%       ('wname', see WFILTERS) or particular wavelet
%       reconstruction filters you specify.
%
%       X = IDWT(CA,CD,'wname') returns the single-level
%       reconstructed approximation coefficients vector X
%       based on approximation and detail coefficients
%       vectors CA and CD, and using the wavelet 'wname'.
%
%       X = IDWT(CA,CD,Lo_R,Hi_R) reconstructs as above,
%       using filters you specify:
%       Lo_R is the reconstruction low-pass filter and
%       Hi_R is the reconstruction high-pass filter.
%       Lo_R and Hi_R must be the same length.
%
%       If la = length(CA) = length(CD) and lf is the length of
%       the filters, then length(X) = 2*la-lf+2.
%
%       X = IDWT(CA,CD,'wname',L) or X = IDWT(CA,CD,Lo_R,Hi_R,L)
%       return the length-L central portion of the result
%       obtained using IDWT(CA,CD,'wname'). L must be less than
%       2*la-lf+2
%
%       See also DWT, IDWTPER, UPWLEV.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:11:31 $

%       Uses ERRARGN, DYADUP, WFILTERS, WKEEP.

% Check arguments.
if errargn('idwt',nargin,[3:5],nargout,[0:1]), error('*'), end

if isstr(arg3)
        [LoF_R,HiF_R] = wfilters(arg3,'r');
        if nargin==4 , l = arg4; else , l = 2*length(a)-length(LoF_R)+2; end
else
        LoF_R = arg3;   HiF_R = arg4;
        if nargin==5 , l = arg5; else , l = 2*length(a)-length(LoF_R)+2; end
end

% Reconstruction.
x = conv(dyadup(a),LoF_R)+conv(dyadup(d),HiF_R);
x = wkeep(x,l);
