function x = idwtper(a,d,arg3,arg4,arg5)
%IDWTPER Single-level inverse discrete 1-D wavelet transform (periodized).
%       X = IDWTPER(CA,CD,'wname') returns the single-level
%       reconstructed approximation coefficients vector X
%       based on approximation and detail vectors CA and CD
%       at a given level, using the periodized inverse wavelet
%       transform.
%       'wname' is a string containing the wavelet name
%       (see WFILTERS).
%
%       Instead of giving the wavelet name, you can give the
%       filters.
%       For X = IDWTPER(CA,CD,Lo_R,Hi_R),
%       Lo_R is the reconstruction low-pass filter and
%       Hi_R is the reconstruction high-pass filter
%
%       If la = length(CA) = length(CD) then length(X) = 2*la.
%
%       For X = IDWTPER(CA,CD,'wname',L) or 
%       X = IDWTPER(CA,CD,Lo_R,Hi_R,L), L is the length of the
%       result.
%
%       See also DWTPER.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:11:42 $

%       Uses ERRARGN, DYADUP, WFILTERS, WKEEP.

% Check arguments.
if errargn('idwtper',nargin,[3:5],nargout,[0:1]), error('*'), end

la = length(a);
if isstr(arg3)
        [LoF_R,HiF_R] = wfilters(arg3,'r');
        if nargin==4 , lx = arg4; else , lx = 2*la; end
else
        LoF_R = arg3;   HiF_R = arg4;
        if nargin==5 , lx = arg5; else , lx = 2*la; end
end

% Reconstruction.
lf = length(LoF_R);
lp = ceil(lx/2);
lm = (floor((lx+lf-1)/2)-lp)/2;
ar = ceil(lm);
al = floor(lm);
if size(a,1)==1
        a = [a(lp-al+1:lp) a a(1:ar)];
        d = [d(lp-al+1:lp) d d(1:ar)];
else
        a = [a(lp-al+1:lp);a;a(1:ar)];
        d = [d(lp-al+1:lp);d;d(1:ar)];
end
x = conv(dyadup(a),LoF_R)+conv(dyadup(d),HiF_R);
x = wkeep(x,lx);
