function [d,p] = ind2depo(order,node)
%IND2DEPO Node index to node depth-position.
%       For a tree of order ORD, [D,P] = IND2DEPO(ORD,N)
%       computes the depths D and the positions P (at 
%       this depths D) for the nodes with indices N.
%       The nodes are numbered from left to right and
%       from top to bottom. The root index is 0.
%
%       D, P, N, are column vectors.
%          D = depths, 0 <= D <= dmax
%          P = positions at depth D, 0 <= P <= order^D-1
%          N = indices, 0 <= N < ((order^(dmax+1))-1)/(order-1)
%
%       Note: [D,P] = IND2DEPO(ORD,[D P]).
%
%       See also DEPO2IND, MAKETREE, WTREEMGR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:11:53 $

%       Uses ERRARGN, ERRARGT.

% Check arguments.
if errargn('ind2depo',nargin,[2],nargout,[0:2]), error('*'); end

[r,c] = size(node);
if c==1
        d = zeros(r,1);
        p = zeros(r,1);
        K = find(node>0);
        d(K) = floor(log((order-1)*node(K)+1)/log(order));
        p(K) = node(K) -(order.^d(K)-1)/(order-1);
        K = find(node<0);
        if ~isempty(K)
                d(K) = -ones(length(K),1);
        end

elseif c==2
        d = node(:,1);
        p = node(:,2);
else
        errargt('ind2depo','invalid argument value','msg'); error('*');
end
