function r = isnode(tree,node)
%ISNODE True for existing node.
%       R = ISNODE(T,N) returns 1's for nodes N which
%       exist in the tree structure T, and 0's for others.
%
%       N can be a column vector containing the indices of nodes
%       or a matrix, which contains the depths and positions of nodes.
%       In the last case, N(i,1) is the depth of i-th node 
%       and N(i,2) is the position of i-th node.
%
%       The nodes are numbered from left to right and
%       from top to bottom. The root index is 0.
%
%       See also ISTNODE, MAKETREE, WTREEMGR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:12:20 $

%       Uses ERRARGN, WTREEMGR.

% Check arguments.
if errargn('isnode',nargin,[2],nargout,[0:1]), error('*'); end

r = wtreemgr('isnode',tree,node);
