function r = istnode(tree,node)
%ISTNODE True for terminal nodes.
%       R = ISTNODE(T,N) returns ranks (in left to right
%       terminal nodes  ordering) for terminal nodes N
%       belonging to the tree structure T and 0's for others.
%
%       N can be a column vector containing the indices of nodes
%       or a matrix which contains the depths and positions of
%       nodes.
%       In the last case, N(i,1) is the depth of i-th node 
%       and N(i,2) is the position of i-th node.
%
%       The nodes are numbered from left to right and
%       from top to bottom. The root index is 0.
%
%       See also ISNODE, MAKETREE, WTREEMGR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:12:26 $

%       Uses ERRARGN, WTREEMGR.

% Check arguments.
if errargn('istnode',nargin,[2],nargout,[0:1]), error('*'); end

r = wtreemgr('istnode',tree,node);
