function [out1,out2,out3] = key2info(lin_norm,lin_zero,key,typ)
%KEY2INFO Key driven retrieve from tables.
%       [OUT1,OUT2,OUT3] = KEY2INFO(HDL_NORM,HDL_ZERO,KEY,TYP)
%       returns elements TAB1(index),TAB2(index)  and TAB3(index)
%       where index is the approximate solution for TABX(index) = KEY,
%       where TABX is constructed from the lines of the perfos axes
%       depending on the type of the typ input:
%       typ = N means that the key is a l2-norm recovery value
%       typ = Z means that the key is a number of zeros value
%       typ = T means that the key is a threshold value.
%       TAB1,TAB2 and TAB3 are constructed from the Xdata or Ydata of
%       the lines which handles are lin_norm and lin_zero, depending
%       on the value of key.
%       TAB1,TAB2 and TAB3 are supposed to be of the same length.
%
%       See also WCMPSCR, WPCMPSCR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:12:31 $

%       Uses ERRARGN.

%       Only minimal argument checking for this program.

% Check arguments.
if errargn('key2info',nargin,[4],nargout,[0:3]), error('*'), end

if      typ=='N'
        tab1 = get(lin_norm,'Ydata');
        n = length(tab1);
        if key >= tab1(1)
                argmin = 1;
        elseif key <= tab1(n)
                argmin = n;
        else
                crit = abs(key-tab1);
                [xx,argmin] = min(crit);
        end
        out1 = tab1(argmin);
        clear tab1;
        tab2 = get(lin_zero,'Ydata');
        out2 = tab2(argmin);
        clear tab2;
        tab3 = get(lin_norm,'Xdata');
        out3 = tab3(argmin);
        clear tab3;
elseif  typ=='Z'
        tab1 = get(lin_zero,'Ydata');
        n = length(tab1);
        if key >= tab1(n)
                argmin = n;
        elseif key <= tab1(1)
                argmin = 1;
        else
                crit = abs(key-tab1);
                [xx,argmin] = min(crit);
        end
        out2 = tab1(argmin);
        clear tab1;
        tab2 = get(lin_norm,'Ydata');
        out1 = tab2(argmin);
        clear tab2;
        tab3 = get(lin_norm,'Xdata');
        out3 = tab3(argmin);
        clear tab3;
elseif  typ=='T'
        tab1 = get(lin_norm,'Xdata');
        n = length(tab1);
        if key >= tab1(n)
                argmin = n;
        elseif key <= tab1(1)
                argmin = 1;
        else
                crit = abs(key-tab1);
                [xx,argmin] = min(crit);
        end
        out3 = tab1(argmin);
        clear tab1;
        tab1 = get(lin_norm,'Ydata');
        out1 = tab1(argmin);
        clear tab1;
        tab2 = get(lin_zero,'Ydata');
        out2 = tab2(argmin);
        clear tab2;
end
