function [out1,out2] = mexihat(lb,ub,n)
%MEXIHAT Mexican hat wavelet.
%       [PSI,X] = MEXIHAT(LB,UB,N) returns values of 
%       the Mexican hat wavelet on a N points regular
%       grid on the interval [LB,UB].
%       Output arguments are the wavelet function PSI
%       computed on the grid X, and the grid X.
%
%       This wavelet has [-5 5] as effective support.
%
%       See also WAVEINFO.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:12:52 $

%       Uses ERRARGN.

% Check arguments.
if errargn('mexihat',nargin,[3],nargout,[0:2]), error('*'); end

% Compute values of the Mexican hat wavelet.
out2 = linspace(lb,ub,n);        % wavelet support.
out1 = out2.^2;
out1 = (2/(sqrt(3)*pi^0.25)) * exp(-out1/2) .* (1-out1);


