function [out1,out2] = mngmbtn(option,fig,in3,in4)
%MNGMBTN Manage mouse buttons for the dynamical visualization tool.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:13:36 $

%       Uses ERRARGT, DYNVTOOL, NUM2MSTR, MNGCOOR, MNGMBTN, WMEMUTIL.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% function mngmbtn(option,fig,in3)                                           %
%%----------------------------------------------------------------------------%
%% Cette fonction est associee au callback WindowButtonDownFcn d'une figure   %
%% dans laquelle on veut faire des zooms, translations, interrogations        %
%% de position, etc ... Ce Callback est defini par la fonction mdynvisu.      %
%%      option = 'down'   : pression sur un bouton de la souris.              %
%%      option = 'up'     : bouton de la souris relachee.                     %
%%      option = 'move'   : gestion du mouvement de la souris.                %
%%      option = 'delline': destruction des lignes (position, translation)    %
%%      option = 'delbox' : destruction de la boite de selection.             %
%%      option = 'getbox' : [xdata,ydata] = mngmbtn('getbox',fig)             %
%%                              lecture de la boite de selection.             %
%%      option = 'end'    : fermeture du module de gestion de la souris.      %
%%----------------------------------------------------------------------------%
%% utilise : mngcoor ou fcn_wri (utilisateur)                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Tagged Objects.
%----------------
%       'DynV_Btn_Xpos'
%       'DynV_Btn_Ypos'
%
%       'DynV_Sel_Box'
%       'DynV_Line_Hor'
%       'DynV_Line_Ver'
%
%       'DynV_Buf_Mem'
%       'DynV_Buf_Sel'
%       'DynV_Buf_Tra'

%-----------------------
% msel_box   = 'normal';
% msel_trans = 'alt';
% msel_txt   = 'extend';
%------------------------
msel_box   = 'n';
msel_trans = 'a';
msel_txt   = 'e';

%**********************************************%
%** OPTION = 'move' DEPLACEMENT DE LA SOURIS **%
%**********************************************%
if strcmp(option,'move')
%       DynV_Axe_Sel    = in3(1);
%       DynV_Btn_Xpos   = in3(2);
%       DynV_Btn_Ypos   = in3(3);
%-----------------------------------------
        if get(0,'PointerWindow')~=fig , return; end
        DynV_Axe_Sel    = in3(1);
        mouse = get(fig,'SelectionType');
        mouseT = mouse(1);

        x  = get(DynV_Axe_Sel,'XLim');
        y  = get(DynV_Axe_Sel,'YLim');
        cp = get(DynV_Axe_Sel,'CurrentPoint');
        q = cp(1,1:2);
        if (q(1)<min(x)) | (q(1)>max(x)) | (q(2)<min(y)) | (q(2)>max(y))
                set(fig,'WindowButtonMotionFcn','',     ...
                        'WindowButtonUpFcn','',         ...
                        'Pointer','arrow'               ...
                        );
                lin_handles = findobj(fig,'Type','line');
                if mouseT==msel_box
                        delete(findobj(lin_handles,'Tag','DynV_Sel_Box'));
                else
                        delete([findobj(lin_handles,'Tag','DynV_Line_Hor'),...
                                findobj(lin_handles,'Tag','DynV_Line_Ver')]);
                end

        %--- selection d'un rectangle ---%
        elseif mouseT==msel_box
                DynV_Sel_Box    = findobj(DynV_Axe_Sel,'Type','line',...
                                                       'Tag','DynV_Sel_Box');
                if ~isempty(DynV_Sel_Box)
                        pzbx = get(DynV_Sel_Box,'XData');
                        pzby = get(DynV_Sel_Box,'YData');
                        set(DynV_Sel_Box,...
                                'XData', [pzbx(1) q(1) q(1) pzbx(1) pzbx(1)],...
                                'YData', [pzby(1) pzby(1) q(2) q(2) pzby(1)]);
                end

        %--- ecriture de la position ---%
        elseif mouseT==msel_txt
                lin_handles     = findobj(fig,'Type','line');
                DynV_Line_Hor   = findobj(lin_handles,'Tag','DynV_Line_Hor');
                if isempty(DynV_Line_Hor) , return; end
                DynV_Line_Ver   = findobj(lin_handles,'Tag','DynV_Line_Ver');
                DynV_Btn_Xpos   = in3(2);
                DynV_Btn_Ypos   = in3(3);
                set(DynV_Line_Hor,'YData',[q(2) q(2)]);
                set(DynV_Line_Ver,'XData',[q(1) q(1)]);
                mempos_coor = get(DynV_Btn_Xpos,'UserData');
                fcns_wri  = wmemutil('get',mempos_coor,1);
                param_wri = wmemutil('get',mempos_coor,2);
                [sx,sy] = feval(fcns_wri,q(1),q(2),DynV_Axe_Sel,param_wri);
                set(DynV_Btn_Xpos,'String',sx);
                set(DynV_Btn_Ypos,'String',sy);
        
        %--- gestion des translations ---%
        elseif mouseT==msel_trans
                lin_handles     = findobj(fig,'Type','line');
                DynV_Line_Hor   = findobj(lin_handles,'Tag','DynV_Line_Hor');
                if isempty(DynV_Line_Hor) , return; end
                DynV_Line_Ver   = findobj(lin_handles,'Tag','DynV_Line_Ver');
                DynV_Buf_Tra    = findobj(fig,'Style','edit',...
                                        'Tag','DynV_Buf_Tra');
                x1 = get(DynV_Line_Hor,'XData');
                y1 = get(DynV_Line_Hor,'YData');
                u  = get(DynV_Axe_Sel,'Units');
                set(DynV_Axe_Sel,'Units','pixels');
                rect = get(DynV_Axe_Sel,'Position');
                set(DynV_Axe_Sel,'Units',u);
                rx = abs((x1(2)-q(1))/(x(2)-x(1)));
                ry = abs((y1(2)-q(2))/(y(2)-y(1)));
                k  = rect(3)*rx-rect(4)*ry;
                if k>0
                        set(DynV_Line_Hor,...
                                'XData',[x1(2) x1(2) x1(2)],    ...
                                'YData',[y(1)  y1(2) y(2) ]     ...
                                );
                        set(DynV_Line_Ver,...
                                'XData',[q(1) q(1) q(1)],       ...
                                'YData',[y(1) q(2) y(2)]        ...
                                );
                        DynV_Flg_Trans = 1;
                elseif k<0
                        set(DynV_Line_Hor,...
                                'XData',[x(1)  x1(2) x(2) ],    ...
                                'YData',[y1(2) y1(2) y1(2)]     ...
                                );
                        set(DynV_Line_Ver,...
                                'XData',[x(1) q(1) x(2)],       ...
                                'YData',[q(2) q(2) q(2)]        ...
                                );
                        DynV_Flg_Trans = 2;
                else
                        DynV_Flg_Trans = 0;
                end
                set(DynV_Buf_Tra,'Userdata',DynV_Flg_Trans);
        end

%***************************************************%
%** OPTION = 'down' UN BOUTON DE LA SOURIS APPUYE **%
%***************************************************%
elseif strcmp(option,'down')
        if isempty(find(get(0,'Children')==fig))
                return;
        elseif get(0,'PointerWindow')~=fig
                lin_handles = findobj(fig,'Type','line');
                axe_del = [ findobj(lin_handles,'Tag','DynV_Sel_Box');  ...
                            findobj(lin_handles,'Tag','DynV_Line_Hor'); ...
                            findobj(lin_handles,'Tag','DynV_Line_Ver')];
                delete(axe_del)
                return;
        end
        mouse           = get(fig,'SelectionType');
        mouseT          = mouse(1);
        txt_handles     = findobj(fig,'Style','text');
        DynV_Buf_Mem    = findobj(txt_handles,'Tag','DynV_Buf_Mem');
        DynV_Buf_Sel    = findobj(txt_handles,'Tag','DynV_Buf_Sel');
        mem_buffer      = get(DynV_Buf_Mem,'Userdata');
        DynV_Axe_Sel    = [];
        axe_hdls        = wmemutil('get',mem_buffer,2);    % DynV_Axe_Ind
        if mouseT==msel_txt
                % DynV_Axe_Act + DynV_Axe_Ind
                axe_hdls = [wmemutil('get',mem_buffer,4) , axe_hdls];
        else    % DynV_Axe_Cmd + DynV_Axe_Ind
                axe_hdls = [wmemutil('get',mem_buffer,3) , axe_hdls];
        end
        axe_hdls = findobj(axe_hdls,'flat','Visible','on');
        for i=1:length(axe_hdls)
                ax = axe_hdls(i);
                x  = get(ax,'XLim');
                y  = get(ax,'YLim');
                cp = get(ax,'CurrentPoint');
                q  = cp(1,1:2);
                if      (q(1)>min(x)) & (q(1)<max(x)) & ...
                        (q(2)>min(y)) & (q(2)<max(y))
                        DynV_Axe_Sel = ax;
                        break;
                end
        end
        set(DynV_Buf_Sel,'Userdata',DynV_Axe_Sel);
        if ~isempty(DynV_Axe_Sel)
                lin_handles   = findobj(fig,'Type','line');
                axe_del = [ findobj(lin_handles,'Tag','DynV_Sel_Box');  ...
                            findobj(lin_handles,'Tag','DynV_Line_Hor'); ...
                            findobj(lin_handles,'Tag','DynV_Line_Ver')];
                delete(axe_del)
                set(fig,'Pointer','crosshair','CurrentAxes',DynV_Axe_Sel);
                DynV_Btn_Xpos = findobj(txt_handles,'Tag','DynV_Btn_Xpos');
                DynV_Btn_Ypos = findobj(txt_handles,'Tag','DynV_Btn_Ypos');
                DynV_Col_Line = wmemutil('get',mem_buffer,1);

                %--- selection d'un rectangle ---%
                if mouseT==msel_box
                        set(DynV_Btn_Xpos,'String','X = ');
                        set(DynV_Btn_Ypos,'String','Y = ');
                        DynV_Sel_Box = line(...
                                'Color',DynV_Col_Line,...
                                'EraseMode','xor',...
                                'XData',[q(1) q(1) q(1) q(1) q(1)],...
                                'YData',[q(2) q(2) q(2) q(2) q(2)],...
                                'Tag','DynV_Sel_Box');

                %--- ecriture de la position ---%
                elseif mouseT==msel_txt
                        DynV_Line_Hor = line(...
                                'Color',DynV_Col_Line,...
                                'EraseMode','xor',...
                                'XData',[x(1) x(2)],...
                                'YData',[q(2) q(2)],...
                                'Tag','DynV_Line_Hor');
                        DynV_Line_Ver = line(...
                                'Color',DynV_Col_Line,...
                                'EraseMode','xor',...
                                'XData',[q(1) q(1)],...
                                'YData',[y(1) y(2)],...
                                'Tag','DynV_Line_Ver');
                        mempos_coor = get(DynV_Btn_Xpos,'UserData');
                        fcns_wri  = wmemutil('get',mempos_coor,1);
                        param_wri = wmemutil('get',mempos_coor,2);
                        if isempty(param_wri)
                           [sx,sy] = ...
                               feval(fcns_wri,q(1),q(2),DynV_Axe_Sel);
                        else
                           [sx,sy] =  ...
                               feval(fcns_wri,q(1),q(2),DynV_Axe_Sel,param_wri);
                        end
                        set(DynV_Btn_Xpos,'String',sx);
                        set(DynV_Btn_Ypos,'String',sy);

                %--- gestion des translations ---%
                elseif mouseT==msel_trans
                        set(DynV_Btn_Xpos,'String','X = ');
                        set(DynV_Btn_Ypos,'String','Y = ');
                        DynV_Line_Hor = line(...
                                'LineStyle','--',...
                                'Color',DynV_Col_Line,...
                                'EraseMode','xor',...
                                'XData',[x(1) q(1) x(2)],...
                                'YData',[q(2) q(2) q(2)],...
                                'Tag','DynV_Line_Hor');
                        DynV_Line_Ver = line(...
                                'LineStyle','--',...
                                'Color',DynV_Col_Line,...
                                'EraseMode','xor',...
                                'XData',[q(1) q(1) q(1)],...
                                'YData',[y(1) q(2) y(2)],...
                                'Tag','DynV_Line_Ver');
                        DynV_Flg_Trans = 0;
                        DynV_Buf_Tra = findobj(fig,'Style','edit',...
                                                'Tag','DynV_Buf_Tra');
                        set(DynV_Buf_Tra,'Userdata',DynV_Flg_Trans);
                end
                handles = num2mstr([DynV_Axe_Sel,DynV_Btn_Xpos,DynV_Btn_Ypos]);
                set(fig,'WindowButtonMotionFcn',...
                    ['mngmbtn(''move'',' sprintf('%0.f',fig) ',' handles ');']);
                set(fig,'WindowButtonUpFcn', ...
                    ['mngmbtn(''up'',' sprintf('%0.f',fig) ',' handles ');']);
        end

%*************************************************%
%** OPTION = 'up' UN BOUTON DE LA SOURIS APPUYE **%
%*************************************************%
elseif strcmp(option,'up')
        DynV_Axe_Sel    = in3(1);
        set(fig,'WindowButtonMotionFcn','','WindowButtonUpFcn','',...
                  'Pointer','arrow');
        mouse = get(fig,'SelectionType');
        mouseT = mouse(1);

        %--- gestion des translations ---%
        if mouseT==msel_trans
                lin_handles     = findobj(fig,'Type','line');
                DynV_Line_Hor   = findobj(lin_handles,'Tag','DynV_Line_Hor');
                DynV_Line_Ver   = findobj(lin_handles,'Tag','DynV_Line_Ver');
                txt_handles     = findobj(fig,'Style','text');
                DynV_Buf_Mem    = findobj(txt_handles,'Tag','DynV_Buf_Mem');
                DynV_Buf_Tra    = findobj(fig,'style','edit',   ...
                                                'Tag','DynV_Buf_Tra');
                DynV_Flg_Trans  = get(DynV_Buf_Tra,'Userdata');
                if DynV_Flg_Trans==1
                        x1 = get(DynV_Line_Hor,'XData');
                        x2 = get(DynV_Line_Ver,'XData');
                        dx = x2(2)-x1(2);
                end
                if DynV_Flg_Trans==2
                        y1 = get(DynV_Line_Hor,'YData');
                        y2 = get(DynV_Line_Ver,'YData');
                        dy = y2(2)-y1(2);
                end
                delete([DynV_Line_Hor,DynV_Line_Ver]);
                mem_buffer      = get(DynV_Buf_Mem,'Userdata');
                DynV_Axe_Ind    = wmemutil('get',mem_buffer,2);
                if ~isempty(find(DynV_Axe_Sel==DynV_Axe_Ind))
                        DynV_Axe_Act = DynV_Axe_Sel;
                        DynV_XY_Const = [0 0];
                else
                        DynV_Axe_Act    = wmemutil('get',mem_buffer,4);
                        DynV_XY_Const   = wmemutil('get',mem_buffer,5);
                end
                if DynV_Flg_Trans==1
                        x0 = get(DynV_Axe_Sel,'XLim');
                        if DynV_XY_Const(1)~=0
                                set(DynV_Axe_Act,'XLim',x0-dx);
                        else
                                set(DynV_Axe_Sel,'XLim',x0-dx);
                        end
                        dynvtool('put',fig);
                elseif DynV_Flg_Trans==2
                        y0 = get(DynV_Axe_Sel,'YLim');
                        if DynV_XY_Const(2)~=0
                                set(DynV_Axe_Act,'YLim',y0-dy);
                        else
                                set(DynV_Axe_Sel,'YLim',y0-dy);
                        end
                        dynvtool('put',fig);
                end

        %--- ecriture de la position ---%
%       elseif mouseT==msel_txt
%               lin_handles     = findobj(fig,'Type','line');
%               delete([findobj(lin_handles,'Tag','DynV_Line_Hor'),...
%                       findobj(lin_handles,'Tag','DynV_Line_Ver')]);

        end

%********************************************************%
%** OPTION = 'delbox' DESTRUCTION DU RECTANGLE DE ZOOM **%
%********************************************************%
elseif strcmp(option,'delbox')
        delete(findobj(fig,'Type','line','Tag','DynV_Sel_Box'));

%****************************************************%
%** OPTION = 'getbox' LECTURE DU RECTANGLE DE ZOOM **%
%****************************************************%
elseif strcmp(option,'getbox')
        DynV_Sel_Box    = findobj(fig,'Type','line','Tag','DynV_Sel_Box');
        if ~isempty(DynV_Sel_Box)
                out1 = get(DynV_Sel_Box,'XData');
                out2 = get(DynV_Sel_Box,'YData');
                if (min(out1)==max(out1)) | (min(out2)==max(out2))
                        delete(DynV_Sel_Box);
                        out1 = [];      out2 = [];
                end
        else
                out1 = [];      out2 = [];
        end

%****************************************************************%
%** OPTION = 'delline' DESTRUCTION DES LIGNES (trans. et pos.) **%
%****************************************************************%
elseif strcmp(option,'delline')
        lin_handles = findobj(fig,'Type','line');
        axe_del = [ findobj(lin_handles,'Tag','DynV_Line_Hor'); ...      
                    findobj(lin_handles,'Tag','DynV_Line_Ver')];
        delete(axe_del)

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('mngmbtn','Unknown Option','msg');
        error('*');
end
