function [out1,out2] = morlet(lb,ub,n)
%MORLET Morlet wavelet.
%       [PSI,X] = MORLET(LB,UB,N) returns values of 
%       the Morlet wavelet on a N points regular grid 
%       on the interval [LB,UB].
%       Output arguments are the wavelet function PSI
%       computed on the grid X, and the grid X.
%
%       This wavelet has [-4 4] as effective support.
%
%       See also WAVEINFO.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:13:47 $

%       Uses ERRARGN.

% Check arguments.
if errargn('morlet',nargin,[3],nargout,[0:2]), error('*'); end

% Compute values of the Morlet wavelet.
out2 = linspace(lb,ub,n);        % wavelet support.
out1 = exp(-(out2.^2)/2) .* cos(5*out2);
