function [l1,l2] = nancompl(a,b)
%NANCOMPL Complete with NaN. 
%       [L1,L2] = NANCOMPL(A,B) complete the shortest input 
%       matrix A or B such that output matrix L1 and L2 have 
%       the same number of columns. New elements are set 
%       to NaN.
%
%       If A and B are empty matrix then L1 = L2 = [NaN].

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:14:02 $

if isempty(a) , a = [NaN];   end
if isempty(b) , b = [NaN];   end
[n1,p1] = size(a);
[n2,p2] = size(b);
tmp     = NaN;
l1      = [a tmp(ones(n1,max([p1 p2])-p1))];
l2      = [b tmp(ones(n2,max([p1 p2])-p2))];
