function asc = nodeasc(tree,node,arg)
%NODEASC Node ascendants.
%       A = NODEASC(T,N) returns the indices of all ascendants
%       of the node N in the tree structure T.
%       N can be the index node or the depth and position of node. 
%       A is a column vector with A(1) = index of node N. 
%
%       A = NODEASC(T,N,'deppos') is a matrix which
%       contains the depths and positions of all ascendants.
%       A(i,1) is the depth of i-th ascendant and
%       A(i,2) is the position of i-th ascendant.
%
%       The nodes are numbered from left to right and
%       from top to bottom. The root index is 0.
%
%       See also MAKETREE, NODEDESC, NODEPAR, WTREEMGR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:14:07 $

%       Uses ERRARGN, ERRARGT, WTREEMGR.

% Check arguments.
if errargn('nodeasc',nargin,[2:3],nargout,[0:1]), error('*'); end

if find(wtreemgr('isnode',tree,node)==0)
        errargt('nodeasc','invalid node value','msg'); error('*');
end

if nargin==2
        asc = wtreemgr('nodeasc',tree,node);
else
        asc = wtreemgr('nodeasc',tree,node,arg);
end
