function desc = nodedesc(tree,node,arg)
%NODEDESC Node descendants.
%       D = NODEDESC(T,N) returns the indices of all the
%       descendants of the node N in the tree structure T.
%       N can be the index node or the depth and position of node. 
%       D is a column vector with D(1) = index of node N. 
%
%       D = NODEDESC(T,N,'deppos') is a matrix which
%       contains the depths and positions of all descendants.
%       D(i,1) is the depth of i-th descendant and
%       D(i,2) is the position of i-th descendant.
%
%       The nodes are numbered from left to right and
%       from top to bottom. The root index is 0.
%
%       See also MAKETREE, NODEASC, NODEPAR, WTREEMGR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:14:13 $

%       Uses ERRARGN, ERRARGT, WTREEMGR.

% Check arguments.
if errargn('nodedesc',nargin,[2:3],nargout,[0:1]), error('*'); end

if find(wtreemgr('isnode',tree,node)==0)
        errargt('nodedesc','invalid node value','msg'); error('*');
end

if nargin==2
        desc = wtreemgr('nodedesc',tree,node);
else
        desc = wtreemgr('nodedesc',tree,node,arg);
end
