function tree = nodejoin(tree,node)
%NODEJOIN Recompose node.
%       T = NODEJOIN(T,N) returns the modified tree structure T
%       corresponding to a recomposition of the node N.
%
%       The nodes are numbered from left to right and
%       from top to bottom. The root index is 0.
%
%       T = NODEJOIN(T) is equivalent to T = NODEJOIN(T,0).
%
%       See also MAKETREE, NODESPLT, WTREEMGR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:14:18 $

%       Uses DEPO2IND, WTREEMGR, WREV.

% Check arguments.
if errargn('nodejoin',nargin,[1 2],nargout,[0 1]), error('*'); end
if nargin == 1, node = 0; end

if wtreemgr('istnode',tree,node) , return; end

order     = wtreemgr('order',tree);
depth     = wtreemgr('depth',tree);
node      = depo2ind(order,node);
tab       = wtreemgr('table',tree,0);
[row,col] = find(tab==node);
icol      = find(col>2);
rec       = tab(row(icol),2:max(col(icol)));
rec       = rec(:);
rec       = rec(find(rec>node));

if length(rec>1);
        rec = sort(rec);
        K   = [1;find(diff(rec)~=0)+1];
        rec = rec(K);
end

rec    = wrev([node;rec])';
ord    = [1:order];
i_fils = order*(rec(ones(1,order),:))'+ ord(ones(1,length(rec)),:);

for k = 1:length(rec)
        for j = 1:order
                [r,c] = find(tab==i_fils(k,j));
                i_fils(k,j)  = min(r);        % indices
        end
end

nbinfo = size(tree,1)-1;
lrec   = length(rec);

for k = 1:lrec
        insert_st = [rec(k) nan*ones(1,order-1);zeros(nbinfo,order)];
        tree(:,i_fils(k,:)) = insert_st;
end

tree = tree(:,~isnan(tree(1,:)));
