function tree = nodesplt(tree,node)
%NODESPLT Split (decompose) node.
%       T = NODESPLT(T,N) returns the modified tree
%       structure T corresponding to the decomposition
%       of the node N.
%
%       The nodes are numbered from left to right and
%       from top to bottom. The root index is 0.
%
%       See also MAKETREE, NODEJOIN, WTREEMGR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:14:29 $

%       Uses ERRARGN, ERRARGT, DEPO2IND, WTREEMGR.

% Check arguments.
if errargn('nodesplt',nargin,[2],nargout,[0 1]), error('*'); end

node_rank = wtreemgr('istnode',tree,node);
if node_rank==0
        errargt('nodesplt','invalid node value','msg');       
        return
end

order   = wtreemgr('order',tree);
depth   = wtreemgr('depth',tree);
node    = depo2ind(order,node);
indord  = node*order;
nbinfo  = size(tree,1)-1;
ins_val = [indord+1:indord+order;zeros(nbinfo,order)];
tree    = wtreemgr('replace',tree,ins_val,node_rank,node_rank);
