function y = qmf(x,p)
%QMF    Quadrature mirror filter.
%       Y = QMF(X,P) changes the signs of the even index entries
%       of the reversed vector filter coefficients X if P is even.
%       If P is odd the same holds for odd index entries.
%
%       Y = QMF(X) is equivalent to Y = QMF(X,0).

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:15:47 $

%       Uses ERRARGN, ERRARGT, WREV.

% Check arguments.
if errargn('qmf',nargin,[1:2],nargout,[0:1]), error('*'), end
if nargin == 1 , p = 0; end
if errargt('qmf',p,'in0'), error('*'), end

% Compute quadrature mirror filter.
y = wrev(x);
l = length(y);
y(2:2:l) = -y(2:2:l);
if rem(p,2) , y = -y;   end
