function thr = thrwda1d(c,l,tptr,scal,n)
%THRWDA1D Thresholds for 1D Automatic De-noising using Wavelets.
%       THR = THRWDA1D(C,L,TPTR,SCAL,N) returns thresholds
%       used for automatic de-noising using wavelets.
%       See WDEN for inputs.
%       Output is such that THR(i) = threshold for level i.
%
%       See also WDEN.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:16:39 $

%       Uses ERRARGN, ERRARGT, WNOISEST, THSELECT.

% Check arguments.
if errargn('thrwda1d',nargin,[5],nargout,[0:1]), error('*'), end
if errargt('thrwda1d',tptr,'str'), error('*'), end
if errargt('thrwda1d',scal,'str'), error('*'), end
if errargt('thrwda1d',n,'int'), error('*'), end

% Threshold rescaling coefficients.
if strcmp(scal,'one'), s = ones(1,n);
elseif strcmp(scal,'sln'), s = ones(1,n)*wnoisest(c,l,1);
elseif strcmp(scal,'mln'), s = wnoisest(c,l,1:n);
else
errargt('thrwda1d','invalid argument value','msg'); error('*')
end

% Thresholds.
first = cumsum(l)+1; first = fliplr(first(1:length(first)-2));
ld  = l(length(l)-1:-1:2); last = first+ld-1;
thr = zeros(1,n);
for k = 1:n
        flk = first(k):last(k);
        if tptr=='sqtwolog' | tptr=='minimaxi'
                t = thselect(c,tptr);
        else
                if s(k) < sqrt(eps) * max(c(flk))
                        t = 0;
                else
                        t = thselect(c(flk)/s(k),tptr);
                end     
        end                                     % threshold.
        thr(k) = t * s(k);                      % rescaled threshold.
end


