function [tn,K] = tnodes(tree,arg)
%TNODES Terminal nodes.
%       N = TNODES(T) returns the indices of terminal nodes 
%       of the tree structure T (see MAKETREE). N is a column
%       vector. 
%
%       The nodes are numbered from left to right and
%       from top to bottom. The root index is 0.
%
%       N = TNODES(T,'deppos') returns a matrix N which
%       contains the depths and positions of terminal nodes.
%       N(i,1) is the depth of i-th terminal node and
%       N(i,2) is the position of i-th terminal node.
%
%       For [N,K] = TNODES(T) or [N,K] = TNODES(T,'deppos')
%       M = N(K) are the indices reordered as in tree T,
%       from left to right.
%
%       See also MAKETREE, WTREEMGR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:17:01 $

%       Uses ERRARGN, WTREEMGR.

% Check arguments.
if errargn('tnodes',nargin,[1:2],nargout,[0:2]), error('*'); end

if nargin==1
        [tn,K] = wtreemgr('tnodes',tree);
elseif nargin==2
        [tn,K] = wtreemgr('tnodes',tree,arg);
end
