function [out1,out2] = utsetcol(opt,in2,in3)
%UTSETCOL Utilities for Setting Color.
%       [out1,out2] = utsetcol(opt,in2)
%       opt = 'define' : Construction
%               in2  = [XLeft YDown] is optional
%               in3  = str_title is optional
%               out1 = Handles , out2 = Position
%
%       opt = 'get'   : get color
%               in2  = Handles
%               out1 = [R G B]
%
%       opt = 'set'   : set color
%               in2 = Handles
%               in3 = [R G B]
%
%       opt = 'pos'   : change position
%               in2  = [dx dy]
%               out1 = newpos
%
%       opt = 'change' & 'change_txt' : internal options.       

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:18:10 $

%       Uses ERRARGN, UTSETCOL.

% Handles = [   Sl_Color_R Rval_txt
%               Sl_Color_G Gval_txt
%               Sl_Color_B Bval_txt , ...
%               Frame_col  , hdls]
%
% Frame = hdls(1) , Large = 340 , Hight = 72

% Check arguments.
if errargn('utsetcol',nargin,[1:3],nargout,[0:2]), error('*'); end


if strcmp(opt,'change') | strcmp(opt,'change_txt') | strcmp(opt,'get')...
                        | strcmp(opt,'set')
        Sl_Color_R = in2(1); Rval_txt = in2(2);
        Sl_Color_G = in2(3); Gval_txt = in2(4);
        Sl_Color_B = in2(5); Bval_txt = in2(6);
        Frame_col  = in2(7);
end

%***********************%
%** OPTION = 'define' **%
%***********************%
if strcmp(opt,'define')
        if nargin<2
                xg = 10;        yb = 10;
                str_title = 'Color';
        elseif nargin<3
                xg = in2(1);    yb = in2(2);
                str_title = 'Color';
        else
                xg = in2(1);    yb = in2(2);
                str_title = in3;
        end
        Def_FraBkColor = [0.9 0.9 0.9];
        % Def_EdiBkColor = get(0,'DefaultUiCOntrolBackGroundcolor');
        Def_EdiBkColor = 'w';

        but_High       = 22;

        large = 120;
        ltxt  =  40;    htxt = but_High;
        ljg   =  15;    hjg  = 3*but_High;
        dx = 5;
        lcadre = 2*dx+6*dx+3*ltxt+3*ljg+large+3*dx;
        hcadre = 6+hjg;
        y = yb+3+but_High;

        out2 = [xg yb lcadre hcadre];

        hdls = zeros(1,6);
        hdls(1) = uicontrol('Style','Frame',...
                        'Position',[xg yb lcadre hcadre]);
        col = get(hdls(1),'BackGroundColor');

        xg = xg+2*dx;
        hdls(2) = uicontrol('Style','Frame',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[xg y+but_High-5 large but_High]);
        hdls(3) = uicontrol('Style','Text',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[xg+3 y+but_High-2 large-6 but_High-6],...
                        'HorizontalAlignment','center',...
                        'String',str_title);

        Frame_col = uicontrol('Style','Frame',...
                        'Position',[xg y-but_High+5 large htxt]);
        xg = xg+large+2*dx;
        hdls(4) = uicontrol('Style','Text',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[xg y+20 ltxt htxt],...
                        'String','R');
        Rval_txt = uicontrol('Style','Edit',...
                        'BackGroundColor',Def_EdiBkColor,       ...
                        'Position',[xg y-20 ltxt htxt],         ...
                        'String','');
        xg = xg+ltxt+dx;
        Sl_Color_R = uicontrol('Style','Slider',...
                        'Position',[xg yb+3 ljg hjg]);

        xg = xg+ljg+dx;
        hdls(5) = uicontrol('Style','Text',...
                        'BackGroundColor',Def_FraBkColor,       ...
                        'Position',[xg y+20 ltxt htxt],         ...
                        'String','G');
        Gval_txt = uicontrol('Style','Edit',...
                        'BackGroundColor',Def_EdiBkColor,       ...
                        'Position',[xg y-20 ltxt htxt],         ...
                        'String','');
        xg = xg+ltxt+dx;
        Sl_Color_G = uicontrol('Style','Slider',...
                        'Position',[xg yb+3 ljg hjg]);

        xg = xg+ljg+dx;
        hdls(6) = uicontrol('Style','Text',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[xg,y+20,ltxt htxt],...
                        'String','B');
        Bval_txt = uicontrol('Style','Edit',...
                        'BackGroundColor',Def_EdiBkColor,       ...
                        'Position',[xg y-20 ltxt htxt], ...
                        'String','');
        xg = xg+ltxt+dx;
        Sl_Color_B = uicontrol('Style','Slider',...
                        'Position',[xg yb+3 ljg hjg]);

        out1 = [Sl_Color_R , Rval_txt , ...
                Sl_Color_G , Gval_txt , ...
                Sl_Color_B , Bval_txt , ...
                Frame_col  , hdls];

        action = ['utsetcol(''change'',' num2mstr(out1) ');'];
        set(Sl_Color_R,'CallBack',action);
        set(Sl_Color_G,'CallBack',action);
        set(Sl_Color_B,'CallBack',action);
        set(Sl_Color_R,'Value',col(1));
        set(Sl_Color_G,'Value',col(2));
        set(Sl_Color_B,'Value',col(3));
        action = ['utsetcol(''change_txt'',' num2mstr(out1) ');'];
        set(Rval_txt,'CallBack',action);
        set(Gval_txt,'CallBack',action);
        set(Bval_txt,'CallBack',action);
        eval(get(Sl_Color_R,'Callback'));

%************************%
%** OPTION = 'set'    **%
%************************%
elseif strcmp(opt,'set')
        set(Sl_Color_R,'Value',in3(1));
        set(Sl_Color_G,'Value',in3(2));
        set(Sl_Color_B,'Value',in3(3));
        utsetcol('change',in2);

%************************%
%** OPTION = 'change'  **%
%************************%
elseif strcmp(opt,'change')
        R  = get(Sl_Color_R,'Value');
        txt = sprintf('%4.2f',R);
        set(Rval_txt,'String',txt);
        G  = get(Sl_Color_G,'Value');
        txt = sprintf('%4.2f',G);
        set(Gval_txt,'String',txt);
        B  = get(Sl_Color_B,'Value');
        txt = sprintf('%4.2f',B);
        set(Bval_txt,'String',txt);
        set(Frame_col,'BackGroundColor',[R G B]);

%****************************%
%** OPTION = 'change_txt'  **%
%****************************%
elseif strcmp(opt,'change_txt')
        Rs = get(Sl_Color_R,'Value');
        R = get(Rval_txt,'String');
        R = str2num(R);
        if isempty(R), R = Rs ; elseif (R<0) | (R>1) , R = Rs ; end

        Gs = get(Sl_Color_G,'Value');
        G = get(Gval_txt,'String');
        G = str2num(G);
        if isempty(G), G = Gs ; elseif (G<0) | (G>1) , G = Gs ; end

        Bs = get(Sl_Color_B,'Value');
        B = get(Bval_txt,'String');
        B = str2num(B);
        if isempty(B), B = Bs ; elseif (B<0) | (B>1) , B = Bs ; end

        txt = sprintf('%4.2f',R);
        set(Rval_txt,'String',txt);
        set(Sl_Color_R,'Value',R);

        txt = sprintf('%4.2f',G);
        set(Gval_txt,'String',txt);
        set(Sl_Color_G,'Value',G);

        txt = sprintf('%4.2f',B);
        set(Bval_txt,'String',txt);
        set(Sl_Color_B,'Value',B);

        set(Frame_col,'BackGroundColor',[R G B]);

%**********************%
%** OPTION = 'get'  **%
%**********************%
elseif strcmp(opt,'get')
        out1(1) = get(Sl_Color_R,'Value');
        out1(2) = get(Sl_Color_G,'Value');
        out1(3) = get(Sl_Color_B,'Value');

%**********************%
%** OPTION = 'pos'  **%
%**********************%
elseif strcmp(opt,'pos')
        dx = in3(1);    dy = in3(2);
        set(in2,'Visible','Off');
        for k = 1:length(in2)
                pos  = get(in2(k),'Position');
                npos = [pos(1)+dx pos(2)+dy pos(3:4)];
                set(in2(k),'Position',npos);
        end
        set(in2,'Visible','On');
        out1 = get(in2(8),'Position');  % in2(8) = hdls(1) is the Frame
end
