function [out1,out2,out3,out4] = utsetfon(opt,in2,in3,in4,in5,in6)
%UTSETFON Utilities for Setting Fonts.
%       [out1,out2,out3,out4] = utsetfon(opt,in2,in3,in4,in5,in6)
%
%       opt = 'define' : Construction
%               in2  = [XLeft YDown] is optional
%               out1 = Handles , out2 = Position
%
%       opt = 'read'   : read font parameters of an object
%               in2  = Handles
%               in3  = Object handle
%
%       opt = 'write'  : set font parameters of an object
%               in2  = Handles
%               in3  = Object handle
%
%       opt = 'get'   : get font parameters
%               in2  = Handles
%               out1 = Font Name        out2 = Font Size
%               out3 = Font Weight      out4 = Font Angle
%
%       opt = 'set'   : set font parameters
%               in2 = Handles
%               in3 = Font Name         in4 = Font Size
%               in5 = Font Weight       in6 = Font Angle
%
%       opt = 'pos'   : change position
%               in2  = [dx dy]
%               out1 = newpos

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:18:22 $

%       Uses ERRARGN, UTSETFON.

% Handles = [  Ed_font_name
%              Ed_font_size
%              Pop_font_weight
%              Pop_font_angle  hdls ];
%
% Frame = hdls(1) , Large = 340 , Hight = 86

% Check arguments.
if errargn('utsetfon',nargin,[1:6],nargout,[0:4]), error('*'); end

if strcmp(opt,'change') | strcmp(opt,'get') | strcmp(opt,'set') ...
                        | strcmp(opt,'read') | strcmp(opt,'write')
        Ed_font_name    = in2(1);
        Ed_font_size    = in2(2);
        Pop_font_weight = in2(3);
        Pop_font_angle  = in2(4);
end

%***********************%
%** OPTION = 'define' **%
%***********************%
if strcmp(opt,'define')
        if nargin<2
                xg = 10;        yb = 10;
        else
                xg = in2(1);    yb = in2(2);
        end

        Def_FraBkColor = [0.9 0.9 0.9];
        % Def_EdiBkColor = get(0,'DefaultUiCOntrolBackGroundcolor');
        Def_EdiBkColor = 'w';
        but_High   = 22;
        large1 =  90;   large2 = 65;    large3 = 225;
        dx = 5;         dy = 5;
        lcadre = 340;   hcadre = 3*but_High+4*dy;
        out2 = [xg yb lcadre hcadre];

        hdls = zeros(1,9);
        hdls(1) = uicontrol('Style','Frame',...
                        'Position',[xg yb lcadre hcadre]);
        xg = xg+2*dx;
        yb = yb+dy;
        hdls(2) = uicontrol('Style','Frame',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[large1+large2 yb large1 but_High]);
        hdls(3) = uicontrol('Style','Text',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[large1+large2+3,yb+3,large1-6,but_High-6],...
                        'String','Angle');
        Pop_font_angle = uicontrol('Style','Popup',...
                        'Position',[large1+dx+large1+large2,yb,large1,but_High],...
                        'String','normal|italic|oblique');

        yb = yb+dy+but_High;
        hdls(4) = uicontrol('Style','Frame',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[xg yb large2 but_High]);
        hdls(5) = uicontrol('Style','Text',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[xg+3,yb+3,large2-6,but_High-6],...
                        'String','Size');
        Ed_font_size = uicontrol('Style','Edit',...
                        'BackGroundColor',Def_EdiBkColor,...
                        'Position',[xg+dx+large2,yb,50,but_High]);


        hdls(6) = uicontrol('Style','Frame',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[large1+large2 yb large1 but_High]);
        hdls(7) = uicontrol('Style','Text',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[large1+large2+3,yb+3,large1-6,but_High-6],...
                        'String','Weight');
        Pop_font_weight = uicontrol('Style','Popup',...
                        'Position',[large1+dx+large2+large1,yb,large1,but_High],...
                        'String','light|normal|demi|bold');

        yb = yb+dy+but_High;
        hdls(8) = uicontrol('Style','Frame',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[xg yb large1 but_High]);
        hdls(9) = uicontrol('Style','Text',...
                        'BackGroundColor',Def_FraBkColor,...
                        'Position',[xg+3,yb+3,large1-6,but_High-6],...
                        'String','Font name');
        Ed_font_name = uicontrol('Style','Edit',...
                        'BackGroundColor',Def_EdiBkColor,...
                        'Position',[xg+dx+large1,yb,large3,but_High]);

        out1 = [Ed_font_name Ed_font_size Pop_font_weight Pop_font_angle hdls];

%************************%
%** OPTION = 'read'    **%
%************************%
elseif strcmp(opt,'read')
        set(Ed_font_name,'String',get(in3,'FontName'));
        set(Ed_font_size,'String',int2str(get(in3,'FontSize')));
        s = get(in3,'FontWeight');
        if strcmp(s,'light')
                set(Pop_font_weight,'Value',1);
        elseif strcmp(s,'normal')
                set(Pop_font_weight,'Value',2);
        elseif strcmp(s,'demi')
                set(Pop_font_weight,'Value',3);
        else
                set(Pop_font_weight,'Value',4);
        end
        s = get(in3,'FontAngle');
        if strcmp(s,'normal')
                set(Pop_font_angle,'Value',1);
        elseif strcmp(s,'italic')
                set(Pop_font_angle,'Value',2);
        else
                set(Pop_font_angle,'Value',3);
        end

%************************%
%** OPTION = 'write'   **%
%************************%
elseif strcmp(opt,'write')
        set(in3,'FontName',get(Ed_font_name,'String'));
        set(in3,'FontSize',str2num(get(Ed_font_size,'String')));
        fb = str2mat('light','normal','demi','bold');
        set(in3,'FontWeight',fb(get(Pop_font_weight,'Value'),:));
        fi = str2mat('normal','italic','oblique');
        set(in3,'FontAngle',fi(get(Pop_font_angle,'Value'),:));

%************************%
%** OPTION = 'set'    **%
%************************%
elseif strcmp(opt,'set')
        set(Ed_font_name,'String',in3);
        set(Ed_font_size,'String',int2str(in4));
        set(Pop_font_weight,'Value',in5);
        set(Pop_font_angle,'Value',in6);

%**********************%
%** OPTION = 'get'  **%
%**********************%
elseif strcmp(opt,'get')
        out1 = get(Ed_font_name,'String');
        out2 = str2num(get(Ed_font_size,'String'));
        out3 = get(Pop_font_weight,'Value');
        out4 = get(Pop_font_angle,'Value');

%**********************%
%** OPTION = 'pos'  **%
%**********************%
elseif strcmp(opt,'pos')
        dx = in3(1);    dy = in3(2);
        set(in2,'Visible','Off');
        for k = 1:length(in2)
                pos  = get(in2(k),'Position');
                npos = [pos(1)+dx pos(2)+dy pos(3:4)];
                set(in2(k),'Position',npos);
        end
        set(in2,'Visible','On');
        out1 = get(in2(5),'Position');  % in2(5) = hdls(1) is the Frame
end
