function waveinfo(wav)
%WAVEINFO Information on wavelets.
%       WAVEINFO gives information on all wavelets.
%
%       WAVEINFO('wname') gives information on the wavelet
%       family which short name is specified
%       by the string 'wname'.
%
%       Available family short names are:
%               'haar'   : haar wavelet.
%               'db'     : Daubechies wavelets.
%               'sym'    : symlets.
%               'coif'   : coiflets.
%               'bior'   : biorthogonal wavelets.
%               'meyr'   : Meyer wavelet.
%               'mexh'   : mexican hat wavelet.
%               'morl'   : Morlet wavelet.
%
%       or user-defined short names for their own wavelet
%       families (see WAVEMNGR).
%
%       WAVEINFO('wsys') gives information on wavelet packets.
%
%       See also WAVEMNGR.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:19:21 $

if      nargin==0
        help infowave
elseif  strcmp(wav,'wsys')
        help infowsys
else
        ind = wavemngr('indf',wav);
        if isempty(ind)
                msg = ['invalid wavelet family short name : ' wav];
                errargt('waveinfo',msg,'msg');
        else
                eval(['help ' wav 'info'])
        end
end
