function x = waverec2(c,s,arg3,arg4)
%WAVEREC2  Multi-level 2-D wavelet reconstruction.
%       WAVEREC2 performs a multi-level 2-D wavelet reconstruction
%       using either a specific wavelet ('wname', see WFILTERS) or
%       specific reconstruction filters (Lo_R and Hi_R).
%
%       X = WAVEREC2(C,S,'wname') reconstructs the matrix X
%       based on the multi-level wavelet decomposition structure
%       [C,S] (see WAVEDEC2).
%
%       For X = WAVEREC2(C,S,Lo_R,Hi_R),
%       Lo_R is the reconstruction low-pass filter and
%       Hi_R is the reconstruction high-pass filter.
%
%       See also APPCOEF2, IDWT2, WAVEDEC2.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:19:47 $

%       Uses APPCOEF2.

% Check arguments.
if errargn('waverec2',nargin,[3:4],nargout,[0:1]), error('*'), end

if nargin==3
        x = appcoef2(c,s,arg3,0);
else
        x = appcoef2(c,s,arg3,arg4,0);
end
