function y = wcodemat(x,nb,opt,absol)
%WCODEMAT Extended pseudocolor matrix scaling. 
%       Y = WCODEMAT(X,NB,OPT,ABSOL) returns a coded version 
%       of input matrix X if ABSOL=0, or ABS(X) if ABSOL is 
%       nonzero, using the first NB integers. 
%       Coding can be done rowwise (OPT='row'), columnwise 
%       (OPT='col') or globally (OPT='mat'). 
%       Coding uses a regular grid between the minimum and 
%       the maximum values of each row (column or matrix,
%       respectively).
%
%       Y = WCODEMAT(X,NB,OPT) is equivalent to
%           Y = WCODEMAT(X,NB,OPT,1).
%       Y = WCODEMAT(X,NB) is equivalent to
%           Y = WCODEMAT(X,NB,'mat',1).
%       Y = WCODEMAT(X) is equivalent to
%           Y = WCODEMAT(X,16,'mat',1).

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:20:21 $

% Check arguments.
if errargn('wcodemat',nargin,[1 2 3 4],nargout,[0 1]), error('*'), end

if nargin==1
        nb = 16;        opt = 'mat';    absol = 1;
elseif nargin==2
        opt = 'mat';    absol = 1;
elseif nargin==3
        absol = 1;
end
opt = lower(opt);

trans = 0;
if strcmp(opt,'row')
        trans = 1;
        opt = 'col';
        x = x';
end
[t1,t2] = size(x);
if absol
        x = abs(x);
end
if strcmp(opt,'mat')
        minx = min(min(x));
        x = (x - minx*ones(t1,t2));
        maxx  = max(max(x));
        if maxx<eps
                y = ones(t1,t2);
                return;
        else
                y = fix(1 + (nb*x)/maxx);
                y = y(:);
        end
elseif strcmp(opt,'col')
        minx  = min(x); 
        x = (x - minx(ones(1,t1),:));
        maxx  = max(x);
        echel = maxx(ones(1,t1),:);
        x = x(:);
        echel = echel(:);
        indexs = find(echel>eps);
        y = ones(t1*t2,1);
        y(indexs) = fix(y(indexs) + nb*x(indexs)./echel(indexs));
else
        error('*** wcodemat : Unknown Option ***');
end

indexs    = find(y>nb);
y(indexs) = nb*ones(size(indexs));
y = reshape(y,t1,t2);
if trans, y = y'; end
