function [xind,yind] = wcommon(x,y)
%WCOMMON Find common elements.
%       For two vectors X and Y with integer components,
%       [XI,YI] = WCOMMON(X,Y) returns two vectors
%       with 0 and 1 components such that:
%       XI(k) = 1 if X(k) belongs to Y otherwise XI(k) = 0 and 
%       YI(j) = 1 if Y(j) belongs to X otherwise YI(j) = 0.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:20:27 $

% Check arguments.
if errargn('wcommon',nargin,[2],nargout,[0:2]), error('*'); end

if isempty(x) | isempty(y)
        xind = zeros(size(x));
        yind = zeros(size(y));
        return;
end
[xx,ix]  = sort(x(:));
[nul,ix] = sort(ix);
[yy,iy]  = sort(y(:));
[nul,iy] = sort(iy);
delta    = min(xx(1),yy(1))-1;
xx = xx-delta;
yy = yy-delta;

dx = [1;diff(xx(:))];
zx = find(dx==0);
dy = [1;diff(yy(:))];
zy = find(dy==0);

if length(zx)>0
        nzx = find(dx>0);
        xx(zx) = [];
end
if length(zy)>0
        nzy = find(dy>0);
        yy(zy) = [];
end
ma = max(xx(length(xx)),yy(length(yy)));
S  = sparse(ma,1);
S(xx)  = ones(size(xx));
S(yy)  = S(yy)+ones(size(yy));
xind = S(xx)-1;
yind = S(yy)-1;

if length(zx)>0
        tmp = zeros(size(ix));
        tmp(nzx)= xind;
        for k=1:length(zx)
                j = zx(k);
                tmp(j) = tmp(j-1);
        end
        xind = tmp;
end
if length(zy)>0
        tmp = zeros(size(iy));
        tmp(nzy)= yind;
        for k=1:length(zy)
                j = zy(k);
                tmp(j) = tmp(j-1);
        end

        yind = tmp;
end
xind = xind(ix);
yind = yind(iy);
if size(x,1)==1, xind = xind'; end
if size(y,1)==1, yind = yind'; end
