function [out1,out2,out3,out4] = wfigcrea(option,in2,in3,in4,in5,in6,in7)
%WFIGCREA Utilities for creating figures.
     
%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:21:17 $


% Test option before creating.
%-----------------------------
if strcmp(option,'test')
        out1 = 1; out2 = in2; out3 = in3;
        if ~isstr(in2)
                out2  = 'create'; out3 = in2; 
        end
        if strcmp(out2,'ini')
                wglobals('ini',out3);
                out1 = 0;
        end
        return
end

global  Mat_Version     ShiftTop_Fig    ...
        Def_Btn_Height  Def_Btn_Width   Pop_Min_Width   ...
        X_Spacing       Y_Spacing       X_Graph_Ratio   ...
        Def_FraBkColor  Def_FraFgColor

% Tag property of objects.
%-------------------------
tag_cmd_frame   = 'Cmd_Frame';

if strcmp(option,'create')
        % in2 = init parameter
        %   if in2 = NaN, no init is done 
        % in3 = win_name
        % in4 = tag (optional)
        % in5 = userdata (optional)
        % in6 = extmode (number or strmat)
        %   
        % in7 = closemode (strmat)
        %   if size(in7,1) = 2 , conditional close 
        %-----------------------------------------
        % out1 = win_hld
        % out2 = pos_win
        % out3 = cba_close
        %-------------------------
        if     nargin<4 , in4 = ''; in5 = ''; in6 = ''; in7 = '';
        elseif nargin<5 , in5 = ''; in6 = ''; in7 = '';
        elseif nargin<6 , in6 = ''; in7 = '';
        elseif nargin<7 , in7 = '';
        end

        % Global variables initialization.
        %---------------------------------
        if isnan(in2) , else , wglobals('ini',in2); end

        % Creating extended figure.
        %--------------------------
        win_units   = 'pixels';
        Screen_Size = get(0,'ScreenSize');
        win_height  = 21*Def_Btn_Height+45*Y_Spacing;
        cmd_width   = Def_Btn_Width+2*Pop_Min_Width+6*X_Spacing;
        win_width   = round(cmd_width/(1-X_Graph_Ratio));
        left_win    = Screen_Size(3)-5-win_width;
        down_win    = Screen_Size(4)-win_height-ShiftTop_Fig;
        pos_win     = [left_win,down_win,win_width,win_height];
        win_hld     = mngfig('create',in3,pos_win,win_units);
        set(win_hld,'tag',in4,'userdata',in5);

        out1 = win_hld;
        out2 = pos_win;
        out3 = '';

        % Figure Extension (add menus).
        %-----------------------------
        if ~isempty(in6)
                if isstr(in6)
                        extfig(win_hld,in6(1,:),in6(2,:),in6(3,:));     
                else
                        extfig(win_hld,in6);
                end
        end
        if ~isempty(in7)
                namefunc = deblank(in7(1,:));
                if size(in7,1)==2
                   out3 = mngfig('attach_close',win_hld,namefunc,'cond');
                else
                   out3 = mngfig('attach_close',win_hld,namefunc);      
                end
        end

elseif strcmp(option,'frame')
        % in2 = win_hdl
        % in3 = dynvisu (optional)
        % in4 = txttitl (optional)
        %-------------------------
        % out1 = frame_hdl
        % out2 = frame_pos
        % out3 = graphic_area
        %-------------------------
        if     nargin<3 , in3 = ''; in4 = '';
        elseif nargin<4 , in4 = '';
        end
        cmd_width  = Def_Btn_Width+2*Pop_Min_Width+6*X_Spacing;
        win_units  = 'pixels';
        pos_win    = get(in2,'Position');
        x_frame    = pos_win(3)-cmd_width+1;
        pos_frame  = [x_frame,0,cmd_width,pos_win(4)+5];
        figure(in2);
        out1       = uicontrol(...
                                   'Parent',in2,                   ...
                                   'Style','frame',                ...
                                   'Unit',win_units,               ...
                                   'Position',pos_frame,          ...
                                   'Backgroundcolor',Def_FraBkColor,...
                                   'Foregroundcolor',Def_FraFgColor,...
                                   'Tag',tag_cmd_frame             ...
                                    );
        if ~isempty(in3)
                % Dynamic visualization tool.
                %----------------------------
                pos_dyn_visu = dynvtool('create',in2,X_Graph_Ratio);
                ylow = pos_dyn_visu(4);
                out3 = [0,pos_dyn_visu(4),x_frame,pos_win(4)-ylow];
        else
                out3 = [0,0,x_frame,pos_win(4)];
        end
        out2 = pos_frame;
        if ~isempty(in4)
            % Figure Title.
            %--------------
            wfigtitl('set',in2,X_Graph_Ratio,'','off',Def_FraBkColor);
        end
        drawnow
end
