function hval = wgethist(signal,nbbar)
%WGETHIST Build values to plot histogram.
%       P = WGETHIST(X,N) returns a 2xN matrix
%       X is a vector or a matrix.
%       N is the number of bins.
%       P(1,:)  = X coordinates of points of histogram.
%       P(2,:)  = Y coordinates of points of histogram.
%
%       P = WGETHIST(X) is equivalent to P = WGETHIST(X,10)
%
%       See also WIMGHIST.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:21:57 $

%       Uses WIMGHIST.

sig_len = length(signal);
if sig_len==0, hval = []; return; end
if nargin==1
        nbbar = 10;
else
        nbbar = fix(nbbar);
        if nbbar<2 , nbbar = 10; end
end
[n,x]   = wimghist(signal,nbbar);
if max(x)==min(x)
        nn      = (nbbar-1)/2;
        n       = [zeros(1,floor(nn)) n(1) zeros(1,ceil(nn))];
        y       = [1:length(n)];
        x       = y-y(floor(nn)+1)+x(1);
end
d       = diff(x)/2;
d       = [d d(1)];
xs      = [x-d;x-d;x+d;x+d];
ns      = zeros(size(xs));
ns(2:3,:) = [n;n];
xs      = xs(:)';
ns      = ns(:)';
hval    = [xs;ns];
