function y = wkeep(x,arg2,arg3)
%WKEEP  Keep part of a vector or a matrix.
%       For a vector, Y = WKEEP(X,L,O) extracts the vector Y 
%       from the vector X. L is the length of result Y.
%       If O = 'c' ('l' , 'r' respectively), Y is the central
%       (left, right respectively) part of X.
%
%       Y = WKEEP(X,L) is equivalent to Y = WKEEP(X,L,'c').
%
%       For a matrix, Y = WKEEP(X,S) extracts the central 
%       part of the matrix X. S is the size of Y.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:22:46 $

%       Uses ERRARGN, ERRARGT.

% Check arguments.
if errargn('wkeep',nargin,[2:3],nargout,[0:1]), error('*'), end

[r,c] = size(x);
y = x;
if min(r,c)<=1
        lx = length(x);         l  = arg2;
        if (l>=0) & (l<lx) & (l == fix(l))
                if nargin==2, o = 'c'; else , o = lower(arg3(1)); end
                if o=='c'
                        d = (lx-l)/2;   y = y(1+floor(d):lx-ceil(d));
                elseif o=='l',  y = y(1:l);
                elseif o=='r' , y = y(lx-l+1:lx);
                else
                        errargt('wkeep','invalid argument','msg');error('*');
                end
        end
else
        sx = size(x);   s = arg2(:)';
        K  = find(s>sx);
        s(K) =sx(K);
        m = find((s < 0) | (s ~= fix(s)));
        if isempty(m)
                ss = (sx-s)/2;
                first = 1+floor(ss);
                last  = sx-ceil(ss);    
                y = y(first(1):last(1),first(2):last(2));
        end
end
