function lev = wmaxlev(sizeX,wname);
%WMAXLEV Maximum wavelet decomposition level.
%       WMAXLEV can help you avoid unreasonable maximum level value.
%
%       L = WMAXLEV(S,'wname') returns the maximum level
%       decomposition of signal or image of size S using wavelet
%       named in the string 'wname' (see WFILTERS).
%
%       WMAXLEV gives the maximum allowed level decomposition,
%       but in general, a smaller value is taken.
%       Usual values are 5 for the 1-D case and 3 for the 2-D case.
%
%       See also WAVEDEC, WAVEDEC2, WPDEC, WPDEC2.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:23:05 $

%       Uses DEBLANKL, WAVEMNGR, WFILTERS.

% Check arguments.
if errargn('wmaxlev',nargin,[2],nargout,[0 1]), error('*'); end

if      isempty(sizeX)
        lev = [];
        return;
elseif  length(sizeX)==1
        lx = sizeX;
elseif  min(sizeX)==1
        lx = max(sizeX);
else
        lx = min(sizeX);
end

wname = deblankl(wname);
wtype = wavemngr('type',wname);
if        wtype==1 | wtype==2
        LoF_D = wfilters(wname);
        lw = length(LoF_D);
elseif        wtype==3 | wtype==4
        [lb,ub] = wavemngr('user',wname);
        lw = ub-lb+1;
else
        errargt('wmaxlev','invalid argument','msg'); error('*');
end

% the rule is the last level for which at least one coefficient 
% is correct : (lw-1)*(2^lev) < lx

lev = fix(log(lx/(lw-1))/log(2));
if lev<1 , lev = 0; end
