function [out1,out2,out3,out4,out5,out6,out7,out8,out9,out10,out11,out12] = ...
                        wmemtool(option,in2,                            ...
                                in3,in4,in5,in6,in7,in8,in9,in10,       ...
                                in11,in12,in13,in14,in15,in16,in17,     ...
                                in18,in19,in20,in21,in22,in23,in24,in25)
%WMEMTOOL Manage memory tool.
%
%       out1 = wmemtool(option,in2,in3,in4,in5)
%
%       GENERAL BUFFER OPTIONS :
%               'handle' , 'create' , 'close', 'empty' ,
%               'bput', 'bget', 'bdel', 'find'.
%  
%       hdl = wmemtool('handle')
%       hdl = wmemtool('create')
%       wmemtool('close')
%       wmemtool('empty')
%       wmemtool('bput',name,val) or wmemtool('bput',name,val,strinfo)
%       creates if buffer is not found.
%       val = wmemtool('bget',name,strinfo)
%               returns [] if variable named "name" is not found.
%       wmemtool('bdel',name,val) or wmemtool('bdel',name,val,strinfo)
%       rep = wmemtool('find') returns 1 if buffer exists else
%                       0 is returned.
%
%       BUFFER IN A FIGURE OPTIONS :
%               'ini' , 'put' , 'get' , 'del'
%               'def' , 'write', 'read'
%
%       wmemtool('put',fig,name,val) or
%       wmemtool('put',fig,name,val,strinfo)
%               puts in figure.
%       val = wmemtool('get',fig,name,strinfo)
%               returns [] if variable named "name" is not found.
%       wmemtool('del',fig,name,val) or
%       wmemtool('del',fig,name,val,strinfo)
%
%       wmemtool('ini',fig,blocname,nbval),
%       wmemtool('wmb',fig,blocname,ind1,v1,...,ind12,v12),
%       [v1,..v12] = wmemtool('rmb',fig,blocname,ind1,...,ind12),
%       with : vj = jth value and indj = jth index in the MemBloc.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:23:12 $

%       Uses WMEMTOOL, WGLOBALS.

% Tag for GENERAL BUFFER.
%------------------------
tag_mem         = 'Fig_Mem_Buffer';
tag_axe_mem     = 'Axe_Mem_Buffer';


opt = option(1:3);

%-----------------------------%
%                             %
%  BUFFER IN A FIGURE OPTIONS %
%                             %
%-----------------------------%

%*******************************************%
%** OPTION = 'rmb' - reading in MemBloc. **%
%*******************************************%
if      opt=='rmb'
        % win_handle = in2
        % bloc_name  = in3
        % if nargin>3 , for k= 1...N , N <=12
        % in(k+3) index and out(k) value.
        %--------------------------------------
        wins = get(0,'children');
        if isempty(find(in2==wins)) , return; end
        axe_mem = findobj(in2,'type','axes','tag',tag_axe_mem);
        txt_mem = findobj(get(axe_mem,'Children'),'type','text');
        for k = 4:nargin
                ind     = eval(sprintf('in%.0f',k));
                t       = findobj(txt_mem,'tag',[in3 '.' int2str(ind)]);
                eval([sprintf('out%.0f',k-3) '= get(t,''Userdata'');']);
        end

%******************************************%
%** OPTION = 'wmb' - writing in MemBloc. **%
%******************************************%
elseif  opt=='wmb'
        % win_handle = in2
        % bloc_name  = in3
        % for k= 1...N , N <=12 
        % in(2k+2) index and in(2k+3) value
        %---------------------------------
        wins = get(0,'children');
        if isempty(find(in2==wins)) , return; end
        axe_mem = findobj(in2,'type','axes','tag',tag_axe_mem);
        txt_mem = findobj(get(axe_mem,'Children'),'type','text');
        for k = 4:2:nargin
                ind     = eval(sprintf('in%.0f',k));
                t       = findobj(txt_mem,'tag',[in3 '.' int2str(ind)]);
                set(t,'Userdata',eval(sprintf('in%.0f',k+1)));
        end

%***********************%
%** OPTION = 'put' -  **%
%***********************%
elseif  opt=='put'
        %------------------------------%
        % fig  = in2                   %
        % name = in3                   %
        % val  = in4                   %
        % in5 optional string value    %
        %------------------------------%
        wins = get(0,'children');
        if isempty(find(in2==wins)) , return; end
        if nargin==4
                t = findobj(in2,'style','text','Tag',in3);
                in5 = '';
        elseif nargin==5
                t = findobj(in2,'style','text','Tag',in3,'string',in5);
        end
        if isempty(t)
                t = uicontrol(...
                                'parent',in2,   ...
                                'Style','text', ...
                                'Visible','off',...
                                'String',in5,   ...
                                'Userdata',in4, ...
                                'Tag',in3);
        else
                set(t,'Userdata',in4);
        end

%***********************%
%** OPTION = 'get' -  **%
%***********************%
elseif  opt=='get'
        %------------------------------%
        % fig  = in2                   %
        % name = in3                   %
        % in4 optional string value    %
        %------------------------------%
        wins = get(0,'children');
        if isempty(find(in2==wins)) , out1 = []; return; end
        if nargin==3
                t = findobj(in2,'style','text','Tag',in3);
        elseif nargin==4
                t = findobj(in2,'style','text','Tag',in3,'string',in4);
        end
        if ~isempty(t) , out1 = get(t,'Userdata'); else , out1 = []; end

%***********************%
%** OPTION = 'del' -  **%
%***********************%
elseif  opt=='del'
        %------------------------------%
        % fig  = in2                   %
        % name = in3                   %
        % in4 optional string value    %
        %------------------------------%
        wins = get(0,'children');
        if isempty(find(in2==wins)) , out1 = []; return; end
        if nargin==3
                t = findobj(in2,'style','text','Tag',in3);
        elseif nargin==4
                t = findobj(in2,'style','text','Tag',in3,'string',in4);
        end
        delete(t);

%********************************************%
%** OPTION = 'write' - writing in MemBloc. **%
%********************************************%
elseif  opt=='wri'
        % win_handle = in2
        % bloc_name  = in3
        % for k= 1...N , N <=12 
        % in(2k+2) index and in(2k+3) value
        %---------------------------------
        wins = get(0,'children');
        if isempty(find(in2==wins)) , return; end
        t = findobj(in2,'style','text','Tag',in3);
        if ~isempty(t) , memB = get(t,'Userdata'); else , memB = []; end
        for k = 4:2:nargin
                memB = wmemutil('set',memB,             ...
                        eval(sprintf('in%.0f',k)),      ...
                        eval(sprintf('in%.0f',k+1))     ...
                        );
        end
        if isempty(t)
                t = uicontrol(...
                                'parent',in2,   ...
                                'Style','text', ...
                                'Visible','off',...
                                'Userdata',memB,...
                                'Tag',in3);
        else
                set(t,'Userdata',memB);
        end

%*******************************************%
%** OPTION = 'read' - reading in MemBloc. **%
%*******************************************%
elseif  opt=='rea'
        % win_handle = in2
        % bloc_name  = in3
        % if nargin>3 , for k= 1...N , N <=12
        % in(k+3) index and out(k) value.
        %--------------------------------------
        wins = get(0,'children');
        if isempty(find(in2==wins)) , memB = []; return; end
        t = findobj(in2,'style','text','Tag',in3);
        if ~isempty(t) , memB = get(t,'Userdata'); else , memB = []; end
        for k = 4:nargin
                arg1 = eval(sprintf('in%.0f',k));
                eval([sprintf('out%.0f',k-3) '= wmemutil(''get'',memB,arg1);']);
        end

%******************************************%
%** OPTION = 'def' - creating a MemBloc. **%
%******************************************%
elseif  opt=='def'
        % win_handle = in2
        % bloc_name  = in3
        % nbval = in4
        %--------------------------------------
        wins = get(0,'children');
        if isempty(find(in2==wins)) , return; end
        memB = wmemutil('def',in4);
        t = findobj(in2,'style','text','Tag',in3);
        if isempty(t)
                t = uicontrol(...
                                'parent',in2,   ...
                                'Style','text', ...
                                'Visible','off',...
                                'Userdata',memB,...
                                'Tag',in3);
        else
                set(t,'Userdata',memB);
        end

%******************************************%
%** OPTION = 'ini' - creating a MemBloc. **%
%******************************************%
elseif  opt=='ini'
        % win_handle = in2
        % bloc_name  = in3
        % nbval = in4
        %--------------------------------------
        wins = get(0,'children');
        if isempty(find(in2==wins)) , return; end
        axe_mem = findobj(in2,'type','axes','tag',tag_axe_mem);
        if isempty(axe_mem)
                figure(in2);
                axe_mem = axes(...
                                'Position',[-1 -1 0.0001 0.0001],       ...
                                'Visible','off',                        ...
                                'tag',tag_axe_mem                       ...
                                );
        else
                axes(axe_mem);
        end
        for k=1:in4
                tag = [in3 '.' int2str(k)];
                t = findobj(axe_mem,'type','text','tag',tag);
                if isempty(t)
                        t = text(...
                                'Visible','off',...
                                'Tag',tag);
                else
                        set(t,'Userdata',[]);
                end
        end

%------------------------%
%                        %
% GENERAL BUFFER OPTIONS %
%                        %
%------------------------%

%***************************************************%
%** OPTION = 'handle' - get handle of fig buffer  **%
%***************************************************%
elseif  opt=='han'
        out1 = findobj(get(0,'children'),'flat','Tag',tag_mem);

%********************************************%
%** OPTION = 'create' - create fig buffer  **%
%********************************************%
elseif  opt=='cre'
        out1 = findobj(get(0,'children'),'flat','Tag',tag_mem);
        if ~isempty(out1) , return; end
        out1 = figure('Visible','Off','Tag',tag_mem);

%************************%
%** OPTION = 'bput' -  **%
%************************%
elseif  opt=='bpu'
        %------------------------------%
        % name = in2                   %
        % val  = in3                   %
        % in4 optional string value    %
        %------------------------------%
        fig = findobj(get(0,'children'),'flat','Tag',tag_mem);
        if isempty(fig) , fig = wmemtool('create'); end

        if nargin==3
                t = findobj(fig,'style','text','Tag',in2);
                in4 = '';
        elseif nargin==4
                t = findobj(fig,'style','text','Tag',in2,'string',in4);
        end
        if isempty(t)
                t = uicontrol(...
                                'parent',fig,   ...
                                'Visible','off',...
                                'Style','text', ...
                                'String',in4,   ...
                                'Userdata',in3, ...
                                'Tag',in2       ...
                                );
        else
                set(t,'Userdata',in3);
        end

%************************%
%** OPTION = 'bget' -  **%
%************************%
elseif  opt=='bge'
        %------------------------------%
        % name = in2                   %
        % in3 optional string value    %
        %------------------------------%
        fig = findobj(get(0,'children'),'flat','Tag',tag_mem);
        if isempty(fig) , out1 = [] ; return; end
        if nargin==2
                t = findobj(fig,'style','text','Tag',in2);
        elseif nargin==3
                t = findobj(fig,'style','text','Tag',in2,'string',in3);
        end
        if ~isempty(t) , out1 = get(t,'Userdata'); else , out1 = []; end

%*************************%
%** OPTION = 'bdel' -   **%
%*************************%
elseif  opt=='bde'
        fig = findobj(get(0,'children'),'flat','Tag',tag_mem);
        if isempty(fig) , out1 = [] ; return; end
        %------------------------------------%
        %       name = in2                   %
        %       in3 optional string value    %
        %------------------------------------%
        if nargin==2
                delete(findobj(fig,'style','text','Tag',in2));
        elseif nargin==3
                delete(findobj(fig,'style','text','Tag',in2,'string',in3));
        end

%**************************%
%** OPTION = 'empty' -   **%
%**************************%
elseif  opt=='emp'
        fig = findobj(get(0,'children'),'flat','Tag',tag_mem);
        if isempty(fig) , out1 = [] ; return; end
        delete(findobj(fig,'style','text'));

%************************%
%** OPTION = 'find' -  **%
%************************%
elseif  opt=='fin'
        fig = findobj(get(0,'children'),'flat','Tag',tag_mem);
        if isempty(fig) , out1 = 0; else out1 = 1; end

%******************************************%
%** OPTION = 'close' - close fig buffer  **%
%******************************************%
elseif  opt=='clo'
        fig = findobj(get(0,'children'),'flat','Tag',tag_mem);
        if ~isempty(fig)
                answer = questdlg('Delete Globals Buffer ?',...
                                'yes','no','cancel',2);
                if strcmp(answer,'yes'), close(fig); end
        end

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('wmemtool','Unknown Option','msg');
        error('*');
end
