function [out1,out2] = wmemutil(option,in2,in3,in4)
%WMEMUTIL Memory utilities.
%
%       M = wmemutil('add',M,V) adds V to the memory block M
%       M = wmemutil('add',M,V,in4) adds V to the memory block M
%
%       [V,M] = wmemutil('get',M)
%       [V,M] = wmemutil('get',M,num)
%
%       M = wmemutil('set',M,num,V)
%
%       M = wmemutil('def',N) defines a memory block
%               with N empty variables
%
%       I = wmemutil('ind',M,V) get index in M of a block with value V

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:23:19 $

%*****************************************%
%** OPTION = 'add' - add a memory bloc  **%
%*****************************************%
if      option=='add'
        if isstr(in3), in3 = abs(in3); type = 1 ; else , type  = 0; end
        s = size(in3);
        b = [s type reshape(in3,1,prod(s))];
        if nargin==4, out1 = [b in2]; else, out1 = [in2 b]; end

%*****************************************%
%** OPTION = 'get' - get a memory bloc  **%
%*****************************************%
elseif  option=='get'
        out1 = [];      out2 = [];
        if isempty(in2) , return; end
        if nargin==2 , in3 = 1; end
        count   = 0;
        ltot    = length(in2);
        ind     = 1;
        while (count<in3-1) & (ind<ltot)
                s       = in2(ind:ind+1);
                l       = 3+prod(s);
                ind     = ind+l;
                count   = count+1;
        end
        if ind<ltot
                s       = in2(ind:ind+1);
                l       = 3+prod(s);
                type    = in2(ind+2);
                out1    = reshape(in2(ind+3:ind+l-1),s(1),s(2));
                if type==1 , out1 = setstr(out1); end
                out2 = in2(l+ind:ltot);
        end

%*****************************************%
%** OPTION = 'set' - set a memory bloc  **%
%*****************************************%
elseif  option=='set'
        count   = 0;
        ltot    = length(in2);
        ind     = 1;
        while (count<in3-1) & (ind<ltot)
                s       = in2(ind:ind+1);
                l       = 3+prod(s);
                ind     = ind+l;
                count   = count+1;
        end
        front = in2(1:ind-1);
        if ind<ltot
                s       = in2(ind:ind+1);
                l       = 3+prod(s);
                back    = in2(l+ind:ltot);
        else
                back    = [];
        end
        if isstr(in4), in4 = abs(in4); type = 1 ; else , type  = 0; end
        s = size(in4);
        b = [s type reshape(in4,1,prod(s))];
        out1 = [front b back];

%*****************************************%
%** OPTION = 'def' - def a memory bloc  **%
%*****************************************%
elseif  option=='def'
        out1 = zeros(1,3*in2);
 
%*********************************%
%** OPTION = 'ind' - get index  **%
%*********************************%
elseif  option=='ind'
        count   = 0;
        ok      = 0;
        ltot    = length(in2);
        ind     = 1;
        while (ok==0) & (ind<ltot)
                count   = count+1;
                s       = in2(ind:ind+1);
                type    = in2(ind+2); 
                l       = 3+prod(s);
                if s==size(in3)
                        bloc = reshape(in2(ind+3:ind+l-1),s(1),s(2));
                        if isstr(in3) , in3 = abs(in3); end
                        if in3==bloc , ok = 1; end
                end
                ind = ind+l;
        end
        if ok==1 , out1 = count; else , out1 = 0; end

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('wmemutil','Unknown Option','msg');
        error('*');
end
