function stdc = wnoisest(c,l,s)
%WNOISEST Estimate noise of 1-D wavelet coefficients.
%       STDC = WNOISEST(C,L,S) returns estimates of detail
%       coefficients standard deviation for levels contained 
%       in input vector S.
%       [C,L] is the input wavelet decomposition structure
%       (see WAVEDEC).
%
%       The estimator used is Maximum Absolute Deviation / 0.6745,
%       well suited for zero mean Gaussian white noise in
%       de-noising 1-D model (see THSELECT).
%
%       See also THSELECT, WAVEDEC, WDEN.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:23:41 $

%       Uses ERRARGN.

% Check arguments.
if errargn('wnoisest',nargin,[3],nargout,[0:1]), error('*'), end

rmax = length(l);       nmax = rmax-2;
first = cumsum(l)+1;
first = fliplr(first(1:length(first)-2));
ld  = l(rmax-1:-1:2);
last = first+ld-1;

for k = 1:length(s)
        flk = first(s(k)):last(s(k));
        stdc(k) = median(abs(c(flk)))/0.6745;
end
