function out1 = wp1dcomp(option,in2,in3,in4)
%WP1DCOMP Wavelet packets 1D compression.
%       out1 = wp1dcomp(option,in2,in3,in4)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:23:54 $

%       Uses WMEMTOOL.

global  Machine                         ...
        Def_Btn_Height  Def_Btn_Width   ...
        Pop_Min_Width   X_Graph_Ratio   ...
        X_Spacing       Y_Spacing       ...
        Def_TxtBkColor  Def_EdiBkColor  ...
        Def_FraBkColor  Def_FraFgColor

if nargin==0, option = 'create'; end

% MemBloc1 of stored values.
%---------------------------
n_param_anal    = 'WP1D_Par_Anal';
ind_sig_name    =  1;
ind_wav_name    =  2;
ind_lev_anal    =  3;
ind_ent_anal    =  4;
ind_ent_par     =  5;
ind_sig_size    =  6;
ind_act_option  =  7;
nb1_stored      =  7;

% MemBloc3 of stored values.
%---------------------------
n_structures    = 'Structures';
ind_tree_st     =  1;
ind_data_st     =  2;
nb3_stored      =  2;

% MemBloc4 of stored values. (Local Bloc)
%----------------------------------------
n_miscella_loc  = 'WPComp1D_Misc';
ind_status      = 1;
ind_hdl_winorig = 2;
nb4_stored      = 2;

% Tag property of objects.
%-------------------------
tag_sel_sli     = 'Sel_Sli';
tag_sel_edi     = 'Sel_Edi';
tag_norm_val_a  = 'Norm_Val_A';
tag_zeros_val_a = 'Zeros_Val_A';
tag_axe_perfo   = 'Axe_Perfo';
tag_axe_cfs     = 'Axe_Cfs';
tag_lin_norm    = 'Lin_Norm';
tag_lin_zero    = 'Lin_Zero';
tag_txt_comp    = 'Txt_Comp';
tag_lin_sig     = 'Lin_sig';
tag_lin_comp    = 'Lin_comp';
tag_axe_right_1 = 'axe_right_1';
tag_axe_right_2 = 'axe_right_2';
tag_axe_right_3 = 'axe_right_3';

%*****************************************************************%
%** OPTION = 'create' - constructs the initial wp1dcomp window  **%
%*****************************************************************%
if strcmp(option,'create')

        % Calling figure.
        %----------------
        win_wp1dtool     = in2;
        str_win_wp1dtool = int2str(win_wp1dtool);

        % Window initialization.
        %----------------------
        win_name = 'Wavelet Packet 1-D  --  Compression';
        [win_wp1dcomp,pos_win,cba_close_menu] = ...
                wfigcrea('create',NaN,win_name,'',win_wp1dtool,3,...
                                str2mat('wp1dcomp','cond'));
        str_win_wp1dcomp = int2str(win_wp1dcomp);
        win_units = 'pixels';
        out1      = win_wp1dcomp;

        % Command frame and Dynamical visualization tool construction.
        %-------------------------------------------------------------
        [frame0,pos_frame0,Pos_Graphic_Area] = ...
                        wfigcrea('frame',win_wp1dcomp,'dynv','title');

        % Waiting Frame construction & begin waiting.
        %--------------------------------------------
        wwaiting('create',win_wp1dcomp,X_Graph_Ratio,...
                        'Wait ... initialization');

        % Getting global variables from wp1dtool figure memory block.
        %------------------------------------------------------------
        [WP_Tree,WP_Data]       = wmemtool('rmb',win_wp1dtool,n_structures,...
                                                ind_tree_st,ind_data_st);
        Depth                   = wtreemgr('depth',WP_Tree);
        [Sig_Name,Wav_Name,Ent_Name,Ent_Par] =      ...
                wmemtool('rmb',win_wp1dtool,n_param_anal,      ...
                                ind_sig_name,ind_wav_name,      ...
                                ind_ent_anal,ind_ent_par);
        [Wav_Fam,Wav_Num] = wavattrb('fam_num',Wav_Name);

        % General graphical parameters initialization.
        %---------------------------------------------

        % Borders and double borders.
        dx  = X_Spacing;  dx2 = 2*dx;
        dy  = Y_Spacing;  dy2 = 2*dy;

        % X init position and width of frames.
        x_frame0        = pos_frame0(1);
        cmd_width       = pos_frame0(3);
        h_frame0        = pos_frame0(4);

        % Buttons width
        push_width      = (cmd_width-4*dx)/2;
        txt_width       = Def_Btn_Width;
        pop_width       = Pop_Min_Width;

        % Position property of objects.
        %------------------------------
        pos_input_txt   = [     x_frame0+dx2                            ,...
                                h_frame0-3*dy-Def_Btn_Height            ,...
                                txt_width                               ,...
                                Def_Btn_Height                          ];
        pos_input_data  = [     pos_input_txt(1)+pos_input_txt(3)+dx    ,...
                                pos_input_txt(2)                        ,...
                                2*pop_width                             ,...
                                Def_Btn_Height                          ];
        pos_wav_txt     = pos_input_txt;
        pos_wav_txt(2)  = pos_input_txt(2)-Def_Btn_Height-dy2;
        pos_wav_fams    = [     pos_wav_txt(1)+pos_wav_txt(3)+dx        ,...
                                pos_wav_txt(2)                          ,...
                                pop_width                               ,...
                                Def_Btn_Height                          ];
        pos_wav_nums    = [     pos_wav_fams(1)+pos_wav_fams(3)+dx/2    ,...
                                pos_wav_fams(2)                         ,...
                                pop_width-dx/2                          ,...
                                Def_Btn_Height                          ];
        pos_lev_txt     = pos_wav_txt;
        pos_lev_txt(2)  = pos_wav_txt(2)-Def_Btn_Height-dy2;
        pos_lev_data    = [     pos_lev_txt(1)+pos_lev_txt(3)+dx        ,...
                                pos_lev_txt(2)                          ,...
                                pop_width                               ,...
                                Def_Btn_Height                          ];
        pos_ent_txt     = pos_lev_txt;
        pos_ent_txt(2)  = pos_ent_txt(2)-Def_Btn_Height-dy2;
        pos_ent_val     = [     pos_ent_txt(1)+pos_ent_txt(3)+dx        ,...
                                pos_ent_txt(2)                          ,...
                                2*Pop_Min_Width                         ,...
                                Def_Btn_Height                          ];
        pos_ent_par     = pos_ent_txt;
        pos_ent_par(2)  = pos_ent_par(2)-Def_Btn_Height-dy2;
        pos_ent_par(3)  = pos_ent_par(3)+dx/2;
        pos_uic_ent     = [     pos_ent_par(1)+pos_ent_par(3)+dx/2      ,...
                                pos_ent_par(2)                          ,...
                                2*Pop_Min_Width                         ,...
                                Def_Btn_Height                          ];
        px              = x_frame0+(cmd_width-7*push_width/4)/2;
        pos_sel_txt     = [     px                                      ,...
                                pos_ent_par(2)-3*Def_Btn_Height         ,...
                                7*push_width/4                          ,...
                                Def_Btn_Height                          ];
        wx              = (cmd_width-13*txt_width/5)/4;
        wid1            = 15*txt_width/10;
        wid2            = 9*txt_width/10;
        pos_sel_sli     = [     x_frame0+wx                             ,...
                                pos_sel_txt(2)-5*Def_Btn_Height/4       ,...
                                wid1                                    ,...
                                Def_Btn_Height/2                        ];
        pos_sel_edi     = [     pos_sel_sli(1)+pos_sel_sli(3)+wx        ,...
                                pos_sel_txt(2)-3*Def_Btn_Height/2       ,...
                                wid2                                    ,...
                                Def_Btn_Height                          ];
        pos_norm_txt_a  = [     x_frame0+wx                             ,...
                                pos_sel_edi(2)-3*Def_Btn_Height/2       ,...
                                wid1                                    ,...
                                Def_Btn_Height                          ];
        pos_norm_val_a  = [     pos_norm_txt_a(1)+pos_norm_txt_a(3)+wx  ,...
                                pos_sel_edi(2)-3*Def_Btn_Height/2       ,...
                                wid2                                    ,...
                                Def_Btn_Height                          ];
        pos_norm_per_a  = [     pos_norm_val_a(1)+pos_norm_val_a(3)+wx  ,...
                                pos_sel_edi(2)-3*Def_Btn_Height/2       ,...
                                txt_width/5                             ,...
                                Def_Btn_Height                          ];
        pos_zeros_txt_a = [     x_frame0+wx                             ,...
                                pos_norm_txt_a(2)-3*Def_Btn_Height/2    ,...
                                wid1                                    ,...
                                Def_Btn_Height                          ];
        pos_zeros_val_a = [     pos_zeros_txt_a(1)+pos_zeros_txt_a(3)+wx,...
                                pos_norm_txt_a(2)-3*Def_Btn_Height/2    ,...
                                wid2                                    ,...
                                Def_Btn_Height                          ];
        pos_zeros_per_a = [     pos_zeros_val_a(1)+pos_zeros_val_a(3)+wx,...
                                pos_norm_txt_a(2)-3*Def_Btn_Height/2    ,...
                                txt_width/5                             ,...
                                Def_Btn_Height                          ];
        pos_auto_comp   = [     x_frame0+(cmd_width-3*push_width/2)/2    ,...
                                pos_zeros_txt_a(2)-3*Def_Btn_Height     ,...
                                3*push_width/2                          ,...
                                2*Def_Btn_Height                        ];
        px              = x_frame0+(cmd_width-7*push_width/4)/2;
        pos_close       = [     px                                      ,...
                                pos_frame0(2)+Def_Btn_Height            ,...
                                7*push_width/4                          ,...
                                3*Def_Btn_Height/2                      ];

        % Parameters initialization.
        %---------------------------
        min_sel_sli     = 0;
        max_sel_sli     = 1;
        default_sel_sli = 0;

        % String property of objects.
        %----------------------------
        str_input_txt   = 'Signal';
        str_input_data  = Sig_Name;
        str_wav_txt     = 'Wavelet';
        str_wav_fams    = Wav_Fam;
        str_wav_nums    = Wav_Num;
        str_lev_txt     = 'Level';
        str_lev_data    = int2str(Depth);
        str_ent_txt     = 'Entropy';
        [str_ent_val,str_ent_par] = wpentmng('t',Ent_Name);
        str_uic_ent     = num2str(Ent_Par);
        str_sel_txt     = 'Select global threshold';
        str_sel_edi     = '';
        if strcmp(Wav_Fam,'bior')
                str_norm_txt    = 'Norm cfs recovery';
        else
                str_norm_txt    = 'Retained energy';
        end
        str_norm_val_a  = '';
        str_norm_per    = '%';
        str_zeros_txt   = 'Number of zeros';
        str_zeros_val_a = '';
        str_zeros_per   = '%';
        str_compress    = 'Compress';
        str_close       = 'Close';

        % Command part construction of the window.
        %-----------------------------------------
        figure(win_wp1dcomp)
        txt_input_txt   = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_input_txt,...
                                        'String',str_input_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_input_data  = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_input_data,...
                                        'String',str_input_data,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_wav_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_wav_txt,...
                                        'String',str_wav_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_wav_fams    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_wav_fams,...
                                        'String',str_wav_fams,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        if ~isempty(str_wav_nums)
        txt_wav_nums    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_wav_nums,...
                                        'String',str_wav_nums,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        end
        txt_lev_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_lev_txt,...
                                        'String',str_lev_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_lev_data    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_lev_data,...
                                        'String',str_lev_data,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_ent_txt     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_ent_txt,         ...
                                        'String',str_ent_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_ent_val     = uicontrol(...
                                        'Style','text', ...
                                        'Unit',win_units,       ...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_ent_val, ...
                                        'String',str_ent_val,   ...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        nument          = wpentmng('g',Ent_Name);
        if find(nument==[2 3 5 6])
                txt_ent_par     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_ent_par,         ...
                                        'String',str_ent_par,           ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
                uic_ent         = uicontrol(...
                                        'Style','text',         ...
                                        'Unit',win_units,       ...
                                        'Position',pos_uic_ent, ...
                                        'HorizontalAlignment','center', ...
                                        'String',str_uic_ent,   ...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        end
        txt_sel_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_sel_txt,...
                                        'String',str_sel_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        sli_sel_sli     = uicontrol(...
                                        'Style','Slider',...
                                        'Unit',win_units,...
                                        'Position',pos_sel_sli,...
                                        'Min',min_sel_sli,...
                                        'Max',max_sel_sli,...
                                        'Value',default_sel_sli,...
                                        'tag',tag_sel_sli...
                                        );
        edi_sel_edi     = uicontrol(...
                                        'Style','Edit',...
                                        'Unit',win_units,...
                                        'Position',pos_sel_edi,...
                                        'String',str_sel_edi,...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'HorizontalAlignment','center',...
                                        'tag',tag_sel_edi...
                                        );
        txt_norm_txt_a  = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_norm_txt_a,...
                                        'HorizontalAlignment','left',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'String',str_norm_txt...
                                        );
        edi_norm_val_a  = uicontrol(...
                                        'Style','Edit',...
                                        'Unit',win_units,...
                                        'Position',pos_norm_val_a,...
                                        'String',str_norm_val_a,...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'HorizontalAlignment','center',...
                                        'tag',tag_norm_val_a...
                                        );
        txt_norm_per_a  = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_norm_per_a,...
                                        'HorizontalAlignment','center',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'String',str_norm_per...
                                        );
        txt_zeros_txt_a = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_zeros_txt_a,...
                                        'HorizontalAlignment','left',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'String',str_zeros_txt...
                                        );
        edi_zeros_val_a = uicontrol(...
                                        'Style','Edit',...
                                        'Unit',win_units,...
                                        'Position',pos_zeros_val_a,...
                                        'String',str_zeros_val_a,...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'HorizontalAlignment','center',...
                                        'tag',tag_zeros_val_a...
                                        );
        txt_zeros_per_a = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_zeros_per_a,...
                                        'HorizontalAlignment','center',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'String',str_zeros_per...
                                        );
        pus_auto_comp   = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_auto_comp,...
                                        'String',str_compress...
                                        );
        pus_close       = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_close,...
                                        'String',str_close,...
                                        'Interruptible','yes'...
                                        );
        drawnow

        % Parameters initialization.
        %---------------------------
        [thresh,rl2scr,n0scr,argmin,suggthr] = wpcmpscr(WP_Tree,WP_Data);
        min_sel_sli     = 0;
        max_sel_sli     = thresh(length(thresh));
        default_sel_sli = suggthr;

        % String property of objects.
        %----------------------------
        str_sel_edi     = sprintf('%1.4g',default_sel_sli);
        str_norm_val_a  = sprintf('%1.4g',rl2scr(argmin));
        str_zeros_val_a = sprintf('%1.4g',n0scr(argmin));

        % Callbacks update.
        %------------------
        cba_sel_sli     = ['wp1dcomp(''update_selglo'',' ...
                                str_win_wp1dcomp ',' ...
                                str_win_wp1dtool ',' ...
                                '''sli''' ');'];
        cba_sel_edi     = ['wp1dcomp(''update_selglo'',' ...
                                str_win_wp1dcomp ',' ...
                                str_win_wp1dtool ',' ...
                                '''edi''' ');'];
        cba_norm_val    = ['wp1dcomp(''update_selglo'',' ...
                                str_win_wp1dcomp ',' ...
                                str_win_wp1dtool ',' ...
                                '''nor''' ');'];
        cba_zeros_val   = ['wp1dcomp(''update_selglo'',' ...
                                str_win_wp1dcomp ',' ...
                                str_win_wp1dtool ',' ...
                                '''zer''' ');'];
        cba_compress    = ['wp1dcomp(''compress'',' ...
                                str_win_wp1dcomp ',' ...
                                str_win_wp1dtool ');'];
        set(sli_sel_sli,'Max',max_sel_sli,'Value',default_sel_sli,...
                        'Callback',cba_sel_sli);
        set(edi_sel_edi,'String',str_sel_edi,'Callback',cba_sel_edi);
        set(edi_norm_val_a,'String',str_norm_val_a,'Callback',cba_norm_val);
        set(edi_zeros_val_a,'String',str_zeros_val_a,'Callback',cba_zeros_val);
        set(pus_auto_comp,'Callback',cba_compress);
        set(pus_close,'Callback',cba_close_menu);

        % General graphical parameters initialization.
        %--------------------------------------------
        bdx             = 0.08*pos_win(3);
        bdy             = 0.06*pos_win(4);
        ecy             = 0.03*pos_win(4);
        y_graph         = 2*Def_Btn_Height+dy;
        h_graph         = pos_frame0(4)-y_graph;
        w_graph         = pos_frame0(1);

        % Axes construction parameters.
        %------------------------------
        w_left          = (w_graph-3*bdx)/2;
        x_left          = bdx;
        w_right         = w_left;
        x_right         = x_left+w_left+5*bdx/4;
        n_axeright      = 3;
        ind_right       = n_axeright;

        % Vertical separation.
        %---------------------
        w_fra   = 0.01*pos_win(3);
        x_fra   = (w_graph-w_fra)/2;
        uicontrol(...
                        'Style','frame',...
                        'Unit',win_units,...
                        'Position',[x_fra,y_graph,w_fra,h_graph],...
                        'Backgroundcolor',Def_FraBkColor,...
                        'Tag','Dw1dcomp_obj'...
                        );

        % Building axes on the right part.
        %---------------------------------
        ecy_right       = 2*ecy;
        h_right         =(h_graph-2*bdy-(n_axeright-1)*ecy_right)/n_axeright;
        y_right         = y_graph+2*bdy/3;
        axe_right       = zeros(1,n_axeright);
        pos_right       = [x_right y_right w_right h_right];
        for k = 1:n_axeright
                axe_right(k) = axes(...
                                'Units',win_units,...
                                'Position',pos_right,...
                                'Drawmode','fast',...
                                'Box','On',...
                                'Tag',['axe_right_' int2str(k)]...
                                );
                pos_right(2) = pos_right(2)+pos_right(4)+ecy_right;
        end
        set(axe_right(1),'visible','off');

        % Computing and drawing original signal.
        %---------------------------------------
        Signal_Anal     = get(wp1ddraw('r_orig',win_wp1dtool),'Ydata');
        axes(axe_right(3))
        curr_color      = dw1dcolo('sig');
        hdl_sig = line(1:length(Signal_Anal),Signal_Anal,'erasemode','none',...
                        'Color',curr_color,'tag',tag_lin_sig);
        title('Original signal');      
        xmin = 1;                       
        xmax = length(Signal_Anal);
        ymin = min(Signal_Anal);    
        ymax = max(Signal_Anal);
        if ymin==ymax
                ymin = ymin-0.0001;
                ymax = ymax+0.0001;
        end
        set(axe_right(3),'Xlim',[xmin xmax],'Ylim',[ymin ymax]);

        % Displaying original details coefficients.
        %------------------------------------------
        set(win_wp1dcomp,'Colormap',get(win_wp1dtool,'Colormap'));
        axe_handles     = findobj(win_wp1dtool,'type','axes');
        WP_Axe_Cfs      = findobj(axe_handles,'flat','Tag',tag_axe_cfs);
        xaxis           = get(WP_Axe_Cfs,'Xlim');
        yaxis           = get(WP_Axe_Cfs,'Ylim');
        axes(axe_right(2))
        set(axe_right(2),...
                        'Xlim',xaxis,                           ...
                        'Ylim',yaxis,                           ...
                        'YTicklabelMode','manual',              ...
                        'YTickLabels',[],                       ...
                        'YTick',[],                             ...
                        'Box','On'                              ...
                        );
        wpplotcf(axe_right(2),WP_Tree,WP_Data,win_wp1dtool);
        title('Original coefficients');
        set(axe_right(1),...
                        'Xlim',xaxis,                           ...
                        'Ylim',yaxis,                           ...
                        'YTicklabelMode','manual',              ...
                        'YTickLabels',[],                       ...
                        'YTick',[],                             ...
                        'Box','On'                              ...
                        );

        % Displaying perfos.
        %-------------------
        y_axe_perfo     = y_graph+2*bdy/3+h_right+ecy_right;
        h_axe_perfo     = 2*h_right+ecy_right;
        pos_axe_perfo   = [x_left y_axe_perfo w_left h_axe_perfo];
        axe_perfo       = axes(...
                                'Units',win_units,...
                                'Position',pos_axe_perfo,...
                                'Drawmode','fast',...
                                'Box','On',...
                                'Tag',tag_axe_perfo);
        if abs(thresh)<eps , epsx  = 0.0001; else , epsx  = 0; end;
        xaxis = [-(max(thresh)/100)-epsx    max(thresh)+(max(thresh)/100)+epsx];
        set(axe_perfo,'Xlim',xaxis,'Ylim',[0 104]);
        lin_zero        = line( 'Xdata',thresh,...
                                'Ydata',n0scr,...
                                'Color','cyan',...
                                'EraseMode','none',...
                                'Tag',tag_lin_zero);
        lin_norm        = line( 'Xdata',thresh,...
                                'Ydata',rl2scr,...
                                'Color','magenta',...
                                'EraseMode','none',...
                                'Tag',tag_lin_norm);
        lin_perfo       = line( 'Xdata',[suggthr suggthr],...
                                'Ydata',[0.5 104],...
                                'Color','y',...
                                'EraseMode','xor',...
                                'linestyle',':');
        set(axe_perfo,'Userdata',lin_perfo);

        % Set a text as a super title.
        %-----------------------------
        title(' '); 
        wtxttitl(axe_perfo,'Automatic thresholding');    

        % Displaying legend.
        %-------------------
        y_axe_legend    = y_graph+h_right/2;
        h_axe_legend    = h_right/2;
        pos_axe_legend  = [x_left y_axe_legend w_left h_axe_legend];
        axe_legend      = wlegend(win_wp1dcomp,pos_axe_legend,Wav_Fam);

        % Memory blocks update.
        %----------------------
        wmemtool('ini',win_wp1dcomp,n_miscella_loc,nb4_stored);
        wmemtool('wmb',win_wp1dcomp,n_miscella_loc,                   ...
                                        ind_status,0,                   ...
                                        ind_hdl_winorig,win_wp1dtool    ...
                                        );

        % Axes attachment.
        %-----------------
        axe_cmd = axe_right(3);
        axe_act = axe_right(1:2);
        dynvtool('attach',win_wp1dcomp,[],axe_cmd,axe_act,[1 0],'','','');
        dynvtool('put',win_wp1dcomp);

        % Setting units to normalized.
        %-----------------------------
        set(findobj(win_wp1dcomp,'Units','pixels'),'Units','Normalized');

        % End waiting.
        %-------------
        wwaiting('off',win_wp1dcomp);

%***************************************%
%** OPTION = 'compress' - COMPRESSION **%
%***************************************%
elseif strcmp(option,'compress')
        win_wp1dcomp    = in2;
        win_wp1dtool    = in3;

        % Waiting message.
        %-----------------
        wwaiting('msg',win_wp1dcomp,'Wait ... computing');

        % Handles of tagged objects.
        %---------------------------
        axe_handles     = findobj(win_wp1dcomp,'Type','axes');
        txt_handles     = findobj(win_wp1dcomp,'Type','text');
        sli_handles     = findobj(win_wp1dcomp,'Style','slider');
        lin_handles     = findobj(win_wp1dcomp,'Type','line');
        axe_right_1     = findobj(axe_handles,'flat','Tag',tag_axe_right_1);
        axe_right_2     = findobj(axe_handles,'flat','Tag',tag_axe_right_2);
        axe_right_3     = findobj(axe_handles,'flat','Tag',tag_axe_right_3);
        txt_perfcmp     = findobj(txt_handles,'flat','Tag',tag_txt_comp);
        sli_sel_sli     = findobj(sli_handles,'Tag',tag_sel_sli);
        lin_norm        = findobj(lin_handles,'Tag',tag_lin_norm);
        lin_zero        = findobj(lin_handles,'Tag',tag_lin_zero);

        % Setting the compressed coefs axes invisible.
        %---------------------------------------------
        lin_compsig     = get(axe_right_3,'userdata');
        if  ~isempty(lin_compsig)
                vis     = get(lin_compsig,'Visible');
                if vis(1:2)=='on'
                        mngaxe('vis',axe_right_1,'off');
                        title('Original signal');
                        axes(axe_right_3);
                        set(lin_compsig,'Visible','off');
                        set(txt_perfcmp,'Visible','off');
                end
        end
        drawnow

        % Getting memory blocks.
        %-----------------------
        [WP_Tree,WP_Data] = wmemtool('rmb',win_wp1dtool,n_structures,...
                                                ind_tree_st,ind_data_st);
        Depth    = wtreemgr('depth',WP_Tree);
        Wav_Name = wmemtool('rmb',win_wp1dtool,n_param_anal,ind_wav_name);
        Wav_Fam  = wavattrb('fam_num',Wav_Name);

        % Compression.
        %-------------
        threshold       = get(sli_sel_sli,'Value');
        [C_Sig,C_Tree,C_Data] = wpdencmp(WP_Tree,WP_Data,...
                                    'h','nobest',threshold,1);
        [perfl2,perf0,new_thresh] = ... 
                key2info(lin_norm,lin_zero,threshold,'T');

        % Displaying compressed signal.
        %------------------------------
        axes(axe_right_3);
        if ~isempty(lin_compsig)
                set(lin_compsig,'Ydata',C_Sig);
                set(lin_compsig,'Visible','on');
        else
                curr_color      = dw1dcolo('ssig');
                lin_compsig     = line( 'Xdata',1:length(C_Sig),...
                                        'Ydata',C_Sig,...
                                        'color',curr_color,...
                                        'tag',tag_lin_comp);
                set(axe_right_3,'userdata',lin_compsig)
        end     
        if strcmp(Wav_Fam,'bior')
                lin_sig         = findobj(axe_right_3,'tag',tag_lin_sig);
                Sig_Anal        = get(lin_sig,'Ydata');
                perfl2          = 100*(norm(C_Sig)/norm(Sig_Anal))^2;
        end

        % Set a text as a super title.
        %-----------------------------
        str_norm_txt    = 'Retained energy ';
        title('Original and compressed signals');
        txt_comp = [str_norm_txt num2str(perfl2) ...
                    ' % -- Zeros ' num2str(perf0) ' %'];
        wtxttitl(axe_right_3,txt_comp,tag_txt_comp);

        % Displaying thresholded details coefficients.
        %---------------------------------------------
        delete(findobj(axe_right_1,'type','image'));
        wpplotcf(axe_right_1,C_Tree,C_Data,win_wp1dtool);
        axes(axe_right_1);
        set(axe_right_1,...
                        'Xlim',get(axe_right_2,'Xlim'),...
                        'Ylim',get(axe_right_2,'Ylim'),...
                        'Tag',tag_axe_right_1);
        title('Thresholded coefficients');
        mngaxe('vis',axe_right_1,'on');

        % Memory blocks update.
        %----------------------
        wmemtool('wmb',win_wp1dcomp,n_miscella_loc,ind_status,1);

        % End waiting.
        %-------------
        wwaiting('off',win_wp1dcomp);

%***************************************************************%
%** OPTION = 'update_selglo' - UPDATE INFOS FOR GLOBAL THRESH **%
%***************************************************************%
elseif strcmp(option,'update_selglo')
        win_wp1dcomp    = in2;
        win_wp1dtool    = in3;
        upd_orig        = in4;

        % Handles of tagged objects continuing.
        %-------------------------------------
        axe_handles     = findobj(win_wp1dcomp,'Type','axes');
        txt_handles     = findobj(win_wp1dcomp,'Type','text');
        sli_handles     = findobj(win_wp1dcomp,'Style','slider');
        edi_handles     = findobj(win_wp1dcomp,'Style','edit');
        lin_handles     = findobj(win_wp1dcomp,'Type','line');
        axe_perfo       = findobj(axe_handles,'flat','Tag',tag_axe_perfo);
        axe_right_1     = findobj(axe_handles,'flat','Tag',tag_axe_right_1);
        axe_right_3     = findobj(axe_handles,'flat','Tag',tag_axe_right_3);
        txt_perfcmp     = findobj(txt_handles,'flat','Tag',tag_txt_comp);
        sli_sel_sli     = findobj(sli_handles,'Tag',tag_sel_sli);
        edi_sel_edi     = findobj(edi_handles,'Tag',tag_sel_edi);
        edi_norm_val_a  = findobj(edi_handles,'Tag',tag_norm_val_a);
        edi_zeros_val_a = findobj(edi_handles,'Tag',tag_zeros_val_a);
        lin_norm        = findobj(lin_handles,'Tag',tag_lin_norm);
        lin_zero        = findobj(lin_handles,'Tag',tag_lin_zero);

        % Setting the compressed coefs axes invisible.
        %---------------------------------------------
        lin_compsig     = get(axe_right_3,'userdata');
        if ~isempty(lin_compsig)
                vis     = get(lin_compsig,'Visible');
                if vis(1:2)=='on'
                        mngaxe('vis',axe_right_1,'off');
                        axes(axe_right_3);
                        title('Original signal');
                        set(lin_compsig,'Visible','off');
                        set(txt_perfcmp,'Visible','off');
                end
        end
        drawnow

        % Updating compression information.
        %----------------------------------
        if      upd_orig=='sli'
                new_thresh      = get(sli_sel_sli,'value');
                [new_rl2scr,new_n0scr,new_thresh] = ... 
                        key2info(lin_norm,lin_zero,new_thresh,'T');
        elseif  upd_orig=='edi'
                new_thresh      = str2num(get(edi_sel_edi,'string'));
                [new_rl2scr,new_n0scr,new_thresh] = ... 
                        key2info(lin_norm,lin_zero,new_thresh,'T');
        elseif  upd_orig=='nor'
                new_rl2scr      = str2num(get(edi_norm_val_a,'string'));
                [new_rl2scr,new_n0scr,new_thresh] = ... 
                        key2info(lin_norm,lin_zero,new_rl2scr,'N');
        elseif  upd_orig=='zer'
                new_n0scr       = str2num(get(edi_zeros_val_a,'string'));
                [new_rl2scr,new_n0scr,new_thresh] = ... 
                        key2info(lin_norm,lin_zero,new_n0scr,'Z');
        end
        if isempty(new_thresh)|isempty(new_rl2scr)|isempty(new_n0scr)
                new_thresh      = get(sli_sel_sli,'value');
                [new_rl2scr,new_n0scr,new_thresh] = ... 
                        key2info(lin_norm,lin_zero,new_thresh,'T');
        end

        set(sli_sel_sli,'value',new_thresh);
        set(edi_sel_edi,'string',sprintf('%1.4g',new_thresh));
        set(edi_norm_val_a,'string',sprintf('%1.4g',new_rl2scr));
        set(edi_zeros_val_a,'string',sprintf('%1.4g',new_n0scr));
        newline = 1;
        xnew    = [new_thresh new_thresh];
        lin_per = get(axe_perfo,'Userdata');
        xold    = get(lin_per,'Xdata');
        if ~isempty(xold)
                if size(xold)==[1 2]
                        if abs(xold - xnew)<sqrt(eps)
                                newline = 0;
                        end
                end
        end
        if newline
                if      strcmp(Machine(1:3),'PCW')
                        yper = get(lin_per,'Ydata');
                        delete(lin_per)
                        axes(axe_perfo);
                        lin_per = line(...
                                        'Xdata',xnew,...
                                        'ydata',yper,...
                                        'Color','y',...
                                        'linestyle',':');
                        set(axe_perfo,'Userdata',lin_per);
                else
                        set(lin_per,'Xdata',xnew);
                end

        end

        % Memory blocks update.
        %----------------------
        wmemtool('wmb',win_wp1dcomp,n_miscella_loc,ind_status,0);

%**************************************%
%** OPTION = 'close' -  CLOSE FIGURE **%
%**************************************%
elseif strcmp(option,'close')
        win_wp1dcomp    = in2;

        [status,hdl_winorig] =  wmemtool('rmb',win_wp1dcomp,n_miscella_loc,...
                                                ind_status,ind_hdl_winorig);
        if status==1

                % Test for Updating.
                %--------------------
                status = wwaitans(win_wp1dcomp,...
                                  'Update the synthesized signal ?',2,'cancel');
        end
        if status==1
                wwaiting('msg',win_wp1dcomp,'Wait ... computing');
                lin_handles     = findobj(win_wp1dcomp,'type','line');
                lin_compsig     = findobj(lin_handles,'tag',tag_lin_comp);
                wp1dmngr('return_comp',hdl_winorig,status,lin_compsig);
                wwaiting('off',win_wp1dcomp);
        elseif  status==0
                wp1dmngr('return_comp',hdl_winorig,status);
        else

        end
        out1 = status;

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('wp1dcomp','Unknown Option','msg');
        error('*');
end
