function out1 = wp2dcomp(option,in2,in3,in4)
%WP2DCOMP Wavelet packets 2D compression.
%       out1 = wp2dcomp(option,in2,in3,in4)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:25:11 $

%       Uses WMEMTOOL.

global  Machine        ...
        Def_Btn_Height  Def_Btn_Width   ...
        Pop_Min_Width   X_Graph_Ratio   ...
        X_Spacing       Y_Spacing       ...
        Def_TxtBkColor  Def_EdiBkColor  ...
        Def_FraBkColor  Def_FraFgColor

if nargin==0, option = 'create'; end

% Image Coding Value.
%-------------------
codemat_v       = wimgcode('get');

% MemBloc1 of stored values.
%---------------------------
n_param_anal    = 'WP2D_Par_Anal';
ind_img_name    =  1;
ind_wav_name    =  2;
ind_lev_anal    =  3;
ind_ent_anal    =  4;
ind_ent_par     =  5;
ind_img_size    =  6;
ind_img_t_name  =  7;
ind_act_option  =  8;
nb1_stored      =  8;

% MemBloc2 of stored values.
%---------------------------
n_wp1d2d_utils  = 'WP1D2D_Utils';
ind_tree_lin    =  1;
ind_tree_txt    =  2;
ind_type_txt    =  3;
ind_sel_nodes   =  4;
ind_gra_area    =  5;
ind_nb_colors   =  6;
ind_wav_len     =  7;
nb2_stored      =  7;

% MemBloc3 of stored values.
%---------------------------
n_structures    = 'Structures';
ind_tree_st     =  1;
ind_data_st     =  2;
nb3_stored      =  2;

% MemBloc4 of stored values. (Local Bloc)
%----------------------------------------
n_miscella_loc  = 'WPComp2D_Misc';
ind_status      = 1;
ind_hdl_winorig = 2;
nb4_stored      = 2;

% Tag property of objects.
%-------------------------
tag_sel_sli     = 'Sel_Sli';
tag_sel_edi     = 'Sel_Edi';
tag_norm_val_a  = 'Norm_Val_A';
tag_zeros_val_a = 'Zeros_Val_A';
tag_axe_perfo   = 'Axe_Perfo';
tag_axe_comp    = 'Axe_Comp';
tag_img_comp    = 'Img_Comp';
tag_axe_orig    = 'Axe_Orig';
tag_lin_norm    = 'Lin_Norm';
tag_lin_zero    = 'Lin_Zero';
tag_img_orig    = 'Img_Orig';
                
%*****************************************************************%
%** OPTION = 'create' - constructs the initial wp2dcomp window  **%
%*****************************************************************%
if strcmp(option,'create')

        % Calling figure.
        %----------------
        win_wp2dtool     = in2;
        str_win_wp2dtool = int2str(win_wp2dtool);

        % Window initialization.
        %----------------------
        win_name = 'Wavelet Packet 2-D  --  Compression';
        [win_wp2dcomp,pos_win,cba_close_menu] = ...
                wfigcrea('create',NaN,win_name,'',win_wp2dtool,3,...
                                str2mat('wp2dcomp','cond'));
        str_win_wp2dcomp = int2str(win_wp2dcomp);
        win_units = 'pixels';
        out1      = win_wp2dcomp;

        % Command frame and Dynamical visualization tool construction.
        %-------------------------------------------------------------
        [frame0,pos_frame0,Pos_Graphic_Area] = ...
                        wfigcrea('frame',win_wp2dcomp,'dynv','title');

        % Waiting Frame construction & begin waiting.
        %--------------------------------------------
        wwaiting('create',win_wp2dcomp,X_Graph_Ratio,...
                        'Wait ... initialization');

        % Getting global variables from wp2dtool figure memory block.
        %------------------------------------------------------------
        [WP_Tree,WP_Data]       = wmemtool('rmb',win_wp2dtool,n_structures,...
                                                ind_tree_st,ind_data_st);
        Depth                   = wtreemgr('depth',WP_Tree);
        [Img_Name,Wav_Name,Img_Size,Ent_Name,Ent_Par] =  ...
                        wmemtool('rmb',win_wp2dtool,n_param_anal,   ...
                                        ind_img_name,ind_wav_name,  ...
                                        ind_img_size,               ...
                                        ind_ent_anal,ind_ent_par);
        [Wav_Fam,Wav_Num] = wavattrb('fam_num',Wav_Name);
        NB_ColorsInPal    = wmemtool('rmb',win_wp2dtool,n_wp1d2d_utils,...
                                                        ind_nb_colors);

        % General graphical parameters initialization.
        %---------------------------------------------

        % Borders and double borders.
        dx  = X_Spacing;  dx2 = 2*dx;
        dy  = Y_Spacing;  dy2 = 2*dy;

        % X init position and width of frames.
        x_frame0        = pos_frame0(1);
        cmd_width       = pos_frame0(3);
        h_frame0        = pos_frame0(4);

        % Buttons width
        push_width      = (cmd_width-4*dx)/2;
        txt_width       = Def_Btn_Width;
        pop_width       = Pop_Min_Width;

        % Position property of objects.
        %------------------------------
        pos_input_txt   = [     x_frame0+dx2                            ,...
                                h_frame0-3*dy-Def_Btn_Height            ,...
                                txt_width                               ,...
                                Def_Btn_Height                          ];
        pos_input_data  = [     pos_input_txt(1)+pos_input_txt(3)+dx    ,...
                                pos_input_txt(2)                        ,...
                                2*pop_width                             ,...
                                Def_Btn_Height                          ];
        pos_wav_txt     = pos_input_txt;
        pos_wav_txt(2)  = pos_input_txt(2)-Def_Btn_Height-dy2;
        pos_wav_fams    = [     pos_wav_txt(1)+pos_wav_txt(3)+dx        ,...
                                pos_wav_txt(2)                          ,...
                                pop_width                               ,...
                                Def_Btn_Height                          ];
        pos_wav_nums    = [     pos_wav_fams(1)+pos_wav_fams(3)+dx/2    ,...
                                pos_wav_fams(2)                         ,...
                                pop_width-dx/2                          ,...
                                Def_Btn_Height                          ];
        pos_lev_txt     = pos_wav_txt;
        pos_lev_txt(2)  = pos_wav_txt(2)-Def_Btn_Height-dy2;
        pos_lev_data    = [     pos_lev_txt(1)+pos_lev_txt(3)+dx        ,...
                                pos_lev_txt(2)                          ,...
                                pop_width                               ,...
                                Def_Btn_Height                          ];
        pos_ent_txt     = pos_lev_txt;
        pos_ent_txt(2)  = pos_ent_txt(2)-Def_Btn_Height-dy2;
        pos_ent_val     = [     pos_ent_txt(1)+pos_ent_txt(3)+dx        ,...
                                pos_ent_txt(2)                          ,...
                                2*Pop_Min_Width                         ,...
                                Def_Btn_Height                          ];
        pos_ent_par     = pos_ent_txt;
        pos_ent_par(2)  = pos_ent_par(2)-Def_Btn_Height-dy2;
        pos_ent_par(3)  = pos_ent_par(3)+dx/2;
        pos_uic_ent     = [     pos_ent_par(1)+pos_ent_par(3)+dx/2      ,...
                                pos_ent_par(2)                          ,...
                                2*Pop_Min_Width                         ,...
                                Def_Btn_Height                          ];
        px              = x_frame0+(cmd_width-7*push_width/4)/2;
        pos_sel_txt     = [     px                                      ,...
                                pos_ent_par(2)-3*Def_Btn_Height         ,...
                                7*push_width/4                          ,...
                                Def_Btn_Height                          ];
        wx              = (cmd_width-13*txt_width/5)/4;
        wid1                = 15*txt_width/10;
        wid2                = 9*txt_width/10;
        pos_sel_sli     = [     x_frame0+wx                             ,...
                                pos_sel_txt(2)-5*Def_Btn_Height/4       ,...
                                wid1                                    ,...
                                Def_Btn_Height/2                        ];
        pos_sel_edi     = [     pos_sel_sli(1)+pos_sel_sli(3)+wx        ,...
                                pos_sel_txt(2)-3*Def_Btn_Height/2       ,...
                                wid2                                    ,...
                                Def_Btn_Height                          ];
        pos_norm_txt_a  = [     x_frame0+wx                             ,...
                                pos_sel_edi(2)-3*Def_Btn_Height/2       ,...
                                wid1                                    ,...
                                Def_Btn_Height                          ];
        pos_norm_val_a  = [     pos_norm_txt_a(1)+pos_norm_txt_a(3)+wx  ,...
                                pos_sel_edi(2)-3*Def_Btn_Height/2       ,...
                                wid2                                    ,...
                                Def_Btn_Height                          ];
        pos_norm_per_a  = [     pos_norm_val_a(1)+pos_norm_val_a(3)+wx  ,...
                                pos_sel_edi(2)-3*Def_Btn_Height/2       ,...
                                txt_width/5                             ,...
                                Def_Btn_Height                          ];
        pos_zeros_txt_a = [     x_frame0+wx                             ,...
                                pos_norm_txt_a(2)-3*Def_Btn_Height/2    ,...
                                wid1                                    ,...
                                Def_Btn_Height                          ];
        pos_zeros_val_a = [     pos_zeros_txt_a(1)+pos_zeros_txt_a(3)+wx,...
                                pos_norm_txt_a(2)-3*Def_Btn_Height/2    ,...
                                wid2                                    ,...
                                Def_Btn_Height                          ];
        pos_zeros_per_a = [     pos_zeros_val_a(1)+pos_zeros_val_a(3)+wx,...
                                pos_norm_txt_a(2)-3*Def_Btn_Height/2    ,...
                                txt_width/5                             ,...
                                Def_Btn_Height                          ];
        pos_auto_comp   = [     x_frame0+(cmd_width-3*push_width/2)/2    ,...
                                pos_zeros_txt_a(2)-3*Def_Btn_Height     ,...
                                3*push_width/2                          ,...
                                2*Def_Btn_Height                        ];
        px              = x_frame0+(cmd_width-7*push_width/4)/2;
        pos_close       = [     px                                      ,...
                                pos_frame0(2)+Def_Btn_Height            ,...
                                7*push_width/4                          ,...
                                3*Def_Btn_Height/2                      ];

        % String property of objects.
        %----------------------------
        str_input_txt   = 'Image';
        str_input_data  = Img_Name;
        str_wav_txt     = 'Wavelet';
        str_wav_fams    = Wav_Fam;
        str_wav_nums    = Wav_Num;
        str_lev_txt     = 'Level';
        str_lev_data    = int2str(Depth);
        str_ent_txt     = 'Entropy';
        [str_ent_val,str_ent_par] = wpentmng('t',Ent_Name);
        str_uic_ent     = num2str(Ent_Par);
        str_sel_txt     = 'Select global threshold';
        str_sel_edi     = ' ';
        if strcmp(Wav_Fam,'bior')
                str_norm_txt        = 'Norm cfs recovery';
        else
                str_norm_txt        = 'Retained energy';
        end
        str_norm_val_a  = ' ';
        str_norm_per    = '%';
        str_zeros_txt   = 'Number of zeros';
        str_zeros_val_a = ' ';
        str_zeros_per   = '%';
        str_compress    = 'Compress';
        str_close       = 'Close';

        % Command part construction of the window.
        %-----------------------------------------
        figure(win_wp2dcomp)
        txt_input_txt   = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_input_txt,...
                                        'String',str_input_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_input_data  = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_input_data,...
                                        'String',str_input_data,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_wav_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_wav_txt,...
                                        'String',str_wav_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_wav_fams    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_wav_fams,...
                                        'String',str_wav_fams,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        if ~isempty(str_wav_nums)
        txt_wav_nums    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_wav_nums,...
                                        'String',str_wav_nums,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        end
        txt_lev_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_lev_txt,...
                                        'String',str_lev_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_lev_data    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_lev_data,...
                                        'String',str_lev_data,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_ent_txt     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_ent_txt,         ...
                                        'String',str_ent_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_ent_val     = uicontrol(...
                                        'Style','text', ...
                                        'Unit',win_units,       ...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_ent_val, ...
                                        'String',str_ent_val,   ...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        nument          = wpentmng('g',Ent_Name);
        if find(nument==[2 3 5 6])
                txt_ent_par     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_ent_par,         ...
                                        'String',str_ent_par,           ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
                uic_ent         = uicontrol(...
                                        'Style','text',         ...
                                        'Unit',win_units,       ...
                                        'Position',pos_uic_ent, ...
                                        'HorizontalAlignment','center', ...
                                        'String',str_uic_ent,   ...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        end

        % Parameters initialization.
        %---------------------------
        min_sel_sli     = 0;
        max_sel_sli     = 1;
        default_sel_sli = 0;

        txt_sel_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_sel_txt,...
                                        'String',str_sel_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        sli_sel_sli     = uicontrol(...
                                        'Style','Slider',...
                                        'Unit',win_units,...
                                        'Position',pos_sel_sli,...
                                        'Min',min_sel_sli,...
                                        'Max',max_sel_sli,...
                                        'Value',default_sel_sli,...
                                        'tag',tag_sel_sli...
                                        );
        edi_sel_edi     = uicontrol(...
                                        'Style','Edit',...
                                        'Unit',win_units,...
                                        'Position',pos_sel_edi,...
                                        'String',str_sel_edi,...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'HorizontalAlignment','center',...
                                        'tag',tag_sel_edi...
                                        );
        txt_norm_txt_a  = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_norm_txt_a,...
                                        'HorizontalAlignment','left',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'String',str_norm_txt...
                                        );
        edi_norm_val_a  = uicontrol(...
                                        'Style','Edit',...
                                        'Unit',win_units,...
                                        'Position',pos_norm_val_a,...
                                        'String',str_norm_val_a,...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'HorizontalAlignment','center',...
                                        'tag',tag_norm_val_a...
                                        );
        txt_norm_per_a  = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_norm_per_a,...
                                        'HorizontalAlignment','center',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'String',str_norm_per...
                                        );
        txt_zeros_txt_a = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_zeros_txt_a,...
                                        'HorizontalAlignment','left',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'String',str_zeros_txt...
                                        );
        edi_zeros_val_a = uicontrol(...
                                        'Style','Edit',...
                                        'Unit',win_units,...
                                        'Position',pos_zeros_val_a,...
                                        'String',str_zeros_val_a,...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'HorizontalAlignment','center',...
                                        'tag',tag_zeros_val_a...
                                        );
        txt_zeros_per_a = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'Position',pos_zeros_per_a,...
                                        'HorizontalAlignment','center',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'String',str_zeros_per...
                                        );
        pus_auto_comp   = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_auto_comp,...
                                        'String',str_compress...
                                        );
        pus_close       = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_close,...
                                        'String',str_close,...
                                        'Interruptible','yes'...
                                        );
        drawnow

        % Parameters initialization.
        %---------------------------
        [thresh,rl2scr,n0scr,argmin,suggthr] = wpcmpscr(WP_Tree,WP_Data);
        min_sel_sli     = 0;
        max_sel_sli     = thresh(length(thresh));
        default_sel_sli = suggthr;

        % Callbacks update.
        %------------------
        cba_sel_sli     = ['wp2dcomp(''update_selglo'',' ...
                                str_win_wp2dcomp ',' ...
                                str_win_wp2dtool ',' ...
                                '''sli''' ');'];
        cba_sel_edi     = ['wp2dcomp(''update_selglo'',' ...
                                str_win_wp2dcomp ',' ...
                                str_win_wp2dtool ',' ...
                                '''edi''' ');'];
        cba_norm_val    = ['wp2dcomp(''update_selglo'',' ...
                                str_win_wp2dcomp ',' ...
                                str_win_wp2dtool ',' ...
                                '''nor''' ');'];
        cba_zeros_val   = ['wp2dcomp(''update_selglo'',' ...
                                str_win_wp2dcomp ',' ...
                                str_win_wp2dtool ',' ...
                                '''zer''' ');'];
        cba_compress    = ['wp2dcomp(''compress'',' ...
                                str_win_wp2dcomp ',' ...
                                str_win_wp2dtool ');'];
        set(sli_sel_sli,'Max',max_sel_sli,'Value',default_sel_sli,'Callback',cba_sel_sli);
        set(edi_sel_edi,'Callback',cba_sel_edi);
        set(edi_norm_val_a,'Callback',cba_norm_val);
        set(edi_zeros_val_a,'Callback',cba_zeros_val);
        set(pus_auto_comp,'Callback',cba_compress);
        set(pus_close,'Callback',cba_close_menu);

        % General graphical parameters initialization.
        %--------------------------------------------
        bdx             = 0.08*pos_win(3);
        ecx             = 0.04*pos_win(3);
        bdy             = 0.06*pos_win(4);
        ecy             = 0.03*pos_win(4);
        y_graph         = 2*Def_Btn_Height+dy;
        h_graph         = pos_frame0(4)-y_graph-Def_Btn_Height;
        w_graph         = pos_frame0(1);

        % Building axes for original image.
        %----------------------------------
        x_axe                = bdx;
        w_axe                = (w_graph-ecx-3*bdx/2)/2;
        h_axe                = (h_graph-3*bdy)/2;
        y_axe                = y_graph+h_graph-h_axe-bdy;
        cx_ori                 = x_axe+w_axe/2;
        cy_ori                 = y_axe+h_axe/2;
        cx_cmp                 = cx_ori+w_axe+ecx;
        cy_cmp                 = cy_ori;
        [w_used,h_used] = wpropimg(Img_Size,w_axe,h_axe,'pixels');
        pos_axe         = [cx_ori-w_used/2 cy_ori-h_used/2 w_used h_used];
        axe_orig        = axes(...
                                'Units',win_units,...
                                'Position',pos_axe,...
                                'Drawmode','fast',...
                                'Box','On',...
                                'Tag',tag_axe_orig);

        % Displaying original image.
        %---------------------------
        set(win_wp2dcomp,'Colormap',get(win_wp2dtool,'Colormap'));
        image([1 Img_Size(1)],[1,Img_Size(2)],...
                wimgcode('cod',0,get(wp2ddraw('r_orig',win_wp2dtool),'Cdata'),...
                                NB_ColorsInPal,codemat_v),...
                'tag',tag_img_orig);
        set(axe_orig,'Tag',tag_axe_orig);
                        
        % Set a text as a super title.
        %-----------------------------
        title('Original image');
        wtxttitl(axe_orig,'Automatic thresholding');

        % Building axes for compressed image.
        %------------------------------------
        pos_axe         = [cx_cmp-w_used/2 cy_cmp-h_used/2 w_used h_used];
        axe_comp        = axes(...
                                'Units',win_units,...
                                'Position',pos_axe,...
                                'Drawmode','fast',...
                                'Visible','off',...
                                'Box','On',...
                                'Xlim',get(axe_orig,'Xlim'),...
                                'Ylim',get(axe_orig,'Ylim'),...
                                'Tag',tag_axe_comp);

        % Displaying perfos.
        %-------------------
        x_axe           = bdx;
        y_axe           = y_graph+bdy;
        pos_axe         = [x_axe y_axe w_axe h_axe];
        axe_perfo       = axes(...
                                'Units',win_units,...
                                'Position',pos_axe,...
                                'Drawmode','fast',...
                                'Box','On',...
                                'Tag',tag_axe_perfo);
        if abs(thresh)<eps , epsx  = 0.0001; else , epsx  = 0; end;
        xaxis = [-(max(thresh)/100)-epsx    max(thresh)+(max(thresh)/100)+epsx];
        set(axe_perfo,'Xlim',xaxis,'Ylim',[0 104]);
        lin_zero    = line( 'Xdata',thresh,...
                                'Ydata',n0scr,...
                                'Color','cyan',...
                                'EraseMode','none',...
                                'Tag',tag_lin_zero);
        lin_norm        = line( 'Xdata',thresh,...
                                'Ydata',rl2scr,...
                                'Color','magenta',...
                                'EraseMode','none',...
                                'Tag',tag_lin_norm);
        lin_perfo       = line( 'Xdata',[suggthr suggthr],...
                                'Ydata',[0.5 104],...
                                'Color','y',...
                                'EraseMode','xor',...
                                'linestyle',':');
        set(axe_perfo,'Userdata',lin_perfo);

        [new_rl2scr,new_n0scr,new_thresh] = ... 
                key2info(lin_norm,lin_zero,suggthr,'T');
        set(sli_sel_sli,'value',new_thresh);
        set(edi_sel_edi,'string',sprintf('%1.4g',new_thresh));
        set(get(axe_perfo,'Userdata'),'Xdata',[new_thresh new_thresh]);
        set(edi_norm_val_a,'string',sprintf('%1.4g',new_rl2scr));
        set(edi_zeros_val_a,'string',sprintf('%1.4g',new_n0scr));

        % Displaying legend.
        %-------------------
        x_axe           = bdx+w_axe+ecx;
        y_axe           = y_graph+w_axe/3+bdy;
        h_axe           = w_axe/3;
        pos_axe_legend  = [x_axe y_axe w_axe h_axe];
        axe_legend      = wlegend(win_wp2dcomp,pos_axe_legend,Wav_Fam);
        
        % Memory blocks update.
        %----------------------
        wmemtool('ini',win_wp2dcomp,n_miscella_loc,nb4_stored);
        wmemtool('wmb',win_wp2dcomp,n_miscella_loc,                   ...
                                        ind_status,0,                        ...
                                        ind_hdl_winorig,win_wp2dtool    ...
                                        );

        % Axes attachment.
        %-----------------
        axe_cmd = [axe_orig axe_comp];
        dynvtool('attach',win_wp2dcomp,[],axe_cmd,[],[1 1],'','','');
        dynvtool('put',win_wp2dcomp);

        % Setting units to normalized.
        %-----------------------------
        set(findobj(win_wp2dcomp,'Units','pixels'),'Units','Normalized');

        % End waiting.
        %-------------
        wwaiting('off',win_wp2dcomp);

%***************************************%
%** OPTION = 'compress' - COMPRESSION **%
%***************************************%
elseif strcmp(option,'compress')
        win_wp2dcomp    = in2;
        win_wp2dtool    = in3;

        % Waiting message.
        %-----------------
        wwaiting('msg',win_wp2dcomp,'Wait ... computing');

        % Handles of tagged objects.
        %---------------------------
        axe_handles     = findobj(win_wp2dcomp,'Type','axes');
        sli_handles     = findobj(win_wp2dcomp,'Style','slider');
        lin_handles     = findobj(win_wp2dcomp,'Type','line');
        axe_comp        = findobj(axe_handles,'flat','Tag',tag_axe_comp);
        axe_orig        = findobj(axe_handles,'flat','Tag',tag_axe_orig);
        sli_sel_sli     = findobj(sli_handles,'Tag',tag_sel_sli);
        lin_norm        = findobj(lin_handles,'Tag',tag_lin_norm);
        lin_zero        = findobj(lin_handles,'Tag',tag_lin_zero);

        % Setting the compressed coefs axes invisible.
        %---------------------------------------------
        mngaxe('vis',axe_comp,'off');
        drawnow

        % Getting memory blocks.
        %-----------------------
        [WP_Tree,WP_Data]   = wmemtool('rmb',win_wp2dtool,n_structures,...
                                                ind_tree_st,ind_data_st);
        [Img_Size,Wav_Name] = wmemtool('rmb',win_wp2dtool,n_param_anal,...
                                                ind_img_size,ind_wav_name);
        Wav_Fam = wavattrb('fam_num',Wav_Name);
        NB_ColorsInPal      = wmemtool('rmb',win_wp2dtool,n_wp1d2d_utils,...
                                                ind_nb_colors);

        % Compression.
        %-------------
        threshold       = get(sli_sel_sli,'Value');
        [C_Img,C_Tree,C_Data] = wpdencmp(WP_Tree,WP_Data,...
                                    'h','nobest',threshold,1);
        [perfl2,perf0,new_thresh] = ... 
                key2info(lin_norm,lin_zero,threshold,'T');

        % Displaying compressed image.
        %------------------------------
        axes(axe_comp);
        image([1 Img_Size(1)],[1,Img_Size(2)],...
                wimgcode('cod',0,C_Img,NB_ColorsInPal,codemat_v),...
                        'tag',tag_img_comp);
        set(axe_comp,   'Xlim',get(axe_orig,'Xlim'),...
                        'Ylim',get(axe_orig,'Ylim'),...
                        'Visible','on',...
                        'Tag',tag_axe_comp);
        if strcmp(Wav_Fam,'bior')
                img_orig        = findobj(axe_orig,'tag',tag_img_orig);
                Img_Anal        = get(img_orig,'Cdata');
                perfl2          = 100*(norm(C_Img(:))/norm(Img_Anal(:)))^2;
        end

        % Set a text as a super title.
        %-----------------------------
        str_norm_txt        = 'Retained energy ';
        title('Compressed image');       
        txt_comp = [str_norm_txt num2str(perfl2) ...
                    ' % -- Zeros ' num2str(perf0) ' %'];
        wtxttitl(axe_comp,txt_comp);
        
        % Memory blocks update.
        %----------------------
        wmemtool('wmb',win_wp2dcomp,n_miscella_loc,ind_status,1);

        % End waiting.
        %-------------
        wwaiting('off',win_wp2dcomp);

%***************************************************************%
%** OPTION = 'update_selglo' - UPDATE INFOS FOR GLOBAL THRESH **%
%***************************************************************%
elseif strcmp(option,'update_selglo')
        win_wp2dcomp    = in2;
        win_wp2dtool    = in3;
        upd_orig        = in4;

        % Waiting message.
        %-----------------
        wwaiting('msg',win_wp2dcomp,'Wait ... computing');

        % Handles of tagged objects.
        %---------------------------
        axe_handles     = findobj(win_wp2dcomp,'Type','axes');
        axe_perfo       = findobj(axe_handles,'flat','Tag',tag_axe_perfo);
        axe_comp        = findobj(axe_handles,'flat','Tag',tag_axe_comp);
        sli_handles     = findobj(win_wp2dcomp,'Style','slider');
        edi_handles     = findobj(win_wp2dcomp,'Style','edit');
        lin_handles     = findobj(win_wp2dcomp,'Type','line');
        sli_sel_sli     = findobj(sli_handles,'Tag',tag_sel_sli);
        edi_sel_edi     = findobj(edi_handles,'Tag',tag_sel_edi);
        edi_norm_val_a  = findobj(edi_handles,'Tag',tag_norm_val_a);
        edi_zeros_val_a = findobj(edi_handles,'Tag',tag_zeros_val_a);
        lin_norm        = findobj(lin_handles,'Tag',tag_lin_norm);
        lin_zero        = findobj(lin_handles,'Tag',tag_lin_zero);

        % Setting the compressed coefs axes invisible.
        %---------------------------------------------
        mngaxe('vis',axe_comp,'off');
        drawnow

        % Updating compression information.
        %----------------------------------
        if      upd_orig=='sli'
                new_thresh      = get(sli_sel_sli,'value');
                [new_rl2scr,new_n0scr,new_thresh] = ... 
                        key2info(lin_norm,lin_zero,new_thresh,'T');
        elseif  upd_orig=='edi'
                new_thresh      = str2num(get(edi_sel_edi,'string'));
                [new_rl2scr,new_n0scr,new_thresh] = ... 
                        key2info(lin_norm,lin_zero,new_thresh,'T');
        elseif  upd_orig=='nor'
                new_rl2scr      = str2num(get(edi_norm_val_a,'string'));
                [new_rl2scr,new_n0scr,new_thresh] = ... 
                        key2info(lin_norm,lin_zero,new_rl2scr,'N');
        elseif  upd_orig=='zer'
                new_n0scr       = str2num(get(edi_zeros_val_a,'string'));
                [new_rl2scr,new_n0scr,new_thresh] = ... 
                        key2info(lin_norm,lin_zero,new_n0scr,'Z');
        end
        if isempty(new_thresh)|isempty(new_rl2scr)|isempty(new_n0scr)
                new_thresh      = get(sli_sel_sli,'value');
                [new_rl2scr,new_n0scr,new_thresh] = ... 
                        key2info(lin_norm,lin_zero,new_thresh,'T');
        end

        set(sli_sel_sli,'value',new_thresh);
        set(edi_sel_edi,'string',sprintf('%1.4g',new_thresh));
        set(edi_norm_val_a,'string',sprintf('%1.4g',new_rl2scr));
        set(edi_zeros_val_a,'string',sprintf('%1.4g',new_n0scr));

        newline     = 1;
        xnew        = [new_thresh new_thresh];
        lin_per     = get(axe_perfo,'Userdata');
        xold        = get(lin_per,'Xdata');
        if ~isempty(xold)
                if size(xold)==[1 2]
                        if abs(xold - xnew)<sqrt(eps)
                                newline        = 0;
                        end
                end
        end
        if newline
                if      strcmp(Machine(1:3),'PCW')
                        yper = get(lin_per,'Ydata');
                        delete(lin_per)
                        axes(axe_perfo);
                        lin_per = line(...
                                        'Xdata',xnew,...
                                        'ydata',yper,...
                                        'Color','y',...
                                        'linestyle',':');
                        set(axe_perfo,'Userdata',lin_per);
                else
                        set(lin_per,'Xdata',xnew);
                end

        end

        % Memory blocks update.
        %----------------------
        wmemtool('wmb',win_wp2dcomp,n_miscella_loc,ind_status,0);

        % End waiting.
        %-------------
        wwaiting('off',win_wp2dcomp);

%**************************************%
%** OPTION = 'close' -  CLOSE FIGURE **%
%**************************************%
elseif strcmp(option,'close')
        win_wp2dcomp    = in2;

        [status,hdl_winorig] = wmemtool('rmb',win_wp2dcomp,n_miscella_loc,...
                                        ind_status,ind_hdl_winorig);
        if status==1

                % Test for Updating.
                %--------------------
                status = wwaitans(win_wp2dcomp,...
                                  'Update the synthesized image ?',2,'cancel');

        end
        if status==1
                wwaiting('msg',win_wp2dcomp,'Wait ... computing');
                img_comp = findobj(win_wp2dcomp,'type','image',...
                                                'tag',tag_img_comp);
                wp2dmngr('return_comp',hdl_winorig,status,img_comp);
                wwaiting('off',win_wp2dcomp);
        elseif  status==0
                wp2dmngr('return_comp',hdl_winorig,status);
        else

        end
        out1 = status;

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('wp2dcomp','Unknown Option','msg');
        error('*');
end

