function out1 = wp2dstat(option,in2,in3,in4,in5)
%WP2DSTAT Wavelet packets 2D statistics.
%       out1 = wp2dstat(option,in2,in3,in4,in5)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.

%       Uses WMEMTOOL.

global  Def_Btn_Height  Def_Btn_Width   ...
        Pop_Min_Width   X_Graph_Ratio   ...
        X_Spacing       Y_Spacing       ...
        Def_TxtBkColor  Def_EdiBkColor  ...
        Def_FraBkColor  Def_FraFgColor

if nargin==0, option = 'create'; end

% Image Coding Value.
%-------------------
codemat_v       = wimgcode('get');

% MemBloc1 of stored values.
%---------------------------
n_param_anal    = 'WP2D_Par_Anal';
ind_img_name    =  1;
ind_wav_name    =  2;
ind_lev_anal    =  3;
ind_ent_anal    =  4;
ind_ent_par     =  5;
ind_img_size    =  6;
ind_img_t_name  =  7;
ind_act_option  =  8;
nb1_stored      =  8;

% MemBloc2 of stored values.
%---------------------------
n_wp1d2d_utils  = 'WP1D2D_Utils';
ind_tree_lin    =  1;
ind_tree_txt    =  2;
ind_type_txt    =  3;
ind_sel_nodes   =  4;
ind_gra_area    =  5;
ind_nb_colors   =  6;
ind_wav_len     =  7;
nb2_stored      =  7;

% MemBloc3 of stored values.
%---------------------------
n_structures    = 'Structures';
ind_tree_st     =  1;
ind_data_st     =  2;
nb3_stored      =  2;

% MemBloc4 of stored values.
%---------------------------
n_miscella_loc  = 'WPStat2D_Misc';
ind_curr_img    = 1;
ind_curr_color  = 2;
nb4_stored      = 2;

% Tag property of objects.
%-------------------------
tag_sel_cfs     = 'Sel_Cfs';
tag_sel_rec     = 'Sel_Rec';
tag_bins_txt    = 'Bins_Txt';
tag_bins_data   = 'Bins_Data';
tag_mean_val    = 'Mean_Val';
tag_med_val     = 'Med_Val';
tag_mode_val    = 'Mode_Val';
tag_max_val     = 'Max_Val';
tag_min_val     = 'Min_Val';
tag_range_val   = 'Range_Val';
tag_std_val     = 'Std_Val';
tag_mad_val     = 'Mad_Val';
tag_madm_val    = 'Madm_Val';
tag_ax_image    = 'Ax_Image';
tag_ax_hist     = 'Ax_Hist';
tag_ax_cumhist  = 'Ax_Cumhist';
tag_show_stat   = 'Show_Stat';

%*****************************************************************%
%** OPTION = 'create' - constructs the initial wp2dstat window  **%
%*****************************************************************%
if strcmp(option,'create')

        % Calling figure and node.
        %-------------------------
        win_wp2dtool     = in2;
        node             = in3;
        str_win_wp2dtool = int2str(win_wp2dtool);
        str_node         = int2str(node);

        % Window initialization.
        %----------------------
        win_name = 'Wavelet Packet 2-D  --  Statistics';
        [win_wp2dstat,pos_win,cba_close_menu] = ...
                wfigcrea('create',NaN,win_name,'',win_wp2dtool,...
                        str2mat('-p','-0','-w'),'wp2dstat');
        str_numwin = int2str(win_wp2dstat);
        win_units  = 'pixels';
        out1       = win_wp2dstat;

        % Command frame and Dynamical visualization tool construction.
        %-------------------------------------------------------------
        [frame0,pos_frame0,Pos_Graphic_Area] = ...
                        wfigcrea('frame',win_wp2dstat,'','title');

        % Waiting Frame construction & begin waiting.
        %--------------------------------------------
        wwaiting('create',win_wp2dstat,X_Graph_Ratio,...
                        'Wait ... initialization');

        % Getting global variables from wp2dtool figure memory block.
        %------------------------------------------------------------
        WP_Tree         = wmemtool('rmb',win_wp2dtool,n_structures,...
                                                ind_tree_st);
        Depth           = wtreemgr('depth',WP_Tree);
        [Img_Name,Img_Size,Wave_Name,Ent_Name,Ent_Par] =                ...
                        wmemtool('rmb',win_wp2dtool,n_param_anal,      ...
                                        ind_img_name,ind_img_size,      ...
                                        ind_wav_name,ind_ent_anal,      ...
                                        ind_ent_par);
        [Wav_Fam,Wav_Num] = wavattrb('fam_num',Wave_Name);

        % General graphical parameters initialization.
        %--------------------------------------------

        % Borders and double borders.
        dx  = X_Spacing;  dx2 = 2*dx;
        dy  = Y_Spacing;  dy2 = 2*dy;

        % X init position and width of frames.
        gra_width       = Pos_Graphic_Area(3);
        x_frame0        = pos_frame0(1);
        cmd_width       = pos_frame0(3);
        h_frame0        = pos_frame0(4);

        % Buttons width
        push_width      = (cmd_width-4*dx)/2;
        txt_width       = Def_Btn_Width;
        pop_width       = Pop_Min_Width;

        % Parameters initialization.
        %---------------------------
        default_bins    = 50;

        % Position property of objects.
        %------------------------------
        pos_input_txt   = [     x_frame0+dx2                            ,...
                                h_frame0-3*dy-Def_Btn_Height            ,...
                                txt_width                               ,...
                                Def_Btn_Height                          ];
        pos_input_data  = [     pos_input_txt(1)+pos_input_txt(3)+dx    ,...
                                pos_input_txt(2)                        ,...
                                2*pop_width                             ,...
                                Def_Btn_Height                          ];
        pos_wav_txt     = pos_input_txt;
        pos_wav_txt(2)  = pos_input_txt(2)-Def_Btn_Height-dy2;
        pos_wav_fams    = [     pos_wav_txt(1)+pos_wav_txt(3)+dx        ,...
                                pos_wav_txt(2)                          ,...
                                pop_width                               ,...
                                Def_Btn_Height                          ];
        pos_wav_nums    = [     pos_wav_fams(1)+pos_wav_fams(3)+dx/2    ,...
                                pos_wav_fams(2)                         ,...
                                pop_width-dx/2                          ,...
                                Def_Btn_Height                          ];
        pos_lev_txt     = pos_wav_txt;
        pos_lev_txt(2)  = pos_wav_txt(2)-Def_Btn_Height-dy2;
        pos_lev_data    = [     pos_lev_txt(1)+pos_lev_txt(3)+dx        ,...
                                pos_lev_txt(2)                          ,...
                                pop_width                               ,...
                                Def_Btn_Height                          ];
        pos_ent_txt     = pos_lev_txt;
        pos_ent_txt(2)  = pos_ent_txt(2)-Def_Btn_Height-dy2;
        pos_ent_val     = [     pos_ent_txt(1)+pos_ent_txt(3)+dx        ,...
                                pos_ent_txt(2)                          ,...
                                2*Pop_Min_Width                         ,...
                                Def_Btn_Height                          ];
        pos_ent_par     = pos_ent_txt;
        pos_ent_par(2)  = pos_ent_par(2)-Def_Btn_Height-dy2;
        pos_ent_par(3)  = pos_ent_par(3)+dx/2;
        pos_uic_ent     = [     pos_ent_par(1)+pos_ent_par(3)+dx/2      ,...
                                pos_ent_par(2)                          ,...
                                2*Pop_Min_Width                         ,...
                                Def_Btn_Height                          ];
        px              = x_frame0+(cmd_width-5*push_width/4)/2;
        pos_sel_cfs     = [     px                                      ,...
                                pos_ent_par(2)-4*Def_Btn_Height         ,...
                                5*push_width/4                          ,...
                                3*Def_Btn_Height/2                      ];
        pos_sel_rec     = [     pos_sel_cfs(1)                          ,...
                                pos_sel_cfs(2)-3*Def_Btn_Height         ,...
                                5*push_width/4                          ,...
                                3*Def_Btn_Height/2                      ];
        px              = x_frame0+(cmd_width-3*pop_width)/2;
        pos_bins_txt    = [     px                                      ,...
                                pos_sel_rec(2)-3*Def_Btn_Height         ,...
                                2*pop_width                             ,...
                                Def_Btn_Height                          ];
        pos_bins_data   = pos_bins_txt;
        pos_bins_data(1)= pos_bins_txt(1)+pos_bins_txt(3)+dx;
        pos_bins_data(3)= pop_width;
        px              = x_frame0+(cmd_width-3*push_width/2)/2;
        pos_show_stat   = [     px                                      ,...
                                pos_bins_data(2)-3*Def_Btn_Height       ,...
                                3*push_width/2                          ,...
                                2*Def_Btn_Height                        ];
        px              = x_frame0+(cmd_width-7*push_width/4)/2;
        pos_close       = [     px                                      ,...
                                pos_frame0(2)+Def_Btn_Height            ,...
                                7*push_width/4                          ,...
                                3*Def_Btn_Height/2                      ];

        h_frame1        = 3*Def_Btn_Height+8*dy;
        pos_frame1      = [     dx2                                     ,...
                                dy2                                     ,...
                                gra_width-2*dx2                         ,...
                                h_frame1                                ];

        wx              = (pos_frame1(3)-4*dx)/8;
        pos_mean_txt    = [     pos_frame1(1)+dx                        ,...
                                pos_frame1(2)+h_frame1-Def_Btn_Height-dy2,...
                                4*wx/5                                  ,...
                                Def_Btn_Height                          ];
        pos_med_txt     = [     pos_mean_txt(1)                         ,...
                                pos_mean_txt(2)-Def_Btn_Height-dy2      ,...
                                4*wx/5                                  ,...
                                Def_Btn_Height                          ];
        pos_mode_txt    = [     pos_mean_txt(1)                         ,...
                                pos_med_txt(2)-Def_Btn_Height-dy2       ,...
                                4*wx/5                                  ,...
                                Def_Btn_Height                          ];
        px              = pos_mean_txt(1)+pos_mean_txt(3)+dx+6*wx/5;
        pos_max_txt     = [     px                                      ,...
                                pos_frame1(2)+h_frame1-Def_Btn_Height-dy2,...
                                wx                                      ,...
                                Def_Btn_Height                          ];
        pos_min_txt     = [     pos_max_txt(1)                          ,...
                                pos_max_txt(2)-Def_Btn_Height-dy2       ,...
                                wx                                      ,...
                                Def_Btn_Height                          ];
        pos_range_txt   = [     pos_max_txt(1)                          ,...
                                pos_min_txt(2)-Def_Btn_Height-dy2       ,...
                                wx                                      ,...
                                Def_Btn_Height                          ];
        px              = pos_max_txt(1)+pos_max_txt(3)+dx+6*wx/5;
        pos_std_txt     = [     px                                      ,...
                                pos_frame1(2)+h_frame1-Def_Btn_Height-dy2,...
                                13*wx/5                                 ,...
                                Def_Btn_Height                          ];
        pos_mad_txt     = [     pos_std_txt(1)                          ,...
                                pos_std_txt(2)-Def_Btn_Height-dy2       ,...
                                13*wx/5                                 ,...
                                Def_Btn_Height                          ];
        pos_madm_txt    = [     pos_mad_txt(1)                          ,...
                                pos_mad_txt(2)-Def_Btn_Height-dy2       ,...
                                13*wx/5                                 ,...
                                Def_Btn_Height                          ];
        pos_mean_val    = [     pos_mean_txt(1)+pos_mean_txt(3)         ,...
                                pos_mean_txt(2)                         ,...
                                6*wx/5                                  ,...
                                Def_Btn_Height                          ];
        pos_med_val     = [     pos_med_txt(1)+pos_med_txt(3)           ,...
                                pos_med_txt(2)                          ,...
                                6*wx/5                                  ,...
                                Def_Btn_Height                          ];
        pos_mode_val    = [     pos_mode_txt(1)+pos_mode_txt(3)         ,...
                                pos_mode_txt(2)                         ,...
                                6*wx/5                                  ,...
                                Def_Btn_Height                          ];
        pos_max_val     = [     pos_max_txt(1)+pos_max_txt(3)           ,...
                                pos_max_txt(2)                          ,...
                                6*wx/5                                  ,...
                                Def_Btn_Height                          ];
        pos_min_val     = [     pos_min_txt(1)+pos_min_txt(3)           ,...
                                pos_min_txt(2)                          ,...
                                6*wx/5                                  ,...
                                Def_Btn_Height                          ];
        pos_range_val   = [     pos_range_txt(1)+pos_range_txt(3)       ,...
                                pos_range_txt(2)                        ,...
                                6*wx/5                                  ,...
                                Def_Btn_Height                          ];
        pos_std_val     = [     pos_std_txt(1)+pos_std_txt(3)           ,...
                                pos_std_txt(2)                          ,...
                                6*wx/5                                  ,...
                                Def_Btn_Height                          ];
        pos_mad_val     = [     pos_mad_txt(1)+pos_mad_txt(3)           ,...
                                pos_mad_txt(2)                          ,...
                                6*wx/5                                  ,...
                                Def_Btn_Height                          ];
        pos_madm_val    = [     pos_madm_txt(1)+pos_madm_txt(3)         ,...
                                pos_madm_txt(2)                         ,...
                                6*wx/5                                  ,...
                                Def_Btn_Height                          ];

        % String property of objects.
        %----------------------------
        str_input_txt   = 'Image';
        str_input_data  = Img_Name;
        str_wav_txt     = 'Wavelet';
        str_wav_fams    = Wav_Fam;
        str_wav_nums    = Wav_Num;
        str_lev_txt     = 'Level';
        str_lev_data    = int2str(Depth);
        str_ent_txt     = 'Entropy';
        [str_ent_val,str_ent_par] = wpentmng('t',Ent_Name);
        str_uic_ent     = num2str(Ent_Par);
        str_sel_cfs     = 'Coefficients';
        str_sel_rec     = 'Reconstructed';
        str_bins_txt    = 'Number of bins';
        str_bins_data   = int2str(default_bins);
        str_show_stat   = 'Show statistics';
        str_close       = 'Close';
        str_mean_txt    = 'Mean';
        str_med_txt     = 'Median';
        str_mode_txt    = 'Mode';
        str_max_txt     = 'Maximum';
        str_min_txt     = 'Minimum';
        str_range_txt   = 'Range';
        str_std_txt     = 'Standard deviation';
        str_mad_txt     = 'Median absolute deviation';
        str_madm_txt    = 'Mean absolute deviation';

        % Command part construction of the window.
        %-----------------------------------------
        figure(win_wp2dstat);
        txt_input_txt   = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_input_txt,...
                                        'String',str_input_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_input_data  = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_input_data,...
                                        'String',str_input_data,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_wav_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_wav_txt,...
                                        'String',str_wav_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_wav_fams    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_wav_fams,...
                                        'String',str_wav_fams,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        if ~isempty(str_wav_nums)
        txt_wav_nums    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_wav_nums,...
                                        'String',str_wav_nums,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        end
        txt_lev_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_lev_txt,...
                                        'String',str_lev_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_lev_data    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_lev_data,...
                                        'String',str_lev_data,...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_ent_txt     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_ent_txt,         ...
                                        'String',str_ent_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        txt_ent_val     = uicontrol(...
                                        'Style','text', ...
                                        'Unit',win_units,       ...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_ent_val, ...
                                        'String',str_ent_val,   ...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        nument          = wpentmng('g',Ent_Name);
        if find(nument==[2 3 5 6])
                txt_ent_par     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_ent_par,         ...
                                        'String',str_ent_par,           ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
                uic_ent         = uicontrol(...
                                        'Style','text',         ...
                                        'Unit',win_units,       ...
                                        'Position',pos_uic_ent, ...
                                        'HorizontalAlignment','center', ...
                                        'String',str_uic_ent,   ...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        end
        drawnow
        rad_sel_cfs     = uicontrol(...
                                        'Style','Radiobutton',...
                                        'Unit',win_units,...
                                        'Position',pos_sel_cfs,...
                                        'String',str_sel_cfs,...
                                        'Tag',tag_sel_cfs,...
                                        'Userdata',0,...
                                        'Value',0);
        rad_sel_rec     = uicontrol(...
                                        'Style','Radiobutton',...
                                        'Unit',win_units,...
                                        'Position',pos_sel_rec,...
                                        'String',str_sel_rec,...
                                        'Tag',tag_sel_rec,...
                                        'Userdata',1,...
                                        'Value',1);
        txt_bins_txt    = uicontrol(...
                                        'Style','text',...
                                        'Unit',win_units,...
                                        'Position',pos_bins_txt,...
                                        'String',str_bins_txt,...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_bins_txt...
                                        );
        edi_bins_data   = uicontrol(...
                                        'Style','Edit',...
                                        'Units',win_units,...
                                        'Position',pos_bins_data,...
                                        'String',str_bins_data,...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'Tag',tag_bins_data...
                                        );
        pus_show_stat   = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_show_stat,...
                                        'String',str_show_stat,...
                                        'Userdata',[],...
                                        'Tag',tag_show_stat...
                                        );
        pus_close       = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_close,...
                                        'String',str_close,...
                                        'Interruptible','yes'...
                                        );
        drawnow
        fra_frame1      = uicontrol(...
                                        'Style','frame',...
                                        'Unit',win_units,...
                                        'Position',pos_frame1,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_TxtBkColor,...
                                        'Foregroundcolor','k'...
                                        );
        txt_mean_txt    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_mean_txt,...
                                        'String',str_mean_txt,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_mean_val    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_mean_val,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_mean_val...
                                        );
        txt_med_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_med_txt,...
                                        'String',str_med_txt,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_med_val     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_med_val,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_med_val...
                                        );
        drawnow
        txt_mode_txt    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_mode_txt,...
                                        'String',str_mode_txt,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_mode_val    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_mode_val,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_mode_val...
                                        );
        txt_max_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_max_txt,...
                                        'String',str_max_txt,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_max_val     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_max_val,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_max_val...
                                        );
        txt_min_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_min_txt,...
                                        'String',str_min_txt,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_min_val     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_min_val,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_min_val...
                                        );
        drawnow
        txt_range_txt   = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_range_txt,...
                                        'String',str_range_txt,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_range_val   = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_range_val,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_range_val...
                                        );
        txt_std_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_std_txt,...
                                        'String',str_std_txt,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_std_val     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_std_val,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_std_val...
                                        );
        txt_mad_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_mad_txt,...
                                        'String',str_mad_txt,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_mad_val     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_mad_val,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_mad_val...
                                        );
        txt_madm_txt    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_madm_txt,...
                                        'String',str_madm_txt,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_TxtBkColor...
                                        );
        txt_madm_val    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','center',...
                                        'Position',pos_madm_val,...
                                        'Visible','off',...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_madm_val...
                                        );
        drawnow

        % Sets of handles.
        %-----------------
        infos_hdls      = [     fra_frame1
                                txt_mean_txt
                                txt_med_txt
                                txt_mode_txt
                                txt_max_txt
                                txt_min_txt
                                txt_range_txt
                                txt_std_txt
                                txt_mad_txt
                                txt_madm_txt
                                txt_mean_val
                                txt_med_val
                                txt_mode_val
                                txt_max_val
                                txt_min_val
                                txt_range_val
                                txt_std_val
                                txt_mad_val
                                txt_madm_val];

        % Callbacks update.
        %------------------
        str_infos_hdls          = num2mstr(infos_hdls);
        str_rad_sel_rec         = num2mstr(rad_sel_rec);
        str_rad_sel_cfs         = num2mstr(rad_sel_cfs);
        str_edi_bins_data       = num2mstr(edi_bins_data);
        cba_sel_rec             = ['wp2dstat(''select'',' ...
                                        str_numwin ',' ...
                                        str_rad_sel_rec ',' ...
                                        str_infos_hdls ...
                                        ');'];
        cba_sel_cfs             = ['wp2dstat(''select'',' ...
                                        str_numwin ',' ...
                                        str_rad_sel_cfs ',' ...
                                        str_infos_hdls ...
                                        ');'];
        cba_bins_data           = ['wp2dstat(''update_bins'',' ...
                                        str_numwin ',' ...
                                        str_edi_bins_data ',' ...
                                        str_infos_hdls ...
                                        ');'];
        cba_show_stat           = ['wp2dstat(''draw'',' ...
                                        str_numwin ',' ...
                                        str_win_wp2dtool ',' ...
                                        str_infos_hdls ',' ...
                                        str_node ...
                                        ');'];

        set(rad_sel_rec,'Callback',cba_sel_rec);
        set(rad_sel_cfs,'Callback',cba_sel_cfs);
        set(edi_bins_data,'Callback',cba_bins_data);
        set(pus_show_stat,'Callback',cba_show_stat);
        set(pus_close,'Callback',cba_close_menu);

        % Axes construction.
        %-------------------
        xspace          = gra_width/10;
        yspace          = pos_frame0(4)/10;
        axe_height      = (pos_frame0(4)-Def_Btn_Height-h_frame1-4*dy)/2-yspace;
        axe_width       = gra_width-2*xspace;
        half_width      = axe_width/2-xspace/2;

        cx              = xspace-axe_height/2+axe_width/2;
        cx              = gra_width/2;

        cy              = h_frame1+2*dy2+axe_height+4*yspace/3+axe_height/2;
        [w_used,h_used] = wpropimg(Img_Size,axe_width,axe_height,'pixels');
        pos_ax_image    = [cx-w_used/2,cy-h_used/2,w_used,h_used];
        pos_ax_hist     = [xspace h_frame1+2*dy2+yspace/3 ...
                                 half_width axe_height];
        pos_ax_cumhist  = [2*xspace+half_width h_frame1+2*dy2+yspace/3 ...
                                 half_width axe_height];
        axe_ax_image    = axes(...
                                'Units',win_units,...
                                'Position',pos_ax_image,...
                                'Visible','Off',...
                                'box','on',...
                                'NextPlot','Replace',...
                                'Drawmode','fast',...
                                'Tag',tag_ax_image...
                                );
        axe_ax_hist     = axes(...
                                'Units',win_units,...
                                'Position',pos_ax_hist,...
                                'Visible','Off',...
                                'box','on',...
                                'NextPlot','Replace',...
                                'Drawmode','fast',...
                                'Tag',tag_ax_hist...
                                );
        axe_ax_cumhist  = axes(...
                                'Units',win_units,...
                                'Position',pos_ax_cumhist,...
                                'Visible','Off',...
                                'box','on',...
                                'NextPlot','Replace',...
                                'Drawmode','fast',...
                                'Tag',tag_ax_cumhist...
                                );
        drawnow

        % Displaying the window title.
        %-----------------------------
        str_par = [];
        if find(nument==[2 3 5 6])
                str_par = [' (' lower(str_ent_par) ' = ',num2str(Ent_Par),')'];
        end

        str_nb_val      = [' (' int2str(Img_Size(1)) ' x ' int2str(Img_Size(2)) ')'];
        str_wintitle    = [Img_Name,str_nb_val,' analyzed at level ',...
                           int2str(Depth),' with ',Wave_Name,...
                           ' and ''',str_ent_val,''' entropy',str_par];
        wfigtitl('string',win_wp2dstat,str_wintitle,'off');

        % Setting units to normalized.
        %-----------------------------
        set(findobj(win_wp2dstat,'Units','pixels'),'Units','Normalized');

        % End waiting.
        %-------------
        wwaiting('off',win_wp2dstat);

%***********************************************%
%** OPTION = 'select' - SIGNAL TYPE SELECTION **%
%***********************************************%
elseif strcmp(option,'select')
        win_wp2dstat    = in2;
        sel_rad_btn     = in3;
        infos_hdls      = in4;

        % Set to the current selection.
        %------------------------------
        rad_handles     = findobj(win_wp2dstat,'Style','radiobutton');
        old_rad         = findobj(rad_handles,'Userdata',1);
        set(rad_handles,'Value',0,'Userdata',0);
        set(sel_rad_btn,'Value',1,'Userdata',1)
        if old_rad==sel_rad_btn , return; end

        % Reset all.
        %-----------
        set(infos_hdls,'Visible','off');
        axe_handles     = findobj(win_wp2dstat,'Type','axes');
        axe_ax_image   = findobj(axe_handles,'flat','Tag',tag_ax_image);
        axe_ax_hist     = findobj(axe_handles,'flat','Tag',tag_ax_hist);
        axe_ax_cumhist  = findobj(axe_handles,'flat','Tag',tag_ax_cumhist);
        mngaxe('vis',[axe_ax_image,axe_ax_hist,axe_ax_cumhist],'off');
        drawnow

%**********************************************%
%** OPTION = 'draw' - DRAW AXES              **%
%**********************************************%
elseif strcmp(option,'draw')
        win_wp2dstat    = in2;
        win_wp2dtool    = in3;
        infos_hdls      = in4;
        node            = in5;

        % Handles of tagged objects.
        %---------------------------
        pus_show_stat   = findobj(win_wp2dstat,...
                                        'Style','pushbutton',...
                                        'Tag',tag_show_stat...
                                        );
        axe_handles     = findobj(win_wp2dstat,'Type','axes');
        axe_ax_image    = findobj(axe_handles,'flat','Tag',tag_ax_image);
        axe_ax_hist     = findobj(axe_handles,'flat','Tag',tag_ax_hist);
        axe_ax_cumhist  = findobj(axe_handles,'flat','Tag',tag_ax_cumhist);

        rad_handles     = findobj(win_wp2dstat,'Style','radiobutton');
        edi_handles     = findobj(win_wp2dstat,'Style','edit');
        rad_sel_cfs     = findobj(rad_handles,'Tag',tag_sel_cfs);
        edi_bins_data   = findobj(edi_handles,'Tag',tag_bins_data);

        % Main parameters selection before drawing.
        %------------------------------------------
        sel_cfs         = (get(rad_sel_cfs,'Value')~=0);

        % Check the bins number.
        %-----------------------
        default_bins    = 50;
        old_params      = get(pus_show_stat,'Userdata');
        if ~isempty(old_params)
                default_bins = old_params(1);
        end
        nb_bins         = str2num(get(edi_bins_data,'String'));
        if isempty(nb_bins)
                nb_bins = default_bins;   
                set(edi_bins_data,'String',int2str(default_bins))
        elseif nb_bins<2
                nb_bins = default_bins;
                set(edi_bins_data,'String',int2str(default_bins))
        end
        new_params = [nb_bins sel_cfs node];
        if      ~isempty(old_params) & (new_params==old_params)
                vis = get(axe_ax_hist,'Visible');
                if vis(1:2)=='on', return, end
        end

        % Deseable new selection.
        %-------------------------
        set([edi_handles;rad_handles],'Enable','off');

        % Updating parameters.
        %--------------------- 
        set(pus_show_stat,'Userdata',new_params);

        % Show the status line.
        %----------------------
        wfigtitl('vis',win_wp2dstat,'on');

        % Cleaning the graphical part.
        %-----------------------------
        set(infos_hdls,'Visible','off');

        % Waiting message.
        %-----------------
        wwaiting('msg',win_wp2dstat,'Wait ... computing');

        % Cleaning the graphical part continuing.
        %----------------------------------------
        mngaxe('vis',[axe_ax_image,axe_ax_hist,axe_ax_cumhist],'off');
        drawnow

        % Handles of tagged objects continuing.
        %-------------------------------------
        txt_handles     = findobj(win_wp2dstat,'Style','text');
        txt_mean_val    = findobj(txt_handles,'Tag',tag_mean_val);
        txt_med_val     = findobj(txt_handles,'Tag',tag_med_val);
        txt_mode_val    = findobj(txt_handles,'Tag',tag_mode_val);
        txt_max_val     = findobj(txt_handles,'Tag',tag_max_val)';
        txt_min_val     = findobj(txt_handles,'Tag',tag_min_val);
        txt_range_val   = findobj(txt_handles,'Tag',tag_range_val);
        txt_std_val     = findobj(txt_handles,'Tag',tag_std_val);
        txt_mad_val     = findobj(txt_handles,'Tag',tag_mad_val);
        txt_madm_val    = findobj(txt_handles,'Tag',tag_madm_val);

        % Parameters initialization.
        %---------------------------
        NB_ColorsInPal  = wmemtool('rmb',win_wp2dtool,n_wp1d2d_utils,...
                                                ind_nb_colors);
        if node>-1

                % Getting memory blocks.
                %-----------------------
                [WP_Tree,WP_Data]       = wmemtool('rmb',win_wp2dtool,n_structures,...
                                                ind_tree_st,ind_data_st);
                Depth                   = wtreemgr('depth',WP_Tree);

                % Current image construction.
                %----------------------------
                if sel_cfs
                        curr_img = wpcoef(WP_Tree,WP_Data,node);
                        str_title= 'Coefficients of ';
                else
                        curr_img = wprcoef(WP_Tree,WP_Data,node);
                        str_title= 'Reconstructed ';
                end
                size_img        = size(curr_img);
                if size_img(1)<3 | size_img(2)<3
                        warndlg(['          Not enough coefficients ' ...
                                'remaining at level ' ...
                                int2str(level)],...
                                'Wavelet Packet 2-D -- Statistics');
                        wwaiting('off',win_wp2dstat);
                        return;
                end
                Tree_Type_TxtV  = wmemtool('rmb',win_wp2dtool,n_wp1d2d_utils,...
                                                ind_type_txt);
                order           = wtreemgr('order',WP_Tree);
                [level,pos]     = ind2depo(order,node);
                if strcmp(Tree_Type_TxtV,'i')
                        ind     = depo2ind(order,node);
                        str_pck = ['Packet ('  int2str(ind) ')'];
                else
                        str_pck = ['Packet (' int2str(level) ',' int2str(pos), ')'];
                end
                if      pos==0
                        if level==0
                                curr_color      = dw1dcolo('sig');
                                str_title       = [str_title str_pck ...
                                                   ' ---> Original image'];
                                flg_code        = 0;

                        else
                                col_app         = dw1dcolo('app',Depth);
                                curr_color      = col_app(level,:);
                                str_title       = [str_title str_pck ...
                                           ' ---> Approximation at level ' ...
                                                   int2str(level)];
                        end
                        if sel_cfs
                                flg_code        = 1;
                        else
                                flg_code        = 0;
                        end

                else
                        col_det         = dw1dcolo('det',Depth);
                        curr_color      = col_det(level,:);
                        str_title       = [str_title str_pck];
                        flg_code        = 1;
                end
        else
                curr_img = get(wpssnode('r_synt',win_wp2dtool),'Userdata');
                curr_color = 'm';
                if      node==-1
                        str_title = ['Compressed Image'];
                elseif  node==-2
                        str_title = ['De-noised Image'];
                end
                flg_code  = 0;
        end

        % Displaying the image.
        %-----------------------
        set(win_wp2dstat,'Colormap',get(win_wp2dtool,'Colormap'));
        axes(axe_ax_image);
        image(wimgcode('cod',flg_code,curr_img,NB_ColorsInPal,codemat_v));
        set(axe_ax_image,'Tag',tag_ax_image);
        title(str_title);
        drawnow;

        % Check the bins number.
        %-----------------------
        nb_bins = str2num(get(edi_bins_data,'String'));
        if isempty(nb_bins)
                nb_bins = default_bins;   
                set(edi_bins_data,'String',int2str(default_bins))
        elseif nb_bins<2
                nb_bins = default_bins;
                set(edi_bins_data,'String',int2str(default_bins))
        end

        % Displaying histogram.
        %----------------------
        his             = wgethist(curr_img(:),nb_bins);
        [xx,imod]       = max(his(2,:));
        mode_val        = (his(1,imod)+his(1,imod+1))/2;
        his(2,:)        = his(2,:)/length(curr_img(:));
        axes(axe_ax_hist);
        wplothis(axe_ax_hist,his,curr_color);
        title('Histogram');

        % Displaying cumulated histogram.
        %--------------------------------
        for i=6:4:length(his(2,:));
                his(2,i)        = his(2,i)+his(2,i-4);
                his(2,i+1)      = his(2,i);
        end
        axes(axe_ax_cumhist);
        wplothis(axe_ax_cumhist,[his(1,:);his(2,:)],curr_color);
        title('Cumulative histogram');
        drawnow;

        % Displaying statistics.
        %-----------------------
        mean_val        = mean(mean(curr_img));
        max_val         = max(max(curr_img));
        min_val         = min(min(curr_img));
        range_val       = max_val-min_val;
        std_val         = std(curr_img(:));
        med_val         = median(curr_img(:));
        set(txt_mean_val,'string',sprintf('%1.4g',mean_val));
        set(txt_med_val,'string',sprintf('%1.4g',med_val));
        set(txt_mode_val,'string',sprintf('%1.4g',mode_val));
        set(txt_max_val,'string',sprintf('%1.4g',max_val));
        set(txt_min_val,'string',sprintf('%1.4g',min_val));
        set(txt_range_val,'string',sprintf('%1.4g',range_val));
        set(txt_std_val,'string',sprintf('%1.4g',std_val));
        set(txt_mad_val,'string',...
                        sprintf('%1.4g',median(abs(curr_img(:)-med_val))));
        set(txt_madm_val,'string',...
                        sprintf('%1.4g',mean(mean(abs(curr_img-mean_val)))));

        % Memory blocks update.
        %----------------------
        wmemtool('ini',win_wp2dstat,n_miscella_loc,nb4_stored);
        wmemtool('wmb',win_wp2dstat,n_miscella_loc,                   ...
                                        ind_curr_img,curr_img(:),       ...
                                        ind_curr_color,curr_color       ...
                                        );

        % End waiting.
        %-------------
        wwaiting('off',win_wp2dstat);

        % Setting infos visible.
        %-----------------------
        set(infos_hdls,'Visible','on');

        % Enable new selection.
        %-------------------------
        set([edi_handles;rad_handles],'Enable','on');

%**************************************************************%
%** OPTION = 'update_bins' - UPDATE HISTOGRAMS WITH NEW BINS **%
%**************************************************************%
elseif strcmp(option,'update_bins')
        win_wp2dstat    = in2;
        edi_bins_data   = in3;
        infos_hdls      = in4;

        % Handles of tagged objects.
        %---------------------------
        pus_show_stat   = findobj(win_wp2dstat,...
                                        'Style','pushbutton',...
                                        'Tag',tag_show_stat...
                                        );
        axe_handles     = findobj(win_wp2dstat,'Type','axes');
        axe_ax_hist     = findobj(axe_handles,'flat','Tag',tag_ax_hist);
        axe_ax_cumhist  = findobj(axe_handles,'flat','Tag',tag_ax_cumhist);

        % Return if no current display.
        %------------------------------
        vis     = get(axe_ax_hist,'Visible');
        if vis(1:2)=='of', return, end

        % Check the bins number.
        %-----------------------
        default_bins    = 50;
        old_params      = get(pus_show_stat,'Userdata');
        if ~isempty(old_params)
                default_bins = old_params(1);
        end
        nb_bins         = str2num(get(edi_bins_data,'String'));
        if isempty(nb_bins)
                nb_bins = default_bins;   
                set(edi_bins_data,'String',int2str(default_bins))
        elseif nb_bins<2
                nb_bins = default_bins;
                set(edi_bins_data,'String',int2str(default_bins))
        end
        if default_bins==nb_bins , return; end

        % Waiting message.
        %-----------------
        set(infos_hdls,'Visible','off');
        wwaiting('msg',win_wp2dstat,'Wait ... computing');

        % Getting memory blocks.
        %-----------------------
        [curr_img,curr_color] = wmemtool('rmb',win_wp2dstat,n_miscella_loc,...
                                                        ind_curr_img,...
                                                        ind_curr_color);

        % Updating histograms.
        %---------------------
        if ~isempty(curr_img)
                old_params(1) = nb_bins;
                set(pus_show_stat,'Userdata',old_params);
                his             = wgethist(curr_img,nb_bins);
                his(2,:)        = his(2,:)/length(curr_img);
                axes(axe_ax_hist);
                wplothis(axe_ax_hist,his,curr_color);
                title('Histogram');

                for i=6:4:length(his(2,:));
                        his(2,i)        = his(2,i)+his(2,i-4);
                        his(2,i+1)      = his(2,i);
                end
                axes(axe_ax_cumhist);
                wplothis(axe_ax_cumhist,[his(1,:);his(2,:)],curr_color);
                title('Cumulative histogram');
        end

        % End waiting.
        %-------------
        wwaiting('off',win_wp2dstat);
        set(infos_hdls,'Visible','on');

%****************************************%
%** OPTION = 'demo' -  DEMOS or TESTS  **%
%****************************************%
elseif strcmp(option,'demo')
        win_wp2dstat    = in2;
        pus_show_stat   = findobj(win_wp2dstat,...
                                        'Style','pushbutton',...
                                        'Tag',tag_show_stat...
                                        );
        eval(get(pus_show_stat,'Callback'));

%****************************************%
%** OPTION = 'close' -  CLOSE FIGURE   **%
%****************************************%
elseif strcmp(option,'close')

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('wp2dstat','Unknown Option','msg');
        error('*');
end
