function [out1,out2] = wp2dtool(option,in2)
%WP2DTOOL Wavelet packets 2D tool.
%       [out1,out2] = wp2dtool(option,in2)
%
%       option = 'create' , 'close' , 'read'

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.

global  Def_Btn_Height  Def_Btn_Width   Pop_Min_Width   ...
        X_Spacing       Y_Spacing       X_Graph_Ratio   ...
        Lst_ColorMap    Def_TxtBkColor  Def_EdiBkColor  ...
        Def_FraBkColor  Def_FraFgColor

% Test inputs.
%-------------
if nargin==0
        option  = 'create'; in2 = [];
elseif nargin==1
        in2 = [];
end
[continu,option,in2] = wfigcrea('test',option,in2);
if ~continu , return; end 

% Default values.
%----------------
max_lev_anal     = 5;
min_nbcolors     = 2;
max_nbcolors     = 256;
default_nbcolors = 255;
min_bright       = -2;
max_bright       = 2;
default_bright   = 0;

% MemBloc0 of stored values.
%---------------------------
n_InfoInit      = 'WP2D_InfoInit';
ind_filename    =  1;
ind_pathname    =  2;
nb0_stored      =  2;

% MemBloc1 of stored values.
%---------------------------
n_param_anal    = 'WP2D_Par_Anal';
ind_img_name    =  1;
ind_wav_name    =  2;
ind_lev_anal    =  3;
ind_ent_anal    =  4;
ind_ent_par     =  5;
ind_img_size    =  6;
ind_img_t_name  =  7;
ind_act_option  =  8;
nb1_stored      =  8;

% MemBloc2 of stored values.
%---------------------------
n_wp1d2d_utils  = 'WP1D2D_Utils';
ind_tree_lin    =  1;
ind_tree_txt    =  2;
ind_type_txt    =  3;
ind_sel_nodes   =  4;
ind_gra_area    =  5;
ind_nb_colors   =  6;
ind_wav_len     =  7;
nb2_stored      =  7;

% MemBloc3 of stored values.
%---------------------------
n_structures    = 'Structures';
ind_tree_st     =  1;
ind_data_st     =  2;
nb3_stored      =  2;

% MemBloc4 of stored values.
%---------------------------
n_sav_struct    = 'Sav_Struct';
ind_sav_tree_st =  1;
ind_sav_data_st =  2;
nb4_stored      =  2;

% Tag property of objects.
%-------------------------
tag_m_files     = 'Files';
tag_m_savesyn   = 'Save_Syn';
tag_m_savedec   = 'Save_Dec';
tag_input_txt   = 'Input_Txt';
tag_input_data  = 'Input_Data';
tag_wav_fams    = 'Wav_Fams';
tag_wav_nums    = 'Wav_Nums';
tag_lev_data    = 'Lev_Data';
tag_pop_ent     = 'Pop_Ent';
tag_txt_entp    = 'Txt_EntP';
tag_uic_ent     = 'Uic_Ent';
tag_pus_anal    = 'Pus_Anal';
tag_pus_deno    = 'Pus_Deno';
tag_pus_comp    = 'Pus_Comp';
tag_pus_btree   = 'Pus_Btree';
tag_pus_blev    = 'Pus_Blev';
tag_inittree    = 'Pus_InitTree';
tag_wavtree     = 'Pus_WavTree';
tag_curtree     = 'Pop_CurTree';
tag_nodlab      = 'Pop_NodLab';
tag_nodact      = 'Pop_NodAct';
tag_nodsel      = 'Pus_NodSel';
tag_txt_full    = 'Txt_Full';
tag_pus_full    = str2mat(...
                        'Pus_Full.1','Pus_Full.2',...
                        'Pus_Full.3','Pus_Full.4'...
                        );
tag_cfs_map     = 'Pop_ColorMap';
tag_sli_nbc     = 'Sli_NBColors';
tag_edi_nbc     = 'Edi_NBColors';
tag_sli_bri     = 'Sli_Brightness';
tag_txt_map     = 'Txt_Map';
tag_txt_nbc     = 'Txt_Nbc';
tag_btn_close   = 'Wave_Close';
tag_axe_t_lin   = 'Axe_TreeLines';
tag_axe_t_txt   = 'Axe_TreeTexts';
tag_axe_sig     = 'Axe_Sig';
tag_axe_pack    = 'Axe_Pack';
tag_axe_cfs     = 'Axe_Cfs';
tag_axe_col     = 'Axe_Col';
tag_sli_size    = 'Sli_Size';
tag_sli_pos     = 'Sli_Pos';

%*****************************************************************%
%** OPTION = 'create' - constructs the initial wp2dtool window  **%
%*****************************************************************%
if strcmp(option,'create')

        % Wavelet Packets 2-D window initialization.
        %-------------------------------------------
        win_name = 'Wavelet Packets 2-D';
        [win_wptool,pos_win,cba_close_menu] = ...
                    wfigcrea('create',in2,win_name,'WP2Dtool','',3,'wp2dtool');
        str_numwin = int2str(win_wptool);
        win_units  = 'pixels';
        out1       = win_wptool;

        % Menu construction for current figure.
        %--------------------------------------
        lst_menu  = findobj(win_wptool,'type','uimenu','Parent',win_wptool);
        m_files   = wfindmen(lst_menu,'file');
        set(m_files,'tag',tag_m_files);
        m_loadimg = uimenu(m_files,...
                                'Label','Load Image ',          ...
                                'Position',1,                   ...
                                'Callback',                     ...
                                ['wp2dmngr(''load_img'','       ...
                                        str_numwin ');']        ...
                                );
        m_loaddec = uimenu(m_files,...
                                'Label','Load Decomposition ',  ...
                                'Position',2,                   ...
                                'Callback',                     ...
                                ['wp2dmngr(''load_dec'','       ...
                                        str_numwin ');']        ...
                                );
        m_savesyn = uimenu(m_files,...
                                'Label','Save Synthesized Image',...
                                'Position',3,                   ...
                                'Separator','on',               ...
                                'Enable','Off',                 ...
                                'Tag',tag_m_savesyn,            ...
                                'Callback',                     ...
                                ['wp2dmngr(''save_synt'','      ...
                                        str_numwin ');']        ...
                                );
        m_savedec = uimenu(m_files,...
                                'Label','Save Decomposition ',  ...
                                'Position',4,                   ...
                                'Enable','Off',                 ...
                                'Tag',tag_m_savedec,            ...
                                'Callback',                     ...
                                ['wp2dmngr(''save_dec'','       ...
                                        str_numwin ');']        ...
                                );
        m_loadtst = uimenu(m_files,...
                                'Label','Demo Analysis ',       ...
                                'Position',5,                   ...
                                'Separator','on'                ...
                                );
        %-------------------------
        beg_call_str = ['wp2dmngr(''demo'',' str_numwin];

        lab             = ['db1 - depth : 1 - ent : shannon ---> woman  '];
        end_call_str    = [',''woman'',''db1'',1,''shannon'');'];
        uimenu(m_loadtst,'Label',lab,'Callback',[beg_call_str end_call_str]);

        lab             = ['db1 - depth : 1 - ent : shannon ---> detail  '];
        end_call_str    = [',''detail'',''db1'',1,''shannon'');'];
        uimenu(m_loadtst,'Label',lab,'Callback',[beg_call_str end_call_str]);

        lab             = ['haar - depth : 2 - ent : shannon ---> tartan  '];
        end_call_str    = [',''tartan'',''haar'',2,''shannon'');'];
        uimenu(m_loadtst,'Label',lab,'Callback',[beg_call_str end_call_str]);

        lab             = ['haar - depth : 2 - ent : shannon ---> detfingr  '];
        end_call_str    = [',''detfingr'',''haar'',2,''shannon'');'];
        uimenu(m_loadtst,'Label',lab,'Callback',[beg_call_str end_call_str]);

        lab             = ['db2 - depth : 2 - ent : shannon ---> geometry  '];
        end_call_str    = [',''geometry'',''db2'',2,''shannon'');'];
        uimenu(m_loadtst,'Label',lab,'Callback',[beg_call_str end_call_str]);

        lab             = ['db2 - depth : 2 - ent : shannon ---> sinsin  '];
        end_call_str    = [',''sinsin'',''db2'',2,''shannon'');'];
        uimenu(m_loadtst,'Label',lab,'Callback',[beg_call_str end_call_str]);

        lab             = ['db2 - depth : 2 - ent : shannon ---> tire  '];
        end_call_str    = [',''tire'',''haar'',2,''shannon'');'];
        uimenu(m_loadtst,'Label',lab,'Callback',[beg_call_str end_call_str]);

        lab             = ['sym6 - depth : 2 - ent : shannon ---> Barb  '];
        end_call_str    = [',''wbarb'',''sym6'',2,''shannon'');'];
        uimenu(m_loadtst,'Label',lab,'Callback',[beg_call_str end_call_str]);

        lab             = ['coif4 - depth : 2 - ent : shannon ---> facets  '];
        end_call_str    = [',''facets'',''coif4'',2,''shannon'');'];
        uimenu(m_loadtst,'Label',lab,'Callback',[beg_call_str end_call_str]);

        lab             = ['bior4.4 - depth : 3- ent : shannon ---> noiswom  '];
        end_call_str    = [',''noiswom'',''bior4.4'',3,''shannon'');'];
        uimenu(m_loadtst,'Label',lab,'Callback',[beg_call_str end_call_str]);

        % Command frame and Dynamical visualization tool construction.
        %-------------------------------------------------------------
        [frame0,pos_frame0,Pos_Graphic_Area] = ...
                        wfigcrea('frame',win_wptool,'dynv','title');

        % Waiting Frame construction & begin waiting.
        %--------------------------------------------
        wwaiting('create',win_wptool,X_Graph_Ratio,...
                        'Wait ... initialization');

        % Borders and double borders.
        %----------------------------
        dx  = X_Spacing;        dx2 = 2*dx;
        dy  = Y_Spacing;        dy2 = 2*dy;

        % General graphical parameters initialization.
        %--------------------------------------------
        x_frame0        = pos_frame0(1);
        cmd_width       = pos_frame0(3);
        push_width      = (cmd_width-3*dx2)/2;

        % Position property of objects.
        %------------------------------
        y_low           = pos_win(4)-Def_Btn_Height-dy2;
        x_left          = x_frame0+dx2;
        pos_input_txt   = [     x_left                          ,...
                                y_low                           ,...
                                Def_Btn_Width                   ,...
                                Def_Btn_Height                  ];

        pos_input_data  = [     pos_input_txt(1)+pos_input_txt(3)+dx    ,...
                                pos_input_txt(2)                        ,...
                                2*Pop_Min_Width                         ,...
                                Def_Btn_Height                          ];

        pos_wav_txt     = pos_input_txt;
        pos_wav_txt(2)  = pos_input_txt(2)-Def_Btn_Height-dy2;

        pos_wav_fams    = [     pos_wav_txt(1)+pos_wav_txt(3)+dx        ,...
                                pos_wav_txt(2)                          ,...
                                Pop_Min_Width                           ,...
                                Def_Btn_Height                          ];

        pos_wav_nums    = pos_wav_fams;
        pos_wav_nums(1) = pos_wav_fams(1)+pos_wav_fams(3);
        pos_lev_txt     = pos_wav_txt;
        pos_lev_txt(2)  = pos_wav_txt(2)-Def_Btn_Height-dy2;
        pos_lev_data    = [     pos_lev_txt(1)+pos_lev_txt(3)+dx        ,...
                                pos_lev_txt(2)                          ,...
                                Pop_Min_Width                           ,...
                                Def_Btn_Height                          ];
        pos_ent_txt     = pos_lev_txt;
        pos_ent_txt(2)  = pos_ent_txt(2)-Def_Btn_Height-dy;
        pos_pop_ent     = [     pos_ent_txt(1)+pos_ent_txt(3)+dx        ,...
                                pos_ent_txt(2)                          ,...
                                2*Pop_Min_Width                         ,...
                                Def_Btn_Height                          ];

        pos_ent_par     = pos_ent_txt;
        pos_ent_par(2)  = pos_ent_par(2)-Def_Btn_Height-dy2;
        pos_uic_ent     = [     pos_ent_par(1)+pos_ent_par(3)+dx        ,...
                                pos_ent_par(2)                          ,...
                                2*Pop_Min_Width                         ,...
                                Def_Btn_Height                          ];

        bdx             = (cmd_width-1.5*Def_Btn_Width)/2;
        x_left          = x_frame0+bdx;
        y_low           = pos_ent_par(2)-Def_Btn_Height-4*dy2;
        pos_anal        = [     x_left                                  ,...
                                y_low                                   ,...
                                1.5*Def_Btn_Width                       ,...
                                1.5*Def_Btn_Height                      ];


        x_left          = x_frame0+dx2;
        y_low           = y_low-1.5*Def_Btn_Height-2*dy2;

        pos_comp        = [     x_left                  ,...
                                y_low                   ,...
                                push_width              ,...
                                1.5*Def_Btn_Height      ];

        pos_deno        = pos_comp;
        pos_deno(1)     = pos_deno(1)+pos_deno(3)+dx2;

        y_low           = y_low-Def_Btn_Height-2*dy2;
        pos_inittree    = [     x_left                  ,...
                                y_low                   ,...
                                push_width              ,...
                                Def_Btn_Height          ];

        pos_wavtree     = pos_inittree;
        pos_wavtree(1)  = pos_inittree(1)+pos_inittree(3)+dx2;

        y_low           = y_low-Def_Btn_Height-dy;
        pos_btree       = [     x_left                  ,...
                                y_low                   ,...
                                push_width              ,...
                                Def_Btn_Height          ];
        pos_blev        = pos_btree;
        pos_blev(1)     = pos_btree(1)+pos_btree(3)+dx2;

        y_low           = y_low-Def_Btn_Height-dy;
        pos_t_curtree   = [     x_left                          ,...
                                y_low                           ,...
                                2*(cmd_width-2*dx2-dx)/3         ,...
                                Def_Btn_Height                  ];
        pos_curtree     = pos_t_curtree;
        pos_curtree(1)  = pos_t_curtree(1)+pos_t_curtree(3)+dx;
        pos_curtree(3)  = (cmd_width-2*dx2-dx)/3;

        y_low           = y_low-Def_Btn_Height-dy2;
        pos_t_nodlab    = [     x_left                  ,...
                                y_low                   ,...
                                (cmd_width-2*dx2-dx)/2   ,...
                                Def_Btn_Height          ];
        pos_nodlab      = pos_t_nodlab;
        pos_nodlab(1)   = pos_t_nodlab(1)+pos_t_nodlab(3)+dx;
        pos_t_nodact    = pos_t_nodlab;
        pos_t_nodact(2) = pos_t_nodact(2)-Def_Btn_Height-dy;
        pos_nodact      = pos_t_nodact;
        pos_nodact(1)   = pos_t_nodact(1)+pos_t_nodact(3)+dx;
        pos_t_nodsel    = pos_t_nodact;
        pos_t_nodsel(2) = pos_t_nodsel(2)-Def_Btn_Height-dy;
        pos_t_nodsel(3) = pos_t_nodsel(3)+dx2;
        pos_nodsel      = pos_t_nodsel;
        pos_nodsel(1)   = pos_t_nodsel(1)+pos_t_nodsel(3);
        pos_nodsel(3)   = pos_nodsel(3)-3*dx;

        pos_t_nodlab(3) = pos_t_nodlab(3)-dx2;
        pos_nodlab(1)   = pos_nodlab(1)-dx2;
        pos_nodlab(3)   = pos_nodlab(3)+dx2;
        pos_t_nodact(3) = pos_t_nodact(3)-dx2;
        pos_nodact(1)   = pos_nodact(1)-dx2;
        pos_nodact(3)   = pos_nodact(3)+dx2;

        y_low           = pos_nodsel(2)-Def_Btn_Height-dy2;
        pos_txt_full    = [     x_left                                  ,...
                                y_low-Def_Btn_Height/2                  ,...
                                (cmd_width-2*dx2-dx)/3           ,...
                                Def_Btn_Height                          ];

        pos_pus_full    = zeros(4,4);
        pos_pus_full(1,:) = [   pos_txt_full(1)+pos_txt_full(3)+dx      ,...
                                y_low                                   ,...
                                (cmd_width-2*dx2-dx)/3                   ,...
                                Def_Btn_Height                          ];

        pos_pus_full(2,:) = pos_pus_full(1,:);
        pos_pus_full(2,2) = pos_pus_full(2,2)-Def_Btn_Height;

        pos_pus_full(3,:) = pos_pus_full(1,:);
        pos_pus_full(3,1) = pos_pus_full(3,1)+pos_pus_full(3,3);

        pos_pus_full(4,:) = pos_pus_full(3,:);
        pos_pus_full(4,2) = pos_pus_full(4,2)-pos_pus_full(4,4);

        xleft = x_frame0+(cmd_width-2*Def_Btn_Width-dx-Def_Btn_Width/2.4)/2;
        ylow1   = pos_pus_full(4,2)-Def_Btn_Height-3*dy2;
        ylow2   = 6*Def_Btn_Height;
        ylow    = min(ylow1,ylow2);
        pos_txt_map     = [     xleft,          ...
                                ylow,           ...
                                Def_Btn_Width,  ...
                                Def_Btn_Height];
        pos_pop_map     = pos_txt_map;
        pos_pop_map(1)  = pos_pop_map(1)+pos_txt_map(3);
        pos_txt_nbc     = pos_txt_map;
        pos_txt_nbc(2)  = pos_txt_nbc(2)-Def_Btn_Height-dy;
        pos_sli_nbc     = [     pos_txt_nbc(1)+pos_txt_nbc(3),...
                                pos_txt_nbc(2)+dy               ,...
                                Def_Btn_Width                   ,...
                                pos_txt_nbc(4)-2*dy             ...
                                ];
        pos_edi_nbc     = [     pos_sli_nbc(1)+pos_sli_nbc(3)+dx,       ...
                                pos_txt_nbc(2),                         ...
                                Def_Btn_Width/2.4,                      ...
                                Def_Btn_Height                          ...
                                ];
        pos_txt_bri     = pos_txt_nbc;
        pos_txt_bri(2)  = pos_txt_bri(2)-Def_Btn_Height-dy;
        pos_sli_bri     = [     pos_txt_bri(1)+pos_txt_bri(3),...
                                pos_txt_bri(2)+dy               ,...
                                Def_Btn_Width                   ,...
                                pos_txt_bri(4)-dy2              ...
                                ];


        px              = x_frame0+(cmd_width-7*push_width/4)/2;
        ylow1           = pos_txt_bri(2)-Def_Btn_Height-dy2;
        ylow2           = pos_frame0(2)+Def_Btn_Height;
        ylow            = min(ylow1,ylow2);
        pos_close       = [     px,                     ...
                                ylow,                   ...
                                7*push_width/4,         ...
                                3*Def_Btn_Height/2      ...
                                ];

        % String property of objects.
        %----------------------------
        str_input_txt   = 'Image';
        str_input_data  = '';
        str_wav_txt     = 'Wavelet';
        [str_wav_fams,str_wav_nums] = wavattrb('ini','dwt');
        str_lev_txt     = 'Level';
        str_levels      = [int2str(1)];
        for k=2:max_lev_anal , str_levels = str2mat(str_levels,int2str(k)); end;
        str_ent_txt     = 'Entropy';
        str_pop_ent     = str2mat('shannon', 'threshold' , 'norm',... 
                                        'log energy', 'sure', 'user');
        str_ent_par     = 'Ent. Param.';
        str_uic_ent     = '';

        str_anal        = 'Analyze';
        str_btree       = 'Best Tree';
        str_comp        = 'Compress';
        str_blev        = 'Best Level';
        str_deno        = 'De-noise';
        str_inittree    = 'Initial Tree';
        str_wavtree     = 'Wavelet Tree';
        str_t_curtree   = 'Cut Tree at Level : ';
        str_curtree     = '0';
        str_t_nodlab    = 'Node Label : ';
        str_nodlab      = 'Depth_Pos|Index|Entropy|Opt. Ent.|Size|None|Type';
        str_t_nodact    = 'Node Action : ';
        str_nodact      = 'Visualize|Split / Merge|Recons.|Select On';  
        str_nodact      = [str_nodact '|Select Off|Statistics|View Col. Cfs'];
        str_t_nodsel    = 'Select Nodes and';
        str_nodsel      = 'Reconstruct';
        str_txt_full    = 'Full Size';

        str_txt_map     = 'Colormap';
        str_txt_nbc     = 'Nb. Colors';
        str_cfs_map     = Lst_ColorMap;
        str_edi_nbc     = int2str(size(get(win_wptool,'Colormap'),1));
        str_txt_bri     = 'Brightness';
        str_close       = 'Close';

        % Callback property of objects.
        %------------------------------
        action          = '';
        cba_anal        = ['wp2dmngr(''anal'',' str_numwin ');'];
        cba_comp        = ['wp2dcomp(''create'',' str_numwin ');'];
        cba_deno        = ['wp2ddeno(''create'',' str_numwin ');'];
        cba_btree       = ['wptreeop(''best'',' str_numwin ');'];
        cba_blev        = ['wptreeop(''blvl'',' str_numwin ');'];
        cba_inittree    = ['wptreeop(''restore'',' str_numwin ');'];
        cba_wavtree     = ['wptreeop(''wp2wtree'',' str_numwin ');'];
        cba_nodact      = ['wptreeop(''nodact'',' str_numwin ');'];
        cba_pus_nodsel  = ['wptreeop(''recons'',' str_numwin ');'];

        % Command part of the window.
        %----------------------------
        figure(win_wptool);
        txt_input_txt           = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_input_txt,       ...
                                        'String',str_input_txt,         ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_input_txt             ...
                                        );
        txt_input_data          = uicontrol(...
                                        'Style','Text',                 ...
                                        'Units',win_units,              ...
                                        'Position',pos_input_data,      ...
                                        'String',str_input_data,        ...
                                        'Backgroundcolor',Def_TxtBkColor,...
                                        'Tag',tag_input_data            ...
                                        );
        txt_wav_txt     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_wav_txt,         ...
                                        'String',str_wav_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_wav_fams    = uicontrol(...
                                        'Style','Popup',        ...
                                        'Unit',win_units,       ...
                                        'Position',pos_wav_fams,...
                                        'String',str_wav_fams,  ...
                                        'Enable','off',         ...
                                        'Tag',tag_wav_fams      ...
                                        );
        pop_wav_nums    = uicontrol(...
                                        'Style','Popup',        ...
                                        'Unit',win_units,       ...
                                        'Position',pos_wav_nums,...
                                        'String',str_wav_nums,  ...
                                        'Visible','off',        ...
                                        'Enable','off',         ...
                                        'Tag',tag_wav_nums      ...
                                        );
        txt_lev_txt     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_lev_txt,         ...
                                        'String',str_lev_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_lev_data    = uicontrol(...
                                        'Style','Popup',        ...
                                        'Unit',win_units,       ...
                                        'Position',pos_lev_data,...
                                        'String',str_levels,    ...
                                        'Enable','off',         ...
                                        'Tag',tag_lev_data      ...
                                        );
        txt_ent_txt     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_ent_txt,         ...
                                        'String',str_ent_txt,           ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_ent         = uicontrol(...
                                        'Style','Popup',        ...
                                        'Unit',win_units,       ...
                                        'Position',pos_pop_ent, ...
                                        'String',str_pop_ent,   ...
                                        'Enable','off',         ...
                                        'Callback',action,      ...
                                        'Tag',tag_pop_ent       ...
                                        );

        txt_ent_par     = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'Visible','off',        ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_ent_par,         ...
                                        'String',str_ent_par,           ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_txt_entp              ...
                                        );
        uic_ent         = uicontrol(...
                                        'Style','edit',         ...
                                        'Unit',win_units,       ...
                                        'Position',pos_uic_ent, ...
                                        'Visible','off',        ...
                                        'HorizontalAlignment','center', ...
                                        'String',str_uic_ent,   ...
                                        'Enable','off',         ...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'Tag',tag_uic_ent       ...
                                        );

        pus_anal        = uicontrol(...
                                        'Style','Pushbutton',   ...
                                        'Unit',win_units,       ...
                                        'Position',pos_anal,    ...
                                        'String',str_anal,      ...
                                        'Enable','off',         ...
                                        'Tag',tag_pus_anal,     ...
                                        'Callback',cba_anal,    ...
                                        'Interruptible','yes'   ...
                                        );
        pus_comp        = uicontrol(...
                                        'Style','Pushbutton',   ...
                                        'Unit',win_units,       ...
                                        'Position',pos_comp,    ...
                                        'String',str_comp,      ...
                                        'Enable','off',         ...
                                        'Tag',tag_pus_comp,     ...
                                        'Callback',cba_comp     ...
                                        );
        pus_deno        = uicontrol(...
                                        'Style','Pushbutton',   ...
                                        'Unit',win_units,       ...
                                        'Position',pos_deno,    ...
                                        'String',str_deno,      ...
                                        'Enable','off',         ...
                                        'Tag',tag_pus_deno,     ...
                                        'Callback',cba_deno     ...
                                        );

        pus_inittree    = uicontrol(...
                                        'Style','Pushbutton',   ...
                                        'Unit',win_units,       ...
                                        'Position',pos_inittree,...
                                        'String',str_inittree,  ...
                                        'Enable','off',         ...
                                        'Tag',tag_inittree,     ...
                                        'Callback',cba_inittree ...
                                        );
        pus_wavtree     = uicontrol(...
                                        'Style','Pushbutton',   ...
                                        'Unit',win_units,       ...
                                        'Position',pos_wavtree,...
                                        'String',str_wavtree,   ...
                                        'Enable','off',         ...
                                        'Tag',tag_wavtree,      ...
                                        'Callback',cba_wavtree  ...
                                        );
        pus_btree       = uicontrol(...
                                        'Style','Pushbutton',   ...
                                        'Unit',win_units,       ...
                                        'Position',pos_btree,   ...
                                        'String',str_btree,     ...
                                        'Enable','off',         ...
                                        'Tag',tag_pus_btree,    ...
                                        'Callback',cba_btree    ...
                                        );
        pus_blev        = uicontrol(...
                                        'Style','Pushbutton',   ...
                                        'Unit',win_units,       ...
                                        'Position',pos_blev,    ...
                                        'String',str_blev,      ...
                                        'Enable','off',         ...
                                        'Tag',tag_pus_blev,     ...
                                        'Callback',cba_blev     ...
                                        );
        pop_curtree     = uicontrol(...
                                        'Style','Popupmenu',    ...
                                        'Unit',win_units,       ...
                                        'Position',pos_curtree,...
                                        'String',str_curtree,   ...
                                        'Enable','off',         ...
                                        'Tag',tag_curtree,      ...
                                        'Callback',action       ...
                                        );

        txt_cur_tree    = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_t_curtree,       ...
                                        'String',str_t_curtree,         ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );

        txt_nodlab      = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_t_nodlab,        ...
                                        'String',str_t_nodlab,          ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_nodlab      = uicontrol(...
                                        'Style','Popupmenu',    ...
                                        'Unit',win_units,       ...
                                        'Position',pos_nodlab,...
                                        'String',str_nodlab,    ...
                                        'Enable','off',         ...
                                        'Tag',tag_nodlab        ...
                                        );
        txt_nodact      = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_t_nodact,        ...
                                        'String',str_t_nodact,          ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_nodact      = uicontrol(...
                                        'Style','Popupmenu',    ...
                                        'Unit',win_units,       ...
                                        'Position',pos_nodact,...
                                        'String',str_nodact,    ...
                                        'Enable','off',         ...
                                        'CallBack',cba_nodact,  ...
                                        'Tag',tag_nodact        ...
                                        );
        txt_nodsel      = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_t_nodsel,        ...
                                        'String',str_t_nodsel,          ...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pus_nodsel      = uicontrol(...
                                        'Style','Pushbutton',   ...
                                        'Unit',win_units,       ...
                                        'Position',pos_nodsel,...
                                        'String',str_nodsel,    ...
                                        'Enable','off',         ...
                                        'Tag',tag_nodsel,       ...
                                        'Callback',cba_pus_nodsel...
                                        );

        txt_full        = uicontrol(...
                                        'Style','text',                 ...
                                        'Unit',win_units,               ...
                                        'HorizontalAlignment','left',   ...
                                        'Position',pos_txt_full,        ...
                                        'String',str_txt_full,          ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Tag',tag_txt_full              ...
                                        );

        for k=1:4
                pus_full(k) = uicontrol(...
                                        'Style','Pushbutton',           ...
                                        'Unit',win_units,               ...
                                        'Position',pos_pus_full(k,:),   ...
                                        'String',int2str(k),            ...
                                        'Enable','off',                 ...
                                        'Userdata',0,                   ...
                                        'Tag',tag_pus_full(k,:),        ...
                                        'Callback',action               ...
                                        );
        end

        pus_close       = uicontrol(...
                                        'Style','Pushbutton',           ...
                                        'Unit',win_units,               ...
                                        'Position',pos_close,           ...
                                        'String',str_close,             ...
                                        'Interruptible','yes',          ...
                                        'Callback',cba_close_menu,      ...
                                        'Tag',tag_btn_close             ...     
                                        );

        txt_map         = uicontrol(...
                                        'Style','Text',                 ...
                                        'Unit',win_units,               ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Position',pos_txt_map,         ...
                                        'HorizontalAlignment','left',   ...
                                        'String',str_txt_map,           ...
                                        'Tag',tag_txt_map               ...
                                        );
        pop_cfs_map     = uicontrol(...
                                        'Style','Popup',...
                                        'Unit',win_units,...
                                        'Position',pos_pop_map,...
                                        'String',str_cfs_map,...
                                        'Callback',action,...
                                        'Tag',tag_cfs_map...
                                        );

        txt_nbc         = uicontrol(...
                                        'Style','Text',                 ...
                                        'Unit',win_units,               ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'Position',pos_txt_nbc,         ...
                                        'HorizontalAlignment','left',   ...
                                        'String',str_txt_nbc,           ...
                                        'Tag',tag_txt_nbc               ...
                                        );
        
        sli_nbc         = uicontrol(...
                                        'Style','Slider',               ...
                                        'Unit',win_units,               ...
                                        'Position',pos_sli_nbc,         ...
                                        'Min',min_nbcolors,             ...
                                        'Max',max_nbcolors,             ...
                                        'Value',default_nbcolors,       ...
                                        'Tag',tag_sli_nbc               ...
                                        );                              

        edi_nbc         = uicontrol(...
                                        'Style','Edit',                 ...
                                        'Unit',win_units,               ...
                                        'Backgroundcolor',Def_EdiBkColor,...
                                        'Position',pos_edi_nbc,         ...
                                        'String',str_edi_nbc,           ...
                                        'Callback',action,              ...
                                        'Tag',tag_edi_nbc               ...
                                        );
        txt_bri         = uicontrol(...
                                        'Style','Text',                 ...
                                        'Unit',win_units,               ...
                                        'Position',pos_txt_bri,         ...
                                        'HorizontalAlignment','left',   ...
                                        'Backgroundcolor',Def_FraBkColor,...
                                        'String',str_txt_bri            ...
                                        );

        sli_bri         = uicontrol(...
                                        'Style','Slider',               ...
                                        'Unit',win_units,               ...
                                        'Position',pos_sli_bri,         ...
                                        'Min',min_bright,               ...
                                        'Max',max_bright,               ...
                                        'Value',default_bright,         ...
                                        'Tag',tag_sli_bri               ...
                                        );

        drawnow;

        %  Normalisation.
        %----------------
        Pos_Graphic_Area = Pos_Graphic_Area./[pos_win(3:4),pos_win(3:4)];
        set(findobj(win_wptool,'units','pixels'),'units','normalized');
        drawnow

        %  Axes Construction.
        %---------------------
        [       pos_axe_pack,   pos_axe_tree,   pos_axe_cfs,    ...
                pos_axe_sig,    pos_sli_size,   pos_sli_pos     ...
                pos_axe_col] =  wpposaxe(win_wptool,2,Pos_Graphic_Area);

        WP_Slider_Size = uicontrol(...
                                'Style','slider',               ...
                                'Units','normalized',           ...
                                'Visible','off',                ...
                                'Position',pos_sli_size,        ...
                                'Min',0.5,                      ...
                                'Max',10,                       ...
                                'Value',1,                      ...
                                'UserData',1,                   ...
                                'CallBack','',                  ...
                                'Tag',tag_sli_size              ...
                                );

        WP_Slider_Pos = uicontrol(...
                                'Style','slider',               ...
                                'Units','normalized',           ...
                                'Visible','off',                ...
                                'Position',pos_sli_pos, ...
                                'Min',0,                        ...
                                'Max',1,                        ...
                                'Value',0,                      ...
                                'UserData','',                  ...
                                'Tag',tag_sli_pos               ...
                                );
        drawnow;
        WP_Axe_TreeTxt = axes(...
                                'Visible','off',                        ...
                                'XLim',[-0.5,0.5],                      ...
                                'YDir','reverse',                       ...
                                'YLim',[0 1],                           ...
                                'Units','normalized',                   ...
                                'Position',pos_axe_tree,                ...
                                'XTicklabelMode','manual',              ...
                                'YTicklabelMode','manual',              ...
                                'XTickLabels',[],'YTickLabels',[],      ...
                                'XTick',[],'YTick',[],                  ...
                                'Box','On',                             ...
                                'UserData',[abs('axe_arbre_texte') 1],  ...
                                'Tag',tag_axe_t_txt                     ...
                                );

        WP_Axe_TreeLines = axes(...
                                'Visible','off',                        ...
                                'XLim',[-0.5,0.5],                      ...
                                'YDir','reverse',                       ...
                                'YLim',[0 1],                           ...
                                'Units','normalized',                   ...
                                'Position',pos_axe_tree,                ...
                                'XTicklabelMode','manual',              ...
                                'YTicklabelMode','manual',              ...
                                'XTickLabels',[],'YTickLabels',[],      ...
                                'XTick',[],'YTick',[],                  ...
                                'Box','On',                             ...
                                'UserData',abs('axe_arbre_ligne'),      ...
                                'Tag',tag_axe_t_lin                     ...
                                );
        WP_Axe_Pack = axes(...
                                'Units','normalized',                   ...
                                'Position',pos_axe_pack,                ...
                                'Visible','off',                        ...
                                'XTicklabelMode','manual',              ...
                                'YTicklabelMode','manual',              ...
                                'XTickLabels',[],'YTickLabels',[],      ...
                                'XTick',[],'YTick',[],                  ...
                                'Box','On',                             ...
                                'UserData','',                          ...
                                'Tag',tag_axe_pack                      ...
                                );
        WP_Axe_Cfs = axes(...
                                'Units','normalized',                   ...
                                'Position',pos_axe_cfs,                 ...
                                'Visible','off',                        ...
                                'XTicklabelMode','manual',              ...
                                'YTicklabelMode','manual',              ...
                                'XTickLabels',[],'YTickLabels',[],      ...
                                'XTick',[],'YTick',[],                  ...
                                'Box','On',                             ...
                                'Tag',tag_axe_cfs                       ...
                                );
        WP_Axe_Sig = axes(...
                                'Units','normalized',                   ...
                                'Position',pos_axe_sig,                 ...
                                'Visible','off',                        ...
                                'XTicklabelMode','manual',              ...
                                'YTicklabelMode','manual',              ...
                                'XTickLabels',[],'YTickLabels',[],      ...
                                'XTick',[],'YTick',[],                  ...
                                'Box','On',                             ...
                                'UserData','',                          ...
                                'Tag',tag_axe_sig                       ...
                                );

        WP_Axe_Col = axes(...
                                'Units','normalized',                   ...
                                'Position',pos_axe_col,                 ...
                                'Visible','off',                        ...
                                'XTicklabelMode','manual',              ...
                                'YTicklabelMode','manual',              ...
                                'XTickLabels',[],'YTickLabels',[],      ...
                                'XTick',[],'YTick',[],                  ...
                                'Box','On',                             ...
                                'UserData','',                          ...
                                'Tag',tag_axe_col                       ...
                                );

        % Callbacks update.
        %------------------
        cba_pop_wav_fams = [    'wavattrb(''gettnum'','         ...
                                num2mstr(pop_wav_fams) ','      ...
                                num2mstr(pop_wav_nums) ');'];

        cba_pop_wav_nums = [    'wnumbtn(1,'            ...
                                num2mstr([pop_wav_fams pop_wav_nums]) ',' ...
                                num2mstr([m_files pus_anal]) ');'];

        cba_pop_ent     = ['wpentmng(''set_ent'',' ...
                                num2mstr([pop_ent txt_ent_par uic_ent]) ');'];

        cba_pop_cfs_map = [     'mapcolor(''pal'','     ...
                                str_numwin ','                  ...
                                num2mstr(pop_cfs_map) ');'];

        cba_curtree     = ['wptreeop(''cuttree'',' str_numwin ',' ...
                                num2mstr(pop_curtree) ');'];

        cba_nodlab      = ['wpnodlab(' str_numwin ');'];

        cba_sli_size    = ['wptreeop(''slide_size'',' str_numwin ',' ...
                                num2mstr(WP_Slider_Size) ','    ...
                                num2mstr(WP_Slider_Pos) ');'];

        cba_sli_pos     = ['wptreeop(''slide_pos'',' str_numwin ',' ...
                                num2mstr(WP_Slider_Pos) ');'];

        cba_edi_nbc = [ 'mapcolor(''nbc'','             ...
                                str_numwin ','          ...
                                num2mstr([pop_cfs_map edi_nbc]) ');'];

        cba_sli_nbc = [ 'mapcolor(''nbc'','             ...
                                str_numwin ','                  ...
                                num2mstr([pop_cfs_map sli_nbc]) ');'];
        cba_sli_bri = [ 'mapcolor(''lum'',' ...
                                str_numwin ',' ...
                                num2mstr(sli_bri) ');'];

        set(pop_wav_fams,'Callback',cba_pop_wav_fams);
        set(pop_wav_nums,'Callback',cba_pop_wav_nums);
        set(pop_ent,'Callback',cba_pop_ent);
        set(pop_curtree,'Callback',cba_curtree);
        set(pop_nodlab,'Callback',cba_nodlab);
        set(WP_Slider_Size,'Callback',cba_sli_size);
        set(WP_Slider_Pos,'Callback',cba_sli_pos);
        set(pop_cfs_map,'Callback',cba_pop_cfs_map);
        set(edi_nbc,'Callback',cba_edi_nbc);
        set(sli_nbc,'Callback',cba_sli_nbc);
        set(sli_bri,'Callback',cba_sli_bri);
        for k=1:4
                cba_pus_full = ['wpfullsi(''full'','    ...
                                        str_numwin ',' int2str(k) ');'];
                set(pus_full(k),'Callback',cba_pus_full);
        end
        drawnow;

        % Memory for stored values.
        %--------------------------
        wmemtool('ini',win_wptool,n_InfoInit,nb0_stored);
        wmemtool('ini',win_wptool,n_param_anal,nb1_stored);
        wmemtool('ini',win_wptool,n_wp1d2d_utils,nb2_stored);
        wmemtool('ini',win_wptool,n_structures,nb3_stored);
        wmemtool('ini',win_wptool,n_sav_struct,nb4_stored);
        wmemtool('wmb',win_wptool,n_wp1d2d_utils,ind_gra_area,Pos_Graphic_Area);

        % Colormap Initial Value.
        %------------------------
        mapcolor('set',win_wptool,'pink',[pop_cfs_map],default_nbcolors);

        % End waiting.
        %---------------
        wwaiting('off',win_wptool);

%***********************************************%
%** OPTION = 'close' - close wp2dtool window  **%
%***********************************************%
elseif strcmp(option,'close')
        called_win = findobj(get(0,'children'),'flat','Userdata',in2);
        close(called_win);
        ssig_file = ['ssig_rec.' int2str(in2)];
        if exist(ssig_file)==2
                err = 0;
                eval(['delete ' ssig_file],'err = 1;');
        end

%**************************************************%
%** OPTION = 'read' - read tree and data struct. **%
%**************************************************%
elseif strcmp(option,'read')
        % in2 = hdl fig
        %--------------
        % out1 = tree struct
        % out2 = data struct
        %---------------------
        [out1,out2] = wmemtool('rmb',in2,n_structures,...
                                        ind_tree_st,ind_data_st);

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('wp2dtool','Unknown Option','msg');
        error('*');
end
