function [tree,data,n2m] = wp2wtree(tree,data)
%WP2WTREE Extract wavelet tree from wavelet packet tree.
%       [T,D] = WP2WTREE(T,D) computes the modified tree
%       structure T and data structure D (see MAKETREE),
%       corresponding to the wavelet decomposition tree.
%
%       See also MAKETREE, WPDEC, WPDEC2.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:26:38 $

%       Uses IND2DEPO, WCOMMON, WPJOIN, WTREEMGR.

% Check arguments.
if errargn('wp2wtree',nargin,[2],nargout,[2:3]), error('*'); end

depth = wtreemgr('depth',tree);
if depth==0
        n2m = [];
        return
end

order        = wtreemgr('order',tree);
an           = wtreemgr('allnodes',tree);
tn           = wtreemgr('tnodes',tree);
[ind_an,nul] = wcommon(an,tn);
an           = an(find(1-ind_an));

[d,p]        = ind2depo(order,an);
n2m          = [];
for k=1:order-1
        K   = find(p==k);
        n2m = [n2m an(K)];
end

for n = n2m(:)'
        [tree,data] = wpjoin(tree,data,n);
end
