function [tree,data,n2m] = wpcutree(tree,data,level)
%WPCUTREE Cut wavelet packet tree.
%       [T,D] = WPCUTREE(T,D,L) cuts the tree T at level L
%       and computes the corresponding data structure D
%       (see MAKETREE).
%
%       [T,D,RN] = WPCUTREE(T,D,L) returns the same arguments
%       as above and in addition, the vector RN contains
%       the indices of the reconstructed nodes.
%
%       See also MAKETREE, WPDEC, WPDEC2.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:27:08 $

%       Uses DEPO2IND, WCOMMON, WPJOIN, WTREEMGR.

% Check arguments.
if errargn('wpcutree',nargin,[2 3],nargout,[2 3]), error('*'); end
if nargin==2 , level = 0; end

depth = wtreemgr('depth',tree);
if      level<0
        errargt('wpcutree','invalid level value','msg'); error('*');
        return;
elseif  level>depth
        n2m = [];
        return;
elseif  depth==0
        n2m = [];
        return;
end
order   = wtreemgr('order',tree);
dp      = wtreemgr('allnodes',tree,1);
ind     = find(dp(:,1)==level);
p_an    = dp(ind,2);
dp      = wtreemgr('tnodes',tree,1);
ind     = find(dp(:,1)==level);
p_tn    = dp(ind,2);
[ii,jj] = wcommon(p_an,p_tn);
p_an    = p_an(find(ii==0));
d_an    = level*ones(size(p_an));
n2m     = depo2ind(order,[d_an p_an]);
for n = n2m(:)'
        [tree,data] = wpjoin(tree,data,n);
end

