function [out1,out2,out3,out4,out5] = wpdtool(option,in2,in3,in4,in5)
%WPDTOOL Wavelet packets display tool.
%       [out1,out2,out3,out4,out5] = wpdtool(option,in2,in3,in4,in)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:27:44 $

global  Def_Btn_Height  Def_Btn_Width   ...
        Pop_Min_Width   X_Graph_Ratio   ...
        X_Spacing       Y_Spacing       ...
        Def_TxtBkColor  Def_EdiBkColor  ...
        Def_FraBkColor  Def_FraFgColor

% MemBloc1 of stored values.
%---------------------------
n_miscella      = 'WpDisp_Misc';
ind_graph_area  =  1;
ind_wave_fam    =  2;
ind_wave_nam    =  3;
ind_maxnum      =  4;
ind_refinment   =  5;
nb1_stored      =  5;

if      nargin==0
        option  = 'create';
        in2     = [];
end

% Tag property of objects.
%-------------------------
tag_wav_fams    = 'Wav_Fams';
tag_wav_nums    = 'Wav_Num';
tag_prec_val    = 'Prec_Val';
tag_cmd_frame   = 'Cmd_Frame';
tag_pop_mod     = 'Pop_Mod';
tag_display     = 'Display';
tag_pus_inf1    = 'Pus_Inf1';
tag_pus_inf2    = 'Pus_Inf2';
tag_btn_close   = 'Wave_Close';

%****************************************************************%
%** OPTION = 'create' - constructs the initial wpdtool window  **%
%****************************************************************%
if strcmp(option,'create')

        % Window initialization.
        %----------------------
        win_name = 'Wavelets Packets W System Functions Display';
        [win_wpdtool,pos_win,cba_close_menu] = ...
                     wfigcrea('create',in2,win_name,'','',3,'wpdtool');
        str_win_wpdtool = int2str(win_wpdtool);
        win_units = 'pixels';
        out1      = win_wpdtool;

        % Command frame and Dynamical visualization tool construction.
        %-------------------------------------------------------------
        [frame0,pos_frame0,Pos_Graphic_Area] = ...
                        wfigcrea('frame',win_wpdtool,'dynv','title');


        % Waiting Frame construction & begin waiting.
        %--------------------------------------------
        wwaiting('create',win_wpdtool,X_Graph_Ratio,...
                        'Wait ... initialization');

        % General graphical parameters initialization.
        %--------------------------------------------

        % Borders and double borders.
        dx      = X_Spacing;
        dy      = Y_Spacing;
        dx2     = 2*dx;
        dy2     = 2*dy;

        % X init position and width of frames.
        x_frame0    = pos_frame0(1);
        cmd_width   = pos_frame0(3);
        h_frame0    = pos_frame0(4);

        % Buttons width
        push_width      = (cmd_width-4*dx)/2;

        % Position property of objects.
        %------------------------------
        pos_wav_txt     = [     x_frame0+dx2                            ,...
                                h_frame0-2*Def_Btn_Height               ,...
                                Def_Btn_Width                           ,...
                                Def_Btn_Height                          ];
        pos_wav_fams    = [     pos_wav_txt(1)+pos_wav_txt(3)+dx        ,...
                                pos_wav_txt(2)                          ,...
                                Pop_Min_Width+dx                        ,...
                                Def_Btn_Height                          ];
        pos_wav_nums    = pos_wav_fams;
        pos_wav_nums(1) = pos_wav_fams(1)+pos_wav_fams(3);
        pos_prec_txt    = pos_wav_txt;
        pos_prec_txt(2) = pos_wav_txt(2)-2*Def_Btn_Height;
        pos_prec_val    = pos_wav_fams;
        pos_prec_val(2) = pos_wav_nums(2)-2*Def_Btn_Height;

        pos_txt_mod     = pos_prec_txt;
        pos_txt_mod(2)  = pos_prec_txt(2)-2*Def_Btn_Height;
        pos_txt_mod(3)  = 2*pos_txt_mod(3);
        pos_pop_mod     = [     x_frame0+(cmd_width-Pop_Min_Width)/2     ,...
                                pos_txt_mod(2)-Def_Btn_Height-dy        ,...
                                Pop_Min_Width+dx                        ,...
                                Def_Btn_Height                  ];

        pos_display     = [     x_frame0+(cmd_width-3*push_width/2)/2    ,...
                                pos_wav_nums(2)-10*Def_Btn_Height       ,...
                                3*push_width/2                          ,...
                                2*Def_Btn_Height                        ];


        pos_inf_txt     = [     x_frame0+dx2                            ,...
                                pos_display(2)-3*Def_Btn_Height         ,...
                                2*Def_Btn_Width                         ,...
                                Def_Btn_Height                          ];

        pos_pus_inf1    = pos_display;
        pos_pus_inf1(2) = pos_inf_txt(2)-2*Def_Btn_Height-dy;

        pos_pus_inf2    = pos_pus_inf1;
        pos_pus_inf2(2) = pos_pus_inf1(2)-3*Def_Btn_Height;

        px              = x_frame0+(cmd_width-7*push_width/4)/2;
        pos_close       = [     px                                      ,...
                                pos_frame0(2)+Def_Btn_Height            ,...
                                7*push_width/4                          ,...
                                3*Def_Btn_Height/2                      ];

        % String property of objects.
        %----------------------------
        str_wav_txt     = 'Wavelet';
        [str_wav_fams,...
        str_wav_nums]   = wavattrb('ini','owt');
        str_mod_txt     = 'Wav. Pack. from 0 to :';
        str_pop_mod     = str2mat('1','2','3','4','5','6','7','8');
        str_pop_mod     = str2mat(str_pop_mod,'9','10','11','12','13','14');
        str_display     = 'Display';
        str_inf_txt     = 'Information on';
        str_inf1        = 'HAAR wavelet';
        str_inf2        = 'W Systems';
        str_close       = 'Close';
        str_prec_txt    = 'Refinement';
        str_prec_val    = str2mat('5','6','7','8','9','10','11','12');

        % Command part construction of the window.
        %-----------------------------------------
        figure(win_wpdtool);
        txt_wav_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_wav_txt,...
                                        'String',str_wav_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_wav_fams    = uicontrol(...
                                        'Style','Popup',...
                                        'Unit',win_units,...
                                        'Position',pos_wav_fams,...
                                        'String',str_wav_fams,...
                                        'Tag',tag_wav_fams...
                                        );
        pop_wav_nums    = uicontrol(...
                                        'Style','Popup',...
                                        'Unit',win_units,...
                                        'Position',pos_wav_nums,...
                                        'String',str_wav_nums,...
                                        'Visible','off',...
                                        'Tag',tag_wav_nums...
                                        );
        txt_prec_txt    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_prec_txt,...
                                        'String',str_prec_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_prec_val    = uicontrol(...
                                        'Style','Popup',...
                                        'Unit',win_units,...
                                        'Position',pos_prec_val,...
                                        'String',str_prec_val,...
                                        'Value',4,...
                                        'Tag',tag_prec_val...
                                        );

        txt_mod_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_txt_mod,...
                                        'String',str_mod_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_mod_dis     = uicontrol(...
                                        'Style','Popup',...
                                        'Unit',win_units,...
                                        'Position',pos_pop_mod,...
                                        'String',str_pop_mod,...
                                        'Value',6,...
                                        'Tag',tag_pop_mod...
                                        );

        pus_display     = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_display,...
                                        'String',str_display,...
                                        'Tag',tag_display...
                                        );
        txt_inf_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_inf_txt,...
                                        'String',str_inf_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pus_inf1        = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_pus_inf1,...
                                        'String',str_inf1,...
                                        'Tag',tag_pus_inf1...
                                        );
        pus_inf2        = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_pus_inf2,...
                                        'String',str_inf2,...
                                        'Tag',tag_pus_inf2...
                                        );
        pus_close       = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_close,...
                                        'String',str_close,...
                                        'Interruptible','yes',...
                                        'Userdata',0,...
                                        'Callback',cba_close_menu,      ...
                                        'Tag',tag_btn_close     ...
                                        );
        drawnow

        % Callbacks update.
        %------------------
        cba_pop_wav_fams        = [     'wpdtool(''upd_fam'',' ...
                                        str_win_wpdtool ');'];

        cba_pop_wav_nums = [    'wnumbtn(1,'            ...
                                num2mstr([pop_wav_fams pop_wav_nums]) ',' ...
                                num2mstr([pus_display]) ');'];

        cba_update              = [     'wpdtool(''new'',' ...
                                        str_win_wpdtool ');'];

        cba_draw_1d             = ['wpdtool(''draw1d'',' ...
                                        str_win_wpdtool ');'];
        cba_inf1                = ['wpdtool(''inf1'',' ...
                                        str_win_wpdtool ');'];
        cba_inf2                = ['wpdtool(''inf2'',' ...
                                        str_win_wpdtool ');'];

        set(pop_wav_fams,'Callback',cba_pop_wav_fams);
        set(pop_wav_nums,'Callback',[cba_pop_wav_nums cba_update]);
        set(pop_prec_val,'Callback',cba_update);
        set(pop_mod_dis,'Callback',cba_update);
        set(pus_display,'Callback',cba_draw_1d);
        set(pus_inf1,'Callback',cba_inf1);
        set(pus_inf2,'Callback',cba_inf2);

        % Setting units to normalized.
        %-----------------------------
        Pos_Graphic_Area = Pos_Graphic_Area./[pos_win(3:4),pos_win(3:4)];
        set(findobj(win_wpdtool,'Units','pixels'),'Units','normalized');

        % Memory for stored values.
        %--------------------------
        wmemtool('ini',win_wpdtool,n_miscella,nb1_stored);
        wmemtool('wmb',win_wpdtool,n_miscella,...
                                ind_graph_area,Pos_Graphic_Area,...
                                ind_wave_fam,'haar',            ...
                                ind_wave_nam,'haar',            ...
                                ind_maxnum,6,                   ...
                                ind_refinment,0         ...
                        );

        % End waiting.
        %-------------
        wwaiting('off',win_wpdtool);

%**********************************************************%
%** OPTION = 'upd_fam' -  UPDATE OF THE WAVELET FAMILY   **%
%**********************************************************%
elseif  strcmp(option,'upd_fam')
        win_wpdtool     = in2;
        new =  wpdtool('new',win_wpdtool);
        if new==0 , return; end

        % Handles of tagged objects.
        %---------------------------
        pop_handles     = findobj(win_wpdtool,'Style','popupmenu');
        pop_wav_fams    = findobj(pop_handles,'Tag',tag_wav_fams);
        pop_wav_nums    = findobj(pop_handles,'Tag',tag_wav_nums);
        pus_handles     = findobj(win_wpdtool,'Style','pushbutton');
        pus_inf1        = findobj(pus_handles,'Tag',tag_pus_inf1);

        % Set visible on or off the wavelet number if exists.
        %----------------------------------------------------
        [Tab_Num,Wave_Fam] = wavattrb('gettnum',pop_wav_fams,pop_wav_nums);
        if size(Tab_Num,1)<2
                str_inf1= [upper(Wave_Fam) ' wavelet'] ;
        else
                str_inf1= [upper(Wave_Fam) ' wavelets'] ;
        end
        set(pus_inf1,'String',str_inf1);

%*****************************************%
%** OPTION = 'inf1' - LOCAL INFORMATION **%
%*****************************************%
elseif strcmp(option,'inf1')
        win_wpdtool     = in2;

        % Handles of tagged objects.
        %---------------------------
        pop_handles     = findobj(win_wpdtool,'Style','popupmenu');
        pop_wav_fams    = findobj(pop_handles,'Tag',tag_wav_fams);
        fam_str         = get(pop_wav_fams,'string');
        fam_val         = get(pop_wav_fams,'value');
        infotxt         = [deblankl(fam_str(fam_val,:)) 'info.m'];
        [old_info,fig]  = whelpfun('getflag');
        if ~isempty(old_info) & strcmp(infotxt,old_info)
                figure(fig); return;
        end

        % Waiting message.
        %-----------------
        wwaiting('msg',win_wpdtool,'Wait ... loading');

        [str_inf,fid]   = wreadinf(infotxt);
        if fid==-1
                msg = ['File ' infotxt ' not found !'];
                errargt('wpdtool',msg,'msg');
                wwaiting('off',win_wpdtool);
                return
        else
                dim     = size(str_inf);
                rowfam  = str_inf(2,2:dim(2));
                str_inf = str_inf(3:dim(1),2:dim(2));
                col = 1;
                while all(str_inf(:,col)==' ')
                   col = col+1;
                end
                str_inf = str2mat(rowfam,str_inf(:,col:dim(2)-1));
        end
        whelpfun('create',str_inf,infotxt);

        % End waiting.
        %-------------
        wwaiting('off',win_wpdtool);

%*****************************************%
%** OPTION = 'inf2' - LOCAL INFORMATION **%
%*****************************************%
elseif strcmp(option,'inf2')
        win_wpdtool     = in2;

        % Handles of tagged objects.
        %---------------------------
        infotxt         = 'infowsys.m';
        [old_info,fig]  = whelpfun('getflag');
        if ~isempty(old_info) & strcmp(infotxt,old_info)
                figure(fig); return;
        end


        % Waiting message.
        %-----------------
        wwaiting('msg',win_wpdtool,'Wait ... loading');

        [str_inf,fid]   = wreadinf(infotxt);
        if fid==-1
                msg = ['File ' infotxt ' not found !'];
                errargt('wpdtool',msg,'msg');
                wwaiting('off',win_wpdtool);
                return
        else
                dim     = size(str_inf);
                str_inf = str_inf(2:dim(1),2:dim(2));
        end
        whelpfun('create',str_inf,infotxt);

        % End waiting.
        %-------------
        wwaiting('off',win_wpdtool);

%************************************************%
%** OPTION = 'draw1d' - DRAW AXES IN 1D        **%
%************************************************%
elseif  strcmp(option,'draw1d')
        win_wpdtool     = in2;
        [new,Wave_Fam,Wave_Nam,nb_func,prec_val] =  wpdtool('new',win_wpdtool);
        if new==0 , return; end

        % Waiting message.
        %-----------------
        wwaiting('msg',win_wpdtool,'Wait ... computing');

        % Handles of tagged objects.
        %---------------------------
        fra_handles     = findobj(win_wpdtool,'Style','frame');
        hdl_frame0      = findobj(fra_handles,'Tag',tag_cmd_frame);

        % Update parameters selection before drawing.
        %-------------------------------------------
        wmemtool('wmb',win_wpdtool,n_miscella,...
                                ind_wave_fam,Wave_Fam,          ...
                                ind_wave_nam,Wave_Nam,          ...
                                ind_maxnum,nb_func,             ...
                                ind_refinment,prec_val          ...
                        );

        % General graphical parameters initialization.
        %--------------------------------------------
        pos_g_area      = wmemtool('rmb',win_wpdtool,n_miscella,ind_graph_area);
        pos_hdl_frame0  = get(hdl_frame0,'Position');
        win_units       = 'normalized';
        pos_win         = get(win_wpdtool,'Position');
        bdx             = 0.08*pos_win(3);
        bdy             = 0.09*pos_win(4);
        bdy_d           = bdy;
        bdy_u           = bdy;
        w_graph         = pos_hdl_frame0(1);
        h_graph         = pos_g_area(4);

        % Computing and displaying wavelets and filters.
        %-----------------------------------------------
        wtype           = wavemngr('type',Wave_Nam);
        if      wtype==1
                str_wintitle    = [Wave_Fam '  Wavelet Packets --> ' Wave_Nam];
        else
                % End waiting.
                %-------------
                wwaiting('off',win_wpdtool);
                return;
        end
        nb_axes = nb_func+1;
        pos_axe = zeros(nb_func,4);
        if nb_axes<11
                nb2 = ceil(nb_axes/2);
                w_axe   = (w_graph-3*bdx)/2;
                h_axe   = (h_graph-(nb2-1)*bdy-bdy_u-bdy_d)/nb2;
                x_left  = bdx;
                y_low   = pos_g_area(2)+pos_g_area(4)-bdy_u-h_axe;
                for k= 1:nb2
                        pos_axe(2*k-1,:) = [x_left,y_low,w_axe,h_axe];
                        pos_axe(2*k,:)   = [x_left+w_axe+bdx,y_low,w_axe,h_axe];
                        y_low            = y_low-h_axe-bdy;
                end

        else
                nb2 = ceil(nb_axes/3);
                w_axe   = (w_graph-4*bdx)/3;
                h_axe   = (h_graph-(nb2-1)*bdy-bdy_u-bdy_d)/nb2;
                x_left  = bdx;
                y_low   = pos_g_area(2)+pos_g_area(4)-bdy_u-h_axe;
                for k= 1:nb2
                        pos_axe(3*k-2,:) = [x_left,y_low,w_axe,h_axe];
                        xl               = x_left+w_axe+bdx;
                        pos_axe(3*k-1,:) = [xl,y_low,w_axe,h_axe];
                        xl               = xl+w_axe+bdx;
                        pos_axe(3*k,:)   = [xl,y_low,w_axe,h_axe];
                        y_low            = y_low-h_axe-bdy;
                end
        end
        [wpws,xval]     = wpfun(Wave_Nam,nb_func,prec_val);
        hdl_axe =  zeros(1,nb_func);
        xaxis   = [min(xval)    max(xval)];
        figure(win_wpdtool);
        for k= 1:nb_axes
                yaxis   = [min(wpws(k,:))-eps   max(wpws(k,:))+eps];
                ecart   = abs(yaxis(2)-yaxis(1))/20;
                yaxis(1) = yaxis(1)-ecart;
                yaxis(2) = yaxis(2)+ecart;
                hdl_axe(k)      = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_axe(k,:),...
                                        'DrawMode','Fast',      ...
                                        'Xlim',xaxis,           ...
                                        'Ylim',yaxis,           ...
                                        'Box','On'              ...
                                        );
                line('Xdata',xval,'Ydata',wpws(k,:),'Color','r');
                strlab = ['W' int2str(k-1)];
                if      k==1 , strlab = [strlab '  - phi function -'];
                elseif  k==2 , strlab = [strlab '  - psi function -'];
                end
                title(strlab);

        end

        % Display status line.
        %---------------------
        wfigtitl('string',win_wpdtool,str_wintitle,'on');

        % Axes attachment.
        %-----------------
        dynvtool('attach',win_wpdtool,[],hdl_axe,[],[0 0],'','','');
        dynvtool('put',win_wpdtool);

        % Setting units to normalized.
        %-----------------------------
        set(findobj(win_wpdtool,'Units','pixels'),'Units','normalized');

        % End waiting.
        %-------------
        wwaiting('off',win_wpdtool);

%*************************************************%
%** OPTION = 'new' -  test drawing parameters   **%
%*************************************************%
elseif  strcmp(option,'new')
        win_wpdtool     = in2;

        % Handles of tagged objects.
        %---------------------------
        pop_handles     = findobj(win_wpdtool,'Style','popupmenu');
        pop_wav_fams    = findobj(pop_handles,'Tag',tag_wav_fams);
        pop_wav_nums    = findobj(pop_handles,'Tag',tag_wav_nums);
        pop_mod_dis     = findobj(pop_handles,'Tag',tag_pop_mod);
        pop_prec_val    = findobj(pop_handles,'Tag',tag_prec_val);

        % Test Main parameters selection before drawing.
        %-----------------------------------------------
        [Wave_Nam,Wave_Fam] = wavattrb('wname',pop_wav_fams,pop_wav_nums,'all');
        prec_val        = get(pop_prec_val,'Value')+4;
        ind             = get(pop_mod_dis,'value');
        strnum          = get(pop_mod_dis,'string');
        nb_func         = str2num(strnum(ind,:));

        out1            = 0;
        [wfam,wnam,maxn,raf] = wmemtool('rmb',win_wpdtool,n_miscella,...
                                ind_wave_fam,ind_wave_nam,...
                                ind_maxnum,ind_refinment);
        if      raf~=prec_val
                out1 = 1;
                out2 = Wave_Fam; out3 = Wave_Nam;
                out4 = nb_func; out5 = prec_val;
        elseif ~strcmp(wnam,Wave_Nam)
                out1 = 1;
                out2 = Wave_Fam; out3 = Wave_Nam;
                out4 = nb_func; out5 = prec_val;
        elseif ~strcmp(wfam,Wave_Fam)
                out1 = 1;
                out2 = Wave_Fam; out3 = Wave_Nam;
                out4 = nb_func; out5 = prec_val;
        elseif nb_func~=maxn
                out1 = 1;
                out2 = Wave_Fam; out3 = Wave_Nam;
                out4 = nb_func; out5 = prec_val;
        end
        if out1==0 , return; end

        % Setting refinment to 0 (as flag).
        %----------------------------------
        wmemtool('wmb',win_wpdtool,n_miscella,ind_refinment,0);

        % Cleaning the graphical part.
        %-----------------------------
        dynvtool('off',win_wpdtool);
        axe_handles = findobj(win_wpdtool,'Type','axes','visible','on');
        delete(axe_handles);
        wfigtitl('vis',win_wpdtool,'off');
        drawnow;

%*******************************************%
%** OPTION = 'demo' -  for DEMOS or TESTS **%
%*******************************************%
elseif  strcmp(option,'demo')
        win_wpdtool     = in2;
        Wave_Nam        = in3;

        % Handles of tagged objects.
        %---------------------------
        pop_handles     = findobj(win_wpdtool,'Style','popupmenu');
        pop_wav_fams    = findobj(pop_handles,'Tag',tag_wav_fams);
        pop_wav_nums    = findobj(pop_handles,'Tag',tag_wav_nums);
        pop_prec_val    = findobj(pop_handles,'Tag',tag_prec_val);
        pop_mod_dis     = findobj(pop_handles,'Tag',tag_pop_mod);
        pus_handles     = findobj(win_wpdtool,'Style','pushbutton');
        pus_inf1        = findobj(pus_handles,'Tag',tag_pus_inf1);

        [Wave_Fam,Tab_Num] = ...
             wavattrb('set_wname',Wave_Nam,pop_wav_fams,pop_wav_nums);
        if nargin>3
                set(pop_prec_val,'Value',in4);
                if nargin>4 , set(pop_mod_dis,'Value',in5); end 
        end
        new =  wpdtool('new',win_wpdtool);
        if size(Tab_Num,1)<2
                str_inf1= [upper(Wave_Fam) ' wavelet'] ;
        else
                str_inf1= [upper(Wave_Fam) ' wavelets'] ;
        end
        set(pus_inf1,'String',str_inf1);
        wpdtool('draw1d',win_wpdtool);

%****************************************%
%** OPTION = 'close' -  CLOSE FIGURE   **%
%****************************************%
elseif  strcmp(option,'close')

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('wpdtool','Unknown Option','msg');
        error('*');
end
