function wplothis(axe,pcoor,cfill,cline)
%WPLOTHIS Plots histogram obtained with WGETHIST.
%       WPLOTHIS(A,P,CFILL,CLINE) or
%       WPLOTHIS(A,P,CFILL) or
%       WPLOTHIS(A,P)
% 
%       A       = axes handle.
%       P(1,:)  = X coordinates of points of histogram.
%       P(2,:)  = Y coordinates of points of histogram.
%       CFILL   = color for filling histogram.
%       CLINE   = line color.
%
%       See also WGETHIST.
  
%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:28:32 $

if nargin==2, cfill = 'r'; end
old_units = get(axe,'Units');
set(axe,'Units','pixels'); 
pos     = get(axe,'Position');
set(axe,'Units',old_units); 
nb_clas = size(pcoor,2)/4;
mx_clas =  pos(3)/3;
if nargin==4 | nb_clas>mx_clas
        plot_line = 1;
        if nb_clas>mx_clas , cline = cfill; end
else
        plot_line = 0;  
end
tag_axe = get(axe,'Tag');
fill(pcoor(1,:),pcoor(2,:),cfill);
if plot_line
        set(axe,'NextPlot','Add');
        plot(pcoor(1,:),pcoor(2,:),'Color',cline);
        set(axe,'NextPlot','Replace');
end
set(axe,'Units','Normalized'); 
h               = get(axe,'Position');
n               = 5*h(4);
yaxis           = [0 max(pcoor(2,:))];
yaxis(1)        = yaxis(1)-(yaxis(2)-yaxis(1))/(100*n);
yaxis(2)        = yaxis(2)+(yaxis(2)-yaxis(1))/(100*n);

xaxis           = [min(pcoor(1,:)) max(pcoor(1,:))];
xaxis(1)        = xaxis(1)-(xaxis(2)-xaxis(1))/100;
xaxis(2)        = xaxis(2)+(xaxis(2)-xaxis(1))/100;
if yaxis(1)==yaxis(2)
        yaxis   = yaxis+[-0.01 0.01];
end
if xaxis(1)==xaxis(2)
        xaxis   = xaxis+[-0.01 0.01];
end
axis([xaxis yaxis]);
set(axe,'Units',old_units,'Tag',tag_axe);
