function wpplottr(option,win_wptool,tree,in4,in5)
%WPPLOTTR Plot wavelet packets tree.
%       wpplottr(option,win_wptool,tree,in4,in5)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:29:00 $

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Draw or Redraw a tree after a node modification (split or merge)
%   win_wptool = handle of the figure which contains the plot.
%   d = depth of the node    : 0 <= d <= depth of the decomposition
%   b = position of the node : 0 <= b <= (ordre^d)-1
%   o = order of the tree (2 ou 4)
%   prof = depth of the tree
%   xnpos = row vector which contains the abscisses of the nodes.
%   table_node = row vector containing nodes indices.
%         table_node(i) =-1   if the node which indice is i-1 doesn't exist
%         table_node(i) = i-1 if the node which indice is i-1 exists
%         if depth-pos is (d,b) , i = (order^d-1)/(order-1)+b
%   txtstr = row vector wich contains the string of the children of the node.
%   txtstr = [] if the nodes is a leaf.
%   txtstr = [size(texte1,2) abs(texte1) size(texte2,2) ...]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global Mat_Version

% MemBloc2 of stored values.
%---------------------------
n_wp1d2d_utils  = 'WP1D2D_Utils';
ind_tree_lin    =  1;
ind_tree_txt    =  2;
ind_type_txt    =  3;
ind_sel_nodes   =  4;
ind_gra_area    =  5;
ind_nb_colors   =  6;
ind_wav_len     =  7;
nb2_stored      =  7;

% Tag property of objects.
%-------------------------
tag_axe_t_lin   = 'Axe_TreeLines';
tag_axe_t_txt   = 'Axe_TreeTexts';
tag_txt_in_t    = 'Txt_In_tree';
tag_lin_in_t    = 'Lin_In_tree';

axe_handles     = findobj(win_wptool,'type','axes');
WP_Axe_TreeTxt  = findobj(axe_handles,'flat','Tag',tag_axe_t_txt);
WP_Axe_TreeLin  = findobj(axe_handles,'flat','Tag',tag_axe_t_lin);

% Miscellaneous Values.
%-------------------------
[txt_color,line_color,ftn_size] = ...
                wpmisval('plottree',get(WP_Axe_TreeLin,'Xcolor'));

order = wtreemgr('order',tree);
depth = wtreemgr('depth',tree);
all   = wtreemgr('allnodes',tree);
NB    = (order^(depth+1)-1)/(order-1);
table_node = -ones(1,NB);
table_node(all+1) = all;

[xnpos,ynpos] = xynodpos(table_node,order,depth);
if strcmp(option,'first')
        Tree_Lines = zeros(1,NB);
        Tree_Texts = zeros(1,NB);
        axes(WP_Axe_TreeLin)
        i_fath  = 1;
        i_child = i_fath+[1:order];
        for d=1:depth
                for p=0:order^(d-1)-1
                        if table_node(i_child(1)) ~= -1
                                for k=1:order
                                        ic = i_child(k);
                                        Tree_Lines(ic) = line(...
                                        'XData',[xnpos(i_fath) xnpos(ic)],...
                                        'YData',ynpos(d,:),             ...
                                        'Color',line_color,             ...
                                        'Userdata',[i_fath ic],         ...
                                        'Tag',tag_lin_in_t              ...
                                        );
                                end
                        end
                        i_child = i_child+order;
                        i_fath  = i_fath+1;
                end
        end

        axes(WP_Axe_TreeTxt)
        Tree_Texts(1) = text(...
                                'Clipping','on',                ...
                                'Position',[0 0.1 0],           ...
                                'UserData',table_node(1),       ...
                                'Color',txt_color,              ...
                                'HorizontalAlignment','center', ...
                                'VerticalAlignment','middle',   ...
                                'FontSize',ftn_size,            ...
                                'FontWeight','bold',            ...
                                'Tag',tag_txt_in_t              ...
                                );

        i_fath  = 1;
        i_child = i_fath+[1:order];
        for d=1:depth
                d_str = int2str(d);
                for p=0:order:order^d-1
                        if table_node(i_child(1)) ~= -1
                                p_child = p+[0:order-1];
                                for k=1:order
                                        ic = i_child(k);
                                        p_str = int2str(p_child(k));
                                        Tree_Texts(ic) = text(...
                                        'Clipping','on',                ...
                                        'Position',[xnpos(ic) ynpos(d,2) 0],...
                                        'Color',txt_color,              ...
                                        'FontSize',ftn_size,            ...
                                        'FontWeight','bold',            ...
                                        'HorizontalAlignment','center'  ,...
                                        'VerticalAlignment','middle',   ...
                                        'Userdata',table_node(ic),      ...
                                        'Tag',tag_txt_in_t              ...
                                        );
                                end
                        end
                        i_child = i_child+order;
                end
        end
        Tree_Type_TxtV = 'p';
        %%%%%%%%%%%%  version 5 %%%%%%%%%%%%%
        if Mat_Version>=5
                set(WP_Axe_TreeLin,'Visible','on')
                set(WP_Axe_TreeTxt,'Visible','off')
        end
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

elseif strcmp(option,'split_merge')
        node    = in4;
        txtstr = in5;
        [Tree_Lines,Tree_Texts,Tree_Type_TxtV] =...
                        wmemtool('rmb',win_wptool,n_wp1d2d_utils,...
                                        ind_tree_lin,ind_tree_txt,ind_type_txt);
        btndown_fcn = get(Tree_Texts(1),'ButtonDownFcn');
                
        %
        % Create the new tree.
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%
        node  = depo2ind(order,node);
        [d,b] = ind2depo(order,node);

        %
        % Suppress the descendants of the node.
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        if isempty(txtstr)
                if NB < size(Tree_Texts,2)
                        to_del = find(Tree_Texts(NB+1:size(Tree_Texts,2)))+NB;
                        delete([Tree_Texts(to_del) Tree_Lines(to_del)]);
                        Tree_Texts = Tree_Texts(1:NB);
                        Tree_Lines = Tree_Lines(1:NB);
                end
                K = find((table_node==-1) & (Tree_Texts ~= 0));
                K = K(find(K>1));
                delete([Tree_Texts(K) Tree_Lines(K)]);
                Tree_Texts(K) = zeros(size(K));
                Tree_Lines(K) = zeros(size(K));
        
        %
        % Create the descendants of the node.
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        else
                i_fath  = node+1;
                i_child = (i_fath-1)*order+2+[0:order-1];

                if NB > size(Tree_Lines,2)
                        Tree_Texts = [Tree_Texts zeros(1,NB-size(Tree_Texts,2))];
                        Tree_Lines = [Tree_Lines zeros(1,NB-size(Tree_Lines,2))];
                end
                axes(WP_Axe_TreeLin)
                for k=1:order
                        ic = i_child(k);
                        Tree_Lines(ic) = ...
                                line(...
                                        'XData',[xnpos(i_fath) xnpos(ic)],...
                                        'YData',ynpos(d+1,:),           ...
                                        'Color',line_color,             ...
                                        'Userdata',[i_fath ic],         ...
                                        'Tag','tree_line'               ...
                                        );
                end     
                axes(WP_Axe_TreeTxt)
                for k=1:order
                        ic = i_child(k);
                        Tree_Texts(ic) = text(...
                                'Clipping','on',                        ...
                                'String',setstr(txtstr(2:1+txtstr(1))),...
                                'Position',[xnpos(ic) ynpos(d+1,2) 0],  ...
                                'HorizontalAlignment','center',         ...
                                'VerticalAlignment','middle',           ...
                                'Color',txt_color,                      ...
                                'FontSize',ftn_size,                    ...
                                'FontWeight','bold',                    ...
                                'Userdata',table_node(ic),              ...
                                'ButtonDownFcn',btndown_fcn,            ...
                                'Tag',tag_txt_in_t                      ...
                                );
                        txtstr(1:1+txtstr(1)) = [];
                end
        end

        % Plot the new tree.
        %%%%%%%%%%%%%%%%%%%%
        i_fath = 1;
        i_child = i_fath+[1:order];
        for d=1:depth
                for p=0:order^(d-1)-1
                        if table_node(i_child(1)) ~= -1
                                for k=1:order
                                        ic = i_child(k);
                                        set(Tree_Texts(ic),'Position',...
                                                [xnpos(ic) ynpos(d,2) 0]);
                                        set(Tree_Lines(ic),...
                                        'XData',[xnpos(i_fath) xnpos(ic)], ...
                                        'YData',ynpos(d,:));
                                end
                        end
                        i_child = i_child+order;
                        i_fath  = i_fath+1;
                end
        end

end
wmemtool('wmb',win_wptool,n_wp1d2d_utils,       ...
                ind_tree_lin,Tree_Lines,        ...
                ind_tree_txt,Tree_Texts,        ...
                ind_type_txt,Tree_Type_TxtV     ...
                );
drawnow

