function x = wprcoef(tree,data,node)
%WPRCOEF Reconstruct wavelet packet coefficients.
%       X = WPRCOEF(T,D,N) computes reconstructed coefficients
%       of the node N. T is the tree structure and D
%       the data structure (see MAKETREE).
%
%       X = WPRCOEF(T,D) is equivalent to X = WPRCOEF(T,D,0).
%
%       See also MAKETREE, WPDEC, WPDEC2, WPREC, WPREC2.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:29:18 $

%       Uses DYADUP, ERRARGN, ERRARGT, NODEASC, WDATAMGR
%            WFILTERS, WKEEP, WPCOEF, WTREEMGR.

% Check arguments.
if errargn('wprcoef',nargin,[2 3],nargout,[0:1]), error('*'); end
if nargin==2, node = 0; end
if find(wtreemgr('isnode',tree,node)==0)
        errargt('wprcoef','invalid node value','msg'); error('*');
end

order = wtreemgr('order',tree);
asc   = wtreemgr('nodeasc',tree,node,1);
asc   = rem(asc(:,2),order);
nb_up = size(asc,1)-1;

x      = wpcoef(tree,data,node);
filter = wdatamgr('read_wave',data);
[LoF_R,HiF_R] = wfilters(filter,'r');

f = zeros(nb_up,length(LoF_R));
if order==2
        K      = find(asc==0);
        f(K,:) = LoF_R(ones(size(K)),:);
        K      = find(asc==1);
        f(K,:) = HiF_R(ones(size(K)),:);
        for k=1:nb_up
                x = conv2(dyadup(x),f(k,:));
        end

elseif order==4
        g = f;
        K = find(asc==0);
        f(K,:) = LoF_R(ones(size(K)),:);
        g(K,:) = LoF_R(ones(size(K)),:);
        K = find(asc==1);
        f(K,:) = HiF_R(ones(size(K)),:);
        g(K,:) = LoF_R(ones(size(K)),:);
        K = find(asc==2);
        f(K,:) = LoF_R(ones(size(K)),:);
        g(K,:) = HiF_R(ones(size(K)),:);
        K = find(asc==3);
        f(K,:) = HiF_R(ones(size(K)),:);
        g(K,:) = HiF_R(ones(size(K)),:);
        for k=1:nb_up
                x = conv2(dyadup(x,'r'),f(k,:)');
                x = conv2(dyadup(x,'c'),g(k,:));
        end
end

sizes  = wdatamgr('rsizes',data);
x = wkeep(x,sizes(:,1)');
