function data = wpthcoef(data,tree,keepapp,sorh,thr)
%WPTHCOEF Wavelet packet coefficients thresholding.
%       NDATA = WPTHCOEF(DATA,TREE,KEEPAPP,SORH,THR) 
%       returns new data structure obtained from the wavelet
%       packet decomposition structure [DATA,TREE] (see MAKETREE) 
%       by coefficients thresholding.
%
%       If KEEPAPP = 1, approximation coefficients are not
%       thresholded, otherwise it is possible.
%       If SORH = 's', soft thresholding is applied,
%       if SORH = 'h', hard thresholding is applied
%       (see WTHRESH).
%       THR is the threshold value.
%
%       See also MAKETREE, WPDEC, WPDEC2, WPDENCMP, WTHRESH.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:29:54 $

%       Uses ERRARGN, TNODES, WDATAMGR, WTHRESH.

% Check arguments.
if errargn('wpthcoef',nargin,[5],nargout,[0:1]), error('*'), end

[tnods,ltor] = tnodes(tree);        % Keep terminal nodes.
tnods = tnods(ltor);                % Sort terminal nodes
                                    % from left to right.
                                    % Approximation index is 1.
if keepapp==1
        % Save approximation.
        app_coefs = wdatamgr('read_cfs',data,tree,tnods(1));
end

coefs = wdatamgr('rallcfs',data);
coefs = wthresh(coefs,sorh,thr);
data  = wdatamgr('replace',data,coefs);

if keepapp==1
        % Restore approximation.
        data  = wdatamgr('write_cfs',data,tree,tnods(1),app_coefs);
end
