function out = wstdzoom(m)
%WSTDZOOM Zoom in and out on a 2-D plot (NEW).
%       ZOOM ON turns wstdzoom on for the current figure.  Click
%       the left mouse button to wstdzoom in on the point under the
%       mouse.  Click the right mouse button to wstdzoom out
%       (shift-click on the Macintosh).  Each time you click, 
%       the axes limits will be changed by a factor of 2 (in or out).
%       You can also click and drag to wstdzoom into an area.
%       
%       ZOOM OFF turns wstdzoom off. ZOOM with no arguments
%       toggles the wstdzoom status.  ZOOM OUT returns the plot
%       to its initial (full) wstdzoom.

%       Clay M. Thompson 1-25-93
%       Revised 11 Jan 94 by Steven L. Eddins
%       Copyright (c) 1984-94 by The MathWorks, Inc.
%       Revision: 1.11   Date: 1994/04/26 22:13:30
%
%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/06 13:24:53 $

%       Note: wstdzoom uses the userdata of the zlabel of the axis and
%       the figure buttondown and buttonmotion functions
%
%       ZOOM XON zooms x-axis only
%       ZOOM YON zooms y-axis only

if isstr(m),
        if      strcmp(m,'off')
                set(gcf,'windowbuttondownfcn','',       ...
                        'windowbuttonupfcn','',         ...
                        'windowbuttonmotionfcn','',     ...
                        'buttondownfcn',''              ...
                        );
                return

        elseif  strcmp(m,'on')  
                set(gcf,'windowbuttondownfcn','wstdzoom(''down'')', ...
                        'windowbuttonupfcn','1;',               ...
                        'windowbuttonmotionfcn','',             ...
                        'buttondownfcn','',                     ...
                        'interruptible','yes'                   ...
                        );
                gca_x = utlwzoom(gcf);
                set(gca_x,'interruptible','yes')
                figure(gcf)
                return

        elseif strcmp(m,'xon'),
                set(gcf,'windowbuttondownfcn','wstdzoom(''xdown'')', ...
                        'windowbuttonupfcn','1;', ...
                        'windowbuttonmotionfcn','','buttondownfcn','',...
                        'interruptible','yes');
                set(gca_x,'interruptible','yes')
                figure(gcf)       
                return

        elseif strcmp(m,'yon'),
                set(gcf,'windowbuttondownfcn','wstdzoom(''ydown'')', ...
                        'windowbuttonupfcn','1;', ...
                        'windowbuttonmotionfcn','','buttondownfcn','',...
                        'interruptible','yes');
                set(gca_x,'interruptible','yes')
                figure(gcf)       
                return
        end
end

       
% if any(get(gca,'view')~=[0 90]), error('Only works for 2-D plots'); end

rbbox_mode = 0;
zoomx = 1; zoomy = 1; % Assume no constraints

gca_x = utlwzoom(gcf);
if isempty(gca_x) , return; end

if isstr(m),
        m = lower(m);

        % Catch constrained wstdzoom
        if strcmp(m,'xdown'),
                zoomy = 0; m = 'down'; % Constrain y
        elseif strcmp(m,'ydown')
                zoomx = 0; m = 'down'; % Constrain x
        end

        if strcmp(m,'down'),
                % Activate axis that is clicked in
                ax = get(gcf,'Children');
                ZOOM_found = 0;
                for i=1:length(ax),
                        if strcmp(get(ax(i),'Type'),'axes'),
                                ZOOM_Pt1 = get(ax(i),'CurrentPoint');
                                xlim = get(ax(i),'XLim');
                                ylim = get(ax(i),'YLim');
                                if      (xlim(1) <= ZOOM_Pt1(1,1)       & ...
                                        ZOOM_Pt1(1,1) <= xlim(2)        & ...
                                        ylim(1) <= ZOOM_Pt1(1,2)        & ...
                                        ZOOM_Pt1(1,2) <= ylim(2))
                                        ZOOM_found = 1;
                                        axes(ax(i))
                                        break
                                end
                        end
                end
                if ZOOM_found==0, return, end

                % Check for selection type
                selection_type = get(gcf,'SelectionType');
                if      (strcmp(selection_type, 'normal'))
                        % Zoom in
                        m = 1;
                elseif  (strcmp(selection_type, 'open'))
                        % Zoom all the way out
                        wstdzoom('out');
                        return;
                else
                        % Zoom partially out
                        m = -1;
                end
      
                ZOOM_Pt1 = get(gca_x,'currentpoint');
                ZOOM_Pt2 = ZOOM_Pt1;
                center = ZOOM_Pt1(1,1:2);
      
                if (m == 1)
                        % Zoom in
                        % rbbox([get(gcf,'currentpoint') 0 0],get(gcf,'currentpoint'))

                        o_u     = get(gcf,'Units');
                        set(gcf,'Units','pixels')
                        cp      = get(gcf,'currentpoint');
                        rbbox([cp 0 0],cp);
                        set(gcf,'Units',o_u);

                        ZOOM_Pt2 = get(gca_x,'currentpoint');

                        % Note the currentpoint is set by having a non-trivial up function.
                        if min(abs(ZOOM_Pt1(1,1:2)-ZOOM_Pt2(1,1:2))) >= ...
                                min(.01*[diff(get(gca_x,'xlim')) diff(get(gca_x,'ylim'))]),
                                % determine axis from rbbox 
                                a = [ZOOM_Pt1(1,1:2);ZOOM_Pt2(1,1:2)];
                                a = [min(a);max(a)];
                                rbbox_mode = 1;
                        end
                end
                limits = wstdzoom('getlimits');

        elseif strcmp(m,'out'),
                limits = wstdzoom('getlimits');
                center = [sum(get(gca_x,'Xlim'))/2 sum(get(gca_x,'Ylim'))/2];
                m = -inf; % Zoom totally out

        elseif strcmp(m,'getlimits'), % Get axis limits
                limits = get(get(gca_x,'ZLabel'),'UserData');
                if size(limits,2)==4 & size(limits,1)<=2, % Do simple checking of userdata
                        if all(limits(1,[1 3])<limits(1,[2 4])), 
                                getlimits = 0; out = limits(1,:); return   % Quick return
                        else
                                getlimits = -1; % Don't munge data
                        end
                else
                        if isempty(limits), getlimits = 1; else getlimits = -1; end
                end

                % If I've made it to here, we need to compute appropriate axis
                % limits.

                if      isempty(get(get(gca_x,'ZLabel'),'userdata')),
                        % Use quick method if possible
                        xlim = get(gca_x,'xlim'); xmin = xlim(1); xmax = xlim(2);
                        ylim = get(gca_x,'ylim'); ymin = ylim(1); ymax = ylim(2);

                elseif  strcmp(get(gca_x,'xLimMode'),'auto') & ...
                        strcmp(get(gca_x,'yLimMode'),'auto'),
                        % Use automatic limits if possible
                        xlim = get(gca_x,'xlim'); xmin = xlim(1); xmax = xlim(2);
                        ylim = get(gca_x,'ylim'); ymin = ylim(1); ymax = ylim(2);

                else
                        % Determine which IMAGE coordinate system is being used.
                        s = [version '    ']; k = find(s<46 & s>58);
                        if ~isempty(k), s = s(1:min(k)); end
                        [ver,count,msg,next] = sscanf(s,'%f',1);
                        if      ver > 4.1,
                                useNew = 1;
                        elseif  ver < 4.1,
                                useNew = 0;
                        else
                                if s(next)>='a', useNew = 1; else useNew = 0; end
                        end
  
                        % Use slow method only if someone else is using the userdata
                        h = get(gca_x,'Children');
                        xmin = inf; xmax = -inf; ymin = inf; ymax = -inf;
                        for i=1:length(h),
                                t = get(h(i),'Type');
                                if ~strcmp(t,'text')
                                        if strcmp(t,'image') & useNew, % Determine axis limits for image
                                                x = get(h(i),'Xdata');
                                                y = get(h(i),'Ydata');
                                                x = [min(min(x)) max(max(x))];
                                                y = [min(min(y)) max(max(y))];
                                                [ma,na] = size(get(h(i),'Cdata'));
                                                if na>1, dx = diff(x)/(na-1); else dx = 1; end
                                                if ma>1, dy = diff(y)/(ma-1); else dy = 1; end
                                                x = x + [-dx dx]/2; y = y + [-dy dy]/2;
                                        else
                                                x = get(h(i),'Xdata');
                                                y = get(h(i),'Ydata');
                                        end
                                        xmin = min(xmin,min(min(x)));
                                        xmax = max(xmax,max(max(x)));
                                        ymin = min(ymin,min(min(y)));
                                        ymax = max(ymax,max(max(y)));
                                end
                        end

                        % Use automatic limits if in use (override previous calculation)
                        if strcmp(get(gca_x,'xLimMode'),'auto')
                                xlim = get(gca_x,'xlim'); xmin = xlim(1); xmax = xlim(2);
                        end
                        if strcmp(get(gca_x,'yLimMode'),'auto'),
                                ylim = get(gca_x,'ylim'); ymin = ylim(1); ymax = ylim(2);
                        end
                end
                limits = [xmin xmax ymin ymax];
                if getlimits~=-1, % Don't munge existing userdata.
                        % Store limits in ZLabel userdata
                        set(get(gca_x,'ZLabel'),'UserData',limits);
                end
                out = limits;
                return
  
        elseif strcmp(m,'getconnect'), % Get connected axes
                limits = get(get(gca_x,'ZLabel'),'UserData');
                if all(size(limits)==[2 4]), % Do simple checking
                        out = limits(2,[1 2]);
                else
                        out = [gca_x gca_x];
                end
                return

        else
                error(['Unknown option: ',m,'.']);
        end

else
        error('Only takes the strings ''on'',''off'', or ''out''.')
end

%
% Actual wstdzoom operation
%
if ~rbbox_mode,
        xmin = limits(1); xmax = limits(2);
        ymin = limits(3); ymax = limits(4);
        dx = xmax-xmin;
        dy = ymax-ymin;
        if m~=(-inf)
                pow = 2.^(-m-1);
                dx = min(diff(get(gca_x,'Xlim'))*pow,dx);
                dy = min(diff(get(gca_x,'Ylim'))*pow,dy);
        end

        % Limit wstdzoom.
        center = max(center,[xmin ymin] + [dx dy]);
        center = min(center,[xmax ymax] - [dx dy]);
        a = [   max(xmin,center(1)-dx) min(xmax,center(1)+dx) ...
                max(ymin,center(2)-dy) min(ymax,center(2)+dy)];
end

% Update circular list of connected axes
list = wstdzoom('getconnect'); % Circular list of connected axes.
if zoomx,
        set(gca_x,'xlim',a(1:2))
        if isempty(list) , return; end
        h = list(1);
        while h ~= gca_x,
                set(h,'xlim',a(1:2))
                % Get next axes in the list
                next = get(get(h,'ZLabel'),'UserData');
                if size(next)==[2 4], h = next(2,1); else h = gca_x; end
        end
end
if zoomy,
        set(gca_x,'ylim',a(3:4))
        if length(list)<2, return; end
        h = list(2);
        while h ~= gca_x,
                set(h,'ylim',a(3:4))
                % Get next axes in the list
                next = get(get(h,'ZLabel'),'UserData');
                if size(next)==[2 4], h = next(2,2); else h = gca_x; end
        end
end
