function [out1,out2,out3,out4] = wvdtool(option,in2,in3,in4,in5,in6)
%WVDTOOL Wavelet display tool.
%       [out1,out2,out3,out4] = wvdtool(option,in2,in3,in4)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:31:59 $

global  Def_Btn_Height  Def_Btn_Width   ...
        Pop_Min_Width   X_Graph_Ratio   ...
        X_Spacing       Y_Spacing       ...
        Def_TxtBkColor  Def_EdiBkColor  ...
        Def_FraBkColor  Def_FraFgColor

% MemBloc1 of stored values.
%---------------------------
n_miscella      = 'WvDisp_Misc';
ind_graph_area  =  1;
ind_wave_fam    =  2;
ind_wave_nam    =  3;
ind_refinment   =  4;
nb1_stored      =  4;

if      nargin==0
        option  = 'create';
        in2     = [];
end

% Tag property of objects.
%-------------------------
tag_wav_fams    = 'Wav_Fams';
tag_wav_nums    = 'Wav_Num';
tag_prec_val    = 'Prec_Val';
tag_cmd_frame   = 'Cmd_Frame';
tag_display     = 'Display';
tag_pus_inf1    = 'Pus_Inf1';
tag_pus_inf2    = 'Pus_Inf2';
tag_btn_close   = 'Wave_Close';
                
%****************************************************************%
%** OPTION = 'create' - constructs the initial wvdtool window  **%
%****************************************************************%
if strcmp(option,'create')

        % Window initialization.
        %----------------------
        win_name = 'Wavelet Display';
        [win_wvdtool,pos_win,cba_close_menu] = ...
                wfigcrea('create',in2,win_name,'','',3,'wvdtool');
        str_win_wvdtool = int2str(win_wvdtool);
        win_units = 'pixels';
        out1      = win_wvdtool;

        % Command frame and Dynamical visualization tool construction.
        %-------------------------------------------------------------
        [frame0,pos_frame0,Pos_Graphic_Area] = ...
                        wfigcrea('frame',win_wvdtool,'dynv','title');

        % Waiting Frame construction & begin waiting.
        %--------------------------------------------
        wwaiting('create',win_wvdtool,X_Graph_Ratio,...
                        'Wait ... initialization');

        % General graphical parameters initialization.
        %--------------------------------------------

        % Borders and double borders.
        dx  = X_Spacing;        dx2 = 2*dx;
        dy  = Y_Spacing;        dy2 = 2*dy;

        % X init position and width of frames.
        x_frame0   = pos_frame0(1);
        cmd_width  = pos_frame0(3);
        h_frame0   = pos_frame0(4);

        % Buttons width
        push_width = (cmd_width-4*dx)/2;

        % Position property of objects.
        %------------------------------
        pos_wav_txt     = [     x_frame0+dx2                            ,...
                                h_frame0-2*Def_Btn_Height               ,...
                                Def_Btn_Width                           ,...
                                Def_Btn_Height                          ];
        pos_wav_fams    = [     pos_wav_txt(1)+pos_wav_txt(3)+dx        ,...
                                pos_wav_txt(2)                          ,...
                                Pop_Min_Width+dx                        ,...
                                Def_Btn_Height                          ];
        pos_wav_nums    = pos_wav_fams;
        pos_wav_nums(1) = pos_wav_fams(1)+pos_wav_fams(3);
        pos_prec_txt    = pos_wav_txt;
        pos_prec_txt(2) = pos_prec_txt(2)-2*Def_Btn_Height;
        pos_prec_val    = pos_wav_fams;
        pos_prec_val(2) = pos_prec_val(2)-2*Def_Btn_Height;
        pos_display     = [     x_frame0+(cmd_width-3*push_width/2)/2    ,...
                                pos_prec_txt(2)-5*Def_Btn_Height        ,...
                                3*push_width/2                          ,...
                                2*Def_Btn_Height                        ];


        pos_inf_txt     = [     x_frame0+dx2                            ,...
                                pos_display(2)-3*Def_Btn_Height         ,...
                                2*Def_Btn_Width                         ,...
                                Def_Btn_Height                          ];

        pos_pus_inf1    = pos_display;
        pos_pus_inf1(2) = pos_inf_txt(2)-2*Def_Btn_Height-dy;

        pos_pus_inf2    = pos_pus_inf1;
        pos_pus_inf2(2) = pos_pus_inf1(2)-3*Def_Btn_Height;

        px              = x_frame0+(cmd_width-7*push_width/4)/2;
        pos_close       = [     px                                      ,...
                                pos_frame0(2)+Def_Btn_Height            ,...
                                7*push_width/4                          ,...
                                3*Def_Btn_Height/2                      ];

        % String property of objects.
        %----------------------------
        str_wav_txt     = 'Wavelet';
        [str_wav_fams,...
        str_wav_nums]   = wavattrb('ini','cwt');
        str_display     = 'Display';
        str_inf_txt     = 'Information on';
        str_inf1        = 'HAAR wavelet';
        str_inf2        = 'Wavelets';
        str_close       = 'Close';
        str_prec_txt    = 'Refinement';
        str_prec_val    = str2mat('5','6','7','8','9','10','11','12');

        % Command part construction of the window.
        %-----------------------------------------
        figure(win_wvdtool);
        txt_wav_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_wav_txt,...
                                        'String',str_wav_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_wav_fams    = uicontrol(...
                                        'Style','Popup',...
                                        'Unit',win_units,...
                                        'Position',pos_wav_fams,...
                                        'String',str_wav_fams,...
                                        'Tag',tag_wav_fams...
                                        );
        pop_wav_nums    = uicontrol(...
                                        'Style','Popup',...
                                        'Unit',win_units,...
                                        'Position',pos_wav_nums,...
                                        'String',str_wav_nums,...
                                        'Visible','off',...
                                        'Tag',tag_wav_nums...
                                        );
        txt_prec_txt    = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_prec_txt,...
                                        'String',str_prec_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pop_prec_val    = uicontrol(...
                                        'Style','Popup',...
                                        'Unit',win_units,...
                                        'Position',pos_prec_val,...
                                        'String',str_prec_val,...
                                        'Value',4,...
                                        'Tag',tag_prec_val...
                                        );
        pus_display     = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_display,...
                                        'String',str_display,...
                                        'Tag',tag_display...
                                        );
        txt_inf_txt     = uicontrol(...
                                        'Style','Text',...
                                        'Unit',win_units,...
                                        'HorizontalAlignment','left',...
                                        'Position',pos_inf_txt,...
                                        'String',str_inf_txt,...
                                        'Backgroundcolor',Def_FraBkColor...
                                        );
        pus_inf1        = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_pus_inf1,...
                                        'String',str_inf1,...
                                        'Tag',tag_pus_inf1...
                                        );
        pus_inf2        = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_pus_inf2,...
                                        'String',str_inf2,...
                                        'Tag',tag_pus_inf2...
                                        );              
        pus_close       = uicontrol(...
                                        'Style','Pushbutton',...
                                        'Unit',win_units,...
                                        'Position',pos_close,...
                                        'String',str_close,...
                                        'Interruptible','yes',...
                                        'Userdata',0,...
                                        'Callback',cba_close_menu,...
                                        'Tag',tag_btn_close     ...
                                        );
        drawnow

        % Callbacks update.
        %------------------
        cba_pop_wav_fams = [    'wvdtool(''upd_fam'',' ...
                                        str_win_wvdtool ');'];

        cba_pop_wav_nums = [    'wnumbtn(1,'            ...
                                num2mstr([pop_wav_fams pop_wav_nums]) ',' ...
                                num2mstr([pus_display]) ');'];

        cba_update      = [     'wvdtool(''new'',' ...
                                        str_win_wvdtool ');'];

        cba_draw_1d             = ['wvdtool(''draw1d'',' ...
                                        str_win_wvdtool ');'];
        cba_inf1                = ['wvdtool(''inf1'',' ...
                                        str_win_wvdtool ');'];
        cba_inf2                = ['wvdtool(''inf2'',' ...
                                        str_win_wvdtool ');'];

        set(pop_wav_fams,'Callback',cba_pop_wav_fams);
        set(pop_wav_nums,'Callback',[cba_pop_wav_nums cba_update]);
        set(pop_prec_val,'Callback',cba_update);
        set(pus_display,'Callback',cba_draw_1d);
        set(pus_inf1,'Callback',cba_inf1);
        set(pus_inf2,'Callback',cba_inf2);

        % Setting units to normalized.
        %-----------------------------
        Pos_Graphic_Area = Pos_Graphic_Area./[pos_win(3:4),pos_win(3:4)];
        set(findobj(win_wvdtool,'Units','pixels'),'Units','normalized');

        % Memory for stored values.
        %--------------------------
        wmemtool('ini',win_wvdtool,n_miscella,nb1_stored);
        wmemtool('wmb',win_wvdtool,n_miscella,...
                                ind_graph_area,Pos_Graphic_Area,...
                                ind_wave_fam,'haar',            ...
                                ind_wave_nam,'haar',            ...
                                ind_refinment,0                 ...
                        );

        % End waiting.
        %-------------
        wwaiting('off',win_wvdtool);

%**********************************************************%
%** OPTION = 'upd_fam' -  UPDATE OF THE WAVELET FAMILY   **%
%**********************************************************%
elseif  strcmp(option,'upd_fam')
        win_wvdtool     = in2;
        new =  wvdtool('new',win_wvdtool);
        if new==0 , return; end

        % Handles of tagged objects.
        %---------------------------
        pop_handles     = findobj(win_wvdtool,'Style','popupmenu');
        pop_wav_fams    = findobj(pop_handles,'Tag',tag_wav_fams);
        pop_wav_nums    = findobj(pop_handles,'Tag',tag_wav_nums);
        pus_handles     = findobj(win_wvdtool,'Style','pushbutton');
        pus_inf1        = findobj(pus_handles,'Tag',tag_pus_inf1);

        % Test family and Set visible on or off the wavelet number if exists.
        %--------------------------------------------------------------------
        [Tab_Num,Wave_Fam] = wavattrb('gettnum',pop_wav_fams,pop_wav_nums);
        if size(Tab_Num,1)<2
                str_inf1= [upper(Wave_Fam) ' wavelet'] ;
        else
                str_inf1= [upper(Wave_Fam) ' wavelets'] ;
        end
        set(pus_inf1,'String',str_inf1);

%*****************************************%
%** OPTION = 'inf1' - LOCAL INFORMATION **%
%*****************************************%
elseif strcmp(option,'inf1')
        win_wvdtool     = in2;

        % Handles of tagged objects.
        %---------------------------
        pop_handles     = findobj(win_wvdtool,'Style','popupmenu');
        pop_wav_fams    = findobj(pop_handles,'Tag',tag_wav_fams);
        fam_str         = get(pop_wav_fams,'string');
        fam_val         = get(pop_wav_fams,'value');
        infotxt         = [deblankl(fam_str(fam_val,:)) 'info.m'];
        [old_info,fig]  = whelpfun('getflag');
        if ~isempty(old_info) & strcmp(infotxt,old_info)
                figure(fig);
                return;
        end

        % Waiting message.
        %-----------------
        wwaiting('msg',win_wvdtool,'Wait ... loading');

        [str_inf,fid]   = wreadinf(infotxt);
        if fid==-1
                msg = ['File ' infotxt ' not found !'];
                errargt('wvdtool',msg,'msg');
                wwaiting('off',win_wvdtool);
                return
        else
                dim     = size(str_inf);
                rowfam  = str_inf(2,2:dim(2));
                str_inf = str_inf(3:dim(1),2:dim(2));
                col = 1;
                while all(str_inf(:,col)==' ')
                   col = col+1;
                end
                str_inf = str2mat(rowfam,str_inf(:,col:dim(2)-1));
        end
        whelpfun('create',str_inf,infotxt);

        % End waiting.
        %-------------
        wwaiting('off',win_wvdtool);

%*****************************************%
%** OPTION = 'inf2' - LOCAL INFORMATION **%
%*****************************************%
elseif strcmp(option,'inf2')
        win_wvdtool     = in2;

        % Handles of tagged objects.
        %---------------------------
        infotxt         = 'infowave.m';
        [old_info,fig]  = whelpfun('getflag');
        if ~isempty(old_info) & strcmp(infotxt,old_info)
                figure(fig); return;
        end

        % Waiting message.
        %-----------------
        wwaiting('msg',win_wvdtool,'Wait ... loading');

        [str_inf,fid]   = wreadinf(infotxt);
        if fid==-1
                msg = ['File ' infotxt ' not found !'];
                errargt('wvdtool',msg,'msg');
                wwaiting('off',win_wvdtool);
                return
        else
                dim     = size(str_inf);
                str_inf = str_inf(2:dim(1),2:dim(2));
        end
        whelpfun('create',str_inf,infotxt);

        % End waiting.
        %-------------
        wwaiting('off',win_wvdtool);
                
%************************************************%
%** OPTION = 'draw1d' - DRAW AXES IN 1D        **%
%************************************************%
elseif  strcmp(option,'draw1d')
        win_wvdtool     = in2;
        [new,Wave_Fam,Wave_Nam,prec_val] =  wvdtool('new',win_wvdtool);
        if new==0 , return; end

        % Waiting message.
        %-----------------
        wwaiting('msg',win_wvdtool,'Wait ... computing');

        % Handles of tagged objects.
        %---------------------------
        fra_handles     = findobj(win_wvdtool,'Style','frame');
        hdl_frame0      = findobj(fra_handles,'Tag',tag_cmd_frame);

        % Update parameters selection before drawing.
        %-------------------------------------------
        wmemtool('wmb',win_wvdtool,n_miscella,...
                                ind_wave_fam,Wave_Fam,          ...
                                ind_wave_nam,Wave_Nam,          ...
                                ind_refinment,prec_val          ...
                        );

        % General graphical parameters initialization.
        %--------------------------------------------
        pos_g_area      = wmemtool('rmb',win_wvdtool,n_miscella,ind_graph_area);
        pos_hdl_frame0  = get(hdl_frame0,'Position');
        win_units       = 'normalized';
        pos_win         = get(win_wvdtool,'Position');
        bdx             = 0.08*pos_win(3);
        bdy             = 0.09*pos_win(4);
        bdy_d           = bdy;
        bdy_u           = bdy;
        bdyl            = pos_g_area(2)+bdy_d;
        w_graph         = pos_hdl_frame0(1);
        h_graph         = pos_g_area(4);

        % Computing and displaying wavelets and filters.
        %-----------------------------------------------
        wtype           = wavemngr('type',Wave_Nam);
        if      wtype==1
                str_wintitle = [Wave_Fam ' Wavelet --> ' Wave_Nam];
                [phi,psi,xval]            = wavefun(Wave_Nam,prec_val);
                [lof_d,hif_d,lof_r,hif_r] = wfilters(Wave_Nam);
                xaxis   = [min(xval)    max(xval)];
                xaxis_f = [0            length(lof_d)-1];
                xval_f  = 0:xaxis_f(2);
                nb      = 1;
                len     = length(xval_f);
                while len>15
                        nb = nb+1;
                        len = len/nb;
                end
                tics    = 0:nb:length(xval_f);
                xlabs   = int2str(tics(1));
                for k = 2:length(tics)
                    xlabs = str2mat(xlabs,int2str(tics(k)));
                end
                yaxis   = [min(min(phi),min(psi))       max(max(phi),max(psi))];
                ecart   = abs(yaxis(2)-yaxis(1))/20;
                yaxis(1) = yaxis(1)-ecart;
                yaxis(2) = yaxis(2)+ecart;
                yaxis_r = [min(min(lof_r),min(hif_r))   max(max(lof_r),max(hif_r))];
                yaxis_d = [min(min(lof_d),min(hif_d))   max(max(lof_d),max(hif_d))];
                h_axe_wave      = (h_graph-2*bdy-bdy_d-bdy_u)/2;
                h_axe_filt      = h_axe_wave/2;
                w_axe           = (w_graph-3*bdx)/2;
                pos_phi         = [     bdx,...
                                        bdyl+2*bdy+2*h_axe_filt,...
                                        w_axe,h_axe_wave];
                pos_psi         = [     2*bdx+w_axe,...
                                        bdyl+2*bdy+2*h_axe_filt,...
                                        w_axe,h_axe_wave];
                pos_lof_d       = [     bdx,...
                                        bdyl+bdy+h_axe_filt,...
                                        w_axe,h_axe_filt];
                pos_lof_r       = [     bdx,...
                                        bdyl,w_axe,h_axe_filt];
                pos_hif_d       = [     2*bdx+w_axe,...
                                        bdyl+bdy+h_axe_filt,...
                                        w_axe,h_axe_filt];
                pos_hif_r       = [     2*bdx+w_axe,bdyl,w_axe,h_axe_filt];
  
                figure(win_wvdtool);              
                axe_phi         = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_phi,     ...
                                        'DrawMode','Fast',      ...
                                        'Xlim',xaxis,           ...
                                        'Ylim',yaxis,           ...
                                        'Box','On'              ...
                                        );
                line('Xdata',xval,'Ydata',phi,'Color','r');
                title('Scaling function phi');
                axe_psi         = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_psi,     ...
                                        'DrawMode','Fast',      ...
                                        'Xlim',xaxis,           ...
                                        'Ylim',yaxis,           ...
                                        'Box','On'              ...
                                        );

                line('Xdata',xval,'Ydata',psi,'Color','g');
                title('Wavelet function psi');
                axe_lof_d       = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_lof_d,   ...
                                        'DrawMode','Fast',      ...
                                        'Box','On'              ...
                                        );
                wdstem(xval_f,lof_d,'y',1);
                set(axe_lof_d,...
                                'Ylim',yaxis_d,                 ...
                                'Xlim',xaxis_f,                 ...
                                'Box','On',                     ...
                                'XTicklabelMode','manual',      ...
                                'XTick',tics,                   ...
                                'XTickLabels',xlabs);
                title('Decomposition low-pass filter');
                axe_lof_r       = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_lof_r,   ...
                                        'DrawMode','Fast',      ...
                                        'Box','On'              ...
                                        );
                wdstem(xval_f,lof_r,'y',1);
                set(axe_lof_r,...
                                'Ylim',yaxis_r,                 ...
                                'Xlim',xaxis_f,                 ...
                                'Box','On',                     ...
                                'XTicklabelMode','manual',      ...
                                'XTick',tics,                   ...
                                'XTickLabels',xlabs);
                title('Reconstruction low-pass filter');
                axe_hif_d       = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_hif_d,   ...
                                        'DrawMode','Fast',      ...
                                        'Box','On'              ...
                                        );
                wdstem(xval_f,hif_d,'y',1);
                set(axe_hif_d,...
                                'Ylim',yaxis_d,                 ...
                                'Xlim',xaxis_f,                 ...
                                'Box','On',                     ...
                                'XTicklabelMode','manual',      ...
                                'XTick',tics,                   ...
                                'XTickLabels',xlabs);
                title('Decomposition high-pass filter');
                axe_hif_r       = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_hif_r,   ...
                                        'DrawMode','Fast',      ...
                                        'Box','On'              ...
                                        );
                wdstem(xval_f,hif_r,'y',1);
                set(axe_hif_r,...
                                'Ylim',yaxis_r,                 ...
                                'Xlim',xaxis_f,                 ...
                                'Box','On',                     ...
                                'XTicklabelMode','manual',      ...
                                'XTick',tics,                   ...
                                'XTickLabels',xlabs);
                title('Reconstruction high-pass filter');
                axe_cmd = [axe_phi axe_psi];

        elseif  wtype==2
                [phi1,psi1,phi2,psi2,xval]      = wavefun(Wave_Nam,prec_val);
                [lof_d,hif_d,lof_r,hif_r]       = wfilters(Wave_Nam);
                xaxis   = [min(xval)    max(xval)];
                xaxis_f = [0            length(lof_d)-1];
                xval_f  = 0:xaxis_f(2);
                nb      = 1;
                len     = length(xval_f);
                while len>15
                        nb = nb+1;
                        len = len/nb;
                end
                tics    = 0:nb:length(xval_f);
                xlabs   = int2str(tics(1));
                for k = 2:length(tics)
                    xlabs = str2mat(xlabs,int2str(tics(k)));
                end
                yaxis1  = [min(min(phi1),min(psi1))     max(max(phi1),max(psi1))];
                ecart   = abs(yaxis1(2)-yaxis1(1))/20;
                yaxis1(1) = yaxis1(1)-ecart;
                yaxis1(2) = yaxis1(2)+ecart;
                yaxis2  = [min(min(phi2),min(psi2))     max(max(phi2),max(psi2))];
                ecart   = abs(yaxis2(2)-yaxis2(1))/20;
                yaxis2(1) = yaxis2(1)-ecart;
                yaxis2(2) = yaxis2(2)+ecart;
                yaxis_r = [min(min(lof_r),min(hif_r))   max(max(lof_r),max(hif_r))];
                yaxis_d = [min(min(lof_d),min(hif_d))   max(max(lof_d),max(hif_d))];
                str_wintitle    = ['Biorthogonal Wavelet --> ' Wave_Nam];
                h_axe_wave      = 2*(h_graph-3*bdy-bdy_d-bdy_u)/6;
                h_axe_filt      = (h_graph-3*bdy-bdy_d-bdy_u)/6;
                w_axe           = (w_graph-3*bdx)/2;

                pos_phi1        = [     bdx,...
                                        bdyl+3*bdy+2*h_axe_filt+h_axe_wave,...
                                        w_axe,h_axe_wave];
                pos_phi2        = [     bdx,...
                                        bdyl+bdy+h_axe_filt,...
                                        w_axe,h_axe_wave];
                pos_psi1        = [     2*bdx+w_axe,...
                                        bdyl+3*bdy+2*h_axe_filt+h_axe_wave,...
                                        w_axe,h_axe_wave];
                pos_psi2        = [     2*bdx+w_axe,...
                                        bdyl+bdy+h_axe_filt,...
                                        w_axe,h_axe_wave];
                pos_lof_d       = [     bdx,...
                                        bdyl+2*bdy+h_axe_filt+h_axe_wave,...
                                        w_axe,h_axe_filt];
                pos_lof_r       = [     bdx,...
                                        bdyl,w_axe,h_axe_filt];
                pos_hif_d       = [     2*bdx+w_axe,...
                                        bdyl+2*bdy+h_axe_filt+h_axe_wave,...
                                        w_axe,h_axe_filt];
                pos_hif_r       = [     2*bdx+w_axe,bdyl,w_axe,h_axe_filt];

                figure(win_wvdtool);              
                axe_phi1        = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_phi1,    ...
                                        'DrawMode','Fast',      ...
                                        'Xlim',xaxis,           ...
                                        'Ylim',yaxis1,          ...
                                        'Box','On'              ...
                                        );
                line('Xdata',xval,'Ydata',phi1,'Color','r');
                title('Decomposition scaling function phi');
                axe_phi2        = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_phi2,    ...
                                        'DrawMode','Fast',      ...
                                        'Xlim',xaxis,           ...
                                        'Ylim',yaxis2,          ...
                                        'Box','On'              ...
                                        );
                line('Xdata',xval,'Ydata',phi2,'Color','r');
                title('Reconstruction scaling function phi');
                axe_psi1        = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_psi1,    ...
                                        'DrawMode','Fast',      ...
                                        'Xlim',xaxis,           ...
                                        'Ylim',yaxis1,          ...
                                        'Box','On'              ...
                                        );
                line('Xdata',xval,'Ydata',psi1,'Color','g');
                title('Decomposition wavelet function psi');
                axe_psi2        = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_psi2,    ...
                                        'DrawMode','Fast',      ...
                                        'Xlim',xaxis,           ...
                                        'Ylim',yaxis2,          ...
                                        'Box','On'              ...
                                        );
                line('Xdata',xval,'Ydata',psi2,'Color','g');
                title('Reconstruction wavelet function psi');
                axe_lof_d       = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_lof_d,   ...
                                        'DrawMode','Fast',      ...
                                        'Box','On'              ...
                                        );
                wdstem(xval_f,lof_d,'y',1);
                set(axe_lof_d,...
                                'Ylim',yaxis_d,...
                                'Xlim',xaxis_f,...
                                'Box','On',...
                                'XTicklabelMode','manual',...
                                'XTick',tics,...
                                'XTickLabels',xlabs);
                title('Decomposition low-pass filter');
                axe_lof_r       = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_lof_r,   ...
                                        'DrawMode','Fast',      ...
                                        'Box','On'              ...
                                        );
                wdstem(xval_f,lof_r,'y',1);
                set(axe_lof_r,...
                                'Ylim',yaxis_r,...
                                'Xlim',xaxis_f,...
                                'Box','On',...
                                'XTicklabelMode','manual',...
                                'XTick',tics,...
                                'XTickLabels',xlabs);
                title('Reconstruction low-pass filter');
                axe_hif_d       = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_hif_d,   ...
                                        'DrawMode','Fast',      ...
                                        'Box','On'              ...
                                        );
                wdstem(xval_f,hif_d,'y',1);
                set(axe_hif_d,...
                                'Ylim',yaxis_d,...
                                'Xlim',xaxis_f,...
                                'Box','On',...
                                'XTicklabelMode','manual',...
                                'XTick',tics,...
                                'XTickLabels',xlabs);
                title('Decomposition high-pass filter');
                axe_hif_r       = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_hif_r,   ...
                                        'DrawMode','Fast',      ...
                                        'Box','On'              ...
                                        );
                wdstem(xval_f,hif_r,'y',1);
                set(axe_hif_r,...
                                'Ylim',yaxis_r,...
                                'Xlim',xaxis_f,...
                                'Box','On',...
                                'XTicklabelMode','manual',...
                                'XTick',tics,...
                                'XTickLabels',xlabs);
                title('Reconstruction high-pass filter');

                axe_cmd = [axe_phi1 axe_phi2 axe_psi1 axe_psi2];

        elseif  wtype==3
                str_wintitle    = [Wave_Fam '  Wavelet --> ' Wave_Nam];
                [phi,psi,xval]  = wavefun(Wave_Nam,prec_val);
                xaxis   = [min(xval)                    max(xval)];
                yaxis   = [min(min(phi),min(psi))       max(max(phi),max(psi))];
                h_axe_wave      = h_graph-bdy_d-bdy_u;
                w_axe           = (w_graph-3*bdx)/2;
                pos_phi         = [bdx,bdyl,w_axe,h_axe_wave];
                pos_psi         = [2*bdx+w_axe,bdyl,w_axe,h_axe_wave];

                figure(win_wvdtool);                              
                axe_phi         = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_phi,     ...
                                        'DrawMode','Fast',      ...
                                        'Xlim',xaxis,           ...
                                        'Ylim',yaxis,           ...
                                        'Box','On'              ...
                                        );
                line('Xdata',xval,'Ydata',phi,'Color','r');
                title('Scaling function phi');
                axe_psi         = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_psi,     ...
                                        'DrawMode','Fast',      ...
                                        'Xlim',xaxis,           ...
                                        'Ylim',yaxis,           ...
                                        'Box','On'              ...
                                                );
                line('Xdata',xval,'Ydata',psi,'Color','g');
                title('Wavelet function psi');
                axe_cmd = [axe_phi axe_psi];

        elseif  wtype==4
                str_wintitle    = [Wave_Fam '  Wavelet --> ' Wave_Nam];
                [psi,xval]      = wavefun(Wave_Nam,prec_val);
                xaxis           = [min(xval)    max(xval)];
                yaxis           = [min(psi)     max(psi)];
                h_axe_wave      = h_graph-bdy_d-bdy_u;
                w_axe           = w_graph-2*bdx;
                pos_psi         = [bdx,bdyl,w_axe,h_axe_wave];

                figure(win_wvdtool);              
                axe_psi         = axes(...
                                        'Units',win_units,      ...
                                        'Position',pos_psi,     ...
                                        'DrawMode','Fast',      ...
                                        'Xlim',xaxis,           ...
                                        'Ylim',yaxis,           ...
                                        'Box','On'              ...
                                        );
                line('Xdata',xval,'Ydata',psi,'Color','g');
                title('Wavelet function psi');
                axe_cmd = axe_psi;
        end

        % Display status line.
        %---------------------
        wfigtitl('string',win_wvdtool,str_wintitle,'on');

        % Axes attachment.
        %-----------------
        dynvtool('attach',win_wvdtool,[],axe_cmd,[],[0 0],'','','');
        dynvtool('put',win_wvdtool);

        % Setting units to normalized.
        %-----------------------------
        set(findobj(win_wvdtool,'Units','pixels'),'Units','normalized');

        % End waiting.
        %-------------
        wwaiting('off',win_wvdtool);

%*************************************************%
%** OPTION = 'new' -  test drawing parameters   **%
%*************************************************%
elseif  strcmp(option,'new')
        win_wvdtool     = in2;

        % Handles of tagged objects.
        %---------------------------
        pop_handles     = findobj(win_wvdtool,'Style','popupmenu');
        pop_wav_fams    = findobj(pop_handles,'Tag',tag_wav_fams);
        pop_wav_nums    = findobj(pop_handles,'Tag',tag_wav_nums);
        pop_prec_val    = findobj(pop_handles,'Tag',tag_prec_val);

        % Test Main parameters selection before drawing.
        %-----------------------------------------------
        [Wave_Nam,Wave_Fam] = wavattrb('wname',pop_wav_fams,pop_wav_nums,'all');
        prec_val        = get(pop_prec_val,'Value')+4;

        out1            = 0;
        [wfam,wnam,raf] = wmemtool('rmb',win_wvdtool,n_miscella,...
                                ind_wave_fam,ind_wave_nam,ind_refinment);
        if      raf~=prec_val
                out1 = 1;
                out2 = Wave_Fam; out3 = Wave_Nam; out4 = prec_val;
        elseif ~strcmp(wnam,Wave_Nam)
                out1 = 1;
                out2 = Wave_Fam; out3 = Wave_Nam; out4 = prec_val;
        elseif ~strcmp(wfam,Wave_Fam)
                out1 = 1;
                out2 = Wave_Fam; out3 = Wave_Nam; out4 = prec_val;
        end
        if out1==0 , return; end

        % Setting refinment to 0 (as flag).
        %----------------------------------
        wmemtool('wmb',win_wvdtool,n_miscella,ind_refinment,0);

        % Cleaning the graphical part.
        %-----------------------------
        dynvtool('off',win_wvdtool);
        axe_handles = findobj(win_wvdtool,'Type','axes','visible','on');
        delete(axe_handles);
        wfigtitl('vis',win_wvdtool,'off');
        drawnow;

%*******************************************%
%** OPTION = 'demo' -  for DEMOS or TESTS **%
%*******************************************%
elseif  strcmp(option,'demo')
        win_wvdtool     = in2;
        Wave_Nam        = in3;

        % Handles of tagged objects.
        %---------------------------
        pop_handles     = findobj(win_wvdtool,'Style','popupmenu');
        pop_wav_fams    = findobj(pop_handles,'Tag',tag_wav_fams);
        pop_wav_nums    = findobj(pop_handles,'Tag',tag_wav_nums);
        pop_prec_val    = findobj(pop_handles,'Tag',tag_prec_val);
        pus_handles     = findobj(win_wvdtool,'Style','pushbutton');
        pus_inf1        = findobj(pus_handles,'Tag',tag_pus_inf1);

        [Wave_Fam,Tab_Num] = ...
             wavattrb('set_wname',Wave_Nam,pop_wav_fams,pop_wav_nums);
        if nargin==4
                set(pop_prec_val,'Value',in4);
        end
        new =  wvdtool('new',win_wvdtool);
        if size(Tab_Num,1)<2
                str_inf1= [upper(Wave_Fam) ' wavelet'] ;
        else
                str_inf1= [upper(Wave_Fam) ' wavelets'] ;
        end
        set(pus_inf1,'String',str_inf1);
        wvdtool('draw1d',win_wvdtool);

%****************************************%
%** OPTION = 'close' -  CLOSE FIGURE   **%
%****************************************%
elseif  strcmp(option,'close')

%********************%
%** UNKNOWN OPTION **%
%********************%
else
        errargt('wvdtool','Unknown Option','msg');
        error('*');
end
