function val = wwaitans(fig,quest,default,cancel)
%WWAITANS Wait for an answer to a question.
%       VAL = WWAITANS(FIG,MSG) returns 1 if the answer to
%       question quest is yes and 0 if not.
%
%       VAL = WWAITANS(FIG,MSG,DEF) sets the default answer
%       to "no" (DEF = 2) or "yes" in the other case.
%
%       VAL = WWAITANS(FIG,MSG,DEF,CANCEL) returns 1 
%       if the answer to question quest is yes, 0 if
%       the answer to question quest is no and -1 otherwise.

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:32:05 $

global Mat_Version

if      nargin<3
        default = 1; cancel = 0;
elseif  nargin<4
        if (default~=1) | (default~=2) , default = 1; end 
        cancel = 0;
else
        if (default~=1) | (default~=2) | (default~=3), default = 1; end
        cancel = 1; 
end

% Begin waiting.
%--------------
wwaiting('msg',fig,'Wait ... answer');

%%%%%%%%%%%%  version 5 %%%%%%%%%%%%%
if Mat_Version<5
        if cancel 
                dlgquest(quest,'yes','no','cancel',default);
        else
                dlgquest(quest,'yes','no',default);
        end
        drawnow
        mousefrm(0,'arrow');
        Answer_Quest = [];
        while isempty(Answer_Quest)
                pause(1)
                Answer_Quest = dlgquest;
        end
else
        figtit = ['Wait answer for : ' get(fig,'Name')];
        if cancel 
                Answer_Quest = questdlg(quest,figtit,'yes','no','cancel',default);
        else
                Answer_Quest = questdlg(quest,figtit,'yes','no',default);
        end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if cancel
        if strcmp(Answer_Quest,'yes') , 
                val = 1;
        elseif strcmp(Answer_Quest,'no') , 
                val = 0;
        else
                val = -1;
        end
else
        if ~strcmp(Answer_Quest,'yes') , val = 0; else , val = 1; end
end

% End waiting.
%-------------
wwaiting('off',fig);


