function [xnpos,ynpos] = xynodpos(table_node,order,depth)
%XYNODPOS Computes graphical position of a node in a tree.
%       [xnpos,ynpos] = xynodpos(table_node,order,depth)

%       M. Misiti, Y. Misiti, G. Oppenheim, J.M. Poggi 12-Mar-96.
%       Copyright (c) 1995-96 by The Mathworks, Inc.
%       $Revision: 1.1 $  $Date: 1996/03/05 21:32:16 $

% Create nodes indices table.
%----------------------------
ord_ind = 1:order;
order1  = order+1;
N       = size(table_node,2);
xnpos   = zeros(order1,N);
node_exist = find(table_node ~= -1);

% Setting the width of the subtrees.
% The initial width is 1.
%-----------------------------------------
xnpos(1,node_exist) = ones(1,size(node_exist,2));
i_Ltree = (order.^[0:depth]-1)/(order-1)+1;

for d=depth-1:-1:0
        n_d = i_Ltree(d+1);
        i_p = n_d+[0:order^d-1];
        i_c = (i_p-1)*order+2;
        for k=1:order^d
                n = i_p(k);
                n_fils = i_c(k);
                if table_node(n_fils) ~= -1
                        for i=1:order
                                xnpos(i,n) = sum(xnpos(ord_ind,n_fils+i-1));
                        end
                end
        end
end

% Now the rows 2:2+order-1 contain the width of the subtrees.

%
% Elimination of the nodes for the maximum depth.
%------------------------------------------------
if N > 1, xnpos(:,(N-1)/order+1:size(xnpos,2)) = []; end

% Normalization : the total width is 1.
%--------------------------------------
xnpos(ord_ind,:) = xnpos(ord_ind,:)/sum(xnpos(ord_ind,1));

% Setting the minimum values of the abcisses of the subtrees.
%------------------------------------------------------------
xnpos(order1,i_Ltree) = -0.5*ones(size(i_Ltree));
for d=1:depth-1
        n_d = i_Ltree(d+1);
        for p=n_d+1:n_d+order^d-1
                xnpos(order1,p) = sum(xnpos([1:order1],p-1));
        end
end

% Now the row order+2 contains the abscisses of the left extremity
% of the subtrees.

% Change the width of the subtrees.
%----------------------------------
xnpos(ord_ind,:) = cumsum(xnpos(ord_ind,:)) - xnpos(ord_ind,:)/2;
xnpos(ord_ind,:) = xnpos(ord_ind,:)+xnpos((order1)*ones(1,order),:);

% Suppress the last row.
%-----------------------
xnpos = xnpos(1:order,:);
xnpos = [0 xnpos(:)'];
if depth > 0
        pasy = 0.8/depth;
        y = 0.1+pasy*[0:depth-1]';
        ynpos = [y y+pasy];
else
        ynpos = [0.1];
end

