function [ret,x0,str,ts,xts]=com_dimo(t,x,u,flag);
%COM_DIMO     is the M-file description of the SIMULINK system named COM_DIMO.
%       The block-diagram can be displayed by typing: COM_DIMO.
%
%       SYS=COM_DIMO(T,X,U,FLAG) returns depending on FLAG certain
%     system values given time point, T, current state vector, X,
%    and input vector, U.
%   FLAG is used to indicate the type of output to be returned in SYS.
%
%    Setting FLAG=1 causes COM_DIMO to return state derivatives, FLAG=2
%     discrete states, FLAG=3 system outputs and FLAG=4 next sample
%  time. For more information and other options see SFUNC.
%
%       Calling COM_DIMO with a FLAG of zero:
%  [SIZES]=COM_DIMO([],[],[],0),  returns a vector, SIZES, which
%  contains the sizes of the state vector and other parameters.
%           SIZES(1) number of states
%              SIZES(2) number of discrete states
%             SIZES(3) number of outputs
%             SIZES(4) number of inputs
%              SIZES(5) number of roots (currently unsupported)
%               SIZES(6) direct feedthrough flag
%               SIZES(7) number of sample times
%
%       For the definition of other parameters in SIZES, see SFUNC.
%    See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[19,85,381,664])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  ['Single sided',13,'MASK',13,'demodulation'].

new_system([sys,'/',['Single sided',13,'MASK',13,'demodulation']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation']],'Location',[236,108,954,316])

add_block('built-in/Inport',[sys,'/',['Single sided',13,'MASK',13,'demodulation/in_2']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/in_2']],...
            'Port','2',...
          'position',[70,135,90,155])


%     Subsystem  ['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector'].

new_system([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/out_1']],...
         'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
                'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/one1']],...
              'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/Memory1']],...
          'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/in_1']],...
               'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']],...
             'position',[135,18,165,42])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],...
          'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],...
              'Mask Translate','thld=@1;')
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],...
              'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],...
              'Mask Entries','thld\/')


%     Finished composite block ['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector'].

set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Rising edge',13,'detector']],...
            'ForeGround',4,...
              'position',[170,123,230,167])

add_block('built-in/Inport',[sys,'/',['Single sided',13,'MASK',13,'demodulation/in_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/in_1']],...
          'position',[15,35,35,55])

add_block('built-in/Transfer Fcn',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Transfer Fcn']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Transfer Fcn']],...
                'Numerator','num',...
           'Denominator','den',...
         'position',[75,25,130,65])


%     Subsystem  ['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector'].

new_system([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],'Location',[4,135,827,505])

add_block('built-in/Note',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/average']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/average']],...
               'ForeGround',4,...
              'position',[510,70,515,75])

add_block('built-in/Outport',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/out_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/out_1']],...
             'position',[690,50,710,70])

add_block('built-in/Switch',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Switch4']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Switch4']],...
          'ForeGround',4,...
              'Threshold','eps',...
           'position',[620,114,645,146])

add_block('built-in/Memory',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Memory4']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Memory4']],...
                'orientation',2,...
             'ForeGround',4,...
              'position',[610,170,650,200])

add_block('built-in/Memory',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Memory5']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Memory5']],...
                'orientation',2,...
             'ForeGround',4,...
              'position',[745,180,785,210])

add_block('built-in/Switch',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Switch5']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Switch5']],...
                'ForeGround',4,...
              'Threshold','eps',...
           'position',[750,124,775,156])

add_block('built-in/Gain',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Gain']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Gain']],...
                'Gain','1/3',...
                'position',[520,106,565,134])

add_block('built-in/Sum',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Sum5']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Sum5']],...
         'inputs','+++',...
              'position',[470,102,490,138])

add_block('built-in/Inport',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/in_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/in_1']],...
              'position',[20,100,40,120])

add_block('built-in/Note',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/find peak']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/find peak']],...
                'ForeGround',2,...
              'position',[385,45,390,50])

add_block('built-in/Memory',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Memory2']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Memory2']],...
          'orientation',2,...
             'ForeGround',2,...
              'position',[365,155,405,185])

add_block('built-in/Switch',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Switch']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Switch']],...
          'ForeGround',2,...
              'Threshold','eps',...
           'position',[375,94,400,126])

add_block('built-in/Relational Operator',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Relational',13,'Operator1']],...
                'ForeGround',2,...
              'Operator','>',...
              'position',[300,98,330,122])

add_block('built-in/Memory',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Memory1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Memory1']],...
         'ForeGround',2,...
              'position',[240,125,280,155])

add_block('built-in/Relational Operator',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Relational',13,'Operator']],...
         'ForeGround',2,...
              'position',[180,93,210,117])

add_block('built-in/Memory',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Memory']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector/Memory']],...
           'ForeGround',2,...
              'position',[110,35,150,65])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[650,130;675,130;675,185;655,185])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[675,130;745,130])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[675,130;685,60])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[605,185;590,185;590,140;615,140])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[590,185;455,185;465,130])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[570,120;615,120])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[495,120;515,120])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[740,195;715,195;715,240;440,240;440,120;465,120])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[335,110;370,110])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[345,110;345,125;350,125;350,220;585,220;585,130;615,130])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[585,220;700,220;700,140;745,140])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[740,195;735,195;745,150])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[780,140;800,140;790,195])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[405,110;425,110;425,170;410,170])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[425,110;465,110])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[45,110;95,110;105,50])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[95,110;175,110])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[215,105;295,105])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[225,105;235,140])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[155,50;165,50;175,100])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[360,170;350,170;350,120;370,120])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[285,140;295,115])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],[155,50;345,50;345,100;370,100])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],...
            'Mask Display','Envelop\nDetector',...
          'Mask Type','Envelop Detector',...
              'Mask Help','Envelop Detector detects the envelop of a signal.')


%     Finished composite block ['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector'].

set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Average envelop',13,'detector']],...
            'position',[200,23,260,67])

add_block('built-in/Constant',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Shift key']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Shift key']],...
                'Value','sft',...
               'position',[435,103,455,127])

add_block('built-in/Note',[sys,'/',['Single sided',13,'MASK',13,'demodulation/zero hold']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/zero hold']],...
          'ForeGround',2,...
              'position',[370,15,375,20])

add_block('built-in/Outport',[sys,'/',['Single sided',13,'MASK',13,'demodulation/out_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/out_1']],...
         'position',[685,55,705,75])

add_block('built-in/S-Function',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Minimum']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Minimum']],...
          'function name','arymimai',...
          'parameters','''min''',...
              'position',[600,55,655,75])

add_block('built-in/Abs',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Abs']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Abs']],...
         'position',[545,53,575,77])

add_block('built-in/Sum',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Sum2']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Sum2']],...
               'inputs','+-',...
               'position',[495,48,515,77])

add_block('built-in/Gain',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Gain']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Gain']],...
              'Gain','Ac',...
         'position',[420,41,465,69])

add_block('built-in/Switch',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Switch2']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Switch2']],...
              'ForeGround',2,...
              'Threshold','eps',...
           'position',[350,39,380,71])

add_block('built-in/Memory',[sys,'/',['Single sided',13,'MASK',13,'demodulation/Memory2']])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation/Memory2']],...
              'orientation',2,...
             'ForeGround',2,...
              'position',[345,95,385,125])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[135,45;195,45])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[40,45;70,45])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[580,65;595,65])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[520,65;540,65])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[460,115;465,115;465,70;490,70])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[470,55;490,55])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[385,55;400,55;390,110])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[400,55;415,55])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[235,145;300,145;300,55;345,55])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[265,45;345,45])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[340,110;335,110;345,65])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[95,145;165,145])
add_line([sys,'/',['Single sided',13,'MASK',13,'demodulation']],[660,65;680,65])
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation']],...
                'Mask Display','MASK\ndemodu',...
               'Mask Type','MASK Demodulation')
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation']],...
            'Mask Dialogue','M-ary Amplitude Shift Keying Demodulation:|M-ary number:|Carrier Frequency:|Carrier signal maximum amplitude:|Trigger signal threshold:')
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation']],...
            'Mask Translate','N=@1;Fc=@2;Ac=(N-1)/@3; thld=@4;sft=[0:N-1];[num,den]=cheby1(2,.5,[Fc*1.6*pi, Fc*2.4*pi],''s'');')
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation']],...
                'Mask Help','This block demodulates a MASK modulated signal using noncoherent method. The first input port is for the received signal, which is MASK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation']],...
              'Mask Entries','N\/100\/1\/.2\/')


%     Finished composite block ['Single sided',13,'MASK',13,'demodulation'].

set_param([sys,'/',['Single sided',13,'MASK',13,'demodulation']],...
               'orientation',2,...
             'position',[1255,69,1325,111])


%     Subsystem  ['Single sided',13,'MASK',13,'modulation'].

new_system([sys,'/',['Single sided',13,'MASK',13,'modulation']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation']],'Location',[551,78,1000,337])

add_block('built-in/Constant',[sys,'/',['Single sided',13,'MASK',13,'modulation/Initial phase']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Initial phase']],...
         'Value','Ph',...
                'position',[185,208,205,232])

add_block('built-in/Sum',[sys,'/',['Single sided',13,'MASK',13,'modulation/Sum']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Sum']],...
           'position',[225,168,245,192])

add_block('built-in/Fcn',[sys,'/',['Single sided',13,'MASK',13,'modulation/Oscilation']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Oscilation']],...
             'Expr','sin(u)',...
             'position',[265,168,305,192])

add_block('built-in/Product',[sys,'/',['Single sided',13,'MASK',13,'modulation/Product']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Product']],...
               'position',[335,100,360,120])

add_block('built-in/Outport',[sys,'/',['Single sided',13,'MASK',13,'modulation/out_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/out_1']],...
           'position',[390,100,410,120])

add_block('built-in/Memory',[sys,'/',['Single sided',13,'MASK',13,'modulation/Memory1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Memory1']],...
                'orientation',2,...
             'position',[185,80,225,110])

add_block('built-in/Gain',[sys,'/',['Single sided',13,'MASK',13,'modulation/Gain']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Gain']],...
         'Gain','Ac',...
         'position',[275,31,305,59])

add_block('built-in/Gain',[sys,'/',['Single sided',13,'MASK',13,'modulation/Gain1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Gain1']],...
                'Gain','pi2',...
                'position',[160,162,195,188])


%     Subsystem  ['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator'].

new_system([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/in_1']],...
           'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/Memory']],...
                'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/module']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/module']],...
                'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/Reset',13,'integrator']],...
              'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/one']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/one']],...
          'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/Sum']],...
         'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator/out_1']],...
               'position',[370,30,390,50])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator')
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],...
               'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
              'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],...
          'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],...
          'Mask Entries','1\/0\/')


%     Finished composite block ['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator'].

set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Module',13,'Integrator']],...
              'position',[75,156,135,194])

add_block('built-in/Constant',[sys,'/',['Single sided',13,'MASK',13,'modulation/one']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/one']],...
               'Value','Fc',...
                'position',[25,161,50,189])


%     Subsystem  ['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector'].

new_system([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/out_1']],...
           'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
             'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
            'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/one1']],...
          'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/Memory1']],...
              'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/in_1']],...
           'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']],...
         'position',[135,18,165,42])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],...
            'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],...
                'Mask Translate','thld=@1;')
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],...
                'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],...
                'Mask Entries','thld\/')


%     Finished composite block ['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector'].

set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Rising edge',13,'detector']],...
                'position',[75,78,135,122])

add_block('built-in/Inport',[sys,'/',['Single sided',13,'MASK',13,'modulation/in_2']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/in_2']],...
                'Port','2',...
          'position',[30,90,50,110])

add_block('built-in/Switch',[sys,'/',['Single sided',13,'MASK',13,'modulation/Switch']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/Switch']],...
             'Threshold','eps',...
           'position',[190,29,220,61])

add_block('built-in/Inport',[sys,'/',['Single sided',13,'MASK',13,'modulation/in_1']])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation/in_1']],...
                'position',[85,25,105,45])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[365,110;385,110])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[310,45;315,45;315,105;330,105])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[310,180;315,180;315,115;330,115])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[210,220;220,185])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[140,175;155,175])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[55,175;70,175])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[250,180;260,180])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[55,100;70,100])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[110,35;185,35])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[225,45;250,45;250,95;230,95])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[180,95;165,95;165,55;185,55])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[140,100;150,100;150,45;185,45])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[200,175;220,175])
add_line([sys,'/',['Single sided',13,'MASK',13,'modulation']],[250,45;270,45])
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation']],...
                'Mask Display','MASK',...
               'Mask Type','MASK')
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation']],...
           'Mask Dialogue','M-ary Amplitude Shift Keying Modulation:|M-ary number:|Carrier frequency:|Maximum amplitude:|Trigger signal threshold:|Initial phase:')
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation']],...
                'Mask Translate','pi2=2*pi;N=@1;Fc=@2;Ac=@3/(N-1);thld=@4;Ph=@5;')
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation']],...
            'Mask Help','This block modulates an M-ary digital signal onto a given carrier frequency using amplitude shift keying method. The first input port is for the original digital signal, which is coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input.')
set_param([sys,'/',['Single sided',13,'MASK',13,'modulation']],...
             'Mask Entries','N\/100\/1\/.2\/0\/')


%     Finished composite block ['Single sided',13,'MASK',13,'modulation'].

set_param([sys,'/',['Single sided',13,'MASK',13,'modulation']],...
                'position',[1120,43,1180,87])


%     Subsystem  'MPSK modu'.

new_system([sys,'/','MPSK modu'])
set_param([sys,'/','MPSK modu'],'Location',[126,337,786,595])

add_block('built-in/Constant',[sys,'/','MPSK modu/Initial phase'])
set_param([sys,'/','MPSK modu/Initial phase'],...
             'Value','Ph',...
                'position',[370,178,390,202])

add_block('built-in/Outport',[sys,'/','MPSK modu/out_1'])
set_param([sys,'/','MPSK modu/out_1'],...
         'position',[580,75,600,95])

add_block('built-in/Fcn',[sys,'/','MPSK modu/Oscilation'])
set_param([sys,'/','MPSK modu/Oscilation'],...
             'Expr','Ac*sin(u[1])',...
               'position',[480,70,555,100])

add_block('built-in/Sum',[sys,'/','MPSK modu/Sum'])
set_param([sys,'/','MPSK modu/Sum'],...
          'inputs','+++',...
              'position',[440,67,460,103])

add_block('built-in/Switch',[sys,'/','MPSK modu/Switch1'])
set_param([sys,'/','MPSK modu/Switch1'],...
               'Threshold','eps',...
           'position',[360,124,390,156])

add_block('built-in/Reset Integrator',[sys,'/',['MPSK modu/Reset',13,'integrator']])
set_param([sys,'/',['MPSK modu/Reset',13,'integrator']],...
            'position',[275,154,315,186])

add_block('built-in/Constant',[sys,'/','MPSK modu/one'])
set_param([sys,'/','MPSK modu/one'],...
            'Value','Fc',...
                'position',[200,146,225,174])

add_block('built-in/Memory',[sys,'/','MPSK modu/Memory1'])
set_param([sys,'/','MPSK modu/Memory1'],...
              'orientation',2,...
             'position',[185,85,225,115])

add_block('built-in/Inport',[sys,'/','MPSK modu/in_1'])
set_param([sys,'/','MPSK modu/in_1'],...
             'position',[85,25,105,45])

add_block('built-in/Switch',[sys,'/','MPSK modu/Switch'])
set_param([sys,'/','MPSK modu/Switch'],...
           'Threshold','eps',...
           'position',[190,29,220,61])

add_block('built-in/Inport',[sys,'/','MPSK modu/in_2'])
set_param([sys,'/','MPSK modu/in_2'],...
              'Port','2',...
          'position',[30,185,50,205])


%     Subsystem  ['MPSK modu/Rising edge',13,'detector'].

new_system([sys,'/',['MPSK modu/Rising edge',13,'detector']])
set_param([sys,'/',['MPSK modu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['MPSK modu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['MPSK modu/Rising edge',13,'detector/Relational',13,'Operator']],...
          'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['MPSK modu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['MPSK modu/Rising edge',13,'detector/in_1']],...
              'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['MPSK modu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['MPSK modu/Rising edge',13,'detector/Memory1']],...
          'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['MPSK modu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['MPSK modu/Rising edge',13,'detector/one1']],...
           'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['MPSK modu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['MPSK modu/Rising edge',13,'detector/Relational',13,'Operator2']],...
               'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['MPSK modu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['MPSK modu/Rising edge',13,'detector/Relational',13,'Operator1']],...
               'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['MPSK modu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['MPSK modu/Rising edge',13,'detector/out_1']],...
          'position',[340,25,360,45])
add_line([sys,'/',['MPSK modu/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['MPSK modu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['MPSK modu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['MPSK modu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['MPSK modu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['MPSK modu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['MPSK modu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['MPSK modu/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['MPSK modu/Rising edge',13,'detector']],...
         'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['MPSK modu/Rising edge',13,'detector']],...
             'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['MPSK modu/Rising edge',13,'detector'].

set_param([sys,'/',['MPSK modu/Rising edge',13,'detector']],...
          'position',[75,173,135,217])

add_block('built-in/Product',[sys,'/','MPSK modu/Product'])
set_param([sys,'/','MPSK modu/Product'],...
              'position',[360,36,385,69])

add_block('built-in/Constant',[sys,'/','MPSK modu/Multiple factor'])
set_param([sys,'/','MPSK modu/Multiple factor'],...
              'Value','Sft',...
               'position',[290,48,310,72])
add_line([sys,'/','MPSK modu'],[395,190;420,190;420,95;435,95])
add_line([sys,'/','MPSK modu'],[225,45;250,45;250,100;230,100])
add_line([sys,'/','MPSK modu'],[250,45;355,45])
add_line([sys,'/','MPSK modu'],[140,195;150,195;150,45;185,45])
add_line([sys,'/','MPSK modu'],[150,140;355,140])
add_line([sys,'/','MPSK modu'],[150,195;250,195;250,170;270,170])
add_line([sys,'/','MPSK modu'],[395,140;415,140;415,85;435,85])
add_line([sys,'/','MPSK modu'],[320,170;330,170;330,150;355,150])
add_line([sys,'/','MPSK modu'],[180,100;165,100;165,55;185,55])
add_line([sys,'/','MPSK modu'],[110,35;185,35])
add_line([sys,'/','MPSK modu'],[55,195;70,195])
add_line([sys,'/','MPSK modu'],[560,85;575,85])
add_line([sys,'/','MPSK modu'],[230,160;270,160])
add_line([sys,'/','MPSK modu'],[315,60;355,60])
add_line([sys,'/','MPSK modu'],[390,55;415,55;415,75;435,75])
add_line([sys,'/','MPSK modu'],[465,85;475,85])
set_param([sys,'/','MPSK modu'],...
            'Mask Display','MPSK',...
               'Mask Type','MPSK')
set_param([sys,'/','MPSK modu'],...
          'Mask Dialogue','M-ary Phase Shift Keying Modulation:|M-ary number:|Carrier frequency (Hz):|Output amplitude:|Trigger signal threshold:|Initial phase (rad):')
set_param([sys,'/','MPSK modu'],...
         'Mask Translate','pi2=2*pi;Sft=pi2/@1; Fc=@2*pi2; Ac=@3; thld=@4;Ph=@5;')
set_param([sys,'/','MPSK modu'],...
            'Mask Help','This block modulates an M-ary digital signal onto a given carrier frequency. The first input port is for the original digital signal, which is coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. For best solution, the carrier frequency should be integer times the clock frequency. The initial phase will affect every input process.')
set_param([sys,'/','MPSK modu'],...
          'Mask Entries','16\/100\/1\/.2\/0\/')


%     Finished composite block 'MPSK modu'.

set_param([sys,'/','MPSK modu'],...
             'position',[35,189,95,231])


%     Subsystem  ['Differential',13,'PSK demodu'].

new_system([sys,'/',['Differential',13,'PSK demodu']])
set_param([sys,'/',['Differential',13,'PSK demodu']],'Location',[50,105,913,506])

add_block('built-in/Outport',[sys,'/',['Differential',13,'PSK demodu/out_1']])
set_param([sys,'/',['Differential',13,'PSK demodu/out_1']],...
                'position',[760,165,780,185])

add_block('built-in/Logical Operator',[sys,'/',['Differential',13,'PSK demodu/Logical',13,'Operator1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Logical',13,'Operator1']],...
            'Operator','NOT',...
            'Number of Input Ports','1',...
         'position',[710,163,740,187])

add_block('built-in/Logical Operator',[sys,'/',['Differential',13,'PSK demodu/Logical',13,'Operator']])
set_param([sys,'/',['Differential',13,'PSK demodu/Logical',13,'Operator']],...
              'Operator','XOR',...
            'position',[655,163,685,187])

add_block('built-in/Note',[sys,'/',['Differential',13,'PSK demodu/delayed',13,'output']])
set_param([sys,'/',['Differential',13,'PSK demodu/delayed',13,'output']],...
              'position',[610,175,615,180])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK demodu/Memory3']])
set_param([sys,'/',['Differential',13,'PSK demodu/Memory3']],...
            'orientation',2,...
             'position',[560,260,600,290])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK demodu/Switch2']])
set_param([sys,'/',['Differential',13,'PSK demodu/Switch2']],...
            'Threshold','eps',...
           'position',[560,194,590,226])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK demodu/Memory2']])
set_param([sys,'/',['Differential',13,'PSK demodu/Memory2']],...
            'position',[485,185,525,215])

add_block('built-in/Sum',[sys,'/',['Differential',13,'PSK demodu/Sum']])
set_param([sys,'/',['Differential',13,'PSK demodu/Sum']],...
               'position',[415,83,435,112])

add_block('built-in/Reset Integrator',[sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator1']],...
             'position',[265,49,305,81])

add_block('built-in/Product',[sys,'/',['Differential',13,'PSK demodu/Product']])
set_param([sys,'/',['Differential',13,'PSK demodu/Product']],...
             'position',[540,46,565,79])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK demodu/in_1']])
set_param([sys,'/',['Differential',13,'PSK demodu/in_1']],...
            'position',[440,45,460,65])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK demodu/Switch1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Switch1']],...
              'Threshold','eps',...
           'position',[360,24,390,56])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK demodu/Initial phase']])
set_param([sys,'/',['Differential',13,'PSK demodu/Initial phase']],...
                'Value','Ph',...
                'position',[335,93,355,117])

add_block('built-in/Fcn',[sys,'/',['Differential',13,'PSK demodu/sin']])
set_param([sys,'/',['Differential',13,'PSK demodu/sin']],...
                'Expr','sin(u)',...
             'position',[465,87,505,113])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK demodu/Frequency']])
set_param([sys,'/',['Differential',13,'PSK demodu/Frequency']],...
               'Value','Fc',...
                'position',[180,43,205,67])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK demodu/Const']])
set_param([sys,'/',['Differential',13,'PSK demodu/Const']],...
                'Value','Ac/4',...
              'position',[175,254,205,276])

add_block('built-in/Reset Integrator',[sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator2']])
set_param([sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator2']],...
            'position',[245,279,285,311])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK demodu/Relational',13,'Operator']])
set_param([sys,'/',['Differential',13,'PSK demodu/Relational',13,'Operator']],...
             'position',[320,178,350,202])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK demodu/Switch']])
set_param([sys,'/',['Differential',13,'PSK demodu/Switch']],...
              'Threshold','eps',...
           'position',[405,184,435,216])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK demodu/Memory1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Memory1']],...
            'orientation',2,...
             'position',[400,255,440,285])


%     Subsystem  ['Differential',13,'PSK demodu/Rising edge',13,'detector'].

new_system([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/out_1']],...
           'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']],...
                'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/one1']],...
              'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Memory1']],...
          'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/in_1']],...
               'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector/Relational',13,'Operator']],...
             'position',[135,18,165,42])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],...
              'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],...
          'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['Differential',13,'PSK demodu/Rising edge',13,'detector'].

set_param([sys,'/',['Differential',13,'PSK demodu/Rising edge',13,'detector']],...
            'position',[70,163,130,207])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK demodu/in_2']])
set_param([sys,'/',['Differential',13,'PSK demodu/in_2']],...
           'Port','2',...
          'position',[25,175,45,195])

add_block('built-in/Reset Integrator',[sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator']])
set_param([sys,'/',['Differential',13,'PSK demodu/Reset',13,'integrator']],...
                'position',[235,169,275,201])
add_line([sys,'/',['Differential',13,'PSK demodu']],[440,200;455,200;445,270])
add_line([sys,'/',['Differential',13,'PSK demodu']],[455,200;480,200])
add_line([sys,'/',['Differential',13,'PSK demodu']],[455,200;455,170;650,170])
add_line([sys,'/',['Differential',13,'PSK demodu']],[745,175;755,175])
add_line([sys,'/',['Differential',13,'PSK demodu']],[690,175;705,175])
add_line([sys,'/',['Differential',13,'PSK demodu']],[595,210;640,210;650,180])
add_line([sys,'/',['Differential',13,'PSK demodu']],[615,210;605,275])
add_line([sys,'/',['Differential',13,'PSK demodu']],[355,190;400,190])
add_line([sys,'/',['Differential',13,'PSK demodu']],[290,295;295,295;295,195;315,195])
add_line([sys,'/',['Differential',13,'PSK demodu']],[280,185;315,185])
add_line([sys,'/',['Differential',13,'PSK demodu']],[210,265;220,265;220,285;240,285])
add_line([sys,'/',['Differential',13,'PSK demodu']],[135,185;230,185])
add_line([sys,'/',['Differential',13,'PSK demodu']],[155,185;155,235;370,235;370,200;400,200])
add_line([sys,'/',['Differential',13,'PSK demodu']],[155,235;155,295;240,295])
add_line([sys,'/',['Differential',13,'PSK demodu']],[555,275;545,275;555,220])
add_line([sys,'/',['Differential',13,'PSK demodu']],[530,200;555,200])
add_line([sys,'/',['Differential',13,'PSK demodu']],[360,105;410,105])
add_line([sys,'/',['Differential',13,'PSK demodu']],[155,185;155,40;355,40])
add_line([sys,'/',['Differential',13,'PSK demodu']],[155,100;245,100;245,65;260,65])
add_line([sys,'/',['Differential',13,'PSK demodu']],[50,185;65,185])
add_line([sys,'/',['Differential',13,'PSK demodu']],[465,55;535,55])
add_line([sys,'/',['Differential',13,'PSK demodu']],[570,65;580,65;580,140;220,140;230,175])
add_line([sys,'/',['Differential',13,'PSK demodu']],[440,100;460,100])
add_line([sys,'/',['Differential',13,'PSK demodu']],[210,55;260,55])
add_line([sys,'/',['Differential',13,'PSK demodu']],[510,100;515,100;515,70;535,70])
add_line([sys,'/',['Differential',13,'PSK demodu']],[395,270;380,270;380,210;400,210])
add_line([sys,'/',['Differential',13,'PSK demodu']],[310,65;345,65;355,50])
add_line([sys,'/',['Differential',13,'PSK demodu']],[395,40;400,40;410,90])
set_param([sys,'/',['Differential',13,'PSK demodu']],...
               'Mask Display','DPSK\ndemodul',...
              'Mask Type','DPSK Demodulation')
set_param([sys,'/',['Differential',13,'PSK demodu']],...
                'Mask Dialogue','Differential Phase Shift Keying Demodulation:|Carrier frequency (Hz):|Carrier amplitude:|Trigger signal threshold:|Initial phase (rad):')
set_param([sys,'/',['Differential',13,'PSK demodu']],...
              'Mask Translate','Fc=@1*pi*2; Ac=@2;thld=@3;Ph=@4;')
set_param([sys,'/',['Differential',13,'PSK demodu']],...
            'Mask Help','This block demodulates a MPSK modulated signal using coherent method. The first input port is for the received signal, which is MPSK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The initial phase should match those in the modulation. Becase the correlation computation, the output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Differential',13,'PSK demodu']],...
         'Mask Entries','N\/100\/.2\/0\/')


%     Finished composite block ['Differential',13,'PSK demodu'].

set_param([sys,'/',['Differential',13,'PSK demodu']],...
               'orientation',2,...
             'position',[145,304,210,346])


%     Subsystem  ['APK correlation',13,'demodulation1'].

new_system([sys,'/',['APK correlation',13,'demodulation1']])
set_param([sys,'/',['APK correlation',13,'demodulation1']],'Location',[2,46,536,174])

add_block('built-in/Inport',[sys,'/',['APK correlation',13,'demodulation1/in_2']])
set_param([sys,'/',['APK correlation',13,'demodulation1/in_2']],...
             'Port','2',...
          'position',[25,65,45,85])


%     Subsystem  ['APK correlation',13,'demodulation1/Rising edge',13,'detector'].

new_system([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/out_1']],...
         'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator1']],...
             'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator2']],...
            'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/one1']],...
          'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Memory1']],...
              'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/in_1']],...
           'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector/Relational',13,'Operator']],...
         'position',[135,18,165,42])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],...
                'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],...
            'Mask Translate','thld=@1;')
set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],...
            'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['APK correlation',13,'demodulation1/Rising edge',13,'detector'].

set_param([sys,'/',['APK correlation',13,'demodulation1/Rising edge',13,'detector']],...
                'ForeGround',4,...
              'position',[125,53,185,97])

add_block('built-in/Inport',[sys,'/',['APK correlation',13,'demodulation1/in_1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/in_1']],...
                'position',[85,25,105,45])

add_block('built-in/S-Function',[sys,'/',['APK correlation',13,'demodulation1/S-function']])
set_param([sys,'/',['APK correlation',13,'demodulation1/S-function']],...
         'ForeGround',2,...
              'function name','apskdem2',...
          'parameters','L, Fc, N, P, A',...
               'position',[325,35,400,55])

add_block('built-in/Outport',[sys,'/',['APK correlation',13,'demodulation1/out_1']])
set_param([sys,'/',['APK correlation',13,'demodulation1/out_1']],...
             'position',[430,35,450,55])

add_block('built-in/Mux',[sys,'/',['APK correlation',13,'demodulation1/Mux']])
set_param([sys,'/',['APK correlation',13,'demodulation1/Mux']],...
             'inputs','2',...
                'position',[250,25,285,60])
add_line([sys,'/',['APK correlation',13,'demodulation1']],[50,75;120,75])
add_line([sys,'/',['APK correlation',13,'demodulation1']],[290,45;320,45])
add_line([sys,'/',['APK correlation',13,'demodulation1']],[190,75;210,75;210,50;245,50])
add_line([sys,'/',['APK correlation',13,'demodulation1']],[405,45;425,45])
add_line([sys,'/',['APK correlation',13,'demodulation1']],[110,35;245,35])
set_param([sys,'/',['APK correlation',13,'demodulation1']],...
                'Mask Display','APK\ncorr demo',...
             'Mask Type','APK demodulation')
set_param([sys,'/',['APK correlation',13,'demodulation1']],...
           'Mask Dialogue','ASK/PSK with concentric circles:|Vector of number of symboles on each circle:|Distance to the originall point for each circle:|Phase shift on each circle (rad):|Carrier frequency (Hz):|Trigger signal threshold:')
set_param([sys,'/',['APK correlation',13,'demodulation1']],...
             'Mask Translate','N=@1;A=@2;P=@3;Fc=@4;thld=@5;L=length(N); [num,den]=cheby1(2,.1,Fc*pi/5,''s'');Am=max(A);')
set_param([sys,'/',['APK correlation',13,'demodulation1']],...
             'Mask Help','This block demodulates an ASK/PSK modulated signal in the 1st in-port. The demodulated message are 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The parameter entry should exactly match the ASK/PSK modulation block.')
set_param([sys,'/',['APK correlation',13,'demodulation1']],...
                'Mask Entries','NIL\/AIL\/PIL\/Fc\/.2\/')


%     Finished composite block ['APK correlation',13,'demodulation1'].

set_param([sys,'/',['APK correlation',13,'demodulation1']],...
           'orientation',2,...
             'position',[250,490,310,530])


%     Subsystem  ['APK amp+phase',13,'demodulation'].

new_system([sys,'/',['APK amp+phase',13,'demodulation']])
set_param([sys,'/',['APK amp+phase',13,'demodulation']],'Location',[73,245,769,433])

add_block('built-in/Inport',[sys,'/',['APK amp+phase',13,'demodulation/in_2']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/in_2']],...
          'Port','2',...
          'position',[220,120,240,140])


%     Subsystem  ['APK amp+phase',13,'demodulation/Rising edge',13,'detector'].

new_system([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']],...
          'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/in_1']],...
          'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Memory1']],...
              'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/one1']],...
               'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
           'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
           'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector/out_1']],...
              'position',[340,25,360,45])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],...
           'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],...
               'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['APK amp+phase',13,'demodulation/Rising edge',13,'detector'].

set_param([sys,'/',['APK amp+phase',13,'demodulation/Rising edge',13,'detector']],...
              'ForeGround',4,...
              'position',[320,108,380,152])

add_block('built-in/Outport',[sys,'/',['APK amp+phase',13,'demodulation/out_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/out_1']],...
         'position',[655,65,675,85])

add_block('built-in/S-Function',[sys,'/',['APK amp+phase',13,'demodulation/S-function']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/S-function']],...
              'ForeGround',2,...
              'function name','apskdemo',...
          'parameters','L, Fc, N, P, A',...
               'position',[550,65,625,85])

add_block('built-in/Mux',[sys,'/',['APK amp+phase',13,'demodulation/Mux']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Mux']],...
           'inputs','3',...
                'position',[490,58,525,92])

add_block('built-in/Fcn',[sys,'/',['APK amp+phase',13,'demodulation/sin']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/sin']],...
           'Expr','sqrt(u[1])',...
         'position',[385,64,450,86])

add_block('built-in/Sum',[sys,'/',['APK amp+phase',13,'demodulation/Sum']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Sum']],...
           'position',[340,65,360,85])


%     Subsystem  ['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM'].

new_system([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],'Location',[353,42,897,305])

add_block('built-in/Outport',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/out_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/out_1']],...
          'position',[480,70,500,90])

add_block('built-in/Outport',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/out_2']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/out_2']],...
             'Port','2',...
          'position',[480,175,500,195])

add_block('built-in/Transfer Fcn',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter1']],...
                'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[395,164,445,206])

add_block('built-in/Transfer Fcn',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter']],...
          'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[395,59,445,101])

add_block('built-in/Product',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Product1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Product1']],...
              'position',[330,167,355,198])

add_block('built-in/Product',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Product']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Product']],...
               'position',[330,62,355,93])

add_block('built-in/Fcn',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Fcn1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Fcn1']],...
           'Expr','sin(u[1]+Pg)',...
               'position',[220,176,295,204])

add_block('built-in/Fcn',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Fcn']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Fcn']],...
           'Expr','sin(u[1]+Ph)',...
               'position',[225,56,300,84])

add_block('built-in/Gain',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Gain']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Gain']],...
          'Gain','pi2',...
                'position',[165,109,200,141])


%     Subsystem  ['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator'].

new_system([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Outport',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/out_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/out_1']],...
            'position',[370,30,390,50])

add_block('built-in/Sum',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Sum']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Sum']],...
               'position',[195,30,215,50])

add_block('built-in/Constant',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/one']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/one']],...
          'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Reset Integrator',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Reset',13,'integrator']],...
                'position',[110,19,150,51])

add_block('built-in/Fcn',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/module']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/module']],...
         'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Memory',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Memory']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Memory']],...
              'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Inport',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/in_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/in_1']],...
         'position',[35,15,55,35])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[340,40;340,90;265,90])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[205,90;180,90;190,45])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
         'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
           'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
            'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'Mask Entries','1\/0\/')


%     Finished composite block ['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator'].

set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'position',[80,109,140,141])

add_block('built-in/Constant',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Constant']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Constant']],...
             'Value','Fc',...
                'position',[35,115,55,135])

add_block('built-in/Note',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
                'position',[285,280,290,285])

add_block('built-in/Inport',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/in_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/in_1']],...
              'position',[230,120,250,140])

add_block('built-in/Gain',[sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Gain1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM/Gain1']],...
              'Gain','2',...
          'position',[270,118,295,142])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[450,185;475,185])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[360,185;390,185])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[450,80;475,80])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[360,80;390,80])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[300,190;325,190])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[305,70;325,70])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[205,125;215,190])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[205,125;205,70;220,70])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[145,125;160,125])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[60,125;75,125])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[255,130;265,130])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],[300,130;305,130;305,175;325,175])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
             'Mask Display','QM\nDSB-SC\nADM',...
            'Mask Type','Quadrature Demultiplexed DSB-SC AM')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
         'Mask Dialogue','Quadrature Demultiplexed Double-Sideband Suppressed-Carrier Amplitude Demodulation:|Carrier amplitude:|Carrier frequency:|Initial phase:|Filter numerator:|Filter denominator:')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
         'Mask Translate','Ac=@1;Fc=@2;Ph=@3;Fn=@4;Fd=@5;pi2=2*pi;Pg=Ph+pi/2;')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
            'Mask Help','The Quadratic Demultiplexed Double-Sideband Supressed-Carrier Amplitude Demodulation block demodulates the QM-DSB-SC-AM signal using quadratic duplex method.')
set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
           'Mask Entries','Am\/Fc\/0\/num\/den\/')


%     Finished composite block ['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM'].

set_param([sys,'/',['APK amp+phase',13,'demodulation/Quad multi',13,'DSB-SC-ADM']],...
             'ForeGround',5,...
              'position',[125,49,200,96])

add_block('built-in/Product',[sys,'/',['APK amp+phase',13,'demodulation/Product']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Product']],...
               'position',[250,45,275,65])

add_block('built-in/Product',[sys,'/',['APK amp+phase',13,'demodulation/Product1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/Product1']],...
             'position',[250,80,275,100])

add_block('built-in/Inport',[sys,'/',['APK amp+phase',13,'demodulation/in_1']])
set_param([sys,'/',['APK amp+phase',13,'demodulation/in_1']],...
             'position',[35,65,55,85])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[280,90;300,90;300,80;335,80])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[205,85;215,85;215,95;245,95])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[205,85;245,85])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[280,55;300,55;300,70;335,70])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[205,60;245,60])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[205,60;215,60;215,50;245,50])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[455,75;485,75])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[60,75;120,75])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[85,75;85,25;470,25;470,65;485,65])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[365,75;380,75])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[630,75;650,75])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[385,130;460,130;460,85;485,85])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[530,75;545,75])
add_line([sys,'/',['APK amp+phase',13,'demodulation']],[245,130;315,130])
set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
              'Mask Display','APK\na-p demo',...
              'Mask Type','APK demodulation')
set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
              'Mask Dialogue','ASK/PSK with concentric circles:|Vector of number of symboles on each circle:|Distance to the originall point for each circle:|Phase shift on each circle (rad):|Carrier frequency (Hz):|Trigger signal threshold:')
set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
                'Mask Translate','N=@1;A=@2;P=@3;Fc=@4;thld=@5;L=length(N); [num,den]=cheby1(2,.1,Fc*pi/5,''s'');Am=max(A);')
set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
                'Mask Help','This block demodulates an ASK/PSK modulated signal in the 1st in-port. The demodulated message are 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The parameter entry should exactly match the ASK/PSK modulation block.')
set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
           'Mask Entries','NIL\/AIL\/PIL\/Fc\/.2\/')


%     Finished composite block ['APK amp+phase',13,'demodulation'].

set_param([sys,'/',['APK amp+phase',13,'demodulation']],...
         'orientation',2,...
             'position',[145,485,205,525])


%     Subsystem  ['Correlation',13,'MPSK demodu'].

new_system([sys,'/',['Correlation',13,'MPSK demodu']])
set_param([sys,'/',['Correlation',13,'MPSK demodu']],'Location',[100,128,948,388])

add_block('built-in/Constant',[sys,'/',['Correlation',13,'MPSK demodu/Frequency']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Frequency']],...
            'Value','Fc',...
                'position',[180,33,205,57])

add_block('built-in/Outport',[sys,'/',['Correlation',13,'MPSK demodu/out_1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/out_1']],...
         'position',[805,150,825,170])

add_block('built-in/S-Function',[sys,'/',['Correlation',13,'MPSK demodu/Maximum']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Maximum']],...
                'function name','arymimai',...
          'parameters','''max''',...
              'position',[730,150,785,170])

add_block('built-in/Memory',[sys,'/',['Correlation',13,'MPSK demodu/Memory1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Memory1']],...
            'orientation',2,...
             'position',[660,200,700,230])

add_block('built-in/Switch',[sys,'/',['Correlation',13,'MPSK demodu/Switch']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Switch']],...
              'Threshold','eps',...
           'position',[665,144,695,176])

add_block('built-in/Reset Integrator',[sys,'/',['Correlation',13,'MPSK demodu/Reset',13,'integrator']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Reset',13,'integrator']],...
              'position',[590,134,630,166])

add_block('built-in/Inport',[sys,'/',['Correlation',13,'MPSK demodu/in_2']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/in_2']],...
          'Port','2',...
          'position',[30,140,50,160])


%     Subsystem  ['Correlation',13,'MPSK demodu/Rising edge',13,'detector'].

new_system([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator']],...
           'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/in_1']],...
                'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Memory1']],...
            'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/one1']],...
             'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']],...
         'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector/out_1']],...
            'position',[340,25,360,45])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],...
              'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],...
          'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['Correlation',13,'MPSK demodu/Rising edge',13,'detector'].

set_param([sys,'/',['Correlation',13,'MPSK demodu/Rising edge',13,'detector']],...
            'position',[75,128,135,172])

add_block('built-in/Constant',[sys,'/',['Correlation',13,'MPSK demodu/Initial phase']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Initial phase']],...
               'Value','Ph',...
                'position',[295,108,315,132])

add_block('built-in/Constant',[sys,'/',['Correlation',13,'MPSK demodu/Shift key']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Shift key']],...
              'Value','sft',...
               'position',[355,78,375,102])

add_block('built-in/Sum',[sys,'/',['Correlation',13,'MPSK demodu/Sum1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Sum1']],...
              'inputs','+++',...
              'position',[415,72,435,108])

add_block('built-in/S-Function',[sys,'/',['Correlation',13,'MPSK demodu/Array sin']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Array sin']],...
             'function name','arysin',...
            'parameters','''sin''',...
              'position',[455,80,505,100])

add_block('built-in/Reset Integrator',[sys,'/',['Correlation',13,'MPSK demodu/Reset',13,'integrator1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Reset',13,'integrator1']],...
             'position',[265,39,305,71])

add_block('built-in/Product',[sys,'/',['Correlation',13,'MPSK demodu/Product']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Product']],...
             'position',[540,36,565,69])

add_block('built-in/Inport',[sys,'/',['Correlation',13,'MPSK demodu/in_1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/in_1']],...
            'position',[440,35,460,55])

add_block('built-in/Switch',[sys,'/',['Correlation',13,'MPSK demodu/Switch1']])
set_param([sys,'/',['Correlation',13,'MPSK demodu/Switch1']],...
              'Threshold','eps',...
           'position',[360,14,390,46])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[140,150;585,150])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[155,150;155,90;235,90;235,55;260,55])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[155,90;155,30;355,30])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[700,160;725,160])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[715,160;705,215])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[155,150;155,200;640,200;640,160;660,160])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[320,120;390,120;390,100;410,100])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[395,30;400,30;410,80])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[790,160;800,160])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[635,150;660,150])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[310,55;345,55;355,40])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[655,215;650,215;660,170])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[510,90;515,90;515,60;535,60])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[380,90;410,90])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[210,45;260,45])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[440,90;450,90])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[570,55;575,55;585,140])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[465,45;535,45])
add_line([sys,'/',['Correlation',13,'MPSK demodu']],[55,150;70,150])
set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
                'Mask Display','MPSK\ndemodu',...
               'Mask Type','MPSK Demodulation')
set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
                'Mask Dialogue','M-ary Phase Shift Keying Demodulation:|M-ary number:|Carrier frequency:|Trigger signal threshold:|Initial phase:')
set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
               'Mask Translate','pi2=2*pi;N=@1;sft=[0:N-1]*pi2/N; Fc=@2*pi2; thld=@3;Ph=@4;')
set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
          'Mask Help','This block demodulates a MPSK modulated signal using coherent method. The first input port is for the received signal, which is MPSK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The initial phase should match those in the modulation. Becase the correlation computation, the output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
         'Mask Entries','16\/100\/.2\/0\/')


%     Finished composite block ['Correlation',13,'MPSK demodu'].

set_param([sys,'/',['Correlation',13,'MPSK demodu']],...
              'orientation',2,...
             'position',[140,220,210,260])


%     Subsystem  ['Coherent',13,'MFSK demodu'].

new_system([sys,'/',['Coherent',13,'MFSK demodu']])
set_param([sys,'/',['Coherent',13,'MFSK demodu']],'Location',[80,310,915,581])

add_block('built-in/Outport',[sys,'/',['Coherent',13,'MFSK demodu/out_1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/out_1']],...
                'position',[785,170,805,190])

add_block('built-in/S-Function',[sys,'/',['Coherent',13,'MFSK demodu/Maximum']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Maximum']],...
            'function name','arymimai',...
          'parameters','''max''',...
              'position',[715,170,770,190])

add_block('built-in/Memory',[sys,'/',['Coherent',13,'MFSK demodu/Memory1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Memory1']],...
                'orientation',2,...
             'position',[640,220,680,250])

add_block('built-in/Switch',[sys,'/',['Coherent',13,'MFSK demodu/Switch']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Switch']],...
          'Threshold','eps',...
           'position',[645,164,675,196])

add_block('built-in/Reset Integrator',[sys,'/',['Coherent',13,'MFSK demodu/Reset',13,'integrator']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Reset',13,'integrator']],...
          'position',[575,154,615,186])

add_block('built-in/Product',[sys,'/',['Coherent',13,'MFSK demodu/Product']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Product']],...
               'position',[520,36,545,69])

add_block('built-in/S-Function',[sys,'/',['Coherent',13,'MFSK demodu/Array sin']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Array sin']],...
          'function name','arysin',...
            'parameters','''sin''',...
              'position',[445,80,495,100])

add_block('built-in/Sum',[sys,'/',['Coherent',13,'MFSK demodu/Sum1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Sum1']],...
          'position',[405,73,425,102])

add_block('built-in/Switch',[sys,'/',['Coherent',13,'MFSK demodu/Switch1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Switch1']],...
         'Threshold','eps',...
           'position',[350,14,380,46])

add_block('built-in/Constant',[sys,'/',['Coherent',13,'MFSK demodu/Initial phase']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Initial phase']],...
            'Value','Ph',...
                'position',[300,113,320,137])

add_block('built-in/Reset Integrator',[sys,'/',['Coherent',13,'MFSK demodu/Reset',13,'integrator1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Reset',13,'integrator1']],...
                'position',[285,49,325,81])

add_block('built-in/Constant',[sys,'/',['Coherent',13,'MFSK demodu/Shift key']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Shift key']],...
            'Value','sft',...
               'position',[175,83,195,107])

add_block('built-in/Constant',[sys,'/',['Coherent',13,'MFSK demodu/Frequency']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Frequency']],...
           'Value','Fc',...
                'position',[175,33,200,57])


%     Subsystem  ['Coherent',13,'MFSK demodu/Rising edge',13,'detector'].

new_system([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/out_1']],...
               'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']],...
             'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']],...
            'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/one1']],...
          'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Memory1']],...
              'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/in_1']],...
           'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator']],...
         'position',[135,18,165,42])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],...
                'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],...
            'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['Coherent',13,'MFSK demodu/Rising edge',13,'detector'].

set_param([sys,'/',['Coherent',13,'MFSK demodu/Rising edge',13,'detector']],...
                'position',[75,148,135,192])

add_block('built-in/Inport',[sys,'/',['Coherent',13,'MFSK demodu/in_2']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/in_2']],...
               'Port','2',...
          'position',[30,160,50,180])

add_block('built-in/Sum',[sys,'/',['Coherent',13,'MFSK demodu/Sum2']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/Sum2']],...
           'position',[240,38,260,67])

add_block('built-in/Inport',[sys,'/',['Coherent',13,'MFSK demodu/in_1']])
set_param([sys,'/',['Coherent',13,'MFSK demodu/in_1']],...
                'position',[440,35,460,55])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[680,180;710,180])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[695,180;685,235])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[200,95;220,95;220,60;235,60])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[265,55;280,55])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[205,45;235,45])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[325,125;345,125;345,95;400,95])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[55,170;70,170])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[465,45;515,45])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[550,55;560,55;570,160])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[430,90;440,90])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[500,90;505,90;515,60])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[635,235;630,235;640,190])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[330,65;335,65;345,40])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[620,170;640,170])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[775,180;780,180])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[385,30;390,30;400,80])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[140,170;570,170])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[155,170;155,220;625,220;625,180;640,180])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[155,170;155,150;270,150;280,65])
add_line([sys,'/',['Coherent',13,'MFSK demodu']],[155,150;155,30;345,30])
set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
             'Mask Display','Coherent\nMFSK dm',...
         'Mask Type','MFSK Demodulation')
set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
          'Mask Dialogue','M-ary Frequency Shift Keying Demodulation:|M-ary number:|Carrier frequency:|Trigger signal threshold:|Initial phase:|Tone space (N/T):')
set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
           'Mask Translate','pi2=2*pi;N=@1;Fc=@2*pi2;thld=@3;Ph=@4;Ton=@5;sft=[0:N-1]*Ton*pi2;')
set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
             'Mask Help','This block demodulates a MFSK modulated signal using coherent method. The first input port is for the received signal, which is MFSK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The initial phase should match those in the modulation. Becase the correlation computation, the output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
           'Mask Entries','8\/100\/.2\/0\/1/.1\/')


%     Finished composite block ['Coherent',13,'MFSK demodu'].

set_param([sys,'/',['Coherent',13,'MFSK demodu']],...
             'orientation',2,...
             'position',[150,135,220,175])


%     Subsystem  ['Noncoherent',13,'MFSK demodu'].

new_system([sys,'/',['Noncoherent',13,'MFSK demodu']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],'Location',[52,135,966,390])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demodu/Sum2']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Sum2']],...
               'position',[235,53,255,82])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demodu/Frequency']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Frequency']],...
              'Value','Fc',...
                'position',[170,48,195,72])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demodu/Shift key']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Shift key']],...
              'Value','sft',...
               'position',[170,98,190,122])

add_block('built-in/Reset Integrator',[sys,'/',['Noncoherent',13,'MFSK demodu/Reset',13,'integrator1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Reset',13,'integrator1']],...
           'position',[280,64,320,96])

add_block('built-in/Switch',[sys,'/',['Noncoherent',13,'MFSK demodu/Switch1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Switch1']],...
            'Threshold','eps',...
           'position',[345,29,375,61])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demodu/Sum1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Sum1']],...
             'position',[400,38,420,67])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demodu/Sum3']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Sum3']],...
             'position',[445,78,465,107])

add_block('built-in/Mux',[sys,'/',['Noncoherent',13,'MFSK demodu/Mux']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Mux']],...
              'inputs','[N N]',...
            'position',[485,43,515,87])

add_block('built-in/S-Function',[sys,'/',['Noncoherent',13,'MFSK demodu/Array sin']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Array sin']],...
            'function name','arysin',...
            'parameters','''sin''',...
              'position',[530,55,580,75])

add_block('built-in/Product',[sys,'/',['Noncoherent',13,'MFSK demodu/Product']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Product']],...
           'position',[600,41,625,74])

add_block('built-in/Inport',[sys,'/',['Noncoherent',13,'MFSK demodu/in_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/in_1']],...
          'position',[535,15,555,35])

add_block('built-in/Reset Integrator',[sys,'/',['Noncoherent',13,'MFSK demodu/Reset',13,'integrator']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Reset',13,'integrator']],...
              'position',[655,54,695,86])

add_block('built-in/Product',[sys,'/',['Noncoherent',13,'MFSK demodu/Product1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Product1']],...
         'position',[730,51,755,84])

add_block('built-in/Demux',[sys,'/',['Noncoherent',13,'MFSK demodu/Demux']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Demux']],...
         'outputs','[N N]',...
           'position',[780,50,820,85])

add_block('built-in/Sum',[sys,'/',['Noncoherent',13,'MFSK demodu/Sum4']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Sum4']],...
             'position',[850,53,870,82])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demodu/Initial phase']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Initial phase']],...
              'Value','Ph',...
                'position',[335,103,355,127])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demodu/Initial phase1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Initial phase1']],...
          'Value','Ph',...
                'position',[395,118,415,142])


%     Subsystem  ['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector'].

new_system([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator']],...
            'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/in_1']],...
              'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Memory1']],...
          'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/one1']],...
           'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator2']],...
               'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/Relational',13,'Operator1']],...
               'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector/out_1']],...
          'position',[340,25,360,45])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],...
             'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],...
         'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector'].

set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Rising edge',13,'detector']],...
          'position',[65,138,125,182])

add_block('built-in/Inport',[sys,'/',['Noncoherent',13,'MFSK demodu/in_2']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/in_2']],...
         'Port','2',...
          'position',[20,150,40,170])

add_block('built-in/Outport',[sys,'/',['Noncoherent',13,'MFSK demodu/out_1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/out_1']],...
               'position',[790,150,810,170])

add_block('built-in/S-Function',[sys,'/',['Noncoherent',13,'MFSK demodu/Maximum']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Maximum']],...
              'function name','arymimai',...
          'parameters','''max''',...
              'position',[720,150,775,170])

add_block('built-in/Memory',[sys,'/',['Noncoherent',13,'MFSK demodu/Memory1']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Memory1']],...
          'orientation',2,...
             'position',[645,200,685,230])

add_block('built-in/Switch',[sys,'/',['Noncoherent',13,'MFSK demodu/Switch']])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu/Switch']],...
            'Threshold','eps',...
           'position',[650,144,680,176])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[130,160;530,160;530,100;635,100;635,70;650,70])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[530,160;645,160])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[265,160;275,80])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[140,160;140,45;340,45])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[875,70;885,70;885,125;620,125;620,150;645,150])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[825,75;845,75])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[825,60;845,60])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[760,70;775,70])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[700,70;705,70;705,75;725,75])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[700,70;705,70;705,60;725,60])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[630,60;650,60])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[560,25;580,25;580,50;595,50])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[585,65;595,65])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[520,65;525,65])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[470,95;480,75])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[425,55;480,55])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[420,130;430,130;440,100])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[425,55;430,55;440,85])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[380,45;395,45])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[780,160;785,160])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[325,80;330,80;340,55])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[640,215;635,215;645,170])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[45,160;60,160])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[360,115;385,115;395,60])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[200,60;230,60])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[260,70;275,70])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[195,110;215,110;215,75;230,75])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[685,160;715,160])
add_line([sys,'/',['Noncoherent',13,'MFSK demodu']],[700,160;690,215])
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
           'Mask Display','Noncohe\nMFSK dm',...
           'Mask Type','MPSK Demodulation')
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
               'Mask Dialogue','Noncoherent M-ary Frequency Shift Keying Demodulation:|M-ary number:|Carrier frequency:|Trigger signal threshold:|Initial phase:|Tone space (N/T):')
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
           'Mask Translate','pi2=2*pi;N=@1;Fc=@2*pi2;thld=@3;Ph=@4;Ton=@5;sft=[0:N-1]*Ton*pi2;')
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
          'Mask Help','This block demodulates a MFSK modulated signal using noncoherent method. The first input port is for the received signal, which is MFSK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The initial phase can be assigned for testing. It should not effect the demodulation result. Becase the correlation computation, the output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
                'Mask Entries','8\/100\/.2\/pi/3\/1/.1\/')


%     Finished composite block ['Noncoherent',13,'MFSK demodu'].

set_param([sys,'/',['Noncoherent',13,'MFSK demodu']],...
            'orientation',2,...
             'position',[255,135,325,175])


%     Subsystem  ['MASK',13,'demodulation'].

new_system([sys,'/',['MASK',13,'demodulation']])
set_param([sys,'/',['MASK',13,'demodulation']],'Location',[199,151,917,359])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/in_2']])
set_param([sys,'/',['MASK',13,'demodulation/in_2']],...
              'Port','2',...
          'position',[70,135,90,155])


%     Subsystem  ['MASK',13,'demodulation/Rising edge',13,'detector'].

new_system([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],'Location',[431,241,820,415])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/out_1']],...
           'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
             'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
            'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/one1']],...
          'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Memory1']],...
              'x0','ini',...
          'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/in_1']],...
           'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector/Relational',13,'Operator']],...
         'position',[135,18,165,42])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
            'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:|Initial condition:')
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
             'Mask Translate','thld=@1;ini=@2;',...
          'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
                'Mask Entries','thld\/1\/')


%     Finished composite block ['MASK',13,'demodulation/Rising edge',13,'detector'].

set_param([sys,'/',['MASK',13,'demodulation/Rising edge',13,'detector']],...
             'ForeGround',4,...
              'position',[170,123,230,167])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/in_1']],...
              'position',[15,35,35,55])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/Shift key']])
set_param([sys,'/',['MASK',13,'demodulation/Shift key']],...
              'Value','sft',...
               'position',[435,103,455,127])

add_block('built-in/Note',[sys,'/',['MASK',13,'demodulation/zero hold']])
set_param([sys,'/',['MASK',13,'demodulation/zero hold']],...
              'ForeGround',2,...
              'position',[370,15,375,20])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/out_1']],...
             'position',[685,55,705,75])

add_block('built-in/S-Function',[sys,'/',['MASK',13,'demodulation/Minimum']])
set_param([sys,'/',['MASK',13,'demodulation/Minimum']],...
              'function name','arymimai',...
          'parameters','''min''',...
              'position',[600,55,655,75])

add_block('built-in/Abs',[sys,'/',['MASK',13,'demodulation/Abs']])
set_param([sys,'/',['MASK',13,'demodulation/Abs']],...
             'position',[545,53,575,77])

add_block('built-in/Sum',[sys,'/',['MASK',13,'demodulation/Sum2']])
set_param([sys,'/',['MASK',13,'demodulation/Sum2']],...
           'inputs','+-',...
               'position',[495,48,515,77])

add_block('built-in/Switch',[sys,'/',['MASK',13,'demodulation/Switch2']])
set_param([sys,'/',['MASK',13,'demodulation/Switch2']],...
          'ForeGround',2,...
              'Threshold','eps',...
           'position',[350,39,380,71])

add_block('built-in/Memory',[sys,'/',['MASK',13,'demodulation/Memory2']])
set_param([sys,'/',['MASK',13,'demodulation/Memory2']],...
          'orientation',2,...
             'ForeGround',2,...
              'x0','-Ac',...
          'position',[345,95,385,125])


%     Subsystem  ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas'].

new_system([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],'Location',[150,97,844,378])

add_block('built-in/Note',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Ref: Hambley: An Intro to Comm. Systems. pp69']],...
              'position',[260,350,265,355])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/in_1']],...
          'position',[45,45,65,65])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin']],...
           'orientation',2,...
             'Expr','sin(u[1]*pi2)',...
              'position',[120,113,205,137])

add_block('built-in/Product',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product']],...
           'position',[125,50,150,70])

add_block('built-in/Transfer Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter']],...
                'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[240,39,290,81])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/sin1']],...
               'orientation',2,...
             'Expr','sin(u[1]*pi2+pih)',...
          'position',[120,160,220,190])

add_block('built-in/Product',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product2']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product2']],...
         'position',[125,215,150,235])

add_block('built-in/Transfer Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter2']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter2']],...
            'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[325,204,375,246])


%     Subsystem  ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator'].

new_system([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],'Location',[529,321,954,458])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/out_1']],...
              'position',[370,30,390,50])

add_block('built-in/Sum',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Sum']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Sum']],...
           'position',[195,30,215,50])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/one']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/one']],...
              'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Reset Integrator',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Reset',13,'integrator']],...
            'position',[110,19,150,51])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/module']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/module']],...
             'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Memory',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Memory']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/Memory']],...
          'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Inport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/in_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator/in_1']],...
             'position',[35,15,55,35])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[340,40;340,90;265,90])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],[205,90;180,90;190,45])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
         'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
             'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
              'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
                'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
                'Mask Entries','1\/0\/')


%     Finished composite block ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator'].

set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Module',13,'Integrator']],...
          'orientation',2,...
             'position',[290,110,350,140])

add_block('built-in/Sum',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Sum']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Sum']],...
               'orientation',2,...
             'position',[380,115,400,135])

add_block('built-in/Transfer Fcn',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Lowpass',13,'filter1']],...
            'orientation',2,...
             'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[450,100,500,140])

add_block('built-in/Constant',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Carrier',13,'frequency']],...
            'orientation',2,...
             'Value','Fc',...
                'position',[460,175,480,195])

add_block('built-in/Product',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Product1']],...
         'orientation',2,...
             'position',[525,110,555,130])

add_block('built-in/Gain',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Gain']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/Gain']],...
            'Gain','G',...
          'position',[605,45,630,75])

add_block('built-in/Outport',[sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/out_1']])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas/out_1']],...
         'position',[660,50,680,70])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[380,225;580,225;580,125;560,125])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[155,225;320,225])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[70,55;120,55])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[90,55;90,230;120,230])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[115,175;105,175;105,220;120,220])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[445,120;405,120])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[520,120;505,120])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[375,125;355,125])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[455,185;430,185;430,130;405,130])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[115,125;105,125;105,65;120,65])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[155,60;235,60])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[635,60;655,60])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[285,125;210,125])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[250,125;250,175;225,175])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[295,60;600,60])
add_line([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],[580,60;580,115;560,115])
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
                'Mask Display','Costas PL\nDSB ADM',...
         'Mask Type','DSB-SC ADM')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
           'Mask Dialogue','Double-sideband suppressed-carrier amplitude demodulation:|Carrier frequency:|Filter numerator:|Filter denominator:|Output gain:')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
         'Mask Translate','Fc=@1;Fn=@2;Fd=@3;G=@4;pi2=pi*2;pih=pi/2;')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
               'Mask Help','The Double-Sideband Supressed-Carrier Amplitude Modulation demodulates a DSB-SC-AM signal using Costas Phase-Locked Loop method.')
set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
          'Mask Entries','Fc\/num\/den\/2\/')


%     Finished composite block ['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas'].

set_param([sys,'/',['MASK',13,'demodulation/DSB-SC-ADM',13,'by-Costas']],...
             'position',[150,25,220,65])
add_line([sys,'/',['MASK',13,'demodulation']],[40,45;145,45])
add_line([sys,'/',['MASK',13,'demodulation']],[580,65;595,65])
add_line([sys,'/',['MASK',13,'demodulation']],[520,65;540,65])
add_line([sys,'/',['MASK',13,'demodulation']],[460,115;465,115;465,70;490,70])
add_line([sys,'/',['MASK',13,'demodulation']],[385,55;400,55;390,110])
add_line([sys,'/',['MASK',13,'demodulation']],[400,55;490,55])
add_line([sys,'/',['MASK',13,'demodulation']],[235,145;305,145;305,55;345,55])
add_line([sys,'/',['MASK',13,'demodulation']],[340,110;335,110;345,65])
add_line([sys,'/',['MASK',13,'demodulation']],[95,145;165,145])
add_line([sys,'/',['MASK',13,'demodulation']],[660,65;680,65])
add_line([sys,'/',['MASK',13,'demodulation']],[225,45;345,45])
set_param([sys,'/',['MASK',13,'demodulation']],...
                'Mask Display','MASK\ndemodu',...
               'Mask Type','MASK Demodulation')
set_param([sys,'/',['MASK',13,'demodulation']],...
              'Mask Dialogue','M-ary Amplitude Shift Keying Demodulation:|M-ary number:|Carrier Frequency:|Carrier signal maximum amplitude:|Trigger signal threshold:')
set_param([sys,'/',['MASK',13,'demodulation']],...
              'Mask Translate','N=@1;Fc=@2;Ac=@3;thld=@4;sft=[0:N-1]*Ac*2/(N-1)-Ac;[num,den]=cheby1(2,.1,Fc*pi/5,''s'');')
set_param([sys,'/',['MASK',13,'demodulation']],...
          'Mask Help','This block demodulates a MASK modulated signal using noncoherent method. The first input port is for the received signal, which is MASK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The output signal has one clock period delay over the original signal.')
set_param([sys,'/',['MASK',13,'demodulation']],...
                'Mask Entries','16\/100\/1\/.2\/')


%     Finished composite block ['MASK',13,'demodulation'].

set_param([sys,'/',['MASK',13,'demodulation']],...
          'orientation',2,...
             'position',[150,45,225,85])


%     Subsystem  ['Multiplel',13,'QASDK'].

new_system([sys,'/',['Multiplel',13,'QASDK']])
set_param([sys,'/',['Multiplel',13,'QASDK']],'Location',[129,443,1004,743])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Sum5']])
set_param([sys,'/',['Multiplel',13,'QASDK/Sum5']],...
            'position',[630,153,650,182])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Shift key2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Shift key2']],...
            'position',[540,114,565,136])


%     Subsystem  ['Multiplel',13,'QASDK/2-D Table'].

new_system([sys,'/',['Multiplel',13,'QASDK/2-D Table']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],'Location',[436,148,718,302])

add_block('built-in/Mux',[sys,'/',['Multiplel',13,'QASDK/2-D Table/Mux']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table/Mux']],...
           'inputs','2',...
                'position',[90,46,120,79])

add_block('built-in/S-Function',[sys,'/',['Multiplel',13,'QASDK/2-D Table/S-function']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table/S-function']],...
         'function name','sftable2',...
          'parameters','xindex, yindex, table',...
                'position',[140,52,190,78])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/2-D Table/x0']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table/x0']],...
            'position',[20,25,40,45])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/2-D Table/table out']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table/table out']],...
               'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/2-D Table/y0']])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table/y0']],...
            'Port','2',...
          'position',[20,80,40,100])
add_line([sys,'/',['Multiplel',13,'QASDK/2-D Table']],[125,65;135,65])
add_line([sys,'/',['Multiplel',13,'QASDK/2-D Table']],[45,35;65,35;65,55;85,55])
add_line([sys,'/',['Multiplel',13,'QASDK/2-D Table']],[195,65;210,65])
add_line([sys,'/',['Multiplel',13,'QASDK/2-D Table']],[45,90;65,90;65,70;85,70])
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
                'Mask Display','plot(-10,-10,110,110,[90,50,10],[90,40,30],[90,50,10],[50,26,20],[90,50,10],[22,13,10])',...
            'Mask Type','2-D Table Lookup')
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
               'Mask Dialogue','Two Dimensional Table Lookup\nThe first input corresponds to X Index and the second input corresponds to the Y Index|X Index|Y Index|Table')
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
         'Mask Translate','xindex=@1; yindex=@2; table=@3; sftab2chk(xindex,yindex,table);')
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
           'Mask Help','This block returns a linearly interpolated intersection from the table using the X index (which corresponds to the rows of the table) and the Y index (which corresponds to the columns of the table).  Extrapolation is used.')
set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
         'Mask Entries','x\/y\/tab\/')


%     Finished composite block ['Multiplel',13,'QASDK/2-D Table'].

set_param([sys,'/',['Multiplel',13,'QASDK/2-D Table']],...
               'position',[675,68,705,92])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Sum3']])
set_param([sys,'/',['Multiplel',13,'QASDK/Sum3']],...
               'inputs','+-',...
               'position',[740,73,760,102])

add_block('built-in/Saturation',[sys,'/',['Multiplel',13,'QASDK/Saturation']])
set_param([sys,'/',['Multiplel',13,'QASDK/Saturation']],...
           'Lower Limit','0',...
           'Upper Limit','N-1',...
         'position',[790,78,820,102])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/out_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/out_1']],...
                'position',[845,80,865,100])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Sum4']])
set_param([sys,'/',['Multiplel',13,'QASDK/Sum4']],...
              'position',[630,58,650,87])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Sum1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Sum1']],...
               'inputs','+-',...
               'position',[440,33,460,62])

add_block('built-in/Memory',[sys,'/',['Multiplel',13,'QASDK/Memory2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Memory2']],...
              'orientation',2,...
             'ForeGround',2,...
              'position',[300,205,340,235])

add_block('built-in/Switch',[sys,'/',['Multiplel',13,'QASDK/Switch2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Switch2']],...
            'ForeGround',2,...
              'Threshold','eps',...
           'position',[305,149,335,181])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Sum2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Sum2']],...
             'inputs','+-',...
               'position',[450,158,470,187])

add_block('built-in/Abs',[sys,'/',['Multiplel',13,'QASDK/Abs']])
set_param([sys,'/',['Multiplel',13,'QASDK/Abs']],...
               'position',[500,163,530,187])

add_block('built-in/S-Function',[sys,'/',['Multiplel',13,'QASDK/Minimum']])
set_param([sys,'/',['Multiplel',13,'QASDK/Minimum']],...
                'function name','arymimai',...
          'parameters','''min''',...
              'position',[555,165,610,185])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Shift key']])
set_param([sys,'/',['Multiplel',13,'QASDK/Shift key']],...
              'Value','sfty',...
              'position',[385,214,410,236])

add_block('built-in/Memory',[sys,'/',['Multiplel',13,'QASDK/Memory1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Memory1']],...
            'orientation',2,...
             'ForeGround',2,...
              'position',[295,80,335,110])

add_block('built-in/Switch',[sys,'/',['Multiplel',13,'QASDK/Switch1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Switch1']],...
             'ForeGround',2,...
              'Threshold','eps',...
           'position',[300,24,330,56])

add_block('built-in/Abs',[sys,'/',['Multiplel',13,'QASDK/Abs1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Abs1']],...
               'position',[495,38,525,62])

add_block('built-in/S-Function',[sys,'/',['Multiplel',13,'QASDK/Minimum1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Minimum1']],...
                'function name','arymimai',...
          'parameters','''min''',...
              'position',[550,40,605,60])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Shift key1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Shift key1']],...
              'Value','sftx',...
              'position',[380,89,405,111])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/in_2']])
set_param([sys,'/',['Multiplel',13,'QASDK/in_2']],...
           'Port','2',...
          'position',[20,180,40,200])


%     Subsystem  ['Multiplel',13,'QASDK/Rising edge',13,'detector'].

new_system([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],'Location',[431,241,820,415])

add_block('built-in/Relational Operator',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator']],...
           'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/in_1']],...
                'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Memory1']],...
            'x0','ini',...
          'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/one1']],...
             'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator2']],...
         'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector/out_1']],...
            'position',[340,25,360,45])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],...
              'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:|Initial condition:')
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],...
               'Mask Translate','thld=@1;ini=@2;',...
          'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],...
          'Mask Entries','thld\/0\/')


%     Finished composite block ['Multiplel',13,'QASDK/Rising edge',13,'detector'].

set_param([sys,'/',['Multiplel',13,'QASDK/Rising edge',13,'detector']],...
         'ForeGround',4,...
              'position',[125,168,185,212])


%     Subsystem  ['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM'].

new_system([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],'Location',[353,42,897,305])

add_block('built-in/Gain',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Gain1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Gain1']],...
          'Gain','2',...
          'position',[270,118,295,142])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/in_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/in_1']],...
            'position',[230,120,250,140])

add_block('built-in/Note',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
            'position',[285,280,290,285])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Constant']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Constant']],...
          'Value','Fc',...
                'position',[35,115,55,135])


%     Subsystem  ['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator'].

new_system([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/in_1']],...
                'position',[35,15,55,35])

add_block('built-in/Memory',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Memory']],...
              'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Fcn',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/module']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/module']],...
              'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Reset Integrator',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Reset',13,'integrator']],...
            'position',[110,19,150,51])

add_block('built-in/Constant',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/one']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/one']],...
                'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Sum',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/Sum']],...
               'position',[195,30,215,50])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator/out_1']],...
             'position',[370,30,390,50])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[205,90;180,90;190,45])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],[340,40;340,90;265,90])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
               'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
              'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
              'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
         'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
         'Mask Entries','1\/0\/')


%     Finished composite block ['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator'].

set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Module',13,'Integrator']],...
            'position',[80,109,140,141])

add_block('built-in/Gain',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Gain']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Gain']],...
               'Gain','pi2',...
                'position',[165,109,200,141])

add_block('built-in/Fcn',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Fcn']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Fcn']],...
         'Expr','sin(u[1]+Ph)',...
               'position',[225,56,300,84])

add_block('built-in/Fcn',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Fcn1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Fcn1']],...
         'Expr','sin(u[1]+Pg)',...
               'position',[220,176,295,204])

add_block('built-in/Product',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Product']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Product']],...
             'position',[330,62,355,93])

add_block('built-in/Product',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Product1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Product1']],...
             'position',[330,167,355,198])

add_block('built-in/Transfer Fcn',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter']],...
                'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[395,59,445,101])

add_block('built-in/Transfer Fcn',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/Lowpass',13,'filter1']],...
               'Numerator','Fn',...
            'Denominator','Fd',...
          'position',[395,164,445,206])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/out_2']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/out_2']],...
         'Port','2',...
          'position',[480,175,500,195])

add_block('built-in/Outport',[sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/out_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM/out_1']],...
         'position',[480,70,500,90])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[300,130;305,130;305,175;325,175])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[300,130;305,130;305,85;325,85])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[255,130;265,130])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[60,125;75,125])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[145,125;160,125])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[205,125;205,70;220,70])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[205,125;215,190])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[305,70;325,70])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[300,190;325,190])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[360,80;390,80])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[450,80;475,80])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[360,185;390,185])
add_line([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],[450,185;475,185])
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
         'Mask Display','QM\nDSB-SC\nADM',...
            'Mask Type','Quadrature Demultiplexed DSB-SC AM')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
            'Mask Dialogue','Quadrature Demultiplexed Double-Sideband Suppressed-Carrier Amplitude Demodulation:|Carrier amplitude:|Carrier frequency:|Initial phase:|Filter numerator:|Filter denominator:')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
            'Mask Translate','Ac=@1;Fc=@2;Ph=@3;Fn=@4;Fd=@5;pi2=2*pi;Pg=Ph+pi/2;')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
               'Mask Help','The Quadratic Demultiplexed Double-Sideband Supressed-Carrier Amplitude Demodulation block demodulates the QM-DSB-SC-AM signal using quadratic duplex method.')
set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
              'Mask Entries','Ac\/Fc\/Ph\/num\/den\/')


%     Finished composite block ['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM'].

set_param([sys,'/',['Multiplel',13,'QASDK/Quad multi',13,'DSB-SC-ADM']],...
          'ForeGround',5,...
              'position',[140,19,215,66])

add_block('built-in/Inport',[sys,'/',['Multiplel',13,'QASDK/in_1']])
set_param([sys,'/',['Multiplel',13,'QASDK/in_1']],...
            'position',[15,35,35,55])
add_line([sys,'/',['Multiplel',13,'QASDK']],[655,75;670,75])
add_line([sys,'/',['Multiplel',13,'QASDK']],[570,125;720,125;720,95;735,95])
add_line([sys,'/',['Multiplel',13,'QASDK']],[610,125;610,80;625,80])
add_line([sys,'/',['Multiplel',13,'QASDK']],[610,125;610,160;625,160])
add_line([sys,'/',['Multiplel',13,'QASDK']],[655,170;660,170;670,85])
add_line([sys,'/',['Multiplel',13,'QASDK']],[615,175;625,175])
add_line([sys,'/',['Multiplel',13,'QASDK']],[610,50;610,65;625,65])
add_line([sys,'/',['Multiplel',13,'QASDK']],[765,90;785,90])
add_line([sys,'/',['Multiplel',13,'QASDK']],[710,80;735,80])
add_line([sys,'/',['Multiplel',13,'QASDK']],[825,90;840,90])
add_line([sys,'/',['Multiplel',13,'QASDK']],[190,190;260,190;260,165;300,165])
add_line([sys,'/',['Multiplel',13,'QASDK']],[260,165;260,40;295,40])
add_line([sys,'/',['Multiplel',13,'QASDK']],[220,55;250,55;250,155;300,155])
add_line([sys,'/',['Multiplel',13,'QASDK']],[220,30;295,30])
add_line([sys,'/',['Multiplel',13,'QASDK']],[530,50;545,50])
add_line([sys,'/',['Multiplel',13,'QASDK']],[465,50;490,50])
add_line([sys,'/',['Multiplel',13,'QASDK']],[410,100;415,100;415,55;435,55])
add_line([sys,'/',['Multiplel',13,'QASDK']],[335,40;350,40;340,95])
add_line([sys,'/',['Multiplel',13,'QASDK']],[350,40;435,40])
add_line([sys,'/',['Multiplel',13,'QASDK']],[290,95;285,95;295,50])
add_line([sys,'/',['Multiplel',13,'QASDK']],[45,190;120,190])
add_line([sys,'/',['Multiplel',13,'QASDK']],[295,220;290,220;300,175])
add_line([sys,'/',['Multiplel',13,'QASDK']],[340,165;355,165;345,220])
add_line([sys,'/',['Multiplel',13,'QASDK']],[355,165;445,165])
add_line([sys,'/',['Multiplel',13,'QASDK']],[415,225;420,225;420,180;445,180])
add_line([sys,'/',['Multiplel',13,'QASDK']],[475,175;495,175])
add_line([sys,'/',['Multiplel',13,'QASDK']],[535,175;550,175])
add_line([sys,'/',['Multiplel',13,'QASDK']],[40,45;135,45])
set_param([sys,'/',['Multiplel',13,'QASDK']],...
               'Mask Display','MQASK\ndemodu',...
              'Mask Type','MASK Demodulation')
set_param([sys,'/',['Multiplel',13,'QASDK']],...
                'Mask Dialogue','M-ary Amplitude Shift Keying Demodulation:|M-ary number:|Carrier Frequency:|Carrier signal maximum amplitude:|Trigger signal threshold:|Inital phase:')
set_param([sys,'/',['Multiplel',13,'QASDK']],...
          'Mask Translate','N=@1;Fc=@2;Ac=@3;thld=@4;Ph=@5;[num,den]=cheby1(2,.1,Fc*pi/6,''s'');sftx=[1 -1 3 -3 5 -5 7 -7 9 -9 11 -11 13 -13 15 -15];sftx=sftx(1:2*ceil(sqrt(N)/2));sfty=sftx;if N==8,sfty=sfty(1:2);end;sftx=sftx/max(sftx)*Ac;sfty=sfty/max(sfty)*Ac;tab=qaskdeco(length(sftx),length(sfty),''fetch'');x=[1:length(sftx)];y=[1:length(sfty)];')
set_param([sys,'/',['Multiplel',13,'QASDK']],...
         'Mask Help','This block demodulates a MQASK modulated signal. The first input port is for the received signal, which is MQASK modulated signal. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The output signal has one clock period delay over the original signal.')
set_param([sys,'/',['Multiplel',13,'QASDK']],...
          'Mask Entries','16\/100\/1\/.2\/0\/')


%     Finished composite block ['Multiplel',13,'QASDK'].

set_param([sys,'/',['Multiplel',13,'QASDK']],...
           'orientation',2,...
             'position',[135,390,210,430])


%     Subsystem  ['Multiple',13,'QASK'].

new_system([sys,'/',['Multiple',13,'QASK']])
set_param([sys,'/',['Multiple',13,'QASK']],'Location',[130,348,773,605])


%     Subsystem  ['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM'].

new_system([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],'Location',[122,503,654,707])


%     Subsystem  ['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator'].

new_system([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],'Location',[196,490,621,627])

add_block('built-in/Outport',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/out_1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/out_1']],...
            'position',[370,30,390,50])

add_block('built-in/Sum',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Sum']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Sum']],...
           'position',[195,30,215,50])

add_block('built-in/Constant',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/one']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/one']],...
              'orientation',3,...
             'move name',0,...
               'position',[70,55,90,75])

add_block('built-in/Reset Integrator',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Reset',13,'integrator']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Reset',13,'integrator']],...
            'position',[110,19,150,51])

add_block('built-in/Fcn',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/module']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/module']],...
             'Expr','rem(u[1],modu)',...
             'position',[235,29,325,51])

add_block('built-in/Memory',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Memory']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/Memory']],...
          'orientation',2,...
             'x0','init',...
         'position',[210,75,260,105])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/in_1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator/in_1']],...
             'position',[35,15,55,35])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[330,40;365,40])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[340,40;340,90;265,90])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[80,50;80,35;105,35])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[60,25;105,25])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[220,40;230,40])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[155,35;190,35])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],[205,90;180,90;190,45])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
         'Mask Display','Mod\nint',...
           'Mask Type','Module Integrator')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
         'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:',...
              'Mask Translate','init=@2; modu=@1;')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
            'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
            'Mask Entries','1\/0\/')


%     Finished composite block ['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator'].

set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Module',13,'Integrator']],...
          'position',[70,79,130,111])

add_block('built-in/Constant',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Constant']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Constant']],...
          'Value','Fc',...
                'position',[25,85,45,105])

add_block('built-in/Note',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
             'position',[250,305,255,310])

add_block('built-in/Fcn',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Fcn']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Fcn']],...
               'Expr','sin(u[1]+Ph)',...
               'position',[235,56,310,84])

add_block('built-in/Product',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Product']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Product']],...
             'position',[355,47,380,78])

add_block('built-in/Product',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Product1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Product1']],...
           'position',[355,112,380,143])

add_block('built-in/Sum',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Sum2']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Sum2']],...
             'position',[430,90,450,110])

add_block('built-in/Outport',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/out_1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/out_1']],...
                'position',[490,90,510,110])

add_block('built-in/Fcn',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Fcn1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Fcn1']],...
              'Expr','sin(u[1]+Pg)',...
               'position',[235,106,310,134])

add_block('built-in/Gain',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Gain']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/Gain']],...
            'Gain','pi2',...
                'position',[155,79,190,111])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/in_1']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/in_1']],...
           'position',[160,30,180,50])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/in_2']])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM/in_2']],...
            'Port','2',...
          'position',[160,145,180,165])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[50,95;65,95])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[135,95;150,95])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[455,100;485,100])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[195,95;205,95;205,70;230,70])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[205,95;205,120;230,120])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[315,70;350,70])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[185,40;325,40;325,55;350,55])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[315,120;350,120])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[185,155;320,155;320,135;350,135])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[385,65;400,65;400,95;425,95])
add_line([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],[385,130;400,130;400,105;425,105])
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
              'Mask Display','QM\nDSB-SC\nAM',...
             'Mask Type','Quadrature Multiplexed DSB-SC AM')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
         'Mask Dialogue','Quadrature multiplexed double-sideband suppressed-carrier amplitude modulation:|Amplitude scale factor:|Carrier frequency:|Initial phase:')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
            'Mask Translate','Am=@1;Fc=@2;Ph=@3;Pg=Ph+pi/2;pi2=pi*2;')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
              'Mask Help','The Quadratic Multiplexed Double-sideband-supressed-carrier AM block causes the amplitude of the sinusoidal carrier to depend on the input message Signal, resulting in amplitude modulation. There are two input Signal being modulated at the same time using quadratic multiplex method.')
set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
           'Mask Entries','Ac\/Fc\/Ph\/')


%     Finished composite block ['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM'].

set_param([sys,'/',['Multiple',13,'QASK/Quad multi',13,'DSB-SC-AM']],...
          'ForeGround',4,...
              'position',[435,73,505,117])

add_block('built-in/Outport',[sys,'/',['Multiple',13,'QASK/out_1']])
set_param([sys,'/',['Multiple',13,'QASK/out_1']],...
            'position',[565,85,585,105])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/in_1']])
set_param([sys,'/',['Multiple',13,'QASK/in_1']],...
               'position',[65,50,85,70])

add_block('built-in/Look Up Table',[sys,'/',['Multiple',13,'QASK/c-y axis']])
set_param([sys,'/',['Multiple',13,'QASK/c-y axis']],...
           'Input_Values','z',...
          'Output_Values','y',...
         'position',[355,110,380,130])

add_block('built-in/Look Up Table',[sys,'/',['Multiple',13,'QASK/s-x axis']])
set_param([sys,'/',['Multiple',13,'QASK/s-x axis']],...
               'Input_Values','z',...
          'Output_Values','x',...
         'position',[355,60,380,80])

add_block('built-in/Switch',[sys,'/',['Multiple',13,'QASK/Switch']])
set_param([sys,'/',['Multiple',13,'QASK/Switch']],...
            'Threshold','eps',...
           'position',[215,54,245,86])

add_block('built-in/Memory',[sys,'/',['Multiple',13,'QASK/Memory1']])
set_param([sys,'/',['Multiple',13,'QASK/Memory1']],...
          'orientation',2,...
             'position',[210,105,250,135])


%     Subsystem  ['Multiple',13,'QASK/Rising edge',13,'detector'].

new_system([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/out_1']],...
             'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator1']],...
             'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator2']],...
            'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/one1']],...
          'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Memory1']],...
              'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/in_1']],...
           'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector/Relational',13,'Operator']],...
         'position',[135,18,165,42])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],...
                'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],...
            'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['Multiple',13,'QASK/Rising edge',13,'detector'].

set_param([sys,'/',['Multiple',13,'QASK/Rising edge',13,'detector']],...
                'position',[115,138,175,182])

add_block('built-in/Inport',[sys,'/',['Multiple',13,'QASK/in_2']])
set_param([sys,'/',['Multiple',13,'QASK/in_2']],...
              'Port','2',...
          'position',[65,150,85,170])
add_line([sys,'/',['Multiple',13,'QASK']],[510,95;560,95])
add_line([sys,'/',['Multiple',13,'QASK']],[385,120;400,120;400,105;430,105])
add_line([sys,'/',['Multiple',13,'QASK']],[385,70;400,70;400,85;430,85])
add_line([sys,'/',['Multiple',13,'QASK']],[250,70;275,70;275,120;255,120])
add_line([sys,'/',['Multiple',13,'QASK']],[275,120;350,120])
add_line([sys,'/',['Multiple',13,'QASK']],[275,70;350,70])
add_line([sys,'/',['Multiple',13,'QASK']],[90,60;210,60])
add_line([sys,'/',['Multiple',13,'QASK']],[90,160;110,160])
add_line([sys,'/',['Multiple',13,'QASK']],[205,120;190,120;190,80;210,80])
add_line([sys,'/',['Multiple',13,'QASK']],[180,160;185,160;185,70;210,70])
set_param([sys,'/',['Multiple',13,'QASK']],...
         'Mask Display','MQASK',...
              'Mask Type','MQASK')
set_param([sys,'/',['Multiple',13,'QASK']],...
              'Mask Dialogue','M-ary Amplitude Shift Keying Modulation:|M-ary number:|Carrier frequency (Hz):|Maximum amplitude:|Trigger signal threshold:|Initial phase (rad):')
set_param([sys,'/',['Multiple',13,'QASK']],...
         'Mask Translate','N=@1;Fc=@2;Ac=@3;thld=@4;Ph=@5;z=[[1:N];[1:N]];z=z(:);[x,y]=qaskenco(z,N);z=z-1.5;z=[z(2:2*N);N-.5];x=x/max(x);y=y/max(y);')
set_param([sys,'/',['Multiple',13,'QASK']],...
            'Mask Help','This block modulates an M-ary digital signal onto a given carrier frequency using amplitude shift keying method. The first input port is for the original digital signal, which is coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input.')
set_param([sys,'/',['Multiple',13,'QASK']],...
         'Mask Entries','16\/100\/1\/.2\/0\/')


%     Finished composite block ['Multiple',13,'QASK'].

set_param([sys,'/',['Multiple',13,'QASK']],...
               'position',[35,358,95,402])


%     Subsystem  ['ASK//PSK',13,'modulation'].

new_system([sys,'/',['ASK//PSK',13,'modulation']])
set_param([sys,'/',['ASK//PSK',13,'modulation']],'Location',[59,72,945,387])

add_block('built-in/Product',[sys,'/',['ASK//PSK',13,'modulation/Product1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Product1']],...
               'position',[520,180,545,200])

add_block('built-in/Look Up Table',[sys,'/',['ASK//PSK',13,'modulation/dividing base']])
set_param([sys,'/',['ASK//PSK',13,'modulation/dividing base']],...
         'Input_Values','x',...
          'Output_Values','2*pi ./ N',...
         'position',[445,122,480,148])

add_block('built-in/Look Up Table',[sys,'/',['ASK//PSK',13,'modulation/initial phase',13,'match']])
set_param([sys,'/',['ASK//PSK',13,'modulation/initial phase',13,'match']],...
           'Input_Values','x',...
          'Output_Values','P',...
         'position',[445,67,480,93])

add_block('built-in/Outport',[sys,'/',['ASK//PSK',13,'modulation/out_1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/out_1']],...
         'position',[800,75,820,95])

add_block('built-in/Product',[sys,'/',['ASK//PSK',13,'modulation/Product']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Product']],...
             'position',[755,75,780,95])

add_block('built-in/Fcn',[sys,'/',['ASK//PSK',13,'modulation/Oscilation']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Oscilation']],...
           'position',[650,75,725,105])

add_block('built-in/Sum',[sys,'/',['ASK//PSK',13,'modulation/Sum1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Sum1']],...
              'inputs','+++',...
              'position',[610,72,630,108])

add_block('built-in/Look Up Table',[sys,'/',['ASK//PSK',13,'modulation/base number',13,'match']])
set_param([sys,'/',['ASK//PSK',13,'modulation/base number',13,'match']],...
                'Input_Values','x',...
          'Output_Values','s',...
         'position',[380,147,415,173])

add_block('built-in/Sum',[sys,'/',['ASK//PSK',13,'modulation/Sum']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Sum']],...
               'inputs','-+',...
               'position',[455,185,475,205])

add_block('built-in/Switch',[sys,'/',['ASK//PSK',13,'modulation/Switch1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Switch1']],...
            'Threshold','eps',...
           'position',[410,214,440,246])

add_block('built-in/Constant',[sys,'/',['ASK//PSK',13,'modulation/freq']])
set_param([sys,'/',['ASK//PSK',13,'modulation/freq']],...
                'Value','Fc',...
                'position',[225,236,250,264])

add_block('built-in/Reset Integrator',[sys,'/',['ASK//PSK',13,'modulation/Reset',13,'integrator']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Reset',13,'integrator']],...
              'position',[320,264,360,296])

add_block('built-in/Look Up Table',[sys,'/',['ASK//PSK',13,'modulation/amplitude',13,'match']])
set_param([sys,'/',['ASK//PSK',13,'modulation/amplitude',13,'match']],...
           'Input_Values','x',...
          'Output_Values','A',...
         'position',[380,27,415,53])

add_block('built-in/Look Up Table',[sys,'/',['ASK//PSK',13,'modulation/index match']])
set_param([sys,'/',['ASK//PSK',13,'modulation/index match']],...
               'Input_Values','z',...
          'Output_Values','y',...
         'position',[285,27,320,53])


%     Subsystem  ['ASK//PSK',13,'modulation/Rising edge',13,'detector'].

new_system([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/out_1']],...
         'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
                'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/one1']],...
              'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Memory1']],...
          'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/in_1']],...
               'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']],...
             'position',[135,18,165,42])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],...
          'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],...
              'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['ASK//PSK',13,'modulation/Rising edge',13,'detector'].

set_param([sys,'/',['ASK//PSK',13,'modulation/Rising edge',13,'detector']],...
            'ForeGround',4,...
              'position',[75,108,135,152])

add_block('built-in/Switch',[sys,'/',['ASK//PSK',13,'modulation/Switch']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Switch']],...
               'Threshold','eps',...
           'position',[190,24,220,56])

add_block('built-in/Memory',[sys,'/',['ASK//PSK',13,'modulation/Memory1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/Memory1']],...
              'orientation',2,...
             'position',[185,75,225,105])

add_block('built-in/Inport',[sys,'/',['ASK//PSK',13,'modulation/in_1']])
set_param([sys,'/',['ASK//PSK',13,'modulation/in_1']],...
           'position',[65,20,85,40])

add_block('built-in/Inport',[sys,'/',['ASK//PSK',13,'modulation/in_2']])
set_param([sys,'/',['ASK//PSK',13,'modulation/in_2']],...
              'Port','2',...
          'position',[20,120,40,140])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[325,40;375,40])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[360,40;360,80;440,80])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[360,80;360,160;375,160])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[360,135;440,135])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[485,135;495,135;495,185;515,185])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[445,230;585,230;585,100;605,100])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[140,130;155,130;155,40;185,40])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[155,130;155,280;315,280])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[155,230;405,230])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[365,280;380,280;380,240;405,240])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[255,250;280,250;280,270;315,270])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[550,190;575,190;575,90;605,90])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[485,80;605,80])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[420,40;735,40;735,80;750,80])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[785,85;795,85])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[730,90;750,90])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[635,90;645,90])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[480,195;515,195])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[225,40;250,40;250,90;230,90])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[250,90;250,200;450,200])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[420,160;435,160;435,190;450,190])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[250,40;280,40])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[90,30;185,30])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[45,130;70,130])
add_line([sys,'/',['ASK//PSK',13,'modulation']],[180,90;165,90;165,50;185,50])
set_param([sys,'/',['ASK//PSK',13,'modulation']],...
             'Mask Display','APK',...
                'Mask Type','APK')
set_param([sys,'/',['ASK//PSK',13,'modulation']],...
          'Mask Dialogue','ASK/PSK with concentric circles:|Vector of number of symboles on each circle:|Distance to the originall point for each circle:|Phase shift on each circle (rad):|Carrier frequency (Hz):|Trigger signal threshold:')
set_param([sys,'/',['ASK//PSK',13,'modulation']],...
               'Mask Translate','N=@1;A=@2;P=@3;Fc=@4*2*pi;thld=@5;M=length(N);for i=1:M,s(i)=sum(N(1:i));end;z=[s(:)'';s(:)''];z=z(:);z=[-.5;z(1:2*M-1)-.5];x=[1:M];y=[x;x];y=y(:);s=[0,s(1:M-1)];')
set_param([sys,'/',['ASK//PSK',13,'modulation']],...
              'Mask Help','This block modulates the first port inputted message by ASK/PSK modulation method. The message should be coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The vector size of the 1st, 2nd, and 3rd entry of this block should be the same. The summation of the first entry is M, the M-ary number of the modulation.')
set_param([sys,'/',['ASK//PSK',13,'modulation']],...
           'Mask Entries','[6 12 18 24 30 38]\/[1 1.93 2.88 3.83 4.78 6.05]\/[0 0 0 0 0 0]\/100\/.2\/')


%     Finished composite block ['ASK//PSK',13,'modulation'].

set_param([sys,'/',['ASK//PSK',13,'modulation']],...
            'position',[35,453,95,497])


%     Subsystem  ['MASK',13,'modulation'].

new_system([sys,'/',['MASK',13,'modulation']])
set_param([sys,'/',['MASK',13,'modulation']],'Location',[113,410,606,682])

add_block('built-in/Sum',[sys,'/',['MASK',13,'modulation/Sum']])
set_param([sys,'/',['MASK',13,'modulation/Sum']],...
               'position',[230,178,250,202])

add_block('built-in/Fcn',[sys,'/',['MASK',13,'modulation/Oscilation']])
set_param([sys,'/',['MASK',13,'modulation/Oscilation']],...
         'Expr','sin(u)',...
             'position',[270,178,310,202])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Gain diff']])
set_param([sys,'/',['MASK',13,'modulation/Gain diff']],...
              'Value','Ac',...
                'position',[265,101,300,129])

add_block('built-in/Sum',[sys,'/',['MASK',13,'modulation/Sum1']])
set_param([sys,'/',['MASK',13,'modulation/Sum1']],...
             'inputs','+-',...
               'position',[335,68,355,92])

add_block('built-in/Outport',[sys,'/',['MASK',13,'modulation/out_1']])
set_param([sys,'/',['MASK',13,'modulation/out_1']],...
         'position',[450,100,470,120])

add_block('built-in/Product',[sys,'/',['MASK',13,'modulation/Product']])
set_param([sys,'/',['MASK',13,'modulation/Product']],...
           'position',[395,100,420,120])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/in_1']])
set_param([sys,'/',['MASK',13,'modulation/in_1']],...
          'position',[85,25,105,45])

add_block('built-in/Switch',[sys,'/',['MASK',13,'modulation/Switch']])
set_param([sys,'/',['MASK',13,'modulation/Switch']],...
         'Threshold','eps',...
           'position',[190,29,220,61])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/in_2']])
set_param([sys,'/',['MASK',13,'modulation/in_2']],...
            'Port','2',...
          'position',[30,90,50,110])


%     Subsystem  ['MASK',13,'modulation/Rising edge',13,'detector'].

new_system([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']],...
            'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/in_1']],...
                'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Memory1']],...
            'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/one1']],...
             'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
         'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector/out_1']],...
            'position',[340,25,360,45])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],...
              'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],...
          'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['MASK',13,'modulation/Rising edge',13,'detector'].

set_param([sys,'/',['MASK',13,'modulation/Rising edge',13,'detector']],...
            'position',[75,78,135,122])

add_block('built-in/Gain',[sys,'/',['MASK',13,'modulation/Gain']])
set_param([sys,'/',['MASK',13,'modulation/Gain']],...
              'Gain','Kc',...
         'position',[265,30,305,60])

add_block('built-in/Memory',[sys,'/',['MASK',13,'modulation/Memory1']])
set_param([sys,'/',['MASK',13,'modulation/Memory1']],...
              'orientation',2,...
             'position',[185,80,225,110])

add_block('built-in/Clock',[sys,'/',['MASK',13,'modulation/Clock']])
set_param([sys,'/',['MASK',13,'modulation/Clock']],...
          'position',[100,175,120,195])

add_block('built-in/Gain',[sys,'/',['MASK',13,'modulation/Gain1']])
set_param([sys,'/',['MASK',13,'modulation/Gain1']],...
          'Gain','Fc',...
         'position',[150,166,200,204])

add_block('built-in/Constant',[sys,'/',['MASK',13,'modulation/Initial phase']])
set_param([sys,'/',['MASK',13,'modulation/Initial phase']],...
              'Value','Ph',...
                'position',[140,224,180,246])
add_line([sys,'/',['MASK',13,'modulation']],[305,115;315,115;315,85;330,85])
add_line([sys,'/',['MASK',13,'modulation']],[360,80;370,80;370,105;390,105])
add_line([sys,'/',['MASK',13,'modulation']],[310,45;315,45;315,75;330,75])
add_line([sys,'/',['MASK',13,'modulation']],[225,45;250,45;250,95;230,95])
add_line([sys,'/',['MASK',13,'modulation']],[250,45;260,45])
add_line([sys,'/',['MASK',13,'modulation']],[205,185;225,185])
add_line([sys,'/',['MASK',13,'modulation']],[140,100;150,100;150,45;185,45])
add_line([sys,'/',['MASK',13,'modulation']],[180,95;165,95;165,55;185,55])
add_line([sys,'/',['MASK',13,'modulation']],[110,35;185,35])
add_line([sys,'/',['MASK',13,'modulation']],[55,100;70,100])
add_line([sys,'/',['MASK',13,'modulation']],[255,190;265,190])
add_line([sys,'/',['MASK',13,'modulation']],[185,235;205,235;205,195;225,195])
add_line([sys,'/',['MASK',13,'modulation']],[315,190;340,190;340,115;390,115])
add_line([sys,'/',['MASK',13,'modulation']],[425,110;445,110])
add_line([sys,'/',['MASK',13,'modulation']],[125,185;145,185])
set_param([sys,'/',['MASK',13,'modulation']],...
         'Mask Display','MASK',...
               'Mask Type','MASK')
set_param([sys,'/',['MASK',13,'modulation']],...
             'Mask Dialogue','M-ary Amplitude Shift Keying Modulation:|M-ary number:|Carrier frequency (Hz):|Maximum amplitude:|Trigger signal threshold:|Initial phase (rad):')
set_param([sys,'/',['MASK',13,'modulation']],...
               'Mask Translate','pi2=2*pi;N=@1;Fc=@2*pi2;Ac=@3;Kc=Ac*2/(N-1);thld=@4;Ph=@5;')
set_param([sys,'/',['MASK',13,'modulation']],...
          'Mask Help','This block modulates an M-ary digital signal onto a given carrier frequency using amplitude shift keying method. The first input port is for the original digital signal, which is coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input.')
set_param([sys,'/',['MASK',13,'modulation']],...
               'Mask Entries','16\/100\/1\/.2\/0\/')


%     Finished composite block ['MASK',13,'modulation'].

set_param([sys,'/',['MASK',13,'modulation']],...
           'position',[40,13,100,57])


%     Subsystem  ['MFSK',13,'modulation'].

new_system([sys,'/',['MFSK',13,'modulation']])
set_param([sys,'/',['MFSK',13,'modulation']],'Location',[283,451,1036,711])

add_block('built-in/Constant',[sys,'/',['MFSK',13,'modulation/Initial phase']])
set_param([sys,'/',['MFSK',13,'modulation/Initial phase']],...
              'Value','Ph',...
                'position',[485,183,505,207])

add_block('built-in/Inport',[sys,'/',['MFSK',13,'modulation/in_2']])
set_param([sys,'/',['MFSK',13,'modulation/in_2']],...
          'Port','2',...
          'position',[30,190,50,210])


%     Subsystem  ['MFSK',13,'modulation/Rising edge',13,'detector'].

new_system([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/out_1']],...
             'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator1']],...
         'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator2']],...
                'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/one1']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/one1']],...
              'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Memory1']],...
          'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/in_1']],...
               'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector/Relational',13,'Operator']],...
             'position',[135,18,165,42])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],...
              'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],...
          'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['MFSK',13,'modulation/Rising edge',13,'detector'].

set_param([sys,'/',['MFSK',13,'modulation/Rising edge',13,'detector']],...
            'position',[75,178,135,222])

add_block('built-in/Reset Integrator',[sys,'/',['MFSK',13,'modulation/Reset',13,'integrator']])
set_param([sys,'/',['MFSK',13,'modulation/Reset',13,'integrator']],...
               'position',[395,159,435,191])

add_block('built-in/Sum',[sys,'/',['MFSK',13,'modulation/Sum1']])
set_param([sys,'/',['MFSK',13,'modulation/Sum1']],...
             'position',[340,148,360,177])

add_block('built-in/Constant',[sys,'/',['MFSK',13,'modulation/one']])
set_param([sys,'/',['MFSK',13,'modulation/one']],...
          'Value','Fc',...
                'position',[275,158,295,182])

add_block('built-in/Outport',[sys,'/',['MFSK',13,'modulation/out_1']])
set_param([sys,'/',['MFSK',13,'modulation/out_1']],...
               'position',[700,140,720,160])

add_block('built-in/Fcn',[sys,'/',['MFSK',13,'modulation/Oscilation']])
set_param([sys,'/',['MFSK',13,'modulation/Oscilation']],...
         'Expr','Ac*sin(u[1])',...
               'position',[595,135,670,165])

add_block('built-in/Sum',[sys,'/',['MFSK',13,'modulation/Sum']])
set_param([sys,'/',['MFSK',13,'modulation/Sum']],...
               'position',[555,133,575,162])

add_block('built-in/Switch',[sys,'/',['MFSK',13,'modulation/Switch1']])
set_param([sys,'/',['MFSK',13,'modulation/Switch1']],...
            'Threshold','eps',...
           'position',[475,124,505,156])

add_block('built-in/Gain',[sys,'/',['MFSK',13,'modulation/Gain']])
set_param([sys,'/',['MFSK',13,'modulation/Gain']],...
            'Gain','Ton',...
                'position',[255,38,305,72])

add_block('built-in/Memory',[sys,'/',['MFSK',13,'modulation/Memory1']])
set_param([sys,'/',['MFSK',13,'modulation/Memory1']],...
              'orientation',2,...
             'position',[175,90,215,120])

add_block('built-in/Switch',[sys,'/',['MFSK',13,'modulation/Switch']])
set_param([sys,'/',['MFSK',13,'modulation/Switch']],...
               'Threshold','eps',...
           'position',[180,39,210,71])

add_block('built-in/Inport',[sys,'/',['MFSK',13,'modulation/in_1']])
set_param([sys,'/',['MFSK',13,'modulation/in_1']],...
            'position',[105,20,125,40])
add_line([sys,'/',['MFSK',13,'modulation']],[140,200;150,200;150,55;175,55])
add_line([sys,'/',['MFSK',13,'modulation']],[150,200;375,200;375,175;390,175])
add_line([sys,'/',['MFSK',13,'modulation']],[150,140;470,140])
add_line([sys,'/',['MFSK',13,'modulation']],[215,55;250,55])
add_line([sys,'/',['MFSK',13,'modulation']],[230,55;220,105])
add_line([sys,'/',['MFSK',13,'modulation']],[310,55;320,55;320,155;335,155])
add_line([sys,'/',['MFSK',13,'modulation']],[300,170;335,170])
add_line([sys,'/',['MFSK',13,'modulation']],[365,165;390,165])
add_line([sys,'/',['MFSK',13,'modulation']],[130,30;150,30;150,45;175,45])
add_line([sys,'/',['MFSK',13,'modulation']],[510,195;525,195;525,155;550,155])
add_line([sys,'/',['MFSK',13,'modulation']],[510,140;550,140])
add_line([sys,'/',['MFSK',13,'modulation']],[580,150;590,150])
add_line([sys,'/',['MFSK',13,'modulation']],[675,150;695,150])
add_line([sys,'/',['MFSK',13,'modulation']],[55,200;70,200])
add_line([sys,'/',['MFSK',13,'modulation']],[170,105;155,105;155,65;175,65])
add_line([sys,'/',['MFSK',13,'modulation']],[440,175;450,175;450,150;470,150])
set_param([sys,'/',['MFSK',13,'modulation']],...
            'Mask Display','MFSK',...
               'Mask Type','MFSK')
set_param([sys,'/',['MFSK',13,'modulation']],...
             'Mask Dialogue','M-ary Frequency Shift Keying Modulation:|M-ary number:|Carrier frequency (Hz):|Output amplitude:|Trigger signal threshold:|Initial phase (rad):|Tone space (Hz):')
set_param([sys,'/',['MFSK',13,'modulation']],...
               'Mask Translate','pi2=2*pi;N=@1;Fc=@2*pi2;Ac=@3;thld=@4;Ph=@5;Ton=@6*pi2;')
set_param([sys,'/',['MFSK',13,'modulation']],...
             'Mask Help','MFSK modulates the input signal to carrier signal using M-ary frequency shift-keying method. The first input port is for the original digital signal, which is coded as 0,1,..,M-1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. The tone space N/T is N times of clock frequency 1/T, N is 0.5 or positive integer. The carrier frequency should be integer times of clock frequency.')
set_param([sys,'/',['MFSK',13,'modulation']],...
                'Mask Entries','8\/100\/1\/.2\/0\/1/0.1\/')


%     Finished composite block ['MFSK',13,'modulation'].

set_param([sys,'/',['MFSK',13,'modulation']],...
             'position',[40,103,100,147])


%     Subsystem  ['Differential',13,'PSK modu'].

new_system([sys,'/',['Differential',13,'PSK modu']])
set_param([sys,'/',['Differential',13,'PSK modu']],'Location',[146,38,930,343])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK modu/Initial phase']])
set_param([sys,'/',['Differential',13,'PSK modu/Initial phase']],...
                'Value','Ph',...
                'position',[480,228,500,252])

add_block('built-in/Gain',[sys,'/',['Differential',13,'PSK modu/Gain']])
set_param([sys,'/',['Differential',13,'PSK modu/Gain']],...
                'Gain','pi',...
         'position',[595,39,630,71])

add_block('built-in/Logical Operator',[sys,'/',['Differential',13,'PSK modu/Logical',13,'Operator']])
set_param([sys,'/',['Differential',13,'PSK modu/Logical',13,'Operator']],...
            'Operator','XOR',...
            'position',[535,43,565,67])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK modu/in_1']])
set_param([sys,'/',['Differential',13,'PSK modu/in_1']],...
                'position',[105,55,125,75])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK modu/Switch']])
set_param([sys,'/',['Differential',13,'PSK modu/Switch']],...
            'Threshold','eps',...
           'position',[220,59,250,91])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK modu/Memory1']])
set_param([sys,'/',['Differential',13,'PSK modu/Memory1']],...
          'orientation',2,...
             'position',[215,115,255,145])

add_block('built-in/Note',[sys,'/',['Differential',13,'PSK modu/zero-hold',13,'input']])
set_param([sys,'/',['Differential',13,'PSK modu/zero-hold',13,'input']],...
                'position',[280,35,285,40])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK modu/Memory2']])
set_param([sys,'/',['Differential',13,'PSK modu/Memory2']],...
          'position',[340,60,380,90])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK modu/Memory3']])
set_param([sys,'/',['Differential',13,'PSK modu/Memory3']],...
          'orientation',2,...
             'position',[420,125,460,155])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK modu/Switch1']])
set_param([sys,'/',['Differential',13,'PSK modu/Switch1']],...
                'Threshold','eps',...
           'position',[425,69,455,101])

add_block('built-in/Note',[sys,'/',['Differential',13,'PSK modu/delayed',13,'input']])
set_param([sys,'/',['Differential',13,'PSK modu/delayed',13,'input']],...
             'position',[485,50,490,55])

add_block('built-in/Outport',[sys,'/',['Differential',13,'PSK modu/out_1']])
set_param([sys,'/',['Differential',13,'PSK modu/out_1']],...
             'position',[695,155,715,175])

add_block('built-in/Sum',[sys,'/',['Differential',13,'PSK modu/Sum']])
set_param([sys,'/',['Differential',13,'PSK modu/Sum']],...
           'inputs','+++',...
              'position',[555,147,575,183])

add_block('built-in/Fcn',[sys,'/',['Differential',13,'PSK modu/Oscilation']])
set_param([sys,'/',['Differential',13,'PSK modu/Oscilation']],...
             'Expr','Ac*sin(u[1])',...
               'position',[595,150,670,180])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK modu/in_2']])
set_param([sys,'/',['Differential',13,'PSK modu/in_2']],...
              'Port','2',...
          'position',[55,235,75,255])


%     Subsystem  ['Differential',13,'PSK modu/Rising edge',13,'detector'].

new_system([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/out_1']],...
               'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator1']],...
             'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator2']],...
            'Operator','>',...
              'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/one1']],...
          'Value','thld',...
              'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Memory1']],...
              'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/in_1']],...
           'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector/Relational',13,'Operator']],...
         'position',[135,18,165,42])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],...
                'Mask Display','Edge\ndetector',...
             'Mask Type','Edge Detection',...
                'Mask Dialogue','Rising edge detection:|Threshold:',...
         'Mask Translate','thld=@1;')
set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],...
            'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.',...
         'Mask Entries','thld\/')


%     Finished composite block ['Differential',13,'PSK modu/Rising edge',13,'detector'].

set_param([sys,'/',['Differential',13,'PSK modu/Rising edge',13,'detector']],...
                'position',[100,223,160,267])

add_block('built-in/Reset Integrator',[sys,'/',['Differential',13,'PSK modu/Reset',13,'integrator']])
set_param([sys,'/',['Differential',13,'PSK modu/Reset',13,'integrator']],...
          'position',[335,209,375,241])

add_block('built-in/Constant',[sys,'/',['Differential',13,'PSK modu/one']])
set_param([sys,'/',['Differential',13,'PSK modu/one']],...
              'Value','Fc',...
                'position',[260,201,285,229])

add_block('built-in/Switch',[sys,'/',['Differential',13,'PSK modu/Switch2']])
set_param([sys,'/',['Differential',13,'PSK modu/Switch2']],...
                'Threshold','eps',...
           'position',[435,179,465,211])
add_line([sys,'/',['Differential',13,'PSK modu']],[570,55;590,55])
add_line([sys,'/',['Differential',13,'PSK modu']],[80,245;95,245])
add_line([sys,'/',['Differential',13,'PSK modu']],[210,130;200,130;200,85;215,85])
add_line([sys,'/',['Differential',13,'PSK modu']],[130,65;215,65])
add_line([sys,'/',['Differential',13,'PSK modu']],[415,140;400,140;400,95;420,95])
add_line([sys,'/',['Differential',13,'PSK modu']],[385,75;420,75])
add_line([sys,'/',['Differential',13,'PSK modu']],[290,215;330,215])
add_line([sys,'/',['Differential',13,'PSK modu']],[380,225;415,225;415,205;430,205])
add_line([sys,'/',['Differential',13,'PSK modu']],[165,245;190,245;190,75;215,75])
add_line([sys,'/',['Differential',13,'PSK modu']],[190,245;305,245;305,225;330,225])
add_line([sys,'/',['Differential',13,'PSK modu']],[190,195;430,195])
add_line([sys,'/',['Differential',13,'PSK modu']],[580,165;590,165])
add_line([sys,'/',['Differential',13,'PSK modu']],[460,85;485,85;485,140;465,140])
add_line([sys,'/',['Differential',13,'PSK modu']],[485,85;520,85;530,60])
add_line([sys,'/',['Differential',13,'PSK modu']],[255,75;335,75])
add_line([sys,'/',['Differential',13,'PSK modu']],[280,75;280,130;260,130])
add_line([sys,'/',['Differential',13,'PSK modu']],[320,75;320,40;520,40;530,50])
add_line([sys,'/',['Differential',13,'PSK modu']],[635,55;650,55;650,115;530,115;530,155;550,155])
add_line([sys,'/',['Differential',13,'PSK modu']],[675,165;690,165])
add_line([sys,'/',['Differential',13,'PSK modu']],[470,195;525,195;525,165;550,165])
add_line([sys,'/',['Differential',13,'PSK modu']],[505,240;535,240;535,175;550,175])
set_param([sys,'/',['Differential',13,'PSK modu']],...
             'Mask Display','DPSK',...
               'Mask Type','DPSK')
set_param([sys,'/',['Differential',13,'PSK modu']],...
               'Mask Dialogue','Differential Phase Shift Keying Modulation:|Carrier frequency (Hz):|Output amplitude:|Trigger signal threshold:|Initial phase (rad):')
set_param([sys,'/',['Differential',13,'PSK modu']],...
           'Mask Translate','pi2=2*pi;Fc=@1*pi2; Ac=@2; thld=@3;Ph=@4;')
set_param([sys,'/',['Differential',13,'PSK modu']],...
             'Mask Help','This block modulates a binary digital signal onto a given carrier frequency. The first input port is for the binary signal, which is either 0 or 1. The second input port inputs the clock pulse. The clock rising edge triggers the block to process next input. For best solution, the carrier frequency should be integer times the clock frequency. The initial phase will affect every input process.')
set_param([sys,'/',['Differential',13,'PSK modu']],...
         'Mask Entries','N\/100\/1\/.2\/')


%     Finished composite block ['Differential',13,'PSK modu'].

set_param([sys,'/',['Differential',13,'PSK modu']],...
           'position',[30,274,95,316])
add_line(sys,[100,210;225,210;215,230])
add_line(sys,[100,295;225,295;215,315])
add_line(sys,[1185,65;1340,65;1330,80])
add_line(sys,[105,125;340,125;330,145])
add_line(sys,[105,35;240,35;230,55])
add_line(sys,[100,380;225,380;215,400])
add_line(sys,[100,475;220,475;210,495])
add_line(sys,[235,125;225,145])
add_line(sys,[220,475;325,475;315,500])

drawnow

% Return any arguments.
if (nargin | nargout)
      % Must use feval here to access system in memory
        if (nargin > 3)
         if (flag == 0)
                  eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
              else
                    eval(['ret =', sys,'(t,x,u,flag);'])
            end
     else
            [ret,x0,str,ts,xts] = feval(sys);
       end
else
 drawnow % Flash up the model and execute load callback
end
