function [ret,x0,str,ts,xts]=com_moce(t,x,u,flag);
%COM_MOCE	is the M-file description of the SIMULINK system named COM_MOCE.
%	The block-diagram can be displayed by typing: COM_MOCE.
%
%	SYS=COM_MOCE(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes COM_MOCE to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling COM_MOCE with a FLAG of zero:
%	[SIZES]=COM_MOCE([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[256,75,789,641])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','Digital Modulation//Demodulation Library'])
set_param([sys,'/','Digital Modulation//Demodulation Library'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[250,0,255,5])


%     Subsystem  ['MFSK mod',13,'baseband'].

new_system([sys,'/',['MFSK mod',13,'baseband']])
set_param([sys,'/',['MFSK mod',13,'baseband']],'Location',[21,547,367,688])

add_block('built-in/Inport',[sys,'/',['MFSK mod',13,'baseband/in_1']])
set_param([sys,'/',['MFSK mod',13,'baseband/in_1']],...
		'position',[15,60,35,80])

add_block('built-in/Outport',[sys,'/',['MFSK mod',13,'baseband/out_1']])
set_param([sys,'/',['MFSK mod',13,'baseband/out_1']],...
		'position',[290,60,310,80])


%     Subsystem  ['MFSK mod',13,'baseband/FM',13,'baseband'].

new_system([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],'Location',[55,571,668,718])

add_block('built-in/S-Function',[sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Scheduled',13,'reset-int']])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int',...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/pi2\/',...
		'position',[155,14,215,56])

add_block('built-in/Gain',[sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Sensitivity']])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Sensitivity']],...
		'Gain','pi2',...
		'position',[80,25,120,55])

add_block('built-in/Outport',[sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/out_1']])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/out_1']],...
		'position',[550,40,570,60])

add_block('built-in/Mux',[sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Mux']])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[415,31,450,64])

add_block('built-in/Fcn',[sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/sin']])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/sin']],...
		'Expr','sin(u)',...
		'position',[330,86,385,114])

add_block('built-in/Fcn',[sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/cos']])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/cos']],...
		'Expr','cos(u)',...
		'position',[330,26,385,54])

add_block('built-in/Inport',[sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/in_1']])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/in_1']],...
		'position',[35,25,55,45])

add_block('built-in/Sum',[sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Sum']])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Sum']],...
		'position',[265,30,285,50])

add_block('built-in/Constant',[sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Constant']])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband/Constant']],...
		'Value','Ph',...
		'position',[180,90,205,110])
add_line([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],[125,40;150,35])
add_line([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],[60,35;60,40;75,40])
add_line([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],[390,100;395,100;395,55;410,55])
add_line([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],[455,50;545,50])
add_line([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],[390,40;410,40])
add_line([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],[220,35;260,35])
add_line([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],[210,100;250,100;260,45])
add_line([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],[290,40;325,40])
add_line([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],[300,40;300,100;325,100])
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);FM',...
		'Mask Type','FM CE')
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of the FM signal.|Initial phase (rad):|Sample time (second):|Symbol interval (for digital mod, use Inf for analog mod):')
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],...
		'Mask Translate','Kc=2*pi;Ph=@1;pi2=2*pi;ts=@2;td=@3;if isinf(td),td=inf;end;[x,y]=moduicon(3);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the frequency modulated signal. The output is a complex signal. This block resets the phase at the very beginning of the symbol interval. For continuous-time simulation, the symbol interval can be set as infinity.')
set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],...
		'Mask Entries','Ph\/ts\/td\/')


%     Finished composite block ['MFSK mod',13,'baseband/FM',13,'baseband'].

set_param([sys,'/',['MFSK mod',13,'baseband/FM',13,'baseband']],...
		'ForeGround',4,...
		'position',[185,48,260,92])


%     Subsystem  ['MFSK mod',13,'baseband/MFSK map'].

new_system([sys,'/',['MFSK mod',13,'baseband/MFSK map']])
set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map']],'Location',[90,420,407,543])

add_block('built-in/Inport',[sys,'/',['MFSK mod',13,'baseband/MFSK map/in_1']])
set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map/in_1']],...
		'position',[45,45,65,65])

add_block('built-in/Gain',[sys,'/',['MFSK mod',13,'baseband/MFSK map/Gain']])
set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map/Gain']],...
		'Gain','Ton',...
		'position',[175,38,225,72])

add_block('built-in/Outport',[sys,'/',['MFSK mod',13,'baseband/MFSK map/out_1']])
set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map/out_1']],...
		'position',[260,45,280,65])

add_block('built-in/Zero-Order Hold',[sys,'/',['MFSK mod',13,'baseband/MFSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[105,39,140,71])
add_line([sys,'/',['MFSK mod',13,'baseband/MFSK map']],[230,55;255,55])
add_line([sys,'/',['MFSK mod',13,'baseband/MFSK map']],[70,55;100,55])
add_line([sys,'/',['MFSK mod',13,'baseband/MFSK map']],[145,55;170,55])
set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map']],...
		'Mask Display','MFSK\nmap',...
		'Mask Type','MFSK map')
set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map']],...
		'Mask Dialogue','Map input digital signal to analog tone space for FM modulation. The tone space\nis the frequency distance between two \nconsective digit numbers.|Tone space (Hz):|Input symbol interval and offset (sec):')
set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map']],...
		'Mask Translate','Ton=@1;td=@2;')
set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map']],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the FM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. Tone space is the frequency separation between two consective digits for the input signal. After FM, the modulated signal has a frequency in the range of [Fc, Fc+B]. B is the bandwidth of the FSK, B=(M-1) * Tone_space.')
set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map']],...
		'Mask Entries','Ton\/td\/')


%     Finished composite block ['MFSK mod',13,'baseband/MFSK map'].

set_param([sys,'/',['MFSK mod',13,'baseband/MFSK map']],...
		'position',[70,48,150,92])
add_line([sys,'/',['MFSK mod',13,'baseband']],[265,70;285,70])
add_line([sys,'/',['MFSK mod',13,'baseband']],[155,70;180,70])
add_line([sys,'/',['MFSK mod',13,'baseband']],[40,70;65,70])
set_param([sys,'/',['MFSK mod',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);MFSK',...
		'Mask Type','Baseband MFSK modulation')
set_param([sys,'/',['MFSK mod',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of the\nmultiple-frequency shift keying modulation.|Tone space(Hz):|Symbol interval (sec):|Initial phase (rad):|Sample frequency (sec):')
set_param([sys,'/',['MFSK mod',13,'baseband']],...
		'Mask Translate','Ton=@1;td=@2;Ph=@3;ts=@4;if isinf(td),td=inf;end;[x,y]=moduicon(7);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MFSK mod',13,'baseband']],...
		'Mask Help','This block outputs the complex envelop of MFSK modulated signal. The input signal is integers in the range [0, M-1]. The maximum amplitude of the output is 1. When the symbol interval is a two-element vector, the second element is the offset (default 0). The block takes the input value at the sampling time point.')
set_param([sys,'/',['MFSK mod',13,'baseband']],...
		'Mask Entries','16/.2/5\/.2\/0\/.01\/')


%     Finished composite block ['MFSK mod',13,'baseband'].

set_param([sys,'/',['MFSK mod',13,'baseband']],...
		'position',[45,353,125,397])


%     Subsystem  ['MASK demod',13,'baseband'].

new_system([sys,'/',['MASK demod',13,'baseband']])
set_param([sys,'/',['MASK demod',13,'baseband']],'Location',[82,326,492,462])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/in_1']])
set_param([sys,'/',['MASK demod',13,'baseband/in_1']],...
		'position',[15,35,35,55])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/out_1']])
set_param([sys,'/',['MASK demod',13,'baseband/out_1']],...
		'position',[330,35,350,55])


%     Subsystem  ['MASK demod',13,'baseband/MASK demap'].

new_system([sys,'/',['MASK demod',13,'baseband/MASK demap']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],'Location',[187,342,628,482])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/MASK demap/in_1']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/in_1']],...
		'position',[30,35,50,55])

add_block('built-in/S-Function',[sys,'/',['MASK demod',13,'baseband/MASK demap/Minimum']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/Minimum']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[315,45,370,65])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/MASK demap/out_1']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/out_1']],...
		'position',[400,45,420,65])

add_block('built-in/Abs',[sys,'/',['MASK demod',13,'baseband/MASK demap/Abs']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/Abs']],...
		'position',[235,42,270,68])

add_block('built-in/Sum',[sys,'/',['MASK demod',13,'baseband/MASK demap/Sum2']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/Sum2']],...
		'inputs','+-',...
		'position',[180,38,200,67])

add_block('built-in/Constant',[sys,'/',['MASK demod',13,'baseband/MASK demap/Shift key']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/Shift key']],...
		'Value','sft',...
		'position',[115,93,135,117])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK demod',13,'baseband/MASK demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[85,29,120,61])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[205,55;230,55])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[140,105;155,105;155,60;175,60])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[375,55;395,55])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[125,45;175,45])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[275,55;310,55])
add_line([sys,'/',['MASK demod',13,'baseband/MASK demap']],[55,45;80,45])
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'Mask Display','MASK\ndemap',...
		'Mask Type','MASK demap')
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'Mask Dialogue','Reverse the MASK mapping process\nConvert [-1 1] analog signal to [0, M-1] symbols.|M-ary number (digit integers in ranger [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'Mask Translate','N=@1;Ac=1;sft=[0:N-1]*Ac*2/(N-1)-Ac;td=@2;')
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'Mask Help','This block demaps a MASK mapped signal back to digit symbols. You can place this block after a amplitude demodulation block. The input of this block is an analog signal in the range [-1, 1]. The demodulation decides the closest integer fitting in [0,M-1] range. When the input symbol interval is a two-elements vector, the second element is offset. The default offset value is 0.')
set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'Mask Entries','N\/td\/')


%     Finished composite block ['MASK demod',13,'baseband/MASK demap'].

set_param([sys,'/',['MASK demod',13,'baseband/MASK demap']],...
		'position',[215,23,295,67])


%     Subsystem  ['MASK demod',13,'baseband/DSB-ADM',13,'baseband'].

new_system([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],'Location',[172,360,722,581])

add_block('built-in/Filter',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter2']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter2']],...
		'orientation',2,...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[310,100,370,140])


%     Subsystem  ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO'].

new_system([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],'Location',[493,551,1106,698])

add_block('built-in/Constant',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Constant']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Constant']],...
		'Value','Ph',...
		'position',[160,100,180,120])

add_block('built-in/Sum',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sum']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sum']],...
		'position',[220,30,240,50])


%     Subsystem  ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator'].

new_system([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],'Location',[40,403,515,507])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Dis. Transfer Fcn']],...
		'Numerator','ts(1)',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[90,17,135,53])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/in_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Fcn',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/module']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/module']],...
		'Expr','rem(u[1],modu)',...
		'position',[235,29,325,51])

add_block('built-in/Sum',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Sum']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Sum']],...
		'position',[195,30,215,50])

add_block('built-in/Unit Delay',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Unit Delay']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/Unit Delay']],...
		'Sample time','ts',...
		'x0','init',...
		'position',[345,30,395,50])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/out_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator/out_1']],...
		'position',[445,30,465,50])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[140,35;190,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[40,35;85,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[220,40;230,40])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[330,40;340,40])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[400,40;410,40;410,90;175,90;175,45;190,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],[410,40;440,40])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Display','discrete\nmod-int',...
		'Mask Type','Module Integrator')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Dialogue','Module the given number when state exceed limit|Module bound:|Initial value:|Sample time:')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Translate','init=@2; modu=@1;ts=@3;')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Help','The absolute value of this integrator will not exceed the specified module bound. The state value is set to be zero when the module bound is reached. This block can only be used for scale value calculation.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'Mask Entries','pi2\/0\/ts\/')


%     Finished composite block ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator'].

set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Dis module',13,'integrator']],...
		'position',[135,16,195,54])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/out_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/out_1']],...
		'position',[490,35,510,55])

add_block('built-in/Gain',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity1']],...
		'Gain','Ac',...
		'position',[420,31,460,59])

add_block('built-in/Mux',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Mux']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Mux']],...
		'inputs','2',...
		'position',[355,26,390,59])

add_block('built-in/Fcn',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/sin']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/sin']],...
		'Expr','sin(u)',...
		'position',[270,81,325,109])

add_block('built-in/Fcn',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/cos']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/cos']],...
		'Expr','cos(u)',...
		'position',[270,21,325,49])

add_block('built-in/Gain',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/Sensitivity']],...
		'Gain','Kc',...
		'position',[80,21,120,49])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/in_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO/in_1']],...
		'position',[35,25,55,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[245,40;250,40;250,95;265,95])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[185,110;200,110;200,45;215,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[245,40;245,35;265,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[200,35;215,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[330,95;335,95;335,50;350,50])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[395,45;415,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[330,35;350,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[465,45;485,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[125,35;130,35])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],[60,35;75,35])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Display','FM\ncmplx env',...
		'Mask Type','FM with cmplx env out')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Dialogue','Frequency modulation with complex envelop output:|Amplitude constant:|Modulation sensitivity constant:|Initial phase (rad):|Sample time:')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Translate','Ac=@1;Kc=@2*2*pi;Ph=@3;pi2=2*pi;ts=@4;')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Help','The FM block cause the frequency of the sinusoidal carrier to depend on the input signal voltage, resulting in frequency of the output change depending on the amplitude of the input signal.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'Mask Entries','1\/1\/Ph\/ts\/')


%     Finished composite block ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO'].

set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/FM CE//VCO']],...
		'orientation',2,...
		'position',[215,100,295,140])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/in_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/in_1']],...
		'orientation',2,...
		'position',[185,90,205,110])

add_block('built-in/Filter',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[250,176,305,214])


%     Subsystem  ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

new_system([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],'Location',[297,318,980,694])

add_block('built-in/Gain',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Conjugate']],...
		'Gain','-1',...
		'position',[190,210,230,240])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I2']],...
		'position',[170,225,175,230])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Real']],...
		'position',[495,110,515,130])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Imag']],...
		'Port','2',...
		'position',[485,280,505,300])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I1']],...
		'position',[198,108,203,113])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R1']],...
		'position',[195,65,200,70])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R2']],...
		'position',[190,185,195,190])

add_block('built-in/Product',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product']],...
		'position',[305,83,335,107])

add_block('built-in/Product',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product1']],...
		'position',[305,143,335,167])

add_block('built-in/Sum',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum']],...
		'inputs','+-',...
		'position',[380,110,400,130])

add_block('built-in/Product',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product3']],...
		'position',[305,253,335,277])

add_block('built-in/Product',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Product2']],...
		'position',[305,298,335,322])

add_block('built-in/Sum',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Sum1']],...
		'position',[380,280,400,300])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R_out']],...
		'position',[450,95,455,100])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/I_out']],...
		'position',[450,286,455,291])

add_block('built-in/Note',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/R = Real',13,'I = Imaginary']],...
		'position',[55,0,60,5])

add_block('built-in/Demux',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split']],...
		'position',[85,79,160,121])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 1']],...
		'position',[35,90,55,110])

add_block('built-in/Demux',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'outputs','2',...
		'Mask Display','Complex to\nReal/Imag',...
		'Mask Type','Complex to Real/Imag')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Dialogue','Real and imaginary components of complex vector.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'Mask Help','The Complex to Real/Imag block decomposes a complex vector into its real and imaginary components using a Demux block. The real part is directed to output 1, and the imaginary to output 2.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Split1']],...
		'position',[80,194,155,236])

add_block('built-in/Inport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply/Complex',13,'input 2']],...
		'Port','2',...
		'position',[25,205,45,225])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[235,225;260,225;260,160;300,160])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[260,225;260,270;300,270])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,225;185,225])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,120;490,120])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[405,290;480,290])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[60,100;80,100])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[50,215;75,215])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,95;350,95;350,115;375,115])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,155;350,155;350,125;375,125])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,90;300,90])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[243,90;243,260;300,260])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[160,205;275,205;275,100;300,100])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[275,205;275,305;300,305])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[165,110;250,110;250,150;300,150])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[255,150;255,315;300,315])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,265;350,265;350,285;375,285])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],[340,310;350,310;350,295;375,295])


%     Finished composite block ['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply'].

set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Cmplx-in',13,'Re//Im-out',13,'Multiply']],...
		'orientation',2,...
		'position',[40,90,115,130])

add_block('built-in/Filter',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[260,26,315,64])

add_block('built-in/Product',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Product1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/Product1']],...
		'orientation',2,...
		'position',[390,110,425,130])

add_block('built-in/Outport',[sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/out_1']])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband/out_1']],...
		'position',[485,35,505,55])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[210,120;120,120])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[305,120;300,120])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[385,120;375,120])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[310,195;445,195;445,125;430,125])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[35,120;15,120;15,195;245,195])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[35,100;20,100;20,45;255,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[180,100;120,100])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[320,45;480,45])
add_line([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],[445,45;445,115;430,115])
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);DSB ADM',...
		'Mask Type','DSB-SC ADM CE')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nDSB-SC AM modulated signal.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;pi2=pi*2;ts=@4;[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a DSB-SC-AM modulated signal using Costas phase-locked loop method. This block requires you to specify a lowpass filter that eliminates the carrier frequency and keeps the message signal. This block takes a complex signal.')
set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['MASK demod',13,'baseband/DSB-ADM',13,'baseband'].

set_param([sys,'/',['MASK demod',13,'baseband/DSB-ADM',13,'baseband']],...
		'ForeGround',4,...
		'position',[90,23,170,67])
add_line([sys,'/',['MASK demod',13,'baseband']],[40,45;85,45])
add_line([sys,'/',['MASK demod',13,'baseband']],[300,45;325,45])
add_line([sys,'/',['MASK demod',13,'baseband']],[175,45;210,45])
set_param([sys,'/',['MASK demod',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);MASK',...
		'Mask Type','Baseband MASK demodulation')
set_param([sys,'/',['MASK demod',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nMASK modulated signal.|M-ary number (output integer in range [0, M-1]):|Output symbol interval and offset (sec):|Initial phase (rad):|Lowpass filter numerator:|Lowpass filter denominator:|Filter sample time (sec):')
set_param([sys,'/',['MASK demod',13,'baseband']],...
		'Mask Translate','N=@1;td=@2;Ph=@3;num=@4;den=@5;ts=@6;[x,y]=moduicon(6);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MASK demod',13,'baseband']],...
		'Mask Help','This block demodulates the complex envelope of a MASK modulated signal. The output signal are digits in the range [0, M-1]. When the output symbol interval is a two-element vector, the second element is the offset (default 0). A lowpass filter is required in the demodulation. You can set both numerator and denominator to one for not using the lowpass filter.')
set_param([sys,'/',['MASK demod',13,'baseband']],...
		'Mask Entries','16\/[.2, .2-.01]\/0\/1\/1\/.01\/')


%     Finished composite block ['MASK demod',13,'baseband'].

set_param([sys,'/',['MASK demod',13,'baseband']],...
		'position',[175,53,255,97])


%     Subsystem  ['MPSK demod',13,'baseband'].

new_system([sys,'/',['MPSK demod',13,'baseband']])
set_param([sys,'/',['MPSK demod',13,'baseband']],'Location',[4,554,405,737])

add_block('built-in/Outport',[sys,'/',['MPSK demod',13,'baseband/out_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/out_1']],...
		'position',[295,65,315,85])

add_block('built-in/Inport',[sys,'/',['MPSK demod',13,'baseband/in_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/in_1']],...
		'position',[10,65,30,85])


%     Subsystem  ['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband'].

new_system([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],'Location',[102,505,735,711])

add_block('built-in/Constant',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Initial phase']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Initial phase']],...
		'Value','Ph',...
		'position',[100,93,120,117])

add_block('built-in/Sum',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Sum3']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Sum3']],...
		'position',[535,105,555,125])

add_block('built-in/Inport',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/in_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/in_1']],...
		'position',[175,30,195,50])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int2']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[420,114,480,156])

add_block('built-in/Product',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Product3']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Product3']],...
		'position',[355,116,380,149])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Array sin']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Array sin']],...
		'ForeGround',4,...
		'function name','arysin',...
		'parameters','''sin''',...
		'position',[230,130,280,150])

add_block('built-in/Outport',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/out_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/out_1']],...
		'position',[585,105,605,125])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Array cos']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Array cos']],...
		'ForeGround',3,...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[230,85,280,105])

add_block('built-in/Demux',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Demux']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Demux']],...
		'ForeGround',2,...
		'outputs','2',...
		'position',[235,20,275,55])

add_block('built-in/Product',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Product']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Product']],...
		'position',[355,21,380,54])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Scheduled',13,'reset-int1']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[420,19,480,61])

add_block('built-in/Sum',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Sum1']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Sum1']],...
		'position',[165,75,190,115])

add_block('built-in/Constant',[sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Shift key']])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband/Shift key']],...
		'Value','sft',...
		'position',[40,63,60,87])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[65,75;95,75;95,85;160,85])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[125,105;160,105])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[195,95;225,95])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[205,95;205,140;225,140])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[280,30;350,30])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[285,95;320,95;320,45;350,45])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[560,115;580,115])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[485,135;510,135;510,120;530,120])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[485,40;510,40;510,110;530,110])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[385,40;415,40])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[385,135;415,135])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[285,140;350,140])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[280,45;310,45;310,125;350,125])
add_line([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],[200,40;230,40])
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'Mask Display','plot(0,0,100,100,u,v);  MPSK corr',...
		'Mask Type','Baseband MPSK correlationA')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'Mask Dialogue','Compute Baseband MPSK correlation. Take\nMPSK CE modulated signal. Output a vector of correlation result.|M-ary number (integer in range [0, M-1]):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'Mask Translate','pi2=2*pi;N=@1;sft=[0:N-1]*pi2/N;td=@2;Ph=@3;ts=@4;[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'Mask Help','This block calculates the correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their phase shift the same as that of PM modulated signal of possible resulting digits. The output is an M length vector. The MPSK demodulation result is the index of the largest output, using the Min/max demap block. The input of this block is complex signal.')
set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'Mask Entries','M\/td\/Ph\/ts\/')


%     Finished composite block ['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband'].

set_param([sys,'/',['MPSK demod',13,'baseband/MPSK demod',13,'corr baseband']],...
		'position',[60,53,140,97])


%     Subsystem  ['MPSK demod',13,'baseband/Min//max index2'].

new_system([sys,'/',['MPSK demod',13,'baseband/Min//max index2']])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],'Location',[192,461,623,564])

add_block('built-in/S-Function',[sys,'/',['MPSK demod',13,'baseband/Min//max index2/Maximum']])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2/Maximum']],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])

add_block('built-in/Outport',[sys,'/',['MPSK demod',13,'baseband/Min//max index2/out_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2/out_1']],...
		'position',[335,20,355,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK demod',13,'baseband/Min//max index2/Zero-Order',13,'Hold']])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Inport',[sys,'/',['MPSK demod',13,'baseband/Min//max index2/in_1']])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2/in_1']],...
		'position',[65,20,85,40])
add_line([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],[205,30;235,30])
add_line([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],[325,30;330,30])
add_line([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],[90,30;160,30])
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block ['MPSK demod',13,'baseband/Min//max index2'].

set_param([sys,'/',['MPSK demod',13,'baseband/Min//max index2']],...
		'ForeGround',4,...
		'position',[180,53,260,97])
add_line([sys,'/',['MPSK demod',13,'baseband']],[265,75;290,75])
add_line([sys,'/',['MPSK demod',13,'baseband']],[35,75;55,75])
add_line([sys,'/',['MPSK demod',13,'baseband']],[145,75;175,75])
set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);MPSK',...
		'Mask Type','Baseband MPSK demodulation')
set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nMPSK modulated signal.|M-ary number (integer in range [0, M-1]):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'Mask Translate','M=@1;Ph=@3;td=@2;ts=@4;[x,y]=moduicon(8);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of a MPSK modulated signal using correlation method. The output signal are digits in the range [0, M-1], where M is the M-ary number. When the symbol interval is a two-element vector, the second element is the offset (default 0).')
set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'Mask Entries','16\/.2\/0\/.01\/')


%     Finished composite block ['MPSK demod',13,'baseband'].

set_param([sys,'/',['MPSK demod',13,'baseband']],...
		'position',[175,428,255,472])


%     Subsystem  ['MPSK mod',13,'baseband'].

new_system([sys,'/',['MPSK mod',13,'baseband']])
set_param([sys,'/',['MPSK mod',13,'baseband']],'Location',[7,579,417,733])

add_block('built-in/Inport',[sys,'/',['MPSK mod',13,'baseband/in_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/in_1']],...
		'position',[10,65,30,85])

add_block('built-in/Outport',[sys,'/',['MPSK mod',13,'baseband/out_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/out_1']],...
		'position',[275,65,295,85])


%     Subsystem  ['MPSK mod',13,'baseband/MPSK map'].

new_system([sys,'/',['MPSK mod',13,'baseband/MPSK map']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],'Location',[71,474,419,648])

add_block('built-in/Constant',[sys,'/',['MPSK mod',13,'baseband/MPSK map/Multiple factor']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map/Multiple factor']],...
		'Value','Sft',...
		'position',[130,108,150,132])

add_block('built-in/Outport',[sys,'/',['MPSK mod',13,'baseband/MPSK map/out_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map/out_1']],...
		'position',[310,85,330,105])

add_block('built-in/Product',[sys,'/',['MPSK mod',13,'baseband/MPSK map/Product']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map/Product']],...
		'position',[235,76,260,109])

add_block('built-in/Zero-Order Hold',[sys,'/',['MPSK mod',13,'baseband/MPSK map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[130,29,165,61])

add_block('built-in/Inport',[sys,'/',['MPSK mod',13,'baseband/MPSK map/in_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map/in_1']],...
		'position',[60,35,80,55])
add_line([sys,'/',['MPSK mod',13,'baseband/MPSK map']],[155,120;200,120;200,100;230,100])
add_line([sys,'/',['MPSK mod',13,'baseband/MPSK map']],[265,95;305,95])
add_line([sys,'/',['MPSK mod',13,'baseband/MPSK map']],[85,45;125,45])
add_line([sys,'/',['MPSK mod',13,'baseband/MPSK map']],[170,45;200,45;200,85;230,85])
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'Mask Display','MPSK\nmap',...
		'Mask Type','MPSK map')
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'Mask Dialogue','Map input digital signal to analog phase shift.|M-ary number (input integer in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'Mask Translate','pi2=2*pi;Sft=pi2/@1;td=@2;')
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'Mask Help','This block maps the input digital signal to the analog signal, which is ready for the PM modulation. The input are integers in the range [0, M-1], where M is the M-ary number. You can view the MPSK constellation using the MODMAP function.')
set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['MPSK mod',13,'baseband/MPSK map'].

set_param([sys,'/',['MPSK mod',13,'baseband/MPSK map']],...
		'position',[55,53,135,97])


%     Subsystem  ['MPSK mod',13,'baseband/PM',13,'baseband'].

new_system([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],'Location',[320,489,688,666])

add_block('built-in/Inport',[sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/in_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/in_1']],...
		'position',[35,50,55,70])

add_block('built-in/Fcn',[sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/cos']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/cos']],...
		'Expr','cos(u)',...
		'position',[155,46,210,74])

add_block('built-in/Fcn',[sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/sin']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/sin']],...
		'Expr','sin(u)',...
		'position',[155,106,210,134])

add_block('built-in/Outport',[sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/out_1']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/out_1']],...
		'position',[315,60,335,80])

add_block('built-in/Mux',[sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/Mux']])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[250,51,285,84])
add_line([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],[60,60;150,60])
add_line([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],[130,60;130,120;150,120])
add_line([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],[215,120;230,120;230,75;245,75])
add_line([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],[290,70;310,70])
add_line([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],[215,60;245,60])
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);PM',...
		'Mask Type','PM CE',...
		'Mask Dialogue','Output the complex envelope of a PM\nmodulated signal.|Initial phase (rad):')
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],...
		'Mask Translate','Ph=@1;pi2=2*pi;[x,y]=moduicon(3);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the phase modulated signal. The output of this block is a complex signal.',...
		'Mask Entries','Ph\/')


%     Finished composite block ['MPSK mod',13,'baseband/PM',13,'baseband'].

set_param([sys,'/',['MPSK mod',13,'baseband/PM',13,'baseband']],...
		'ForeGround',4,...
		'position',[165,53,245,97])
add_line([sys,'/',['MPSK mod',13,'baseband']],[35,75;50,75])
add_line([sys,'/',['MPSK mod',13,'baseband']],[250,75;270,75])
add_line([sys,'/',['MPSK mod',13,'baseband']],[140,75;160,75])
set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);MPSK',...
		'Mask Type','Baseband MPSK modulation')
set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of the\nM-ary phase shift keying modulation.|M-ary number (input integers in the range [0, M-1]):|Symbol interval and offset (sec):|Initial phase (rad):')
set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'Mask Translate','M=@1;td=@2;Ph=@3;[x,y]=moduicon(7);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of MPSK modulated signal. The inputs are integers in the range [0, M-1], where M is the M-ary number. When the symbol interval is a two-element vector, the second element is the offset (default 0). The block keeps a same input value in the symbol interval.')
set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'Mask Entries','16\/.2\/0\/')


%     Finished composite block ['MPSK mod',13,'baseband'].

set_param([sys,'/',['MPSK mod',13,'baseband']],...
		'position',[45,428,125,472])


%     Subsystem  ['Coh MFSK',13,'demod baseband'].

new_system([sys,'/',['Coh MFSK',13,'demod baseband']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband']],'Location',[28,542,447,677])

add_block('built-in/Inport',[sys,'/',['Coh MFSK',13,'demod baseband/in_1']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/in_1']],...
		'position',[30,40,50,60])

add_block('built-in/Outport',[sys,'/',['Coh MFSK',13,'demod baseband/out_1']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/out_1']],...
		'position',[360,40,380,60])


%     Subsystem  ['Coh MFSK',13,'demod baseband/Min//max index'].

new_system([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']],'Location',[192,461,623,564])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK',13,'demod baseband/Min//max index/Maximum']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index/Maximum']],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])

add_block('built-in/Outport',[sys,'/',['Coh MFSK',13,'demod baseband/Min//max index/out_1']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index/out_1']],...
		'position',[335,20,355,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Coh MFSK',13,'demod baseband/Min//max index/Zero-Order',13,'Hold']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Inport',[sys,'/',['Coh MFSK',13,'demod baseband/Min//max index/in_1']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index/in_1']],...
		'position',[65,20,85,40])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']],[205,30;235,30])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']],[325,30;330,30])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']],[90,30;160,30])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block ['Coh MFSK',13,'demod baseband/Min//max index'].

set_param([sys,'/',['Coh MFSK',13,'demod baseband/Min//max index']],...
		'ForeGround',4,...
		'position',[215,28,295,72])


%     Subsystem  ['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband'].

new_system([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],'Location',[124,519,842,743])

add_block('built-in/Constant',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Shift key']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Shift key']],...
		'Value','sft',...
		'position',[60,48,80,72])

add_block('built-in/Sum',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Sum1']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Sum1']],...
		'position',[265,77,290,108])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Array sin']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Array sin']],...
		'ForeGround',3,...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[325,85,375,105])

add_block('built-in/Constant',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Initial phase']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Initial phase']],...
		'Value','Ph',...
		'position',[105,113,125,137])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[125,39,185,81])

add_block('built-in/Inport',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/in_1']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/in_1']],...
		'position',[260,30,280,50])

add_block('built-in/Demux',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Demux']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Demux']],...
		'ForeGround',2,...
		'outputs','2',...
		'position',[330,20,370,55])

add_block('built-in/Product',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Product']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Product']],...
		'position',[450,21,475,54])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Array sin1']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Array sin1']],...
		'ForeGround',4,...
		'function name','arysin',...
		'parameters','''sin''',...
		'position',[330,145,380,165])

add_block('built-in/Product',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Product3']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Product3']],...
		'position',[455,131,480,164])

add_block('built-in/Outport',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/out_1']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/out_1']],...
		'position',[685,105,705,125])

add_block('built-in/Sum',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Sum3']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Sum3']],...
		'position',[640,105,660,125])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Entries','N\/td\/ts\/''backward''\/',...
		'position',[505,18,580,62])

add_block('built-in/S-Function',[sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Entries','N\/td\/ts\/''backward''\/',...
		'position',[510,128,585,172])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[130,125;230,125;230,100;260,100])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[190,60;225,60;225,85;260,85])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[85,60;120,60])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[295,95;320,95])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[305,95;305,155;325,155])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[285,40;325,40])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[375,30;445,30])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[380,95;415,95;415,45;445,45])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[665,115;680,115])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[590,150;605,150;605,120;635,120])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[585,40;605,40;605,110;635,110])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[480,40;500,40])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[485,150;505,150])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[385,155;450,155])
add_line([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],[375,45;405,45;405,140;450,140])
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],...
		'Mask Display','plot(0,0,100,100,u,v);   Co MFSK',...
		'Mask Type','Baseband coherent MFSK correlation')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],...
		'Mask Dialogue','Compute baseband MFSK correlation. Take\nMFSK CE modulated signal. Output a vector\nof correlation result.|M-ary number (input in range [0, M-1]):|Tone space (Hz):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],...
		'Mask Translate','pi2=2*pi;N=@1;Ph=@4;Ton=@2;sft=[0:N-1]*Ton*pi2;td=@3;ts=@5;[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],...
		'Mask Help','This block calculates the coherent correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their frequency the same as that of FM modulated signal of possible resulting digits. The output is an M length vector. M is the M-ary number. The MFSK demodulation result is the index of the largest output. The input of this block is complex signal.')
set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],...
		'Mask Entries','M\/Ton\/td\/Ph\/ts\/')


%     Finished composite block ['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband'].

set_param([sys,'/',['Coh MFSK',13,'demod baseband/Coh MFSK demod',13,'corr baseband']],...
		'position',[90,28,170,72])
add_line([sys,'/',['Coh MFSK',13,'demod baseband']],[300,50;355,50])
add_line([sys,'/',['Coh MFSK',13,'demod baseband']],[55,50;85,50])
add_line([sys,'/',['Coh MFSK',13,'demod baseband']],[175,50;210,50])
set_param([sys,'/',['Coh MFSK',13,'demod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v); Co-MFSK',...
		'Mask Type','Baseband coherent MFSK demodulation')
set_param([sys,'/',['Coh MFSK',13,'demod baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nMFSK modulated signal using coherent\ncorrelation method.|M-ary number (output digits in range [0, M-1]):|Tone space (Hz):|Symbol interval (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Coh MFSK',13,'demod baseband']],...
		'Mask Translate','M=@1;Ph=@4;Ton=@2;td=@3;ts=@5;[x,y]=moduicon(8);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Coh MFSK',13,'demod baseband']],...
		'Mask Help','This block demodulates the complex envelope of a MFSK modulated signal using coherent method. The coherent demodulation method is phase sensitive. The tone space is the frequency distance between two successive after the modulation. The inputs are integers in the range [0, M-1], where M is the M-ary number. When the symbol interval is a two-element vector, the second element is the offset (default 0).')
set_param([sys,'/',['Coh MFSK',13,'demod baseband']],...
		'Mask Entries','16\/16/.2/5\/.2\/0\/.01\/')


%     Finished composite block ['Coh MFSK',13,'demod baseband'].

set_param([sys,'/',['Coh MFSK',13,'demod baseband']],...
		'position',[175,353,255,397])


%     Subsystem  ['C-map QASK',13,'mod baseband'].

new_system([sys,'/',['C-map QASK',13,'mod baseband']])
set_param([sys,'/',['C-map QASK',13,'mod baseband']],'Location',[20,563,362,664])


%     Subsystem  ['C-map QASK',13,'mod baseband/QAM',13,'baseband1'].

new_system([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],'Location',[321,500,954,793])

add_block('built-in/Note',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])

add_block('built-in/Note',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/I_out']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Sum',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Sum1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Product',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Product2']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Product',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Product3']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Note',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/I2']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Note',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/R2']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Inport',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/in_2']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/I1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Constant',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Constant1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Constant',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Constant']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Outport',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/out_1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Inport',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/in_1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Mux',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/RI2C']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/RI2C']],...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Note',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/R_out']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Sum',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Sum']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Product',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Product1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Product',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Product']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Note',[sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/R1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1/R1']],...
		'position',[190,15,195,20])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[410,220;425,220;425,150;465,150])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[120,40;295,40])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[238,40;238,190;305,190])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[270,155;270,235;305,235])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[280,175;280,200;305,200])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[250,100;250,245;305,245])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],[550,140;580,140])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],...
		'Mask Entries','Ph\/')


%     Finished composite block ['C-map QASK',13,'mod baseband/QAM',13,'baseband1'].

set_param([sys,'/',['C-map QASK',13,'mod baseband/QAM',13,'baseband1']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[180,23,260,67])


%     Subsystem  ['C-map QASK',13,'mod baseband/QASK',13,'circle-map'].

new_system([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],'Location',[58,103,403,268])

add_block('built-in/Zero-Order Hold',[sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])

add_block('built-in/Inport',[sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/in_1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Look Up Table',[sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/real part']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Look Up Table',[sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/imag part1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Outport',[sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/Real']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Outport',[sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/Imag']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],[50,30;75,30])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],[120,30;175,30])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],[145,30;145,110;170,110])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],[220,30;270,30])
add_line([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],[215,110;270,110])
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],...
		'Mask Display','QASK\nC-map',...
		'Mask Type','QASK C-map')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],...
		'Mask Dialogue','QASK mapping with circle constellation. The constellation is defined in NIC, RIC and PIC.|Number of symbols in each circle NIC:|Radii in each circle RIC:|Phase shift in each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y1=[y1;y1];y1=y1(:);y2=imag(y1);y1=real(y1);x=[-sum(N) 1:sum(N)-1;1:sum(N)-1 10*sum(N)]-.5;x=x(:);')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The circle constellation is defined in NIC, RIC, and PIC. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],...
		'Mask Entries','NIR\/AIR\/PIR\/td\/')


%     Finished composite block ['C-map QASK',13,'mod baseband/QASK',13,'circle-map'].

set_param([sys,'/',['C-map QASK',13,'mod baseband/QASK',13,'circle-map']],...
		'hide name',0,...
		'position',[65,23,145,67])

add_block('built-in/Inport',[sys,'/',['C-map QASK',13,'mod baseband/in_1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/in_1']],...
		'hide name',0,...
		'position',[25,35,40,55])

add_block('built-in/Outport',[sys,'/',['C-map QASK',13,'mod baseband/out_1']])
set_param([sys,'/',['C-map QASK',13,'mod baseband/out_1']],...
		'hide name',0,...
		'position',[290,35,310,55])
add_line([sys,'/',['C-map QASK',13,'mod baseband']],[150,35;175,35])
add_line([sys,'/',['C-map QASK',13,'mod baseband']],[150,55;175,55])
add_line([sys,'/',['C-map QASK',13,'mod baseband']],[265,45;285,45])
add_line([sys,'/',['C-map QASK',13,'mod baseband']],[45,45;60,45])
set_param([sys,'/',['C-map QASK',13,'mod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);C-QASK',...
		'Mask Type','Baseband C-QASK modulation')
set_param([sys,'/',['C-map QASK',13,'mod baseband']],...
		'Mask Dialogue','Output the complex envelope of a QASK\nmodulated signal. The QASK circle conste-\nllation is defined by the NIC, RIC, and PIC.|Number of symbols in each circle (NIC):|Radii in each circle (RIC):|Phase shift in each circle (PIC, rad):|Initial phase (rad):|Symbol interval (sec):|Sampling time (sec):')
set_param([sys,'/',['C-map QASK',13,'mod baseband']],...
		'Mask Translate','NIR=@1;AIR=@2;PIR=@3;Ph=@4;td=@5;ts=@6;[x,y]=moduicon(5);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['C-map QASK',13,'mod baseband']],...
		'Mask Help','This block outputs the complex envelope of a QASK modulated signal. This block uses circle constellation. The vector lengths of numbers on each circle, radii on each circle, and phases on each circle should be the same. Use function DMODCE to view the constellation of the signal distribution.')
set_param([sys,'/',['C-map QASK',13,'mod baseband']],...
		'Mask Entries','[6 12 18 24 30 38]\/[1 1.93 2.88 3.83 4.78 6.05]\/[0 0 0 0 0 0]\/0\/.2\/.01\/')


%     Finished composite block ['C-map QASK',13,'mod baseband'].

set_param([sys,'/',['C-map QASK',13,'mod baseband']],...
		'position',[45,203,125,247])


%     Subsystem  ['C-map QASK',13,'demod baseband'].

new_system([sys,'/',['C-map QASK',13,'demod baseband']])
set_param([sys,'/',['C-map QASK',13,'demod baseband']],'Location',[23,618,381,756])

add_block('built-in/Inport',[sys,'/',['C-map QASK',13,'demod baseband/in_1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/in_1']],...
		'position',[10,65,30,85])

add_block('built-in/Outport',[sys,'/',['C-map QASK',13,'demod baseband/out_1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/out_1']],...
		'position',[285,65,305,85])


%     Subsystem  ['C-map QASK',13,'demod baseband/QADM',13,'baseband3'].

new_system([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],'Location',[283,122,827,462])

add_block('built-in/Inport',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/in_1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/in_1']],...
		'position',[55,115,75,135])

add_block('built-in/Constant',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Sum',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Outport',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/out_2']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Filter',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Product',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Product1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Demux',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Demux']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Constant',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Product',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Product2']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Product',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Product3']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Sum',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Product']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Filter',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Note',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Outport',[sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/out_1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[230,115;230,245;265,245])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[200,255;265,255])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[165,130;255,130])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[180,130;180,210;265,210])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[180,50;255,50])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[215,50;215,200;265,200])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[80,125;115,125])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[360,80;385,80])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[450,80;475,80])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[365,230;390,230])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],[455,230;480,230])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['C-map QASK',13,'demod baseband/QADM',13,'baseband3'].

set_param([sys,'/',['C-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[70,53,150,97])


%     Subsystem  ['C-map QASK',13,'demod baseband/QASK',13,'circle-demap'].

new_system([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],'Location',[96,182,645,417])

add_block('built-in/Zero-Order Hold',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/real']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/imag']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Sum1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Sum6']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Product']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Product1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Sum2']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Minimum1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/out_1']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/real_pt']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/imag_pt']])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[70,45;115,45])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[70,130;115,130])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[160,45;225,45])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[160,130;225,130])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[395,95;410,95])
add_line([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],[480,95;490,95])
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],...
		'Mask Display','QASK\nC-demap',...
		'Mask Type','QASK C-demap')
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Number of symbols on each circle NIC::|Radii for each circle RIC:|Phase shift on each circle PIC (rad):|Symbol interval and offset (sec):')
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],...
		'Mask Translate','N=@1;A=@2;P=@3;td=@4;y1=apkconst(N,A,P);y2=imag(y1);y1=real(y1);')
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using circle constellation. You can place this block after a QAM demodulation block. The circle constellation is defined in NIC, RIC, and PIC. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero. Use function MODMAP to view the constellation.')
set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],...
		'Mask Entries','NIR\/AIR\/PIR\/td\/')


%     Finished composite block ['C-map QASK',13,'demod baseband/QASK',13,'circle-demap'].

set_param([sys,'/',['C-map QASK',13,'demod baseband/QASK',13,'circle-demap']],...
		'hide name',0,...
		'position',[175,53,255,97])
add_line([sys,'/',['C-map QASK',13,'demod baseband']],[155,65;170,65])
add_line([sys,'/',['C-map QASK',13,'demod baseband']],[155,85;170,85])
add_line([sys,'/',['C-map QASK',13,'demod baseband']],[35,75;65,75])
add_line([sys,'/',['C-map QASK',13,'demod baseband']],[260,75;280,75])
set_param([sys,'/',['C-map QASK',13,'demod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);C-QASK',...
		'Mask Type','Baseband C-QASK demodulation')
set_param([sys,'/',['C-map QASK',13,'demod baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a QASK modulated signal. The QASK circle conste-\nllation is defined by NIC, RIC, and PIC.|Number of symbols in each circle (NIC):|Radii in each circle (RIC):|Phase shift in each circle (PIC, rad):|Symbol interval (sec):|Lowpass filter [num; den] (a 2 x n matrix):|Sampling time (sec):')
set_param([sys,'/',['C-map QASK',13,'demod baseband']],...
		'Mask Translate','NIR=@1;AIR=@2;PIR=@3;td=@4;num=@5;ts=@6;Ph=0;den=num(2,:);num=num(1,:);[x,y]=moduicon(6);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['C-map QASK',13,'demod baseband']],...
		'Mask Help','This block demodulates the complex envelope of a QASK modulated signal with circle constellation. The vector lengths of numbers on each circle, radii on each circle, and phase on each circle should be the same. Use function DMODCE to view the constellation of the signal distribution. The default initial phase is zero. To specify non-default parameters, ungroup this block to assign parameters.')
set_param([sys,'/',['C-map QASK',13,'demod baseband']],...
		'Mask Entries','[6 12 18 24 30 38]\/[1 1.93 2.88 3.83  4.78 6.05]\/[0 0 0 0 0 0]\/.2\/[1;1]\/.01\/')


%     Finished composite block ['C-map QASK',13,'demod baseband'].

set_param([sys,'/',['C-map QASK',13,'demod baseband']],...
		'position',[175,203,255,247])


%     Subsystem  ['S-map QASK',13,'demod baseband'].

new_system([sys,'/',['S-map QASK',13,'demod baseband']])
set_param([sys,'/',['S-map QASK',13,'demod baseband']],'Location',[33,553,383,660])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'demod baseband/tab=qaskdeco(']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/tab=qaskdeco(']],...
		'position',[205,180,210,185])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband/out_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/out_1']],...
		'position',[320,40,340,60])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/in_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/in_1']],...
		'position',[40,40,60,60])


%     Subsystem  ['S-map QASK',13,'demod baseband/QADM',13,'baseband'].

new_system([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],'Location',[283,122,827,462])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/in_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/in_1']],...
		'position',[55,115,75,135])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Constant1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Sum1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/out_2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Filter',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Filter1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Demux',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Demux']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Constant']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product3']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Sum']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Filter',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Filter']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/out_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[230,115;230,245;265,245])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[200,255;265,255])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[165,130;255,130])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[180,130;180,210;265,210])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[180,50;255,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[215,50;215,200;265,200])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[80,125;115,125])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[360,80;385,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[450,80;475,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[365,230;390,230])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],[455,230;480,230])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['S-map QASK',13,'demod baseband/QADM',13,'baseband'].

set_param([sys,'/',['S-map QASK',13,'demod baseband/QADM',13,'baseband']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[90,28,170,72])


%     Subsystem  ['S-map QASK',13,'demod baseband/QASK',13,'square-demap'].

new_system([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],'Location',[57,374,831,674])

add_block('built-in/Zero-Order Hold',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[135,24,170,56])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/in_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/in_1']],...
		'position',[60,30,80,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[135,149,170,181])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/in_2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/in_2']],...
		'Port','2',...
		'position',[60,155,80,175])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum5']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum5']],...
		'ForeGround',2,...
		'position',[470,153,490,182])


%     Subsystem  ['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table'].

new_system([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],'Location',[436,148,718,302])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/y0']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/y0']],...
		'Port','2',...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/table out']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/table out']],...
		'position',[215,55,235,75])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/x0']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/x0']],...
		'position',[20,25,40,45])

add_block('built-in/S-Function',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/S-function']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/S-function']],...
		'function name','sftable2',...
		'parameters','xindex, yindex, table',...
		'position',[140,52,190,78])

add_block('built-in/Mux',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/Mux']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table/Mux']],...
		'inputs','2',...
		'position',[90,46,120,79])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],[45,90;65,90;65,70;85,70])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],[195,65;210,65])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],[45,35;65,35;65,55;85,55])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],[125,65;135,65])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'Mask Display','plot(-10,-10,110,110,[90,50,10],[90,40,30],[90,50,10],[50,26,20],[90,50,10],[22,13,10])',...
		'Mask Type','2-D Table Lookup')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'Mask Dialogue','Two Dimensional Table Lookup\nThe first input corresponds to X Index and the second input corresponds to the Y Index|X Index|Y Index|Table')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'Mask Translate','xindex=@1; yindex=@2; table=@3; sftab2chk(xindex,yindex,table);')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'Mask Help','This block returns a linearly interpolated intersection from the table using the X index (which corresponds to the rows of the table) and the Y index (which corresponds to the columns of the table).  Extrapolation is used.')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'Mask Entries','x\/y\/tab\/')


%     Finished composite block ['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table'].

set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/2-D Table']],...
		'position',[515,68,545,92])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum3']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum3']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[580,73,600,102])

add_block('built-in/Saturation',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Saturation']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Saturation']],...
		'Lower Limit','0',...
		'Upper Limit','N-1',...
		'position',[630,78,660,102])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/out_1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/out_1']],...
		'position',[685,80,705,100])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum4']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum4']],...
		'ForeGround',2,...
		'position',[470,58,490,87])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[280,33,300,62])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Sum2']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[290,158,310,187])

add_block('built-in/S-Function',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Minimum']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Minimum']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,165,450,185])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key']],...
		'Value','sfty',...
		'position',[225,214,250,236])

add_block('built-in/S-Function',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Minimum1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[385,40,445,60])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key1']],...
		'Value','sftx',...
		'position',[220,89,245,111])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key2']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Shift key2']],...
		'BackGround',5,...
		'position',[325,114,350,136])

add_block('built-in/Abs',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Abs1']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Abs1']],...
		'position',[325,38,355,62])

add_block('built-in/Abs',[sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Abs']])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap/Abs']],...
		'position',[325,163,355,187])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[85,40;130,40])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[360,175;380,175])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[315,175;320,175])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[255,225;260,225;260,180;285,180])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[250,100;255,100;255,55;275,55])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[305,50;320,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[360,50;380,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[665,90;680,90])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[550,80;575,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[605,90;625,90])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[450,50;450,65;465,65])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[455,175;465,175])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[495,170;500,170;510,85])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[355,125;560,125;560,95;575,95])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[450,125;450,160;465,160])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[450,125;450,80;465,80])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[495,75;510,75])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[85,165;130,165])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[175,165;285,165])
add_line([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],[175,40;275,40])
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'Mask Display','QASK\nS-demap',...
		'Mask Type','QASK S-demap')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|QASK M-ary number (outputs are in range [0, M-1]):|Output symbol interval and offset (sec):')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'Mask Translate','N=@1;td=@2;Ac=1;sftx=[1 -1 3 -3 5 -5 7 -7 9 -9 11 -11 13 -13 15 -15];sftx=sftx(1:2*ceil(sqrt(N)/2));sfty=sftx;if N==8,sfty=sfty(1:2);end;sftx=sftx/max(sftx)*Ac;sfty=sfty/max(sfty)*Ac;tab=qaskdeco(length(sftx),length(sfty),''fetch'')+1;x=[1:length(sftx)];y=[1:length(sfty)];')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using square constellation. You can place this block after a QAM demodulation block. This block assumes the maximum amplitude of the input signals is 1. The output symbols are integers in the range [0, M-1]. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0.')
set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['S-map QASK',13,'demod baseband/QASK',13,'square-demap'].

set_param([sys,'/',['S-map QASK',13,'demod baseband/QASK',13,'square-demap']],...
		'hide name',0,...
		'position',[205,28,285,72])
add_line([sys,'/',['S-map QASK',13,'demod baseband']],[65,50;85,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband']],[290,50;315,50])
add_line([sys,'/',['S-map QASK',13,'demod baseband']],[175,60;200,60])
add_line([sys,'/',['S-map QASK',13,'demod baseband']],[175,40;200,40])
set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);S-QASK',...
		'Mask Type','Baseband S-QASK demodulation')
set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a QASK modulated signal.  This block uses a fixed square constellation with M-ary number M=2^K, where K is an integer.|M-ary number (integer in range [0 M-1]):|Symbol interval and offset (sec):|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'Mask Translate','M=@1;td=@2;num=@3;den=@4;Ph=@5;ts=@6;[x,y]=moduicon(6);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'Mask Help','This block demodulates a QASK modulated signal using square constellation. The output signals are digits in the range [0, M-1], where M is the M-ary number, M=2^K, K is an integer. When the symbol interval is a two-element vector, the second element is the offset (default 0). ')
set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'Mask Entries','16\/.2\/1\/1\/0\/.01\/')


%     Finished composite block ['S-map QASK',13,'demod baseband'].

set_param([sys,'/',['S-map QASK',13,'demod baseband']],...
		'position',[175,128,255,172])


%     Subsystem  'Demonstration blocks'.

new_system([sys,'/','Demonstration blocks'])
set_param([sys,'/','Demonstration blocks'],'Location',[175,552,335,697])
set_param([sys,'/','Demonstration blocks'],...
		'Mask Display','.')


%     Finished composite block 'Demonstration blocks'.

set_param([sys,'/','Demonstration blocks'],...
		'orientation',1,...
		'BackGround',7,...
		'position',[45,503,100,526])


%     Subsystem  'Functional blocks'.

new_system([sys,'/','Functional blocks'])
set_param([sys,'/','Functional blocks'],'Location',[175,552,335,697])
set_param([sys,'/','Functional blocks'],...
		'Mask Display','.')


%     Finished composite block 'Functional blocks'.

set_param([sys,'/','Functional blocks'],...
		'orientation',1,...
		'position',[45,535,100,558])

add_block('built-in/Note',[sys,'/','(basenad simulation)'])
set_param([sys,'/','(basenad simulation)'],...
		'ForeGround',2,...
		'position',[245,20,250,25])


%     Subsystem  ['QASK Mo//Dem',13,'demo1'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo1']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],...
		'Mask Display','C-QASK\ndemo')
set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],...
		'Mask Dialogue','eval(''ts=.01;td=.2;Fc=100/2/pi;NIR=[6 12 18 24 30 38];AIR=[1 1.93 2.88 3.83 4.78 6.05];PIR=zeros(1,6);[num,den]=butter(4,100/pi*ts);M=sum(NIR);tceps2cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo1'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[385,203,465,247])


%     Subsystem  ['QASK Mo//Dem',13,'demo2'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo2']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],...
		'Mask Display','A-QASK\ndemo',...
		'Mask Dialogue','eval(''ts=.02;[num,den]=butter(3,100/pi/2*ts);td=.2;M=32;tceps3cd'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo2'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo2']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[385,278,465,322])


%     Subsystem  ['MPSK discr-flt',13,'Mo//Dem demo'].

new_system([sys,'/',['MPSK discr-flt',13,'Mo//Dem demo']])
set_param([sys,'/',['MPSK discr-flt',13,'Mo//Dem demo']],'Location',[175,552,335,697])
set_param([sys,'/',['MPSK discr-flt',13,'Mo//Dem demo']],...
		'Mask Display','MPSK\ndemo',...
		'Mask Dialogue','eval(''ts=.01;td=.2;M=8;tcemmpsk'')')


%     Finished composite block ['MPSK discr-flt',13,'Mo//Dem demo'].

set_param([sys,'/',['MPSK discr-flt',13,'Mo//Dem demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[385,428,465,472])


%     Subsystem  ['QASK Mo//Dem',13,'demo'].

new_system([sys,'/',['QASK Mo//Dem',13,'demo']])
set_param([sys,'/',['QASK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['QASK Mo//Dem',13,'demo']],...
		'Mask Display','S-QASK\ndemo',...
		'Mask Dialogue','eval(''ts=.04;[num,den]=butter(2,100/pi/2*ts);td=.2;M=64;tcemqask'')')


%     Finished composite block ['QASK Mo//Dem',13,'demo'].

set_param([sys,'/',['QASK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[385,128,465,172])


%     Subsystem  ['MFSK Mo//Dem',13,'demo'].

new_system([sys,'/',['MFSK Mo//Dem',13,'demo']])
set_param([sys,'/',['MFSK Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['MFSK Mo//Dem',13,'demo']],...
		'Mask Display','MFSK\ndemo',...
		'Mask Dialogue','eval(''ts=.02;td=.2;M=8;tcemmfsk'')')


%     Finished composite block ['MFSK Mo//Dem',13,'demo'].

set_param([sys,'/',['MFSK Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[385,353,465,397])


%     Subsystem  ['DSB Mo//Dem',13,'demo'].

new_system([sys,'/',['DSB Mo//Dem',13,'demo']])
set_param([sys,'/',['DSB Mo//Dem',13,'demo']],'Location',[175,552,335,697])
set_param([sys,'/',['DSB Mo//Dem',13,'demo']],...
		'Mask Display','MASK\ndemo',...
		'Mask Dialogue','eval(''ts=.02;[num,den]=butter(2,100/pi/2*ts);td=.1;M=8;tstam2ce'')')


%     Finished composite block ['DSB Mo//Dem',13,'demo'].

set_param([sys,'/',['DSB Mo//Dem',13,'demo']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[385,53,465,97])


%     Subsystem  'help'.

new_system([sys,'/','help'])
set_param([sys,'/','help'],'Location',[95,429,862,629])

add_block('built-in/Note',[sys,'/',['help/This library is the groupped version of Digital Modulation//Demodulation Library',13,'                                                           (map+mode ===> demod+demap).']])
set_param([sys,'/',['help/This library is the groupped version of Digital Modulation//Demodulation Library',13,'                                                           (map+mode ===> demod+demap).']],...
		'position',[305,40,310,45])

add_block('built-in/Note',[sys,'/','help/(3) demo for how to use the blocks.'])
set_param([sys,'/','help/(3) demo for how to use the blocks.'],...
		'ForeGround',7,...
		'position',[190,150,195,155])

add_block('built-in/Note',[sys,'/','help/(2) demodulation blocks: contains analog_demodulation and analog_to_digit_demap.'])
set_param([sys,'/','help/(2) demodulation blocks: contains analog_demodulation and analog_to_digit_demap.'],...
		'position',[365,125,370,130])

add_block('built-in/Note',[sys,'/','help/(1) modulation blocks: contains digit_to_analog_map and analog_modulation. '])
set_param([sys,'/','help/(1) modulation blocks: contains digit_to_analog_map and analog_modulation. '],...
		'position',[340,100,345,105])

add_block('built-in/Note',[sys,'/','help/The blocks in this libraries contains (in three block columns):'])
set_param([sys,'/','help/The blocks in this libraries contains (in three block columns):'],...
		'position',[240,75,245,80])
set_param([sys,'/','help'],...
		'Mask Display','?')


%     Finished composite block 'help'.

set_param([sys,'/','help'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[385,503,410,529])


%     Subsystem  ['MASK mod',13,'baseband'].

new_system([sys,'/',['MASK mod',13,'baseband']])
set_param([sys,'/',['MASK mod',13,'baseband']],'Location',[7,381,369,492])

add_block('built-in/Inport',[sys,'/',['MASK mod',13,'baseband/in_1']])
set_param([sys,'/',['MASK mod',13,'baseband/in_1']],...
		'position',[25,45,45,65])

add_block('built-in/Outport',[sys,'/',['MASK mod',13,'baseband/out_1']])
set_param([sys,'/',['MASK mod',13,'baseband/out_1']],...
		'position',[300,45,320,65])


%     Subsystem  ['MASK mod',13,'baseband/MASK map'].

new_system([sys,'/',['MASK mod',13,'baseband/MASK map']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],'Location',[520,162,902,335])

add_block('built-in/Constant',[sys,'/',['MASK mod',13,'baseband/MASK map/Gain diff']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/Gain diff']],...
		'Value','Ac',...
		'position',[180,96,215,124])

add_block('built-in/Sum',[sys,'/',['MASK mod',13,'baseband/MASK map/Sum1']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/Sum1']],...
		'inputs','+-',...
		'position',[250,63,270,87])

add_block('built-in/Gain',[sys,'/',['MASK mod',13,'baseband/MASK map/Gain']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/Gain']],...
		'Gain','Kc',...
		'position',[180,25,220,55])

add_block('built-in/Inport',[sys,'/',['MASK mod',13,'baseband/MASK map/in_1']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/in_1']],...
		'position',[40,30,60,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['MASK mod',13,'baseband/MASK map/Zero-Order',13,'Hold']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[100,24,135,56])

add_block('built-in/Outport',[sys,'/',['MASK mod',13,'baseband/MASK map/out_1']])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map/out_1']],...
		'position',[315,65,335,85])
add_line([sys,'/',['MASK mod',13,'baseband/MASK map']],[140,40;175,40])
add_line([sys,'/',['MASK mod',13,'baseband/MASK map']],[65,40;95,40])
add_line([sys,'/',['MASK mod',13,'baseband/MASK map']],[275,75;310,75])
add_line([sys,'/',['MASK mod',13,'baseband/MASK map']],[220,110;230,110;230,80;245,80])
add_line([sys,'/',['MASK mod',13,'baseband/MASK map']],[225,40;230,40;230,70;245,70])
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'Mask Display','MASK\nmap',...
		'Mask Type','MASK map')
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'Mask Dialogue','Map a digital symbol onto an analog\nsignal in the range [-1, 1] using M-ary\namplitude shift keying modulation mapping.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'Mask Translate','N=@1;Ac=1;Kc=Ac*2/(N-1);td=@2;')
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'Mask Help','This block maps an input digit signal onto a signal in the range [-1, 1]. The coded signal can be modulated using analog\nmodulation blocks. Input digits are in the range [0, M-1], where M is the M-ary number. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. Use the MODMAP function to see the constellation.')
set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'Mask Entries','n\/td\/')


%     Finished composite block ['MASK mod',13,'baseband/MASK map'].

set_param([sys,'/',['MASK mod',13,'baseband/MASK map']],...
		'position',[75,33,155,77])


%     Subsystem  ['MASK mod',13,'baseband/DSB AM',13,'baseband'].

new_system([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],'Location',[212,430,575,573])

add_block('built-in/Constant',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Constant']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[40,65,60,85])

add_block('built-in/Constant',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Constant1']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[90,90,110,110])

add_block('built-in/Mux',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Mux']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Mux']],...
		'inputs','2',...
		'position',[170,66,205,99])

add_block('built-in/Inport',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/in_1']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/in_1']],...
		'position',[115,15,135,35])

add_block('built-in/Product',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Product']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/Product']],...
		'position',[255,42,280,73])

add_block('built-in/Outport',[sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/out_1']])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband/out_1']],...
		'position',[320,50,340,70])
add_line([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],[210,85;230,85;230,65;250,65])
add_line([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],[285,60;315,60])
add_line([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],[140,25;185,25;185,50;250,50])
add_line([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],[115,100;130,100;130,90;165,90])
add_line([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],[65,75;165,75])
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);DSB AM',...
		'Mask Type','DSB-SC AM CE')
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of a\nDSB-SC AM modulated signal.|Initial Phase (rad):')
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);pi2=2*pi;[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the double-sideband suppressed-carrier amplitude modulated signal. The output is a complex signal.')
set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'Mask Entries','Ph\/')


%     Finished composite block ['MASK mod',13,'baseband/DSB AM',13,'baseband'].

set_param([sys,'/',['MASK mod',13,'baseband/DSB AM',13,'baseband']],...
		'ForeGround',4,...
		'position',[180,33,260,77])
add_line([sys,'/',['MASK mod',13,'baseband']],[50,55;70,55])
add_line([sys,'/',['MASK mod',13,'baseband']],[160,55;175,55])
add_line([sys,'/',['MASK mod',13,'baseband']],[265,55;295,55])
set_param([sys,'/',['MASK mod',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);MASK',...
		'Mask Type','Baseband MASK modulation')
set_param([sys,'/',['MASK mod',13,'baseband']],...
		'Mask Dialogue','Output the complex envelope of the\namplitude shift keying modulated signal.|M-ary number (input integers in the range [0, M-1]):|Input symbol interval and offset (sec):|Initial phase (rad):')
set_param([sys,'/',['MASK mod',13,'baseband']],...
		'Mask Translate','n=@1;td=@2;Ph=@3;[x,y]=moduicon(5);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['MASK mod',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of MASK modulated signal. The inputs are integers in the range [0, M-1], where M is the M-ary number. The maximum amplitude of the output is 1. When the symbol interval is a two-element vector, the second element is the offset (default 0). The block takes the input value at the sampling time point.')
set_param([sys,'/',['MASK mod',13,'baseband']],...
		'Mask Entries','16\/.2\/0\/')


%     Finished composite block ['MASK mod',13,'baseband'].

set_param([sys,'/',['MASK mod',13,'baseband']],...
		'position',[45,53,125,97])


%     Subsystem  ['S-map QASK',13,'mod baseband'].

new_system([sys,'/',['S-map QASK',13,'mod baseband']])
set_param([sys,'/',['S-map QASK',13,'mod baseband']],'Location',[13,347,333,487])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'mod baseband/in_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/in_1']],...
		'position',[5,65,20,85])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'mod baseband/out_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/out_1']],...
		'position',[275,65,295,85])


%     Subsystem  ['S-map QASK',13,'mod baseband/QASK',13,'square-map'].

new_system([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],'Location',[214,372,642,541])

add_block('built-in/Look Up Table',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/c-y axis']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/c-y axis']],...
		'Input_Values','z',...
		'Output_Values','y',...
		'position',[245,90,280,120])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/out_2']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/out_2']],...
		'Port','2',...
		'position',[325,95,345,115])

add_block('built-in/Look Up Table',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/s-x axis']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/s-x axis']],...
		'Input_Values','z',...
		'Output_Values','x',...
		'position',[245,25,280,55])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/out_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/out_1']],...
		'position',[325,30,345,50])

add_block('built-in/Zero-Order Hold',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/Zero-Order',13,'Hold']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[110,24,145,56])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/in_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map/in_1']],...
		'position',[45,30,65,50])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],[70,40;105,40])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],[150,40;240,40])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],[185,40;185,105;240,105])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],[285,105;320,105])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],[285,40;320,40])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'Mask Display','QASK\nS-map',...
		'Mask Type','QASK S-map')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'Mask Dialogue','Use square constellation to map the\ninput digital signal into in-phase and\nquadrature components. M must be\nM=2^K with integer K.|M-ary number (input integers in range [0, M-1]):|Input symbol interval and offset (sec):')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'Mask Translate','N=@1;Ac=1;td=@2;z=[[1:N];[1:N]];z=z(:);[x,y]=qaskenco(z-1,N);z=z-1.5;z=[z(2:2*N);N-.5];x=x/max(x);y=y/max(y);')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The M-ary number must be M=2^K with integer K. The input symbol interval can be a two-element vector with the second element being offset. The default value offset is 0. The maximum amplitudes for the outputs are 1.')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'Mask Entries','M\/td\/')


%     Finished composite block ['S-map QASK',13,'mod baseband/QASK',13,'square-map'].

set_param([sys,'/',['S-map QASK',13,'mod baseband/QASK',13,'square-map']],...
		'hide name',0,...
		'position',[50,53,130,97])


%     Subsystem  ['S-map QASK',13,'mod baseband/QAM',13,'baseband'].

new_system([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],'Location',[321,500,954,793])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R1']],...
		'position',[190,15,195,20])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Sum']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R_out']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Mux',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/RI2C']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/RI2C']],...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/in_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Outport',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/out_1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Constant']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Constant',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Constant1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Inport',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/in_2']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R2']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I2']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product3']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Product',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product2']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Sum',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Sum1']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I_out']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Note',[sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[550,140;580,140])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[250,100;250,245;305,245])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[280,175;280,200;305,200])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[270,155;270,235;305,235])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[120,40;295,40])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[238,40;238,190;305,190])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],[410,220;425,220;425,150;465,150])
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'Mask Entries','Ph\/')


%     Finished composite block ['S-map QASK',13,'mod baseband/QAM',13,'baseband'].

set_param([sys,'/',['S-map QASK',13,'mod baseband/QAM',13,'baseband']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[165,53,245,97])
add_line([sys,'/',['S-map QASK',13,'mod baseband']],[25,75;45,75])
add_line([sys,'/',['S-map QASK',13,'mod baseband']],[250,75;270,75])
add_line([sys,'/',['S-map QASK',13,'mod baseband']],[135,85;160,85])
add_line([sys,'/',['S-map QASK',13,'mod baseband']],[135,65;160,65])
set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);S-QASK',...
		'Mask Type','Baseband S-QASK modulation')
set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'Mask Dialogue','Output the complex envelope of the QASK\nmodulated signal. This block uses a square\nconstellation with M-ary number M=2^K,\nK is an integer.|M-ary number (input digits in range [0, M-1]):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'Mask Translate','M=@1;td=@2;Ph=@3;ts=@4;[x,y]=moduicon(5);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'Mask Help','This block outputs the complex envelope of a QASK modulated signal. This block uses square constellation. The inputs are integers in the range [0, M-1], where M is the M-ary number, M=2^K, and K is an integer. When the symbol interval is a two-element vector, the second element is the offset (default 0). ')
set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'Mask Entries','16\/.2\/0\/.01\/')


%     Finished composite block ['S-map QASK',13,'mod baseband'].

set_param([sys,'/',['S-map QASK',13,'mod baseband']],...
		'position',[45,128,125,172])


%     Subsystem  ['Noncoh MFSK',13,'demod baseband'].

new_system([sys,'/',['Noncoh MFSK',13,'demod baseband']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband']],'Location',[47,515,504,698])

add_block('built-in/Outport',[sys,'/',['Noncoh MFSK',13,'demod baseband/out_1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/out_1']],...
		'position',[375,80,395,100])

add_block('built-in/Inport',[sys,'/',['Noncoh MFSK',13,'demod baseband/in_1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/in_1']],...
		'position',[25,80,45,100])


%     Subsystem  ['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband'].

new_system([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],'Location',[69,218,990,452])

add_block('built-in/Constant',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Shift key']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Shift key']],...
		'Value','sft',...
		'position',[40,43,60,67])

add_block('built-in/S-Function',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'function name','schdint',...
		'parameters','td, ts, limit',...
		'Mask Display','Schdld\nreset-int')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Type','Scheduled reset integration.')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Dialogue','Reset the state to be zero(s) at the scheduled reset point.|Scheduled reset time inteval and offset:|Sample time and offset:|Modulo bound:')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Translate','td=@1;ts=@2;limit=@3;')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Help','This block resets the state(s) to be zero(s) at the begining of reset time inteval. The reset inteval can be a two elements vector with the second element being offset.')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Scheduled',13,'reset-int']],...
		'Mask Entries','td\/ts\/Inf\/',...
		'position',[105,34,165,76])

add_block('built-in/Sum',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Sum1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Sum1']],...
		'position',[210,72,235,103])

add_block('built-in/Sum',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Sum3']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Sum3']],...
		'position',[285,108,305,137])

add_block('built-in/Constant',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Initial phase']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Initial phase']],...
		'Value','Ph',...
		'position',[85,118,105,142])

add_block('built-in/Mux',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Mux']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Mux']],...
		'inputs','2',...
		'position',[325,78,355,122])

add_block('built-in/S-Function',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Array sin']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Array sin']],...
		'ForeGround',3,...
		'function name','arysin',...
		'parameters','''cos''',...
		'position',[390,90,440,110])

add_block('built-in/S-Function',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Array sin1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Array sin1']],...
		'ForeGround',4,...
		'function name','arysin',...
		'parameters','''sin''',...
		'position',[395,150,445,170])

add_block('built-in/Sum',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Sum4']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Sum4']],...
		'inputs','++++',...
		'position',[785,87,805,133])

add_block('built-in/Product',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Product2']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Product2']],...
		'position',[645,141,670,174])

add_block('built-in/Product',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Product3']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Product3']],...
		'position',[480,136,505,169])

add_block('built-in/Inport',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/in_1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/in_1']],...
		'position',[345,40,365,60])

add_block('built-in/Demux',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Demux1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Demux1']],...
		'ForeGround',2,...
		'outputs','2',...
		'position',[395,30,435,65])

add_block('built-in/Product',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Product1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Product1']],...
		'position',[645,36,670,69])

add_block('built-in/Product',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Product']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Product']],...
		'position',[490,31,515,64])

add_block('built-in/Outport',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/out_1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/out_1']],...
		'position',[830,100,850,120])

add_block('built-in/Demux',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Demux2']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Demux2']],...
		'outputs','2',...
		'position',[695,140,735,175])

add_block('built-in/Demux',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Demux']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Demux']],...
		'outputs','2',...
		'position',[685,35,725,70])

add_block('built-in/S-Function',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator']],...
		'Mask Entries','N*2\/td\/ts\/''backward''\/',...
		'position',[530,28,605,72])

add_block('built-in/S-Function',[sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'function name','moveint',...
		'parameters','vec,T,sample_time,method',...
		'Mask Display','Windowed\nInt')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Type','Moving window integration.')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Dialogue','Output the integration  of the input from time t-T to t, where T is the integration window.|Input vector size:|Integration window length:|Sample time:|Method (''forward'', ''backward'', or ''first order''):')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Translate','vec=@1;T=@2;sample_time=@3;method=@4;')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Help','This block output\n   t\nint u(t) dt\n t-T\nThe output vector length is the same as the input vector length.')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband/Limited-length',13,'integrator1']],...
		'Mask Entries','N*2\/td\/ts\/''backward''\/',...
		'position',[525,133,600,177])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[310,125;320,110])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[520,50;525,50])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[610,50;615,45;640,45])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[610,50;615,60;640,60])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[675,55;680,55])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[730,45;760,45;760,95;780,95])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[730,60;755,60;755,105;780,105])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[810,110;825,110])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[65,55;100,55])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[170,55;185,55;185,80;205,80])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[240,90;320,90])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[260,90;260,115;280,115])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[110,130;185,130;185,95;205,95])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[185,130;280,130])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[360,100;385,100])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[370,100;370,160;390,160])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[370,50;390,50])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[675,160;690,160])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[605,155;615,155;615,165;640,165])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[605,155;615,155;615,150;640,150])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[510,155;520,155])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[740,150;755,150;755,115;780,115])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[740,165;760,165;760,125;780,125])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[450,160;475,160])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[440,55;450,55;450,145;475,145])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[440,40;485,40])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],[445,100;460,100;460,55;485,55])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Display','plot(0,0,100,100,u,v);  NC MFSK',...
		'Mask Type','Baseband non-coherent MFSK correlation')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Dialogue','Compute baseband MFSK correlation. Take\nMFSK CE modulated signal. Output a vector\nof correlation result.|M-ary number (input in range [0, M-1]):|Tone space (Hz):|Symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Translate','pi2=2*pi;N=@1;Ph=@4;Ton=@2;sft=[0:N-1]*Ton*pi2;td=@3;ts=@5;[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Help','This block calculates the noncoherent correlation value of the input signal with a vector of sinusoidal signals. These sinusoidal signals have their frequency the same as that of FM modulated signal of possible resulting digits. The output is an M length vector. The MFSK demodulation result is the index of the largest output. The input of this block is complex signal.')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],...
		'Mask Entries','M\/Ton\/td\/Ph\/ts\/')


%     Finished composite block ['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband'].

set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Non-coh MFSK dm',13,'corr baseband']],...
		'position',[110,68,190,112])


%     Subsystem  ['Noncoh MFSK',13,'demod baseband/Min//max index1'].

new_system([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']],'Location',[192,461,623,564])

add_block('built-in/Inport',[sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1/in_1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1/in_1']],...
		'position',[65,20,85,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1/Zero-Order',13,'Hold']],...
		'Sample time','td',...
		'position',[165,14,200,46])

add_block('built-in/Outport',[sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1/out_1']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1/out_1']],...
		'position',[335,20,355,40])

add_block('built-in/S-Function',[sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1/Maximum']])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1/Maximum']],...
		'function name','arymimai',...
		'parameters','mima',...
		'position',[240,20,320,40])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']],[90,30;160,30])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']],[325,30;330,30])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']],[205,30;235,30])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']],...
		'Mask Display','Min/Max\ndemap',...
		'Mask Type','Maximum/minimum index.')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']],...
		'Mask Dialogue','Choose the index of the input vector with\nmax/min value at sampling point. Hold the\nvalue for the rest of the period.|Symbol interval (sec):|''max'' or ''min'':')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']],...
		'Mask Translate','td=@1;mima=@2;')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']],...
		'Mask Help','This block outputs the index of the vector element that has the maximum or minimum value in the input vector. The computation starts at the sampling time point. The block holds the value for the rest of the interval.')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']],...
		'Mask Entries','td\/''max''\/')


%     Finished composite block ['Noncoh MFSK',13,'demod baseband/Min//max index1'].

set_param([sys,'/',['Noncoh MFSK',13,'demod baseband/Min//max index1']],...
		'ForeGround',4,...
		'position',[250,68,330,112])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband']],[335,90;370,90])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband']],[50,90;105,90])
add_line([sys,'/',['Noncoh MFSK',13,'demod baseband']],[195,90;245,90])
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v); NC-MFSK',...
		'Mask Type','Baseband noncoherent MFSK demodulation')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a MFSK\nmodulated signal using noncoherent\ncorrelation method.|M-ary number (output digits in range [0, M-1]):|Tone space (Hz):|Symbol interval (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband']],...
		'Mask Translate','M=@1;Ph=@4;Ton=@2;td=@3;ts=@5;[x,y]=moduicon(8);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband']],...
		'Mask Help','This block demodulates the complex envelope of a MFSK modulated signal using noncoherent method. The coherent demodulation method is phase insensitive. The tone space is the frequency distance between two successive after the modulation. The inputs are integers in the range [0, M-1], where M is the M-ary number. When the symbol interval is a two element vector, the second element is the offset (default 0).')
set_param([sys,'/',['Noncoh MFSK',13,'demod baseband']],...
		'Mask Entries','16\/18/.2/5\/.2\/0\/.01\/')


%     Finished composite block ['Noncoh MFSK',13,'demod baseband'].

set_param([sys,'/',['Noncoh MFSK',13,'demod baseband']],...
		'position',[280,353,360,397])


%     Subsystem  ['A-map QASK',13,'mod baseband'].

new_system([sys,'/',['A-map QASK',13,'mod baseband']])
set_param([sys,'/',['A-map QASK',13,'mod baseband']],'Location',[26,513,372,670])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'mod baseband/out_1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/out_1']],...
		'hide name',0,...
		'position',[270,70,290,90])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'mod baseband/in_1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/in_1']],...
		'position',[5,70,20,90])


%     Subsystem  ['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map'].

new_system([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],'Location',[58,103,403,268])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Imag']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Real']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Look Up Table',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/imag part1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Look Up Table',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/real part']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/in_1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],[215,110;270,110])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],[220,30;270,30])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],[120,30;175,30])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],[145,30;145,110;170,110])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],[50,30;75,30])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'Mask Display','QASK\nA-map',...
		'Mask Type','QASK A-map')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'Mask Dialogue','QASK mapping for arbitrary defined\nmap. Assume input digit is K. 1st\noutport outputs in-phase(K+1). 2nd\noutport outputs quadrature(K+1).|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;ly=length(y1);x=[-10 1:ly-1;1:ly-1 10*ly]-.5;x=x(:);y1=y1(:)'';y1=[y1;y1];y1=y1(:);y2=y2(:)'';y2=[y2;y2];y2=y2(:);')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The in-phase and quadrature constellation vectors must have the same length. The input signal is in the range of [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'Mask Entries','y1\/y2\/td\/')


%     Finished composite block ['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map'].

set_param([sys,'/',['A-map QASK',13,'mod baseband/QASK',13,'arbitrary-map']],...
		'hide name',0,...
		'position',[50,58,130,102])


%     Subsystem  ['A-map QASK',13,'mod baseband/QAM',13,'baseband2'].

new_system([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],'Location',[321,500,954,793])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R1']],...
		'position',[190,15,195,20])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Sum']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R_out']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Mux',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/RI2C']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/RI2C']],...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/in_1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/out_1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Constant']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Constant1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/in_2']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R2']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I2']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product3']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product2']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Sum1']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I_out']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[550,140;580,140])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[250,100;250,245;305,245])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[280,175;280,200;305,200])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[270,155;270,235;305,235])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[120,40;295,40])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[238,40;238,190;305,190])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],[410,220;425,220;425,150;465,150])
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'Mask Entries','Ph\/')


%     Finished composite block ['A-map QASK',13,'mod baseband/QAM',13,'baseband2'].

set_param([sys,'/',['A-map QASK',13,'mod baseband/QAM',13,'baseband2']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[165,58,245,102])
add_line([sys,'/',['A-map QASK',13,'mod baseband']],[250,80;265,80])
add_line([sys,'/',['A-map QASK',13,'mod baseband']],[25,80;45,80])
add_line([sys,'/',['A-map QASK',13,'mod baseband']],[135,70;160,70])
add_line([sys,'/',['A-map QASK',13,'mod baseband']],[135,90;160,90])
set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);A-QASK',...
		'Mask Type','Baseband A-QASK modulation')
set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'Mask Dialogue','Output the complex envelope of QASK\nmodulation. The arbitrary constellation\nis defined by in-phase and quadrature\nvectors.|Constellation in-phase component:|Constellation quadrature component:|Input symbol interval and offset (sec):|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;Ph=@4;ts=@5;[x,y]=moduicon(5);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'Mask Help','This block outputs the complex envelope of a QASK modulated signal with user-defined arbitrary constellation. The vector length of the in-phase and quadrature components vectors should be the same length. The inputs are integers in the range [0, M-1], where M is the vector length of in-phase or quadrature. When the symbol interval is a two-element vector, the second element is the offset (default 0).')
set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'Mask Entries','real(exp(j*[0:16-1]/16*pi*2))\/imag(exp(j*[0:16-1]/16*pi*2))\/.2\/0\/.01\/')


%     Finished composite block ['A-map QASK',13,'mod baseband'].

set_param([sys,'/',['A-map QASK',13,'mod baseband']],...
		'position',[45,278,125,322])


%     Subsystem  ['A-map QASK',13,'demod baseband'].

new_system([sys,'/',['A-map QASK',13,'demod baseband']])
set_param([sys,'/',['A-map QASK',13,'demod baseband']],'Location',[105,539,481,673])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'demod baseband/out_1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/out_1']],...
		'position',[285,50,305,70])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'demod baseband/in_1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/in_1']],...
		'position',[10,50,30,70])


%     Subsystem  ['A-map QASK',13,'demod baseband/QADM',13,'baseband3'].

new_system([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],'Location',[283,122,827,462])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/in_1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/in_1']],...
		'position',[55,115,75,135])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant1']],...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/out_2']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Filter',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Demux',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Demux']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Constant']],...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product2']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product3']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Filter',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Note',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[285,280,290,285])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/out_1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3/out_1']],...
		'position',[480,70,500,90])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[230,115;230,245;265,245])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[200,255;265,255])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[165,130;255,130])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[180,130;180,210;265,210])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[180,50;255,50])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[215,50;215,200;265,200])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[80,125;115,125])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[360,80;385,80])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[450,80;475,80])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[365,230;390,230])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],[455,230;480,230])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'Mask Entries','num\/den\/Ph\/ts\/')


%     Finished composite block ['A-map QASK',13,'demod baseband/QADM',13,'baseband3'].

set_param([sys,'/',['A-map QASK',13,'demod baseband/QADM',13,'baseband3']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[70,38,150,82])


%     Subsystem  ['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap'].

new_system([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],'Location',[45,449,594,684])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/imag_pt']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])

add_block('built-in/Constant',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/real_pt']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Outport',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/out_1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/S-Function',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Minimum1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum2']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Product1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Product',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Product']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum6']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Sum',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Zero-Order Hold',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/imag']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Inport',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/real']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[480,95;490,95])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[395,95;410,95])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[160,130;225,130])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[160,45;225,45])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[70,130;115,130])
add_line([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],[70,45;115,45])
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'Mask Entries','y1\/y2\/td\/')


%     Finished composite block ['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap'].

set_param([sys,'/',['A-map QASK',13,'demod baseband/QASK',13,'arbitrary-demap']],...
		'position',[175,38,255,82])
add_line([sys,'/',['A-map QASK',13,'demod baseband']],[155,70;170,70])
add_line([sys,'/',['A-map QASK',13,'demod baseband']],[155,50;170,50])
add_line([sys,'/',['A-map QASK',13,'demod baseband']],[260,60;280,60])
add_line([sys,'/',['A-map QASK',13,'demod baseband']],[35,60;65,60])
set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);A-QASK',...
		'Mask Type','Baseband A-QASK demodulation')
set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'Mask Dialogue','Demodulate the complex envelope of a QASK modulated signal. The arbitrary constellation is defined by in-phase and quadrature vectors.|Constellation in-phase component:|Constellation quadrature component:|Symbol interval and offset (sec):|Lowpass filter [num; den], a 2 row matrix:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;num=@4;Ph=@5;ts=@6;den=num(2,:);num=num(1,:);[x,y]=moduicon(6);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'Mask Help','This block demodulates the complex envelope of a QASK modulated signal with user-defined arbitrary constellation. The vector length of the in-phase and quadrature components vectors should have the same length. The outputs are integers in the range [0, M-1], where M is the vector length of in-phase or quadrature. When the symbol interval is a two-element vector, the second element is the offset (default 0).')
set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'Mask Entries','real(exp(j*[0:16-1]/16*pi*2))\/imag(exp(j*[0:16-1]/16*pi*2))\/.2\/[1;1]\/0\/.01\/')


%     Finished composite block ['A-map QASK',13,'demod baseband'].

set_param([sys,'/',['A-map QASK',13,'demod baseband']],...
		'position',[175,278,255,322])
add_line(sys,[130,75;170,75])
add_line(sys,[130,150;170,150])
add_line(sys,[130,375;170,375])
add_line(sys,[150,375;150,350;265,350;275,375])
add_line(sys,[130,450;170,450])
add_line(sys,[130,225;170,225])
add_line(sys,[130,300;170,300])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
