function [ret,x0,str,ts,xts]=v34struc(t,x,u,flag);
%V34STRUC	is the M-file description of the SIMULINK system named V34STRUC.
%	The block-diagram can be displayed by typing: V34STRUC.
%
%	SYS=V34STRUC(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes V34STRUC to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling V34STRUC with a FLAG of zero:
%	[SIZES]=V34STRUC([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[326,299,907,554])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '2.8')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','v34cod16;BRATE=28800;SRATE=3200;CON_CODE=1;v34_plot_flag=0;v34_rate_b = 72; v34_rate_p=7;v34_rate_j=16;v34struc;');

add_block('built-in/Note',[sys,'/','V.34 Modem Data Transmission'])
set_param([sys,'/','V.34 Modem Data Transmission'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[270,25,275,30])

add_block('built-in/Constant',[sys,'/','Enable signal2'])
set_param([sys,'/','Enable signal2'],...
		'position',[350,115,370,135])

add_block('built-in/Constant',[sys,'/','Enable signal1'])
set_param([sys,'/','Enable signal1'],...
		'position',[45,105,65,125])


%     Subsystem  'Call modem'.

new_system([sys,'/','Call modem'])
set_param([sys,'/','Call modem'],'Location',[169,449,1021,789])

add_block('built-in/S-Function',[sys,'/',['Call modem/Integer vector',13,'to scalar']])
set_param([sys,'/',['Call modem/Integer vector',13,'to scalar']],...
		'ForeGround',3,...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter')
set_param([sys,'/',['Call modem/Integer vector',13,'to scalar']],...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Call modem/Integer vector',13,'to scalar']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Call modem/Integer vector',13,'to scalar']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Call modem/Integer vector',13,'to scalar']],...
		'Mask Entries','2\/',...
		'position',[240,18,320,62])


%     Subsystem  ['Call modem/Triggered',13,'signal switch'].

new_system([sys,'/',['Call modem/Triggered',13,'signal switch']])
set_param([sys,'/',['Call modem/Triggered',13,'signal switch']],'Location',[624,516,1004,680])

add_block('built-in/Inport',[sys,'/',['Call modem/Triggered',13,'signal switch/in_1']])
set_param([sys,'/',['Call modem/Triggered',13,'signal switch/in_1']],...
		'position',[65,20,85,40])

add_block('built-in/Mux',[sys,'/',['Call modem/Triggered',13,'signal switch/Mux']])
set_param([sys,'/',['Call modem/Triggered',13,'signal switch/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Outport',[sys,'/',['Call modem/Triggered',13,'signal switch/out_1']])
set_param([sys,'/',['Call modem/Triggered',13,'signal switch/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Inport',[sys,'/',['Call modem/Triggered',13,'signal switch/in_2']])
set_param([sys,'/',['Call modem/Triggered',13,'signal switch/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/S-Function',[sys,'/',['Call modem/Triggered',13,'signal switch/S-function']])
set_param([sys,'/',['Call modem/Triggered',13,'signal switch/S-function']],...
		'function name','stdmamux',...
		'parameters','sw,ke,in,tt',...
		'position',[205,60,275,90])
add_line([sys,'/',['Call modem/Triggered',13,'signal switch']],[90,30;120,30;120,65;140,65])
add_line([sys,'/',['Call modem/Triggered',13,'signal switch']],[85,85;140,85])
add_line([sys,'/',['Call modem/Triggered',13,'signal switch']],[180,75;200,75])
add_line([sys,'/',['Call modem/Triggered',13,'signal switch']],[280,75;315,75])
set_param([sys,'/',['Call modem/Triggered',13,'signal switch']],...
		'Mask Display','plot(0,0,100,100,v,w);Vct re-arr',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/',['Call modem/Triggered',13,'signal switch']],...
		'Mask Dialogue','The rising edge from the 2nd inport\ntriggers the output of this block to follow the rule of the next row in the switch box.|Switch box (column number equals block output length):|Keeping value (flag 0 element in switch box):|Initial value (before the 1st trigger is detected):|Trigger threshold:')
set_param([sys,'/',['Call modem/Triggered',13,'signal switch']],...
		'Mask Translate','sw=@1;ke=@2;in=@3;tt=@4;[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Call modem/Triggered',13,'signal switch']],...
		'Mask Help','When the ith element in the current row of the switch box is j, the ith element in the output vector equals jth input element. When j=0, the output keeps the last output value if keep_value >= 0; it equals ini_val otherwise. The switch box column number must be same as the lengths of output, keep_value, and init_value. The rising edge of the 2nd inport triggers the distribution pattern to follow the next row of the switch box.')
set_param([sys,'/',['Call modem/Triggered',13,'signal switch']],...
		'Mask Entries','vec2mat([1:b],ceil(b/4))\/zeros(1,ceil(b/4))\/zeros(1,ceil(b/4))\/.1\/')


%     Finished composite block ['Call modem/Triggered',13,'signal switch'].

set_param([sys,'/',['Call modem/Triggered',13,'signal switch']],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[140,18,220,62])

add_block('built-in/Outport',[sys,'/','Call modem/input binary'])
set_param([sys,'/','Call modem/input binary'],...
		'ForeGround',3,...
		'Port','2',...
		'position',[355,30,375,50])

add_block('built-in/Note',[sys,'/','Call modem/Uo(m)'])
set_param([sys,'/','Call modem/Uo(m)'],...
		'ForeGround',2,...
		'position',[660,235,665,240])


%     Subsystem  ['Call modem/QAM',13,'baseband'].

new_system([sys,'/',['Call modem/QAM',13,'baseband']])
set_param([sys,'/',['Call modem/QAM',13,'baseband']],'Location',[335,197,968,490])

add_block('built-in/Note',[sys,'/',['Call modem/QAM',13,'baseband/R1']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/R1']],...
		'position',[190,15,195,20])

add_block('built-in/Product',[sys,'/',['Call modem/QAM',13,'baseband/Product']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/Product']],...
		'position',[300,33,330,57])

add_block('built-in/Product',[sys,'/',['Call modem/QAM',13,'baseband/Product1']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/Product1']],...
		'position',[300,93,330,117])

add_block('built-in/Sum',[sys,'/',['Call modem/QAM',13,'baseband/Sum']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/Sum']],...
		'inputs','+-',...
		'position',[375,60,395,80])

add_block('built-in/Note',[sys,'/',['Call modem/QAM',13,'baseband/R_out']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/R_out']],...
		'position',[445,45,450,50])

add_block('built-in/Mux',[sys,'/',['Call modem/QAM',13,'baseband/RI2C']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/RI2C']],...
		'inputs','2',...
		'Mask Display','Real/Imag\nto Complex',...
		'Mask Type','Real/Imag to Complex',...
		'Mask Dialogue','Construct complex vector from real and imaginary vectors.')
set_param([sys,'/',['Call modem/QAM',13,'baseband/RI2C']],...
		'Mask Help','The Real/Imag to Complex block creates a complex output from the two inputs. It uses a Mux block to append the complex part (input 2) to the real part (input 1).')
set_param([sys,'/',['Call modem/QAM',13,'baseband/RI2C']],...
		'position',[470,119,545,161])

add_block('built-in/Inport',[sys,'/',['Call modem/QAM',13,'baseband/in_1']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/in_1']],...
		'position',[95,30,115,50])

add_block('built-in/Outport',[sys,'/',['Call modem/QAM',13,'baseband/out_1']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/out_1']],...
		'position',[585,130,605,150])

add_block('built-in/Constant',[sys,'/',['Call modem/QAM',13,'baseband/Constant']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/Constant']],...
		'Value','x1',...
		'position',[80,145,100,165])

add_block('built-in/Constant',[sys,'/',['Call modem/QAM',13,'baseband/Constant1']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/Constant1']],...
		'Value','x2',...
		'position',[130,165,150,185])

add_block('built-in/Note',[sys,'/',['Call modem/QAM',13,'baseband/I1']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/I1']],...
		'position',[193,43,198,48])

add_block('built-in/Inport',[sys,'/',['Call modem/QAM',13,'baseband/in_2']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/in_2']],...
		'Port','2',...
		'position',[135,55,155,75])

add_block('built-in/Note',[sys,'/',['Call modem/QAM',13,'baseband/R2']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/R2']],...
		'position',[125,135,130,140])

add_block('built-in/Note',[sys,'/',['Call modem/QAM',13,'baseband/I2']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/I2']],...
		'position',[190,155,195,160])

add_block('built-in/Product',[sys,'/',['Call modem/QAM',13,'baseband/Product3']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/Product3']],...
		'position',[310,183,340,207])

add_block('built-in/Product',[sys,'/',['Call modem/QAM',13,'baseband/Product2']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/Product2']],...
		'position',[310,228,340,252])

add_block('built-in/Sum',[sys,'/',['Call modem/QAM',13,'baseband/Sum1']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/Sum1']],...
		'position',[385,210,405,230])

add_block('built-in/Note',[sys,'/',['Call modem/QAM',13,'baseband/I_out']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/I_out']],...
		'position',[445,206,450,211])

add_block('built-in/Note',[sys,'/',['Call modem/QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Call modem/QAM',13,'baseband/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[260,370,265,375])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[550,140;580,140])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[345,240;355,240;355,225;380,225])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[345,195;355,195;355,215;380,215])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[160,65;245,65;245,100;295,100])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[250,100;250,245;305,245])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[155,175;280,175;280,110;295,110])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[280,175;280,200;305,200])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[105,155;270,155;270,50;295,50])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[270,155;270,235;305,235])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[120,40;295,40])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[238,40;238,190;305,190])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[335,105;345,105;345,75;370,75])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[335,45;345,45;345,65;370,65])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[400,70;425,70;425,130;465,130])
add_line([sys,'/',['Call modem/QAM',13,'baseband']],[410,220;425,220;425,150;465,150])
set_param([sys,'/',['Call modem/QAM',13,'baseband']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QAM',...
		'Mask Type','QM DSB-SC AM CE')
set_param([sys,'/',['Call modem/QAM',13,'baseband']],...
		'Mask Dialogue','Modulate the in-phase and quadrature\ncomponent signal from the 1st and 2nd\ninput ports, baseband simulation.|Initial phase (rad):')
set_param([sys,'/',['Call modem/QAM',13,'baseband']],...
		'Mask Translate','Ph=@1;x1=cos(Ph);x2=sin(Ph);[x,y]=moduicon(1);[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Call modem/QAM',13,'baseband']],...
		'Mask Help','This block outputs the complex envelope of the quadratic multiplexed double-sideband suppressed-carrier amplitude modulated signal. The 1st and 2nd input ports input the in-phase and quadrature components. The output is a complex signal.')
set_param([sys,'/',['Call modem/QAM',13,'baseband']],...
		'Mask Entries','0\/')


%     Finished composite block ['Call modem/QAM',13,'baseband'].

set_param([sys,'/',['Call modem/QAM',13,'baseband']],...
		'hide name',0,...
		'position',[705,73,785,117])

add_block('built-in/Demux',[sys,'/','Call modem/Demux2'])
set_param([sys,'/','Call modem/Demux2'],...
		'hide name',0,...
		'outputs','2',...
		'position',[645,74,690,116])

add_block('built-in/Note',[sys,'/',['Call modem/x''(n)']])
set_param([sys,'/',['Call modem/x''(n)']],...
		'position',[625,90,630,95])


%     Subsystem  ['Call modem/Non-linear',13,'encoder'].

new_system([sys,'/',['Call modem/Non-linear',13,'encoder']])
set_param([sys,'/',['Call modem/Non-linear',13,'encoder']],'Location',[313,87,639,216])

add_block('built-in/Note',[sys,'/',['Call modem/Non-linear',13,'encoder/This example assume Theta = 0']])
set_param([sys,'/',['Call modem/Non-linear',13,'encoder/This example assume Theta = 0']],...
		'position',[150,25,155,30])

add_block('built-in/Outport',[sys,'/',['Call modem/Non-linear',13,'encoder/x''(n)']])
set_param([sys,'/',['Call modem/Non-linear',13,'encoder/x''(n)']],...
		'position',[215,70,235,90])

add_block('built-in/Inport',[sys,'/',['Call modem/Non-linear',13,'encoder/x(n)']])
set_param([sys,'/',['Call modem/Non-linear',13,'encoder/x(n)']],...
		'position',[75,70,95,90])
add_line([sys,'/',['Call modem/Non-linear',13,'encoder']],[100,80;210,80])


%     Finished composite block ['Call modem/Non-linear',13,'encoder'].

set_param([sys,'/',['Call modem/Non-linear',13,'encoder']],...
		'position',[580,68,615,122])

add_block('built-in/Note',[sys,'/','Call modem/y(m)'])
set_param([sys,'/','Call modem/y(m)'],...
		'position',[545,130,550,135])

add_block('built-in/Outport',[sys,'/',['Call modem/Modulated',13,'input']])
set_param([sys,'/',['Call modem/Modulated',13,'input']],...
		'position',[810,85,830,105])


%     Subsystem  'Call modem/Trellis code'.

new_system([sys,'/','Call modem/Trellis code'])
set_param([sys,'/','Call modem/Trellis code'],'Location',[214,435,1004,747])

add_block('built-in/Inport',[sys,'/','Call modem/Trellis code/y(m)'])
set_param([sys,'/','Call modem/Trellis code/y(m)'],...
		'position',[60,35,80,55])


%     Subsystem  ['Call modem/Trellis code/Symbol to bit',13,'convertor'].

new_system([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],'Location',[147,441,937,645])

add_block('built-in/Note',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Symbol to bit converter']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Symbol to bit converter']],...
		'position',[310,10,315,15])


%     Subsystem  ['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor4'].

new_system([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor4']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor4']],'Location',[175,552,335,697])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor4']],...
		'Mask Display','Sym-to-bit\nconvertor\nFigure 9/V34')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor4']],...
		'Mask Dialogue','eval(''x=[1 5 3 7 5 1 7 3 5 1 7 3 1 5 3 7];y=[1 3 3 1 1 3 3 1 5 7 7 5 5 7 7 5];for i=1:16,text(x(i),y(i),num2str(rem(i-1,8)));end;set(get(gcf,''''child''''),''''Xlim'''',[0,8],''''Ylim'''',[0,8]);xlabel(''''Re'''');ylabel(''''Im'''')'')')


%     Finished composite block ['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor4'].

set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor4']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,110,380,152])


%     Subsystem  ['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor3'].

new_system([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor3']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor3']],'Location',[175,552,335,697])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor3']],...
		'Mask Display','Sym-to-bit\nconvertor\nFigure 10/V34')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor3']],...
		'Mask Dialogue','eval(''x=floor([[0:.5:7.5,0:.5:7.5],rem([0:.5:7.5,0:.5:7.5]+4,8)]);y=[rem(floor([0:2.5:39,1:2.5:40]),4),rem(floor([0:2.5:39,1:2.5:40]),4)+4];for i=1:64,text(x(i),y(i),num2str(rem(i-1,16)));end;set(get(gcf,''''child''''),''''Xlim'''',[-1,8],''''Ylim'''',[-1,8]);xlabel(''''s(2m)'''');ylabel(''''s(2m+1)'''')'')')


%     Finished composite block ['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor3'].

set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Vector',13,'redistributor3']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[565,105,650,152])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Y1-Y4']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Y1-Y4']],...
		'position',[675,60,695,80])


%     Subsystem  ['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1'].

new_system([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],'Location',[45,449,594,684])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/imag_pt']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/real_pt']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/out_1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/S-Function',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Minimum1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Sum',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum2']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/Product',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Product1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Product',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Product']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Sum',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum6']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Sum',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Zero-Order Hold',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/imag']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/real']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/real']],...
		'position',[45,35,65,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[480,95;490,95])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[395,95;410,95])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[270,140;270,145;295,145])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[270,55;270,60;295,60])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[160,130;225,130])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[160,45;225,45])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[70,130;115,130])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[70,45;115,45])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'Mask Entries','floor([[0:.5:7.5,0:.5:7.5],rem([0:.5:7.5,0:.5:7.5]+4,8)])\/[rem(floor([0:2.5:39,1:2.5:40]),4),rem(floor([0:2.5:39,1:2.5:40]),4)+4]\/.28/j/p/4/2\/')


%     Finished composite block ['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1'].

set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'hide name',0,...
		'position',[565,48,645,92])

add_block('built-in/Unit Delay',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Unit Delay']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Unit Delay']],...
		'hide name',0,...
		'Sample time','.28/j/p/4/2',...
		'position',[485,72,535,88])

add_block('built-in/S-Function',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Modulo',13,'operation2']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Modulo',13,'operation2']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Modulo',13,'operation2']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Modulo',13,'operation2']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Modulo',13,'operation2']],...
		'Mask Entries','8\/',...
		'position',[395,46,455,74])


%     Subsystem  ['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap'].

new_system([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],'Location',[45,449,594,684])

add_block('built-in/Zero-Order Hold',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/real']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/imag']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum6']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Product']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Product1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum2']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Minimum1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/out_1']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/real_pt']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/imag_pt']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[70,45;115,45])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[70,130;115,130])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[160,45;225,45])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[160,130;225,130])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[395,95;410,95])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[480,95;490,95])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'Mask Entries','[1 5 3 7 5 1 7 3 5 1 7 3 1 5 3 7]\/[1 3 3 1 1 3 3 1 5 7 7 5 5 7 7 5]\/.28/j/p/4/2\/')


%     Finished composite block ['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap'].

set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'hide name',0,...
		'position',[290,38,370,82])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/y']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/y']],...
		'position',[20,45,40,65])

add_block('built-in/Sum',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Sum']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Sum']],...
		'hide name',0,...
		'position',[90,50,110,70])

add_block('built-in/S-Function',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Modulo',13,'operation']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Modulo',13,'operation']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Modulo',13,'operation']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Modulo',13,'operation']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Modulo',13,'operation']],...
		'Mask Entries','8\/',...
		'position',[125,46,185,74])

add_block('built-in/Demux',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Demux']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Demux']],...
		'hide name',0,...
		'outputs','2',...
		'position',[215,41,260,79])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Constant']])
set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor/Constant']],...
		'Value','80',...
		'position',[45,85,65,105])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[70,95;70,65;85,65])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[45,55;85,55])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[115,60;120,60])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[375,60;390,60])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[460,60;465,60;465,80;480,80])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[540,80;560,80])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[460,60;560,60])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[650,70;670,70])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[190,60;210,60])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[265,50;285,50])
add_line([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],[265,70;285,70])


%     Finished composite block ['Call modem/Trellis code/Symbol to bit',13,'convertor'].

set_param([sys,'/',['Call modem/Trellis code/Symbol to bit',13,'convertor']],...
		'position',[140,17,180,73])

add_block('built-in/Demux',[sys,'/','Call modem/Trellis code/Demux2'])
set_param([sys,'/','Call modem/Trellis code/Demux2'],...
		'hide name',0,...
		'outputs','[tf(2,size(tf,2)), 1]',...
		'position',[540,34,585,76])


%     Subsystem  ['Call modem/Trellis code/Binary vector',13,'convol encode1'].

new_system([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],'Location',[214,496,617,630])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/out_1']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/out_1']],...
		'position',[350,30,370,50])

add_block('built-in/S-Function',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Modulo',13,'operation1']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Modulo',13,'operation1']],...
		'function name','sconvenc',...
		'parameters','tf',...
		'position',[255,25,315,55])

add_block('built-in/Mux',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Mux']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Mux']],...
		'inputs','2',...
		'Mask Display','',...
		'position',[190,21,225,54])


%     Subsystem  ['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector'].

new_system([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],...
		'Mask Entries','thd\/')


%     Finished composite block ['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector'].

set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/Rising edge',13,'detector']],...
		'position',[90,57,145,93])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/in_1']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/in_1']],...
		'position',[40,20,60,40])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/in_2']])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1/in_2']],...
		'Port','2',...
		'position',[40,65,60,85])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],[230,40;250,40])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],[150,75;160,75;160,45;185,45])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],[65,75;85,75])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],[65,30;185,30])
add_line([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],[320,40;345,40])
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl en',...
		'Mask Type','Vector I/O convolution encode')
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],...
		'Mask Dialogue','Convolution encode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Trigger signal threshold:')
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],...
		'Mask Translate','tf=@1;tf=simviter(tf);thd=@2;[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using convolution code. The block refreshes its register memory and output at the rising edge of the second inport pulse. You can also use a SIMULINK block diagram to define the convolution code transfer function.')
set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],...
		'Mask Entries','tf\/.5\/')


%     Finished composite block ['Call modem/Trellis code/Binary vector',13,'convol encode1'].

set_param([sys,'/',['Call modem/Trellis code/Binary vector',13,'convol encode1']],...
		'hide name',0,...
		'position',[440,33,520,77])

add_block('built-in/S-Function',[sys,'/',['Call modem/Trellis code/Integer scalar',13,'to vector']])
set_param([sys,'/',['Call modem/Trellis code/Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter')
set_param([sys,'/',['Call modem/Trellis code/Integer scalar',13,'to vector']],...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Call modem/Trellis code/Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Call modem/Trellis code/Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Call modem/Trellis code/Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Call modem/Trellis code/Integer scalar',13,'to vector']],...
		'Mask Entries','4\/2\/',...
		'position',[200,23,280,67])

add_block('built-in/Mux',[sys,'/','Call modem/Trellis code/Mux'])
set_param([sys,'/','Call modem/Trellis code/Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[300,36,335,69])

add_block('built-in/Demux',[sys,'/','Call modem/Trellis code/Demux'])
set_param([sys,'/','Call modem/Trellis code/Demux'],...
		'hide name',0,...
		'outputs','[tf(2,size(tf,2)), 5-tf(2,size(tf,2))]',...
		'position',[355,35,395,70])

add_block('built-in/Inport',[sys,'/','Call modem/Trellis code/(m+1) pulse'])
set_param([sys,'/','Call modem/Trellis code/(m+1) pulse'],...
		'Port','5',...
		'position',[385,85,405,105])

add_block('built-in/Outport',[sys,'/','Call modem/Trellis code/Uo(m)'])
set_param([sys,'/','Call modem/Trellis code/Uo(m)'],...
		'position',[720,120,740,140])

add_block('built-in/Logical Operator',[sys,'/',['Call modem/Trellis code/Logical',13,'Operator']])
set_param([sys,'/',['Call modem/Trellis code/Logical',13,'Operator']],...
		'hide name',0,...
		'Operator','XOR',...
		'Number of Input Ports','3',...
		'position',[660,112,690,148])

add_block('built-in/Note',[sys,'/','Call modem/Trellis code/Yo(m)'])
set_param([sys,'/','Call modem/Trellis code/Yo(m)'],...
		'position',[605,65,610,70])

add_block('built-in/Constant',[sys,'/','Call modem/Trellis code/Constant'])
set_param([sys,'/','Call modem/Trellis code/Constant'],...
		'position',[235,75,255,95])

add_block('built-in/Inport',[sys,'/','Call modem/Trellis code/k-pulse'])
set_param([sys,'/','Call modem/Trellis code/k-pulse'],...
		'Port','3',...
		'position',[455,220,475,240])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Frame',13,'pulse']])
set_param([sys,'/',['Call modem/Trellis code/Frame',13,'pulse']],...
		'Port','4',...
		'position',[415,195,435,215])


%     Subsystem  ['Call modem/Trellis code/Bit inversion',13,'pattern'].

new_system([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern']],'Location',[66,242,647,415])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Vo(m)']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Vo(m)']],...
		'position',[470,75,490,95])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Bit inversion patterns']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Bit inversion patterns']],...
		'Value','[0 1 1 1 0 1 1 1 1 1 1 1 1 0 1 0]',...
		'position',[90,31,280,59])


%     Subsystem  ['Call modem/Trellis code/Bit inversion',13,'pattern/Counter'].

new_system([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],'Location',[128,50,722,374])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Constant']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Constant']],...
		'ForeGround',3,...
		'Value','thld',...
		'position',[105,100,135,120])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Relational',13,'Operator1']],...
		'ForeGround',2,...
		'Operator','>',...
		'position',[225,53,255,77])

add_block('built-in/Sum',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Sum']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Sum']],...
		'ForeGround',3,...
		'position',[295,100,315,120])

add_block('built-in/Switch',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Switch2']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Switch2']],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[345,149,370,181])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/in_1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/in_1']],...
		'position',[15,50,35,70])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/in_2']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/in_2']],...
		'Port','2',...
		'position',[15,155,35,175])


%     Subsystem  ['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],...
		'Mask Entries','thld\/')


%     Finished composite block ['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],...
		'ForeGround',4,...
		'position',[80,148,140,182])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/out_1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/out_1']],...
		'position',[550,145,570,165])

add_block('built-in/Switch',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Switch3']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Switch3']],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[470,139,495,171])

add_block('built-in/Memory',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Memory3']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Memory3']],...
		'orientation',2,...
		'ForeGround',3,...
		'position',[400,205,440,235])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/in_3']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/in_3']],...
		'Port','3',...
		'position',[315,60,335,80])


%     Subsystem  ['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[300,35;335,35])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],...
		'Mask Entries','thld\/')


%     Finished composite block ['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],...
		'ForeGround',4,...
		'position',[375,53,435,87])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[440,70;450,70;450,155;465,155])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[395,220;275,220;275,175;340,175])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[275,175;275,115;290,115])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[145,165;340,165])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[260,65;275,65;275,105;290,105])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[140,110;190,110;190,70;220,70])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[320,110;330,110;340,155])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[40,60;220,60])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[40,165;75,165])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[340,70;370,70])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[375,165;465,165])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[500,155;545,155])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],[520,155;520,220;445,220])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Counter',...
		'Mask Type','Resettable number counter')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],...
		'Mask Dialogue','If the 1st inport value is larger than the threshold, the counter increases one at the rising edge of the 2nd inport pulse.|Threshold:')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(0,20,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],...
		'Mask Help','If the signal at the 1st inport is larger than or equal to the given threshold at the rising edge of the 2nd inport, the counter increases by one. The rising edge of the 3rd port resets the counter to zero.')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],...
		'Mask Entries','.2\/')


%     Finished composite block ['Call modem/Trellis code/Bit inversion',13,'pattern/Counter'].

set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Counter']],...
		'hide name',0,...
		'position',[235,88,315,132])


%     Subsystem  ['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch'].

new_system([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],'Location',[174,522,554,686])

add_block('built-in/S-Function',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch/S-function']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch/S-function']],...
		'function name','switchbx',...
		'parameters','sw,df',...
		'position',[205,60,275,90])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch/in_2']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch/out_1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Mux',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch/Mux']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch/in_1']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch/in_1']],...
		'position',[65,20,85,40])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],[280,75;315,75])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],[180,75;200,75])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],[85,85;140,85])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],[90,30;120,30;120,65;140,65])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],...
		'Mask Display','Switch\nbox',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],...
		'Mask Dialogue','The output distribution pattern follows the ith row of the switch box, where i is the input from the second port.|Switch box (column number equals block output length):|Default value:')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],...
		'Mask Translate','sw=@1;df=@2;')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],...
		'Mask Help','This block follows the switch pattern of ith row in the switch box when the second input port has value i.  When the value in the second input is larger than the switch box row number or less than 1, the block outputs the defualt value.')
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],...
		'Mask Entries','[1:16]''\/0\/')


%     Finished composite block ['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch'].

set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Signal switch']],...
		'hide name',0,...
		'position',[360,63,440,107])

add_block('built-in/Note',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Modulo encoder']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Modulo encoder']],...
		'position',[365,5,370,10])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/k pulse']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/k pulse']],...
		'position',[100,100,120,120])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/frame pulse']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/frame pulse']],...
		'Port','2',...
		'position',[160,115,180,135])

add_block('built-in/Constant',[sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Constant',13,'one']])
set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern/Constant',13,'one']],...
		'position',[45,85,65,105])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern']],[70,95;230,95])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern']],[125,110;230,110])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern']],[185,125;230,125])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern']],[285,45;305,45;305,75;355,75])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern']],[320,110;340,110;340,95;355,95])
add_line([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern']],[445,85;465,85])


%     Finished composite block ['Call modem/Trellis code/Bit inversion',13,'pattern'].

set_param([sys,'/',['Call modem/Trellis code/Bit inversion',13,'pattern']],...
		'position',[510,190,550,245])

add_block('built-in/Inport',[sys,'/','Call modem/Trellis code/c(m)'])
set_param([sys,'/','Call modem/Trellis code/c(m)'],...
		'Port','2',...
		'position',[250,170,270,190])


%     Subsystem  ['Call modem/Trellis code/Modulo',13,'encoder'].

new_system([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder']])
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder']],'Location',[25,423,606,537])

add_block('built-in/Note',[sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Modulo encoder']])
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Modulo encoder']],...
		'position',[310,5,315,10])

add_block('built-in/Inport',[sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/c(m)']])
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/c(m)']],...
		'position',[60,45,80,65])

add_block('built-in/Sum',[sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Sum']])
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Sum']],...
		'hide name',0,...
		'inputs','+',...
		'position',[130,45,150,65])

add_block('built-in/Unit Delay',[sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Unit Delay']])
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Unit Delay']],...
		'hide name',0,...
		'Sample time','.28/j/p/4/2',...
		'position',[275,67,325,83])

add_block('built-in/S-Function',[sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Modulo',13,'operation2']])
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Modulo',13,'operation2']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Modulo',13,'operation2']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Modulo',13,'operation2']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Modulo',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[185,41,245,69])

add_block('built-in/Logical Operator',[sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Logical',13,'Operator']])
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Logical',13,'Operator']],...
		'hide name',0,...
		'Operator','XOR',...
		'position',[355,48,385,72])

add_block('built-in/Logical Operator',[sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Logical',13,'Operator1']])
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Logical',13,'Operator1']],...
		'hide name',0,...
		'Operator','NOT',...
		'Number of Input Ports','1',...
		'position',[415,48,445,72])

add_block('built-in/Outport',[sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Co(m)']])
set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder/Co(m)']],...
		'position',[480,50,500,70])
add_line([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder']],[250,55;255,55;255,75;270,75])
add_line([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder']],[85,55;125,55])
add_line([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder']],[155,55;180,55])
add_line([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder']],[330,75;335,75;335,65;350,65])
add_line([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder']],[250,55;350,55])
add_line([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder']],[390,60;410,60])
add_line([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder']],[450,60;475,60])


%     Finished composite block ['Call modem/Trellis code/Modulo',13,'encoder'].

set_param([sys,'/',['Call modem/Trellis code/Modulo',13,'encoder']],...
		'position',[295,152,335,208])

add_block('built-in/Note',[sys,'/','Call modem/Trellis code/Co(m)'])
set_param([sys,'/','Call modem/Trellis code/Co(m)'],...
		'position',[355,175,360,180])

add_block('built-in/Note',[sys,'/','Call modem/Trellis code/Vo(m)'])
set_param([sys,'/','Call modem/Trellis code/Vo(m)'],...
		'position',[575,220,580,225])
add_line([sys,'/','Call modem/Trellis code'],[555,220;625,220;625,140;655,140])
add_line([sys,'/','Call modem/Trellis code'],[340,180;555,180;555,130;655,130])
add_line([sys,'/','Call modem/Trellis code'],[185,45;195,45])
add_line([sys,'/','Call modem/Trellis code'],[85,45;135,45])
add_line([sys,'/','Call modem/Trellis code'],[410,95;425,95;435,65])
add_line([sys,'/','Call modem/Trellis code'],[695,130;715,130])
add_line([sys,'/','Call modem/Trellis code'],[440,205;505,205])
add_line([sys,'/','Call modem/Trellis code'],[480,230;505,230])
add_line([sys,'/','Call modem/Trellis code'],[275,180;290,180])
add_line([sys,'/','Call modem/Trellis code'],[525,55;535,55])
add_line([sys,'/','Call modem/Trellis code'],[590,65;625,65;625,120;655,120])
add_line([sys,'/','Call modem/Trellis code'],[285,45;295,45])
add_line([sys,'/','Call modem/Trellis code'],[260,85;285,85;295,60])
add_line([sys,'/','Call modem/Trellis code'],[340,55;350,55])
add_line([sys,'/','Call modem/Trellis code'],[400,45;435,45])


%     Finished composite block 'Call modem/Trellis code'.

set_param([sys,'/','Call modem/Trellis code'],...
		'ForeGround',2,...
		'position',[600,181,640,299])

add_block('built-in/Note',[sys,'/','Call modem/x(n)'])
set_param([sys,'/','Call modem/x(n)'],...
		'position',[550,90,555,95])


%     Subsystem  'Call modem/Rotation'.

new_system([sys,'/','Call modem/Rotation'])
set_param([sys,'/','Call modem/Rotation'],'Location',[15,107,559,375])

add_block('built-in/Note',[sys,'/','Call modem/Rotation/This block implements the rotation part of Section 9.6.1//V.34'])
set_param([sys,'/','Call modem/Rotation/This block implements the rotation part of Section 9.6.1//V.34'],...
		'position',[285,20,290,25])

add_block('built-in/Inport',[sys,'/','Call modem/Rotation/in_1'])
set_param([sys,'/','Call modem/Rotation/in_1'],...
		'position',[70,55,90,75])

add_block('built-in/Inport',[sys,'/','Call modem/Rotation/in_2'])
set_param([sys,'/','Call modem/Rotation/in_2'],...
		'Port','2',...
		'position',[100,70,120,90])

add_block('built-in/Mux',[sys,'/','Call modem/Rotation/Mux'])
set_param([sys,'/','Call modem/Rotation/Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[150,56,185,89])

add_block('built-in/Mux',[sys,'/','Call modem/Rotation/Mux1'])
set_param([sys,'/','Call modem/Rotation/Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[265,51,300,84])

add_block('built-in/Gain',[sys,'/','Call modem/Rotation/Gain1'])
set_param([sys,'/','Call modem/Rotation/Gain1'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[215,80,235,100])

add_block('built-in/Inport',[sys,'/','Call modem/Rotation/Z(m)'])
set_param([sys,'/','Call modem/Rotation/Z(m)'],...
		'Port','4',...
		'position',[50,110,70,130])

add_block('built-in/Sum',[sys,'/','Call modem/Rotation/Sum1'])
set_param([sys,'/','Call modem/Rotation/Sum1'],...
		'hide name',0,...
		'position',[380,127,400,163])

add_block('built-in/Switch',[sys,'/','Call modem/Rotation/Switch'])
set_param([sys,'/','Call modem/Rotation/Switch'],...
		'hide name',0,...
		'Threshold','.5',...
		'position',[245,114,275,156])

add_block('built-in/Inport',[sys,'/','Call modem/Rotation/switch'])
set_param([sys,'/','Call modem/Rotation/switch'],...
		'ForeGround',2,...
		'Port','5',...
		'position',[195,125,215,145])

add_block('built-in/S-Function',[sys,'/',['Call modem/Rotation/Modulo',13,'operation']])
set_param([sys,'/',['Call modem/Rotation/Modulo',13,'operation']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Call modem/Rotation/Modulo',13,'operation']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Call modem/Rotation/Modulo',13,'operation']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Call modem/Rotation/Modulo',13,'operation']],...
		'Mask Entries','4\/',...
		'position',[290,116,355,154])

add_block('built-in/Outport',[sys,'/','Call modem/Rotation/u(m)'])
set_param([sys,'/','Call modem/Rotation/u(m)'],...
		'position',[510,70,530,90])


%     Subsystem  'Call modem/Rotation/Signal switch'.

new_system([sys,'/','Call modem/Rotation/Signal switch'])
set_param([sys,'/','Call modem/Rotation/Signal switch'],'Location',[174,522,554,686])

add_block('built-in/S-Function',[sys,'/','Call modem/Rotation/Signal switch/S-function'])
set_param([sys,'/','Call modem/Rotation/Signal switch/S-function'],...
		'function name','switchbx',...
		'parameters','sw,df',...
		'position',[205,60,275,90])

add_block('built-in/Inport',[sys,'/','Call modem/Rotation/Signal switch/in_2'])
set_param([sys,'/','Call modem/Rotation/Signal switch/in_2'],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/Outport',[sys,'/','Call modem/Rotation/Signal switch/out_1'])
set_param([sys,'/','Call modem/Rotation/Signal switch/out_1'],...
		'position',[320,65,340,85])

add_block('built-in/Mux',[sys,'/','Call modem/Rotation/Signal switch/Mux'])
set_param([sys,'/','Call modem/Rotation/Signal switch/Mux'],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Inport',[sys,'/','Call modem/Rotation/Signal switch/in_1'])
set_param([sys,'/','Call modem/Rotation/Signal switch/in_1'],...
		'position',[65,20,85,40])
add_line([sys,'/','Call modem/Rotation/Signal switch'],[280,75;315,75])
add_line([sys,'/','Call modem/Rotation/Signal switch'],[180,75;200,75])
add_line([sys,'/','Call modem/Rotation/Signal switch'],[85,85;140,85])
add_line([sys,'/','Call modem/Rotation/Signal switch'],[90,30;120,30;120,65;140,65])
set_param([sys,'/','Call modem/Rotation/Signal switch'],...
		'Mask Display','Switch\nbox',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/','Call modem/Rotation/Signal switch'],...
		'Mask Dialogue','The output distribution pattern follows the ith row of the switch box, where i is the input from the second port.|Switch box (column number equals block output length):|Default value:')
set_param([sys,'/','Call modem/Rotation/Signal switch'],...
		'Mask Translate','sw=@1;df=@2;')
set_param([sys,'/','Call modem/Rotation/Signal switch'],...
		'Mask Help','This block follows the switch pattern of ith row in the switch box when the second input port has value i.  When the value in the second input is larger than the switch box row number or less than 1, the block outputs the defualt value.')
set_param([sys,'/','Call modem/Rotation/Signal switch'],...
		'Mask Entries','[1 2;2 3;3 4;4 1]\/[0 0]\/')


%     Finished composite block 'Call modem/Rotation/Signal switch'.

set_param([sys,'/','Call modem/Rotation/Signal switch'],...
		'hide name',0,...
		'position',[425,61,490,94])

add_block('built-in/Sum',[sys,'/','Call modem/Rotation/Sum2'])
set_param([sys,'/','Call modem/Rotation/Sum2'],...
		'hide name',0,...
		'position',[195,172,215,208])

add_block('built-in/Gain',[sys,'/','Call modem/Rotation/Gain'])
set_param([sys,'/','Call modem/Rotation/Gain'],...
		'hide name',0,...
		'Gain','2',...
		'position',[80,180,100,200])

add_block('built-in/Inport',[sys,'/','Call modem/Rotation/I1'])
set_param([sys,'/','Call modem/Rotation/I1'],...
		'Port','3',...
		'position',[40,180,60,200])

add_block('built-in/Sum',[sys,'/','Call modem/Rotation/Sum'])
set_param([sys,'/','Call modem/Rotation/Sum'],...
		'hide name',0,...
		'position',[130,182,150,218])

add_block('built-in/Inport',[sys,'/','Call modem/Rotation/Uo(m)'])
set_param([sys,'/','Call modem/Rotation/Uo(m)'],...
		'Port','6',...
		'position',[75,220,95,240])

add_block('built-in/Note',[sys,'/','Call modem/Rotation/Vo(m)'])
set_param([sys,'/','Call modem/Rotation/Vo(m)'],...
		'position',[170,200,175,205])

add_block('built-in/Constant',[sys,'/','Call modem/Rotation/Constant'])
set_param([sys,'/','Call modem/Rotation/Constant'],...
		'position',[315,180,335,200])
add_line([sys,'/','Call modem/Rotation'],[125,80;145,80])
add_line([sys,'/','Call modem/Rotation'],[95,65;145,65])
add_line([sys,'/','Call modem/Rotation'],[495,80;505,80])
add_line([sys,'/','Call modem/Rotation'],[75,120;240,120])
add_line([sys,'/','Call modem/Rotation'],[220,135;240,135])
add_line([sys,'/','Call modem/Rotation'],[65,190;75,190])
add_line([sys,'/','Call modem/Rotation'],[340,190;365,190;375,155])
add_line([sys,'/','Call modem/Rotation'],[190,75;200,75;200,60;260,60])
add_line([sys,'/','Call modem/Rotation'],[305,70;420,70])
add_line([sys,'/','Call modem/Rotation'],[240,90;245,90;245,75;260,75])
add_line([sys,'/','Call modem/Rotation'],[200,75;210,90])
add_line([sys,'/','Call modem/Rotation'],[405,145;405,85;420,85])
add_line([sys,'/','Call modem/Rotation'],[280,135;285,135])
add_line([sys,'/','Call modem/Rotation'],[360,135;375,135])
add_line([sys,'/','Call modem/Rotation'],[220,190;225,190;225,150;240,150])
add_line([sys,'/','Call modem/Rotation'],[165,120;165,180;190,180])
add_line([sys,'/','Call modem/Rotation'],[155,200;190,200])
add_line([sys,'/','Call modem/Rotation'],[105,190;125,190])
add_line([sys,'/','Call modem/Rotation'],[100,230;105,230;105,210;125,210])


%     Finished composite block 'Call modem/Rotation'.

set_param([sys,'/','Call modem/Rotation'],...
		'position',[425,76,465,194])


%     Subsystem  'Call modem/Precoder'.

new_system([sys,'/','Call modem/Precoder'])
set_param([sys,'/','Call modem/Precoder'],'Location',[4,172,650,542])

add_block('built-in/Sum',[sys,'/','Call modem/Precoder/Sum1'])
set_param([sys,'/','Call modem/Precoder/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[315,107,335,143])

add_block('built-in/Sum',[sys,'/','Call modem/Precoder/Sum'])
set_param([sys,'/','Call modem/Precoder/Sum'],...
		'hide name',0,...
		'position',[205,97,225,133])

add_block('built-in/Note',[sys,'/','Call modem/Precoder/The output of this block is x(n) in Eq.(9-27//V.34) '])
set_param([sys,'/','Call modem/Precoder/The output of this block is x(n) in Eq.(9-27//V.34) '],...
		'position',[220,325,225,330])

add_block('built-in/S-Function',[sys,'/',['Call modem/Precoder/Array',13,'function']])
set_param([sys,'/',['Call modem/Precoder/Array',13,'function']],...
		'orientation',2,...
		'hide name',0,...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nfunction',...
		'Mask Type','Array function')
set_param([sys,'/',['Call modem/Precoder/Array',13,'function']],...
		'Mask Dialogue','Array function block for sin, cos, tan, exp, asin, acos, ln, log10, sgn, abs,\nfloor, ceil, and round.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['Call modem/Precoder/Array',13,'function']],...
		'Mask Help','This block calculates the given function value. The vector length of the output is the same as the input.',...
		'Mask Entries','''round''\/')
set_param([sys,'/',['Call modem/Precoder/Array',13,'function']],...
		'position',[330,210,410,250])

add_block('built-in/Gain',[sys,'/','Call modem/Precoder/Gain3'])
set_param([sys,'/','Call modem/Precoder/Gain3'],...
		'orientation',3,...
		'hide name',0,...
		'Gain','2*((b>=56)+1)',...
		'position',[138,165,162,185])

add_block('built-in/S-Function',[sys,'/',['Call modem/Precoder/Array',13,'function1']])
set_param([sys,'/',['Call modem/Precoder/Array',13,'function1']],...
		'orientation',2,...
		'hide name',0,...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nfunction',...
		'Mask Type','Array function')
set_param([sys,'/',['Call modem/Precoder/Array',13,'function1']],...
		'Mask Dialogue','Array function block for sin, cos, tan, exp, asin, acos, ln, log10, sgn, abs,\nfloor, ceil, and round.|Operation (string):',...
		'Mask Translate','opr=@1;')
set_param([sys,'/',['Call modem/Precoder/Array',13,'function1']],...
		'Mask Help','This block calculates the given function value. The vector length of the output is the same as the input.',...
		'Mask Entries','''round''\/')
set_param([sys,'/',['Call modem/Precoder/Array',13,'function1']],...
		'position',[155,210,235,250])

add_block('built-in/Gain',[sys,'/','Call modem/Precoder/Gain2'])
set_param([sys,'/','Call modem/Precoder/Gain2'],...
		'orientation',2,...
		'hide name',0,...
		'Gain','1/2/(1+(b>=56))',...
		'position',[245,220,265,240])

add_block('built-in/Gain',[sys,'/','Call modem/Precoder/Gain1'])
set_param([sys,'/','Call modem/Precoder/Gain1'],...
		'orientation',2,...
		'hide name',0,...
		'Gain','1.e-7',...
		'position',[295,220,315,240])

add_block('built-in/Gain',[sys,'/','Call modem/Precoder/Gain'])
set_param([sys,'/','Call modem/Precoder/Gain'],...
		'orientation',1,...
		'hide name',0,...
		'Gain','1.e7',...
		'position',[415,200,435,220])

add_block('built-in/S-Function',[sys,'/','Call modem/Precoder/Complex filter'])
set_param([sys,'/','Call modem/Precoder/Complex filter'],...
		'orientation',1,...
		'hide name',0,...
		'function name','cmplxflt',...
		'parameters','num, den, ts',...
		'Mask Display','plot(0,0,100,100,x,y,u,v);Filter')
set_param([sys,'/','Call modem/Precoder/Complex filter'],...
		'Mask Type','Complex filter')
set_param([sys,'/','Call modem/Precoder/Complex filter'],...
		'Mask Dialogue','Vector expression for numerator and\ndenominator. Complex coefficients are in ascending power of 1/z.|Numerator:|Denominator:|Sample time:')
set_param([sys,'/','Call modem/Precoder/Complex filter'],...
		'Mask Translate','num=@1;den=@2;ts=@3;num=[real(num(:))'';imag(num(:))''];den=[real(den(:))'';imag(den(:))''];if max(abs(den(2,:))) <=0, den=den(1,:); end;if max(abs(num(2,:))) <=0, num=num(1,:); end;[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));[x,y]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/','Call modem/Precoder/Complex filter'],...
		'Mask Help','This block takes real or complex signal input and outputs complex signal. The numerator can be a real or a complex vector with the coeficient ordered in ascending power of 1/z. Same for the denominator.')
set_param([sys,'/','Call modem/Precoder/Complex filter'],...
		'Mask Entries','[0 h(1) h(2) h(3)]\/1\/.28/j/p/4/2\/',...
		'position',[385,145,465,185])

add_block('built-in/Note',[sys,'/','Call modem/Precoder/h(1), h(2) and h(3) are the precoder filter complex coeficients in Eq.(9-28//V.34)'])
set_param([sys,'/','Call modem/Precoder/h(1), h(2) and h(3) are the precoder filter complex coeficients in Eq.(9-28//V.34)'],...
		'position',[305,285,310,290])

add_block('built-in/Note',[sys,'/','Call modem/Precoder/The input to this block is the QAM mapping result u(n) from section 9.6.1//V.34.'])
set_param([sys,'/','Call modem/Precoder/The input to this block is the QAM mapping result u(n) from section 9.6.1//V.34.'],...
		'position',[310,305,315,310])

add_block('built-in/Note',[sys,'/','Call modem/Precoder/This block implements Figure 7//V.34'])
set_param([sys,'/','Call modem/Precoder/This block implements Figure 7//V.34'],...
		'position',[280,5,285,10])

add_block('built-in/Outport',[sys,'/','Call modem/Precoder/x(n)'])
set_param([sys,'/','Call modem/Precoder/x(n)'],...
		'position',[500,115,520,135])

add_block('built-in/Outport',[sys,'/','Call modem/Precoder/y(n)'])
set_param([sys,'/','Call modem/Precoder/y(n)'],...
		'Port','2',...
		'position',[455,75,475,95])

add_block('built-in/Outport',[sys,'/','Call modem/Precoder/c(n)'])
set_param([sys,'/','Call modem/Precoder/c(n)'],...
		'Port','3',...
		'position',[380,45,400,65])

add_block('built-in/Note',[sys,'/','Call modem/Precoder/b is the number of bit in high mapping frame in Table 8//V.34'])
set_param([sys,'/','Call modem/Precoder/b is the number of bit in high mapping frame in Table 8//V.34'],...
		'position',[255,265,260,270])

add_block('built-in/Inport',[sys,'/','Call modem/Precoder/u(m)'])
set_param([sys,'/','Call modem/Precoder/u(m)'],...
		'position',[55,95,75,115])
add_line([sys,'/','Call modem/Precoder'],[150,160;150,125;200,125])
add_line([sys,'/','Call modem/Precoder'],[150,230;150,190])
add_line([sys,'/','Call modem/Precoder'],[240,230;240,230])
add_line([sys,'/','Call modem/Precoder'],[290,230;270,230])
add_line([sys,'/','Call modem/Precoder'],[325,230;320,230])
add_line([sys,'/','Call modem/Precoder'],[425,190;425,195])
add_line([sys,'/','Call modem/Precoder'],[425,225;415,230])
add_line([sys,'/','Call modem/Precoder'],[80,105;200,105])
add_line([sys,'/','Call modem/Precoder'],[230,115;310,115])
add_line([sys,'/','Call modem/Precoder'],[340,125;425,125;425,140])
add_line([sys,'/','Call modem/Precoder'],[280,230;280,135;310,135])
add_line([sys,'/','Call modem/Precoder'],[280,115;280,85;450,85])
add_line([sys,'/','Call modem/Precoder'],[150,125;150,55;375,55])
add_line([sys,'/','Call modem/Precoder'],[425,125;495,125])


%     Finished composite block 'Call modem/Precoder'.

set_param([sys,'/','Call modem/Precoder'],...
		'position',[490,76,530,194])

add_block('built-in/Note',[sys,'/','Call modem/c(m)'])
set_param([sys,'/','Call modem/c(m)'],...
		'position',[545,170,550,175])

add_block('built-in/Logical Operator',[sys,'/',['Call modem/Logical',13,'Operator']])
set_param([sys,'/',['Call modem/Logical',13,'Operator']],...
		'ForeGround',6,...
		'hide name',0,...
		'Operator','NOT',...
		'Number of Input Ports','1',...
		'position',[465,272,495,308])


%     Subsystem  ['Call modem/QASK',13,'arbitrary-map'].

new_system([sys,'/',['Call modem/QASK',13,'arbitrary-map']])
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map']],'Location',[58,103,403,268])

add_block('built-in/Outport',[sys,'/',['Call modem/QASK',13,'arbitrary-map/Imag']])
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map/Imag']],...
		'Port','2',...
		'position',[275,100,295,120])

add_block('built-in/Outport',[sys,'/',['Call modem/QASK',13,'arbitrary-map/Real']])
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map/Real']],...
		'position',[275,20,295,40])

add_block('built-in/Look Up Table',[sys,'/',['Call modem/QASK',13,'arbitrary-map/imag part1']])
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map/imag part1']],...
		'Input_Values','x',...
		'Output_Values','y2',...
		'position',[175,97,210,123])

add_block('built-in/Look Up Table',[sys,'/',['Call modem/QASK',13,'arbitrary-map/real part']])
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map/real part']],...
		'Input_Values','x',...
		'Output_Values','y1',...
		'position',[180,17,215,43])

add_block('built-in/Inport',[sys,'/',['Call modem/QASK',13,'arbitrary-map/in_1']])
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map/in_1']],...
		'position',[25,20,45,40])

add_block('built-in/Zero-Order Hold',[sys,'/',['Call modem/QASK',13,'arbitrary-map/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map/Zero-Order',13,'Hold1']],...
		'Sample time','td',...
		'position',[80,14,115,46])
add_line([sys,'/',['Call modem/QASK',13,'arbitrary-map']],[215,110;270,110])
add_line([sys,'/',['Call modem/QASK',13,'arbitrary-map']],[220,30;270,30])
add_line([sys,'/',['Call modem/QASK',13,'arbitrary-map']],[120,30;175,30])
add_line([sys,'/',['Call modem/QASK',13,'arbitrary-map']],[145,30;145,110;170,110])
add_line([sys,'/',['Call modem/QASK',13,'arbitrary-map']],[50,30;75,30])
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map']],...
		'Mask Display','QASK\nA-map',...
		'Mask Type','QASK A-map')
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map']],...
		'Mask Dialogue','QASK mapping for arbitrary defined\nmap. Assume input digit is K. 1st\noutport outputs in-phase(K+1). 2nd\noutport outputs quadrature(K+1).|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;ly=length(y1);x=[-10 1:ly-1;1:ly-1 10*ly]-.5;x=x(:);y1=y1(:)'';y1=[y1;y1];y1=y1(:);y2=y2(:)'';y2=[y2;y2];y2=y2(:);')
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map']],...
		'Mask Help','This block maps a digital signal onto in-phase and quadratic components, which are outputs in the first and second output port respectively. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The input signal is in the range of [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map']],...
		'Mask Entries','v34r\/v34i\/.28/j/p/4/2\/')


%     Finished composite block ['Call modem/QASK',13,'arbitrary-map'].

set_param([sys,'/',['Call modem/QASK',13,'arbitrary-map']],...
		'hide name',0,...
		'position',[275,73,355,117])

add_block('built-in/Note',[sys,'/','Call modem/Z(m)'])
set_param([sys,'/','Call modem/Z(m)'],...
		'position',[365,150,370,155])

add_block('built-in/Note',[sys,'/','Call modem/I1ij(m)'])
set_param([sys,'/','Call modem/I1ij(m)'],...
		'position',[370,120,375,125])


%     Subsystem  ['Call modem/Differential',13,'encoder'].

new_system([sys,'/',['Call modem/Differential',13,'encoder']])
set_param([sys,'/',['Call modem/Differential',13,'encoder']],'Location',[36,184,495,310])

add_block('built-in/Inport',[sys,'/',['Call modem/Differential',13,'encoder/I2ij(m)_and_I3ij(m)']])
set_param([sys,'/',['Call modem/Differential',13,'encoder/I2ij(m)_and_I3ij(m)']],...
		'position',[60,30,80,50])

add_block('built-in/S-Function',[sys,'/',['Call modem/Differential',13,'encoder/Integer vector',13,'to scalar1']])
set_param([sys,'/',['Call modem/Differential',13,'encoder/Integer vector',13,'to scalar1']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter')
set_param([sys,'/',['Call modem/Differential',13,'encoder/Integer vector',13,'to scalar1']],...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Call modem/Differential',13,'encoder/Integer vector',13,'to scalar1']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:')
set_param([sys,'/',['Call modem/Differential',13,'encoder/Integer vector',13,'to scalar1']],...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Call modem/Differential',13,'encoder/Integer vector',13,'to scalar1']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Call modem/Differential',13,'encoder/Integer vector',13,'to scalar1']],...
		'Mask Entries','2\/',...
		'position',[130,18,210,62])

add_block('built-in/Sum',[sys,'/',['Call modem/Differential',13,'encoder/Sum1']])
set_param([sys,'/',['Call modem/Differential',13,'encoder/Sum1']],...
		'hide name',0,...
		'position',[240,32,260,68])

add_block('built-in/S-Function',[sys,'/',['Call modem/Differential',13,'encoder/Modulo',13,'operation']])
set_param([sys,'/',['Call modem/Differential',13,'encoder/Modulo',13,'operation']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Call modem/Differential',13,'encoder/Modulo',13,'operation']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Call modem/Differential',13,'encoder/Modulo',13,'operation']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Call modem/Differential',13,'encoder/Modulo',13,'operation']],...
		'Mask Entries','4\/',...
		'position',[285,35,345,65])

add_block('built-in/Unit Delay',[sys,'/',['Call modem/Differential',13,'encoder/Unit Delay']])
set_param([sys,'/',['Call modem/Differential',13,'encoder/Unit Delay']],...
		'orientation',2,...
		'hide name',0,...
		'Sample time','.28/j/p/4',...
		'position',[275,75,325,95])

add_block('built-in/Outport',[sys,'/',['Call modem/Differential',13,'encoder/Z(m)']])
set_param([sys,'/',['Call modem/Differential',13,'encoder/Z(m)']],...
		'position',[395,40,415,60])
add_line([sys,'/',['Call modem/Differential',13,'encoder']],[265,50;280,50])
add_line([sys,'/',['Call modem/Differential',13,'encoder']],[350,50;390,50])
add_line([sys,'/',['Call modem/Differential',13,'encoder']],[365,50;365,85;330,85])
add_line([sys,'/',['Call modem/Differential',13,'encoder']],[270,85;220,85;220,60;235,60])
add_line([sys,'/',['Call modem/Differential',13,'encoder']],[215,40;235,40])
add_line([sys,'/',['Call modem/Differential',13,'encoder']],[85,40;125,40])


%     Finished composite block ['Call modem/Differential',13,'encoder'].

set_param([sys,'/',['Call modem/Differential',13,'encoder']],...
		'position',[310,128,345,182])

add_block('built-in/Note',[sys,'/','Call modem/Q(n)'])
set_param([sys,'/','Call modem/Q(n)'],...
		'position',[250,90,255,95])

add_block('built-in/Demux',[sys,'/','Call modem/Demux'])
set_param([sys,'/','Call modem/Demux'],...
		'hide name',0,...
		'outputs','[1 2]',...
		'position',[240,130,290,165])

add_block('built-in/Note',[sys,'/','Call modem/Iij'])
set_param([sys,'/','Call modem/Iij'],...
		'position',[225,145,230,150])


%     Subsystem  ['Call modem/Scramble',13,'Parser and',13,'shell mapping'].

new_system([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],'Location',[18,62,804,236])

add_block('built-in/Note',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/This block implements the rotation part of Section 9.3//V.34 and 9.4//V.34']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/This block implements the rotation part of Section 9.3//V.34 and 9.4//V.34']],...
		'position',[375,10,380,15])

add_block('built-in/Outport',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Iij-length 3']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Iij-length 3']],...
		'Port','2',...
		'position',[620,105,640,125])

add_block('built-in/Note',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Qijk-length q']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Qijk-length q']],...
		'position',[440,60,445,65])

add_block('built-in/Note',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/mijk-length 1']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/mijk-length 1']],...
		'position',[435,85,440,90])

add_block('built-in/Sum',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Sum1']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Sum1']],...
		'hide name',0,...
		'position',[620,62,640,98])

add_block('built-in/Gain',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Gain1']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Gain1']],...
		'hide name',0,...
		'Gain','2^q',...
		'position',[490,80,510,100])

add_block('built-in/S-Function',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Integer vector',13,'to scalar']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Integer vector',13,'to scalar']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter')
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Integer vector',13,'to scalar']],...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Integer vector',13,'to scalar']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:')
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Integer vector',13,'to scalar']],...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Integer vector',13,'to scalar']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Integer vector',13,'to scalar']],...
		'Mask Entries','2\/',...
		'position',[515,43,595,87])

add_block('built-in/Demux',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Demux']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Demux']],...
		'hide name',0,...
		'outputs','[q 1 3]',...
		'position',[350,54,395,126])

add_block('built-in/Inport',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Data-input',13,'length b']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Data-input',13,'length b']],...
		'position',[25,70,45,90])

add_block('built-in/Inport',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Frame info']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Frame info']],...
		'Port','2',...
		'position',[80,95,100,115])

add_block('built-in/Outport',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Q(n)-length 1']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Q(n)-length 1']],...
		'position',[690,70,710,90])

add_block('built-in/S-Function',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/S-function']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/S-function']],...
		'function name','v34trans',...
		'parameters','rt,sm''',...
		'position',[265,80,330,100])

add_block('built-in/Mux',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Mux']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/Mux']],...
		'hide name',0,...
		'inputs','3',...
		'position',[205,73,240,107])

add_block('built-in/Inport',[sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/k inform']])
set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping/k inform']],...
		'Port','3',...
		'position',[125,120,145,140])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[400,115;615,115])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[335,90;345,90])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[245,90;260,90])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[50,80;200,80])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[105,105;135,105;135,90;200,90])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[150,130;170,130;170,100;200,100])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[400,65;510,65])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[600,65;600,70;615,70])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[400,90;485,90])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[515,90;615,90])
add_line([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],[645,80;685,80])


%     Finished composite block ['Call modem/Scramble',13,'Parser and',13,'shell mapping'].

set_param([sys,'/',['Call modem/Scramble',13,'Parser and',13,'shell mapping']],...
		'position',[170,95,210,165])

add_block('built-in/Inport',[sys,'/','Call modem/Inport'])
set_param([sys,'/','Call modem/Inport'],...
		'position',[15,255,35,275])


%     Subsystem  ['Call modem/Synchronization',13,'pulses'].

new_system([sys,'/',['Call modem/Synchronization',13,'pulses']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses']],'Location',[59,70,926,261])

add_block('built-in/Inport',[sys,'/',['Call modem/Synchronization',13,'pulses/in_1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/in_1']],...
		'hide name',0,...
		'position',[175,35,195,55])


%     Subsystem  ['Call modem/Synchronization',13,'pulses/D flip-flop'].

new_system([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],'Location',[144,208,694,397])

add_block('built-in/Memory',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Memory1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Memory1']],...
		'position',[90,10,130,40])

add_block('built-in/Memory',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Memory']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Memory']],...
		'orientation',2,...
		'position',[365,115,405,145])

add_block('built-in/Fcn',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Fcn1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Fcn1']],...
		'Expr','u[1]<.2',...
		'position',[150,13,180,37])

add_block('built-in/Fcn',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Fcn']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Fcn']],...
		'orientation',2,...
		'Expr','u[1]>.2',...
		'position',[280,118,325,142])

add_block('built-in/Outport',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/out_2']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/out_2']],...
		'Port','2',...
		'position',[515,65,535,85])

add_block('built-in/Outport',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/out_1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/out_1']],...
		'position',[485,50,505,70])

add_block('built-in/Combinatorial Logic',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Logic']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Logic']],...
		'Truth Table','[0 1;1 0;0 1;1 0;0 1;0 1;1 0;1 0]',...
		'position',[325,50,380,90])

add_block('built-in/Demux',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Demux']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Demux']],...
		'outputs','2',...
		'position',[405,50,445,85])

add_block('built-in/Mux',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Mux1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/Mux1']],...
		'inputs','3',...
		'position',[275,47,305,93])

add_block('built-in/Inport',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/in_2']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/in_2']],...
		'position',[160,60,180,80])


%     Subsystem  ['Call modem/Synchronization',13,'pulses/D flip-flop/AND'].

new_system([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND']],'Location',[59,237,323,377])

add_block('built-in/Inport',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND/in_2']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND/in_2']],...
		'Port','2',...
		'position',[15,70,35,90])

add_block('built-in/Inport',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND/in_1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Mux',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND/Mux']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND/Mux']],...
		'inputs','2',...
		'position',[65,55,95,90])

add_block('built-in/Combinatorial Logic',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND/AND']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND/AND']],...
		'Truth Table','[0;0;0;1]',...
		'position',[130,55,185,95])

add_block('built-in/Outport',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND/out_1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND/out_1']],...
		'position',[215,65,235,85])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND']],[190,75;210,75])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND']],[40,80;60,80])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND']],[40,65;60,65])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND']],[100,75;125,75])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND']],...
		'Mask Display','AND',...
		'Mask Type','AND',...
		'Mask Dialogue','AND Gate',...
		'Mask Help','Calculates the logical AND of the two inputs.')


%     Finished composite block ['Call modem/Synchronization',13,'pulses/D flip-flop/AND'].

set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/AND']],...
		'position',[215,39,250,66])

add_block('built-in/Inport',[sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/in_1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop/in_1']],...
		'Port','2',...
		'position',[20,50,40,70])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[275,130;250,130;250,85;270,85])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[360,130;330,130])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[255,55;270,55])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[45,60;60,60;60,25;85,25])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[45,60;210,60])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[185,25;200,25;210,45])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[135,25;145,25])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[450,75;510,75])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[450,60;480,60])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[185,70;270,70])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[450,60;460,60;460,130;410,130])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[385,70;400,70])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],[310,70;320,70])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],...
		'Mask Display','D   1\n\n>   0',...
		'Mask Type','D flip-flop',...
		'Mask Dialogue','D flip-flop|Initial State for Output "1":')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],...
		'Mask Translate','ini=(@1~=0);')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],...
		'Mask Help','While the clock signal is high, the output will be the same as the input signal.  The flip-flop then latches to the value of the input at the trailing edge of the clock pulse for the remainder of the clock cycle.')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],...
		'Mask Entries','0\/')


%     Finished composite block ['Call modem/Synchronization',13,'pulses/D flip-flop'].

set_param([sys,'/',['Call modem/Synchronization',13,'pulses/D flip-flop']],...
		'hide name',0,...
		'position',[355,31,390,84])

add_block('built-in/Product',[sys,'/',['Call modem/Synchronization',13,'pulses/Product']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Product']],...
		'hide name',0,...
		'position',[480,95,505,115])

add_block('built-in/Product',[sys,'/',['Call modem/Synchronization',13,'pulses/Product1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Product1']],...
		'hide name',0,...
		'position',[480,130,505,150])

add_block('built-in/Demux',[sys,'/',['Call modem/Synchronization',13,'pulses/Demux1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Demux1']],...
		'hide name',0,...
		'outputs','[1 2]',...
		'position',[160,117,210,153])


%     Subsystem  ['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time'].

new_system([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'Mask Entries','.28/j/p\/[1 8 4]\/[0 0 0]\/')


%     Finished composite block ['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time'].

set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'hide name',0,...
		'position',[60,113,140,157])

add_block('built-in/Demux',[sys,'/',['Call modem/Synchronization',13,'pulses/Demux2']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Demux2']],...
		'hide name',0,...
		'outputs','2',...
		'position',[540,122,590,158])

add_block('built-in/Outport',[sys,'/',['Call modem/Synchronization',13,'pulses/k signal']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/k signal']],...
		'Port','2',...
		'position',[695,120,715,140])

add_block('built-in/Outport',[sys,'/',['Call modem/Synchronization',13,'pulses/i signal']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/i signal']],...
		'position',[745,95,765,115])

add_block('built-in/Outport',[sys,'/',['Call modem/Synchronization',13,'pulses/j signal']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/j signal']],...
		'Port','3',...
		'position',[635,140,655,160])


%     Subsystem  ['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector'].

new_system([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Edge det.',...
		'Mask Type','Edge detection')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'Mask Dialogue','Detect the rising edge of the input\nsignal. Output one when the rising\nedge is detected.|Threshold:')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'Mask Help','This block outputs one when the input signal reaches a value larger than or equal to the given threshold value at the current time and the value was below the threshold one time step before. Otherwise, the block outputs zero.')
set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'Mask Entries','0.5\/')


%     Finished composite block ['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector'].

set_param([sys,'/',['Call modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'hide name',0,...
		'position',[230,108,310,142])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[395,45;425,45;425,100;475,100])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[215,125;225,125])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[315,125;335,125;335,70;350,70])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[145,135;155,135])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[200,45;350,45])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[510,105;740,105])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[425,100;425,135;475,135])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[335,110;475,110])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[215,145;475,145])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[510,140;535,140])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[595,130;690,130])
add_line([sys,'/',['Call modem/Synchronization',13,'pulses']],[595,150;630,150])


%     Finished composite block ['Call modem/Synchronization',13,'pulses'].

set_param([sys,'/',['Call modem/Synchronization',13,'pulses']],...
		'ForeGround',6,...
		'position',[75,230,115,300])

add_block('built-in/S-Function',[sys,'/',['Call modem/Triggered read',13,'from wksp']])
set_param([sys,'/',['Call modem/Triggered read',13,'from wksp']],...
		'hide name',0,...
		'function name','trigwksp',...
		'parameters','var,thd,cyclFlag,ini',...
		'Mask Display','plot(0,0,100,100,x,y,v,w);   Rd wksp')
set_param([sys,'/',['Call modem/Triggered read',13,'from wksp']],...
		'Mask Type','Read from workspace')
set_param([sys,'/',['Call modem/Triggered read',13,'from wksp']],...
		'Mask Dialogue','The rising edge of the input pulse triggers\nthe block to output the next row from the specified workspace variable.|Workspace variable:|Threshold for the input trigger pulse:|Cyclic control (1: cyclic read, 0: output zeros after eof):|Output value before first trigger:')
set_param([sys,'/',['Call modem/Triggered read',13,'from wksp']],...
		'Mask Translate','var=@1;thd=@2;cyclFlag=@3;ini=@4;[x,y]=srcsicon(7);[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Call modem/Triggered read',13,'from wksp']],...
		'Mask Help','This block reads the data from a workspace variable. The output is refreshed at the rising edge of the input pulse. When the end of the variable is reached, you can have the block output all zeros or start from the beginning of the variable.')
set_param([sys,'/',['Call modem/Triggered read',13,'from wksp']],...
		'Mask Entries','randint(300,b,2)\/.1\/1\/0\/',...
		'position',[30,86,110,124])

add_block('built-in/Note',[sys,'/','Call modem/v(n)'])
set_param([sys,'/','Call modem/v(n)'],...
		'position',[375,80,380,85])
add_line([sys,'/','Call modem'],[115,105;165,105])
add_line([sys,'/','Call modem'],[350,155;400,155;400,145;420,145])
add_line([sys,'/','Call modem'],[295,140;300,140;300,125;420,125])
add_line([sys,'/','Call modem'],[470,135;485,135])
add_line([sys,'/','Call modem'],[360,105;420,105])
add_line([sys,'/','Call modem'],[360,85;420,85])
add_line([sys,'/','Call modem'],[790,95;805,95])
add_line([sys,'/','Call modem'],[645,240;680,240;680,320;395,320;395,185;420,185])
add_line([sys,'/','Call modem'],[695,85;700,85])
add_line([sys,'/','Call modem'],[695,105;700,105])
add_line([sys,'/','Call modem'],[620,95;640,95])
add_line([sys,'/','Call modem'],[535,95;575,95])
add_line([sys,'/','Call modem'],[535,135;565,135;565,190;595,190])
add_line([sys,'/','Call modem'],[535,175;560,175;560,215;595,215])
add_line([sys,'/','Call modem'],[40,265;70,265])
add_line([sys,'/','Call modem'],[120,265;595,265])
add_line([sys,'/','Call modem'],[120,290;460,290])
add_line([sys,'/','Call modem'],[500,290;595,290])
add_line([sys,'/','Call modem'],[215,115;225,115;225,95;270,95])
add_line([sys,'/','Call modem'],[215,150;235,150])
add_line([sys,'/','Call modem'],[295,155;305,155])
add_line([sys,'/','Call modem'],[120,240;135,240;135,130;165,130])
add_line([sys,'/','Call modem'],[135,130;10,130;10,105;25,105])
add_line([sys,'/','Call modem'],[145,265;145,155;165,155])
add_line([sys,'/','Call modem'],[135,240;595,240])
add_line([sys,'/','Call modem'],[385,290;385,165;420,165])
add_line([sys,'/','Call modem'],[325,40;350,40])
add_line([sys,'/','Call modem'],[225,40;235,40])
add_line([sys,'/','Call modem'],[115,105;120,105;120,30;135,30])
add_line([sys,'/','Call modem'],[120,290;125,290;135,50])
set_param([sys,'/','Call modem'],...
		'Mask Display','Call\nmodem',...
		'Mask Type','Data transfer for calling modem')
set_param([sys,'/','Call modem'],...
		'Mask Dialogue','The input signal enable the block to\ntransfer data.|Symbol rate, S (2400, 2800, 3000, 3200):|Data rate, R (2400, 4800, 9600, 14400, 28800):|Convolution encoder (1:16 state; 2:32 state; 3:64 state):|Precode filter coefficient (1x3 vector):')
set_param([sys,'/','Call modem'],...
		'Mask Translate','[rt,sm,tf,v34r,v34i]=v34param(@1,@2,@3);h=@4;j=rt(3);p=rt(4);b=rt(6);q=rt(7);K=rt(8);M=rt(9);')
set_param([sys,'/','Call modem'],...
		'Mask Help','This block simulate the data translation period of calling modem after modem phase 4 training. Unmask this block for details. ')
set_param([sys,'/','Call modem'],...
		'Mask Entries','SRATE\/BRATE\/CON_CODE\/[1 .8 .4]+sqrt(-1)*[1 .5 .2]\/')


%     Finished composite block 'Call modem'.

set_param([sys,'/','Call modem'],...
		'hide name',0,...
		'position',[115,94,190,136])


%     Subsystem  'Answer modem'.

new_system([sys,'/','Answer modem'])
set_param([sys,'/','Answer modem'],'Location',[148,382,1086,757])

add_block('built-in/Note',[sys,'/','Answer modem/u(n)'])
set_param([sys,'/','Answer modem/u(n)'],...
		'position',[325,50,330,55])


%     Subsystem  ['Answer modem/Descramble',13,'Parser and',13,'shell demapping'].

new_system([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],'Location',[137,419,818,640])

add_block('built-in/Mux',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Mux']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Mux']],...
		'hide name',0,...
		'inputs','5',...
		'position',[420,90,460,190])

add_block('built-in/Inport',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Iij']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Iij']],...
		'Port','2',...
		'position',[180,130,200,150])

add_block('built-in/Inport',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Frame pulse']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Frame pulse']],...
		'Port','3',...
		'position',[220,150,240,170])

add_block('built-in/Inport',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/k pulse']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/k pulse']],...
		'Port','4',...
		'position',[270,170,290,190])

add_block('built-in/Note',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Qijk-length q']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Qijk-length q']],...
		'position',[365,95,370,100])

add_block('built-in/Note',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/mijk']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/mijk']],...
		'position',[355,115,360,120])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/S-function']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/S-function']],...
		'function name','v34recv',...
		'parameters','rt,sm''',...
		'position',[495,130,560,150])

add_block('built-in/Outport',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Recovered data',13,'length b']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Recovered data',13,'length b']],...
		'position',[605,130,625,150])

add_block('built-in/Fcn',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Fcn']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Fcn']],...
		'hide name',0,...
		'Expr','floor(u[1])',...
		'position',[215,107,275,133])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Modulo',13,'operation']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Modulo',13,'operation']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Modulo',13,'operation']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Modulo',13,'operation']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Modulo',13,'operation']],...
		'Mask Entries','2^q\/',...
		'position',[110,45,190,85])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Integer scalar',13,'to vector']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter')
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Integer scalar',13,'to vector']],...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Integer scalar',13,'to vector']],...
		'Mask Entries','q\/2\/',...
		'position',[215,43,295,87])

add_block('built-in/Gain',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Gain1']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Gain1']],...
		'hide name',0,...
		'Gain','1/(2^q)',...
		'position',[145,108,165,132])

add_block('built-in/Inport',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Q(n)']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/Q(n)']],...
		'position',[25,55,45,75])

add_block('built-in/Note',[sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/This block implements the rotation part of Section 9.3 and 9.4']])
set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping/This block implements the rotation part of Section 9.3 and 9.4']],...
		'position',[300,10,305,15])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[465,140;490,140])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[565,140;600,140])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[50,65;105,65])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[195,65;210,65])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[300,65;320,65;320,100;415,100])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[170,120;210,120])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[280,120;415,120])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[205,140;415,140])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[245,160;415,160])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[295,180;415,180])
add_line([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],[75,65;75,120;140,120])


%     Finished composite block ['Answer modem/Descramble',13,'Parser and',13,'shell demapping'].

set_param([sys,'/',['Answer modem/Descramble',13,'Parser and',13,'shell demapping']],...
		'position',[755,175,790,240])

add_block('built-in/Mux',[sys,'/','Answer modem/Mux1'])
set_param([sys,'/','Answer modem/Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[680,180,710,220])


%     Subsystem  'Answer modem/Rotation'.

new_system([sys,'/','Answer modem/Rotation'])
set_param([sys,'/','Answer modem/Rotation'],'Location',[15,130,1005,314])

add_block('built-in/Inport',[sys,'/','Answer modem/Rotation/u(n)'])
set_param([sys,'/','Answer modem/Rotation/u(n)'],...
		'position',[10,25,30,45])

add_block('built-in/Demux',[sys,'/','Answer modem/Rotation/Demux2'])
set_param([sys,'/','Answer modem/Rotation/Demux2'],...
		'hide name',0,...
		'outputs','2',...
		'position',[50,14,95,56])


%     Subsystem  ['Answer modem/Rotation/QASK',13,'arbitrary-demap'].

new_system([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],'Location',[45,449,594,684])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/real']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/imag']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Sum1']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Sum6']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Product']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Product1']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Sum2']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Minimum1']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/out_1']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/real_pt']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/imag_pt']])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[70,45;115,45])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[70,130;115,130])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[160,45;225,45])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[160,130;225,130])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[395,95;410,95])
add_line([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],[480,95;490,95])
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],...
		'Mask Entries','v34r\/v34i\/.28/p/j/4/2\/')


%     Finished composite block ['Answer modem/Rotation/QASK',13,'arbitrary-demap'].

set_param([sys,'/',['Answer modem/Rotation/QASK',13,'arbitrary-demap']],...
		'hide name',0,...
		'position',[115,15,195,55])

add_block('built-in/Constant',[sys,'/','Answer modem/Rotation/Constant'])
set_param([sys,'/','Answer modem/Rotation/Constant'],...
		'Value','4',...
		'position',[420,120,440,140])

add_block('built-in/Outport',[sys,'/','Answer modem/Rotation/Z(m)'])
set_param([sys,'/','Answer modem/Rotation/Z(m)'],...
		'position',[850,25,870,45])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Rotation/Modulo',13,'operation1']])
set_param([sys,'/',['Answer modem/Rotation/Modulo',13,'operation1']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Answer modem/Rotation/Modulo',13,'operation1']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Answer modem/Rotation/Modulo',13,'operation1']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Answer modem/Rotation/Modulo',13,'operation1']],...
		'Mask Entries','4\/',...
		'position',[210,20,270,50])

add_block('built-in/Note',[sys,'/',['Answer modem/Rotation/0,1,2,3 means',13,'0, 90, 180, 270',13,'shifting']])
set_param([sys,'/',['Answer modem/Rotation/0,1,2,3 means',13,'0, 90, 180, 270',13,'shifting']],...
		'position',[320,30,325,35])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Rotation/Zero-Order',13,'Hold']])
set_param([sys,'/',['Answer modem/Rotation/Zero-Order',13,'Hold']],...
		'hide name',0,...
		'Sample time','.28/p/j/4',...
		'position',[400,19,435,51])

add_block('built-in/Sum',[sys,'/','Answer modem/Rotation/Sum2'])
set_param([sys,'/','Answer modem/Rotation/Sum2'],...
		'hide name',0,...
		'inputs','-++',...
		'position',[465,67,485,103])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Rotation/Modulo',13,'operation']])
set_param([sys,'/',['Answer modem/Rotation/Modulo',13,'operation']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Answer modem/Rotation/Modulo',13,'operation']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Answer modem/Rotation/Modulo',13,'operation']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Answer modem/Rotation/Modulo',13,'operation']],...
		'Mask Entries','4\/',...
		'position',[500,67,565,103])

add_block('built-in/Gain',[sys,'/','Answer modem/Rotation/Gain1'])
set_param([sys,'/','Answer modem/Rotation/Gain1'],...
		'hide name',0,...
		'Gain','.51',...
		'position',[600,68,635,102])

add_block('built-in/Fcn',[sys,'/','Answer modem/Rotation/Fcn'])
set_param([sys,'/','Answer modem/Rotation/Fcn'],...
		'hide name',0,...
		'Expr','floor(u[1])',...
		'position',[650,75,710,95])


%     Subsystem  ['Answer modem/Rotation/K-step',13,'delay5'].

new_system([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],'Location',[12,432,357,702])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Rotation/K-step',13,'delay5/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5/Relational',13,'Operator']],...
		'position',[150,168,180,192])

add_block('built-in/Constant',[sys,'/',['Answer modem/Rotation/K-step',13,'delay5/Constant1']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Constant',[sys,'/',['Answer modem/Rotation/K-step',13,'delay5/Constant']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Switch',[sys,'/',['Answer modem/Rotation/K-step',13,'delay5/Switch']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Filter',[sys,'/',['Answer modem/Rotation/K-step',13,'delay5/K-step',13,'delay']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Outport',[sys,'/',['Answer modem/Rotation/K-step',13,'delay5/out_1']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Inport',[sys,'/',['Answer modem/Rotation/K-step',13,'delay5/in_1']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Digital Clock',[sys,'/',['Answer modem/Rotation/K-step',13,'delay5/Digital Clock']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],[185,180;220,180;220,130;265,130])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],[45,90;55,90])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],[300,130;320,130])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay')
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.')
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],...
		'Mask Entries','2*x-1\/.28/j/p/4/2\/0\/')


%     Finished composite block ['Answer modem/Rotation/K-step',13,'delay5'].

set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay5']],...
		'hide name',0,...
		'position',[760,71,840,99])

add_block('built-in/Sum',[sys,'/','Answer modem/Rotation/Sum3'])
set_param([sys,'/','Answer modem/Rotation/Sum3'],...
		'hide name',0,...
		'inputs','-+',...
		'position',[780,117,800,153])

add_block('built-in/Gain',[sys,'/','Answer modem/Rotation/Gain2'])
set_param([sys,'/','Answer modem/Rotation/Gain2'],...
		'hide name',0,...
		'Gain','2',...
		'position',[745,113,765,137])

add_block('built-in/Outport',[sys,'/',['Answer modem/Rotation/Uo(m)',13,'before TCM']])
set_param([sys,'/',['Answer modem/Rotation/Uo(m)',13,'before TCM']],...
		'Port','3',...
		'position',[845,125,865,145])


%     Subsystem  ['Answer modem/Rotation/K-step',13,'delay4'].

new_system([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],'Location',[12,432,357,702])

add_block('built-in/Digital Clock',[sys,'/',['Answer modem/Rotation/K-step',13,'delay4/Digital Clock']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])

add_block('built-in/Inport',[sys,'/',['Answer modem/Rotation/K-step',13,'delay4/in_1']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['Answer modem/Rotation/K-step',13,'delay4/out_1']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Filter',[sys,'/',['Answer modem/Rotation/K-step',13,'delay4/K-step',13,'delay']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Switch',[sys,'/',['Answer modem/Rotation/K-step',13,'delay4/Switch']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Constant',[sys,'/',['Answer modem/Rotation/K-step',13,'delay4/Constant']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Constant',[sys,'/',['Answer modem/Rotation/K-step',13,'delay4/Constant1']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Rotation/K-step',13,'delay4/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4/Relational',13,'Operator']],...
		'position',[150,168,180,192])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],[300,130;320,130])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],[45,90;55,90])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],[185,180;220,180;220,130;265,130])
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay')
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.')
set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],...
		'Mask Entries','x\/.28/j/p/4\/0\/')


%     Finished composite block ['Answer modem/Rotation/K-step',13,'delay4'].

set_param([sys,'/',['Answer modem/Rotation/K-step',13,'delay4']],...
		'hide name',0,...
		'position',[610,21,690,49])

add_block('built-in/Outport',[sys,'/','Answer modem/Rotation/I1(m)'])
set_param([sys,'/','Answer modem/Rotation/I1(m)'],...
		'Port','2',...
		'position',[950,75,970,95])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Rotation/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Answer modem/Rotation/Zero-Order',13,'Hold1']],...
		'hide name',0,...
		'Sample time','.28/p/j/4',...
		'position',[870,69,905,101])
add_line([sys,'/','Answer modem/Rotation'],[445,130;450,130;460,95])
add_line([sys,'/','Answer modem/Rotation'],[490,85;495,85])
add_line([sys,'/','Answer modem/Rotation'],[570,85;595,85])
add_line([sys,'/','Answer modem/Rotation'],[640,85;645,85])
add_line([sys,'/','Answer modem/Rotation'],[200,35;205,35])
add_line([sys,'/','Answer modem/Rotation'],[100,25;110,25])
add_line([sys,'/','Answer modem/Rotation'],[35,35;45,35])
add_line([sys,'/','Answer modem/Rotation'],[100,45;110,45])
add_line([sys,'/','Answer modem/Rotation'],[275,35;395,35])
add_line([sys,'/','Answer modem/Rotation'],[440,35;605,35])
add_line([sys,'/','Answer modem/Rotation'],[695,35;845,35])
add_line([sys,'/','Answer modem/Rotation'],[715,85;755,85])
add_line([sys,'/','Answer modem/Rotation'],[770,125;775,125])
add_line([sys,'/','Answer modem/Rotation'],[730,85;740,125])
add_line([sys,'/','Answer modem/Rotation'],[805,135;840,135])
add_line([sys,'/','Answer modem/Rotation'],[380,35;380,85;460,85])
add_line([sys,'/','Answer modem/Rotation'],[450,35;460,75])
add_line([sys,'/','Answer modem/Rotation'],[580,85;580,145;775,145])
add_line([sys,'/','Answer modem/Rotation'],[845,85;865,85])
add_line([sys,'/','Answer modem/Rotation'],[910,85;945,85])


%     Finished composite block 'Answer modem/Rotation'.

set_param([sys,'/','Answer modem/Rotation'],...
		'position',[355,21,390,89])


%     Subsystem  'Answer modem/Demapping'.

new_system([sys,'/','Answer modem/Demapping'])
set_param([sys,'/','Answer modem/Demapping'],'Location',[75,51,895,282])

add_block('built-in/Inport',[sys,'/','Answer modem/Demapping/Symbol for rotation angle'])
set_param([sys,'/','Answer modem/Demapping/Symbol for rotation angle'],...
		'Port','2',...
		'position',[555,185,575,205])


%     Subsystem  ['Answer modem/Demapping/QASK',13,'arbitrary-demap3'].

new_system([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],'Location',[45,449,594,684])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/imag_pt']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/real_pt']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Outport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/out_1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Minimum1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Sum2']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/Product',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Product1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Product',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Product']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Sum6']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Sum1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Inport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/imag']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Inport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/real']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/real']],...
		'position',[45,35,65,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Zero-Order',13,'Hold']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[480,95;490,95])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[395,95;410,95])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[270,140;270,145;295,145])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[270,55;270,60;295,60])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[160,130;225,130])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[160,45;225,45])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[70,130;115,130])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],[70,45;115,45])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],...
		'Mask Entries','v34r(3:4:length(v34r))\/v34i(3:4:length(v34i))\/.28/p/j/4/2\/')


%     Finished composite block ['Answer modem/Demapping/QASK',13,'arbitrary-demap3'].

set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap3']],...
		'hide name',0,...
		'position',[410,125,490,165])


%     Subsystem  ['Answer modem/Demapping/QASK',13,'arbitrary-demap2'].

new_system([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],'Location',[45,449,594,684])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Zero-Order',13,'Hold']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/real']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/imag']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Sum1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Sum6']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Product']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Product1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Sum2']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Minimum1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/out_1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/real_pt']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/imag_pt']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[70,45;115,45])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[70,130;115,130])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[160,45;225,45])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[160,130;225,130])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[270,55;270,60;295,60])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[270,140;270,145;295,145])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[395,95;410,95])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],[480,95;490,95])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],...
		'Mask Entries','v34r(2:4:length(v34r))\/v34i(2:4:length(v34i))\/.28/p/j/4/2\/')


%     Finished composite block ['Answer modem/Demapping/QASK',13,'arbitrary-demap2'].

set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap2']],...
		'hide name',0,...
		'position',[410,80,490,120])


%     Subsystem  ['Answer modem/Demapping/QASK',13,'arbitrary-demap1'].

new_system([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],'Location',[45,449,594,684])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/imag_pt']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/real_pt']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Outport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/out_1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Minimum1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Sum2']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/Product',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Product1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Product',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Product']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Sum6']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Sum1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Inport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/imag']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Inport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/real']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/real']],...
		'position',[45,35,65,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[480,95;490,95])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[395,95;410,95])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[270,140;270,145;295,145])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[270,55;270,60;295,60])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[160,130;225,130])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[160,45;225,45])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[70,130;115,130])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],[70,45;115,45])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],...
		'Mask Entries','v34r(1:4:length(v34r))\/v34i(1:4:length(v34i))\/.28/p/j/4/2\/')


%     Finished composite block ['Answer modem/Demapping/QASK',13,'arbitrary-demap1'].

set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap1']],...
		'hide name',0,...
		'position',[410,35,490,75])


%     Subsystem  ['Answer modem/Demapping/QASK',13,'arbitrary-demap4'].

new_system([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],'Location',[45,449,594,684])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Zero-Order',13,'Hold']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/real']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/imag']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Sum1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Sum6']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Product']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Product1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Sum2']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Minimum1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/out_1']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/real_pt']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/imag_pt']])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[70,45;115,45])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[70,130;115,130])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[160,45;225,45])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[160,130;225,130])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[270,55;270,60;295,60])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[270,140;270,145;295,145])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[395,95;410,95])
add_line([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],[480,95;490,95])
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],...
		'Mask Entries','v34r(4:4:length(v34r))\/v34i(4:4:length(v34i))\/.28/p/j/4/2\/')


%     Finished composite block ['Answer modem/Demapping/QASK',13,'arbitrary-demap4'].

set_param([sys,'/',['Answer modem/Demapping/QASK',13,'arbitrary-demap4']],...
		'hide name',0,...
		'position',[410,170,490,210])


%     Subsystem  ['Answer modem/Demapping/K-step',13,'delay4'].

new_system([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],'Location',[12,432,357,702])

add_block('built-in/Digital Clock',[sys,'/',['Answer modem/Demapping/K-step',13,'delay4/Digital Clock']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])

add_block('built-in/Inport',[sys,'/',['Answer modem/Demapping/K-step',13,'delay4/in_1']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['Answer modem/Demapping/K-step',13,'delay4/out_1']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Filter',[sys,'/',['Answer modem/Demapping/K-step',13,'delay4/K-step',13,'delay']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Switch',[sys,'/',['Answer modem/Demapping/K-step',13,'delay4/Switch']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/K-step',13,'delay4/Constant']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/K-step',13,'delay4/Constant1']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Demapping/K-step',13,'delay4/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4/Relational',13,'Operator']],...
		'position',[150,168,180,192])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],[300,130;320,130])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],[45,90;55,90])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],[185,180;220,180;220,130;265,130])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay')
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.')
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],...
		'Mask Entries','x*2\/.28/j/p/4/2\/0\/')


%     Finished composite block ['Answer modem/Demapping/K-step',13,'delay4'].

set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay4']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[165,28,245,62])

add_block('built-in/Demux',[sys,'/','Answer modem/Demapping/Demux3'])
set_param([sys,'/','Answer modem/Demapping/Demux3'],...
		'hide name',0,...
		'outputs','2',...
		'position',[95,34,140,76])

add_block('built-in/Inport',[sys,'/','Answer modem/Demapping/u(m)'])
set_param([sys,'/','Answer modem/Demapping/u(m)'],...
		'position',[45,45,65,65])


%     Subsystem  ['Answer modem/Demapping/K-step',13,'delay3'].

new_system([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],'Location',[12,432,357,702])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Demapping/K-step',13,'delay3/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3/Relational',13,'Operator']],...
		'position',[150,168,180,192])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/K-step',13,'delay3/Constant1']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Constant',[sys,'/',['Answer modem/Demapping/K-step',13,'delay3/Constant']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Switch',[sys,'/',['Answer modem/Demapping/K-step',13,'delay3/Switch']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Filter',[sys,'/',['Answer modem/Demapping/K-step',13,'delay3/K-step',13,'delay']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Outport',[sys,'/',['Answer modem/Demapping/K-step',13,'delay3/out_1']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Inport',[sys,'/',['Answer modem/Demapping/K-step',13,'delay3/in_1']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Digital Clock',[sys,'/',['Answer modem/Demapping/K-step',13,'delay3/Digital Clock']])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],[185,180;220,180;220,130;265,130])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],[45,90;55,90])
add_line([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],[300,130;320,130])
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay')
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.')
set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],...
		'Mask Entries','x*2\/.28/j/p/4/2\/0\/')


%     Finished composite block ['Answer modem/Demapping/K-step',13,'delay3'].

set_param([sys,'/',['Answer modem/Demapping/K-step',13,'delay3']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[260,48,340,82])

add_block('built-in/Mux',[sys,'/','Answer modem/Demapping/Mux1'])
set_param([sys,'/','Answer modem/Demapping/Mux1'],...
		'hide name',0,...
		'position',[555,104,585,161])


%     Subsystem  'Answer modem/Demapping/Signal switch'.

new_system([sys,'/','Answer modem/Demapping/Signal switch'])
set_param([sys,'/','Answer modem/Demapping/Signal switch'],'Location',[174,522,554,686])

add_block('built-in/Inport',[sys,'/','Answer modem/Demapping/Signal switch/in_1'])
set_param([sys,'/','Answer modem/Demapping/Signal switch/in_1'],...
		'position',[65,20,85,40])

add_block('built-in/Mux',[sys,'/','Answer modem/Demapping/Signal switch/Mux'])
set_param([sys,'/','Answer modem/Demapping/Signal switch/Mux'],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Outport',[sys,'/','Answer modem/Demapping/Signal switch/out_1'])
set_param([sys,'/','Answer modem/Demapping/Signal switch/out_1'],...
		'position',[320,65,340,85])

add_block('built-in/Inport',[sys,'/','Answer modem/Demapping/Signal switch/in_2'])
set_param([sys,'/','Answer modem/Demapping/Signal switch/in_2'],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/S-Function',[sys,'/','Answer modem/Demapping/Signal switch/S-function'])
set_param([sys,'/','Answer modem/Demapping/Signal switch/S-function'],...
		'function name','switchbx',...
		'parameters','sw,df',...
		'position',[205,60,275,90])
add_line([sys,'/','Answer modem/Demapping/Signal switch'],[90,30;120,30;120,65;140,65])
add_line([sys,'/','Answer modem/Demapping/Signal switch'],[85,85;140,85])
add_line([sys,'/','Answer modem/Demapping/Signal switch'],[180,75;200,75])
add_line([sys,'/','Answer modem/Demapping/Signal switch'],[280,75;315,75])
set_param([sys,'/','Answer modem/Demapping/Signal switch'],...
		'Mask Display','Switch\nbox',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/','Answer modem/Demapping/Signal switch'],...
		'Mask Dialogue','The output distribution pattern follows the ith row of the switch box, where i is the input from the second port.|Switch box (column number equals block output length):|Default value:')
set_param([sys,'/','Answer modem/Demapping/Signal switch'],...
		'Mask Translate','sw=@1;df=@2;')
set_param([sys,'/','Answer modem/Demapping/Signal switch'],...
		'Mask Help','This block follows the switch pattern of ith row in the switch box when the second input port has value i.  When the value in the second input is larger than the switch box row number or less than 1, the block outputs the defualt value.')
set_param([sys,'/','Answer modem/Demapping/Signal switch'],...
		'Mask Entries','[1;2;3;4]\/0\/')


%     Finished composite block 'Answer modem/Demapping/Signal switch'.

set_param([sys,'/','Answer modem/Demapping/Signal switch'],...
		'hide name',0,...
		'position',[630,156,695,189])

add_block('built-in/Outport',[sys,'/',['Answer modem/Demapping/Recovered data',13,'length q']])
set_param([sys,'/',['Answer modem/Demapping/Recovered data',13,'length q']],...
		'position',[735,165,755,185])
add_line([sys,'/','Answer modem/Demapping'],[70,55;90,55])
add_line([sys,'/','Answer modem/Demapping'],[250,45;405,45])
add_line([sys,'/','Answer modem/Demapping'],[345,65;405,65])
add_line([sys,'/','Answer modem/Demapping'],[360,65;360,110;405,110])
add_line([sys,'/','Answer modem/Demapping'],[360,110;360,155;405,155])
add_line([sys,'/','Answer modem/Demapping'],[355,45;355,90;405,90])
add_line([sys,'/','Answer modem/Demapping'],[355,90;355,135;405,135])
add_line([sys,'/','Answer modem/Demapping'],[355,135;355,180;405,180])
add_line([sys,'/','Answer modem/Demapping'],[495,55;520,55;520,110;550,110])
add_line([sys,'/','Answer modem/Demapping'],[495,100;510,100;510,125;550,125])
add_line([sys,'/','Answer modem/Demapping'],[495,145;510,145;510,140;550,140])
add_line([sys,'/','Answer modem/Demapping'],[495,190;515,190;515,155;550,155])
add_line([sys,'/','Answer modem/Demapping'],[590,135;605,135;605,165;625,165])
add_line([sys,'/','Answer modem/Demapping'],[700,175;730,175])
add_line([sys,'/','Answer modem/Demapping'],[580,195;610,195;610,180;625,180])
add_line([sys,'/','Answer modem/Demapping'],[145,45;160,45])
add_line([sys,'/','Answer modem/Demapping'],[145,65;255,65])
add_line([sys,'/','Answer modem/Demapping'],[360,155;360,200;405,200])


%     Finished composite block 'Answer modem/Demapping'.

set_param([sys,'/','Answer modem/Demapping'],...
		'position',[690,73,725,137])


%     Subsystem  ['Answer modem/Differential',13,'decoder'].

new_system([sys,'/',['Answer modem/Differential',13,'decoder']])
set_param([sys,'/',['Answer modem/Differential',13,'decoder']],'Location',[44,107,656,299])

add_block('built-in/Sum',[sys,'/',['Answer modem/Differential',13,'decoder/Sum1']])
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Sum1']],...
		'hide name',0,...
		'inputs','++-',...
		'position',[280,57,300,93])

add_block('built-in/Unit Delay',[sys,'/',['Answer modem/Differential',13,'decoder/Unit Delay']])
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Unit Delay']],...
		'Sample time','.28/j/p/4',...
		'position',[180,105,230,125])

add_block('built-in/Inport',[sys,'/',['Answer modem/Differential',13,'decoder/Z(m)']])
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Z(m)']],...
		'position',[85,65,105,85])

add_block('built-in/Constant',[sys,'/',['Answer modem/Differential',13,'decoder/Constant']])
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Constant']],...
		'Value','4',...
		'position',[170,20,190,40])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Differential',13,'decoder/Modulo',13,'operation']])
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Modulo',13,'operation']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Modulo',13,'operation']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Modulo',13,'operation']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Modulo',13,'operation']],...
		'Mask Entries','4\/',...
		'position',[335,60,395,90])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Differential',13,'decoder/Integer scalar',13,'to vector']])
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter')
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Integer scalar',13,'to vector']],...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Answer modem/Differential',13,'decoder/Integer scalar',13,'to vector']],...
		'Mask Entries','2\/2\/',...
		'position',[420,54,500,96])

add_block('built-in/Outport',[sys,'/',['Answer modem/Differential',13,'decoder/I2ij(m) and',13,'I3ij(m)']])
set_param([sys,'/',['Answer modem/Differential',13,'decoder/I2ij(m) and',13,'I3ij(m)']],...
		'position',[535,65,555,85])
add_line([sys,'/',['Answer modem/Differential',13,'decoder']],[110,75;275,75])
add_line([sys,'/',['Answer modem/Differential',13,'decoder']],[305,75;330,75])
add_line([sys,'/',['Answer modem/Differential',13,'decoder']],[235,115;250,115;250,85;275,85])
add_line([sys,'/',['Answer modem/Differential',13,'decoder']],[135,75;135,115;175,115])
add_line([sys,'/',['Answer modem/Differential',13,'decoder']],[195,30;230,30;230,65;275,65])
add_line([sys,'/',['Answer modem/Differential',13,'decoder']],[400,75;415,75])
add_line([sys,'/',['Answer modem/Differential',13,'decoder']],[505,75;530,75])


%     Finished composite block ['Answer modem/Differential',13,'decoder'].

set_param([sys,'/',['Answer modem/Differential',13,'decoder']],...
		'position',[560,178,595,242])

add_block('built-in/Note',[sys,'/',['Answer modem/I2ij(m) and ',13,'I3ij(m)']])
set_param([sys,'/',['Answer modem/I2ij(m) and ',13,'I3ij(m)']],...
		'position',[640,205,645,210])


%     Subsystem  ['Answer modem/Trellis',13,'decode'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode']],'Location',[4,135,922,474])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],'Location',[50,86,840,290])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Constant']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Constant']],...
		'Value','80',...
		'position',[45,85,65,105])

add_block('built-in/Demux',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Demux']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Demux']],...
		'hide name',0,...
		'outputs','2',...
		'position',[215,41,260,79])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Modulo',13,'operation']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Modulo',13,'operation']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Modulo',13,'operation']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Modulo',13,'operation']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Modulo',13,'operation']],...
		'Mask Entries','8\/',...
		'position',[125,46,185,74])

add_block('built-in/Sum',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Sum']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Sum']],...
		'hide name',0,...
		'position',[90,50,110,70])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/y']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/y']],...
		'position',[20,45,40,65])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],'Location',[45,449,594,684])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/imag_pt']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/real_pt']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Minimum1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Sum',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/Product',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Product1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Product',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Product']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Sum',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum6']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Sum',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/imag']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/real']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/real']],...
		'position',[45,35,65,55])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[480,95;490,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[395,95;410,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[270,140;270,145;295,145])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[270,55;270,60;295,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[160,130;225,130])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[160,45;225,45])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[70,130;115,130])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],[70,45;115,45])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'Mask Entries','[1 5 3 7 5 1 7 3 5 1 7 3 1 5 3 7]\/[1 3 3 1 1 3 3 1 5 7 7 5 5 7 7 5]\/.28/j/p/4/2\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap']],...
		'hide name',0,...
		'position',[290,38,370,82])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Modulo',13,'operation2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Modulo',13,'operation2']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Modulo',13,'operation2']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Modulo',13,'operation2']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Modulo',13,'operation2']],...
		'Mask Entries','8\/',...
		'position',[395,46,455,74])

add_block('built-in/Unit Delay',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Unit Delay']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Unit Delay']],...
		'hide name',0,...
		'Sample time','.28/j/p/4/2',...
		'position',[485,72,535,88])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],'Location',[45,449,594,684])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold']],...
		'ForeGround',2,...
		'Sample time','td',...
		'position',[120,29,155,61])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/real']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/real']],...
		'position',[45,35,65,55])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/imag']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/imag']],...
		'Port','2',...
		'position',[45,120,65,140])

add_block('built-in/Zero-Order Hold',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Zero-Order',13,'Hold1']],...
		'ForeGround',4,...
		'Sample time','td',...
		'position',[120,114,155,146])

add_block('built-in/Sum',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum1']],...
		'ForeGround',2,...
		'inputs','+-',...
		'position',[230,38,250,67])

add_block('built-in/Sum',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum6']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum6']],...
		'ForeGround',4,...
		'inputs','+-',...
		'position',[230,123,250,152])

add_block('built-in/Product',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Product']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Product']],...
		'position',[300,45,325,65])

add_block('built-in/Product',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Product1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Product1']],...
		'position',[300,130,325,150])

add_block('built-in/Sum',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Sum2']],...
		'position',[370,78,390,107])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Minimum1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/Minimum1']],...
		'function name','arymimai',...
		'parameters','''min''',...
		'position',[415,85,475,105])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/out_1']],...
		'position',[495,85,515,105])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/real_pt']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/real_pt']],...
		'BackGround',3,...
		'Value','y1',...
		'position',[170,84,195,106])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/imag_pt']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1/imag_pt']],...
		'BackGround',5,...
		'Value','y2',...
		'position',[165,169,190,191])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[70,45;115,45])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[70,130;115,130])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[200,95;205,95;205,60;225,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[160,45;225,45])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[160,130;225,130])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[195,180;205,180;205,145;225,145])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[255,55;270,55;270,50;295,50])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[270,55;270,60;295,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[255,140;270,140;270,135;295,135])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[270,140;270,145;295,145])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[330,55;340,55;340,85;365,85])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[330,140;340,140;340,100;365,100])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[395,95;410,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],[480,95;490,95])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'Mask Display','QASK\nA-demap',...
		'Mask Type','QASK A-demap')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'Mask Dialogue','Reverse the QASK map. Input in-phase\nand quadrature components from the\ntwo inputs. Output demapped signal.|Constellation for in-phase component:|Constellation for quadrature component:|Symbol interval and offset (sec):')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'Mask Translate','y1=@1;y2=@2;td=@3;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'Mask Help','This block demaps a QASK mapped signal using user defined arbitrary constellation. You can place this block after a QAM demodulation block. The in-phase and quadrature constellation vectors must have the same length, which equals to M, the M-ary number of the QASK. The output symbols are integers in the range [0, M-1]. The symbol interval can be a two elements vector with the first element being offset. The default offset is zero.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'Mask Entries','floor([[0:.5:7.5,0:.5:7.5],rem([0:.5:7.5,0:.5:7.5]+4,8)])\/[rem(floor([0:2.5:39,1:2.5:40]),4),rem(floor([0:2.5:39,1:2.5:40]),4)+4]\/.28/j/p/4/2\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/QASK',13,'arbitrary-demap1']],...
		'hide name',0,...
		'position',[565,48,645,92])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Y1-Y4']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Y1-Y4']],...
		'position',[675,60,695,80])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor3'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor3']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor3']],'Location',[175,552,335,697])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor3']],...
		'Mask Display','Sym-to-bit\nconvertor\nFigure 10/V34')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor3']],...
		'Mask Dialogue','eval(''x=floor([[0:.5:7.5,0:.5:7.5],rem([0:.5:7.5,0:.5:7.5]+4,8)]);y=[rem(floor([0:2.5:39,1:2.5:40]),4),rem(floor([0:2.5:39,1:2.5:40]),4)+4];for i=1:64,text(x(i),y(i),num2str(rem(i-1,16)));end;set(get(gcf,''''child''''),''''Xlim'''',[-1,8],''''Ylim'''',[-1,8]);xlabel(''''s(2m)'''');ylabel(''''s(2m+1)'''')'')')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor3'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor3']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[565,105,650,152])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor4'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor4']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor4']],'Location',[175,552,335,697])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor4']],...
		'Mask Display','Sym-to-bit\nconvertor\nFigure 9/V34')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor4']],...
		'Mask Dialogue','eval(''x=[1 5 3 7 5 1 7 3 5 1 7 3 1 5 3 7];y=[1 3 3 1 1 3 3 1 5 7 7 5 5 7 7 5];for i=1:16,text(x(i),y(i),num2str(rem(i-1,8)));end;set(get(gcf,''''child''''),''''Xlim'''',[0,8],''''Ylim'''',[0,8]);xlabel(''''Re'''');ylabel(''''Im'''')'')')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor4'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Vector',13,'redistributor4']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,110,380,152])

add_block('built-in/Note',[sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Symbol to bit converter']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor/Symbol to bit converter']],...
		'position',[310,10,315,15])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[265,70;285,70])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[265,50;285,50])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[190,60;210,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[650,70;670,70])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[460,60;560,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[540,80;560,80])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[460,60;465,60;465,80;480,80])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[375,60;390,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[115,60;120,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[45,55;85,55])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],[70,95;70,65;85,65])


%     Finished composite block ['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Symbol to bit',13,'convertor']],...
		'position',[110,12,150,68])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/y(m)']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/y(m)']],...
		'Port','2',...
		'position',[55,30,75,50])

add_block('built-in/Note',[sys,'/',['Answer modem/Trellis',13,'decode/Vo(m)']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Vo(m)']],...
		'position',[210,255,215,260])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern']],'Location',[14,135,595,308])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Constant',13,'one']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Constant',13,'one']],...
		'position',[45,85,65,105])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/frame pulse']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/frame pulse']],...
		'Port','2',...
		'position',[160,115,180,135])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/k pulse']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/k pulse']],...
		'position',[100,100,120,120])

add_block('built-in/Note',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Modulo encoder']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Modulo encoder']],...
		'position',[365,5,370,10])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],'Location',[174,522,554,686])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch/in_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch/in_1']],...
		'position',[65,20,85,40])

add_block('built-in/Mux',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch/Mux']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch/in_2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch/S-function']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch/S-function']],...
		'function name','switchbx',...
		'parameters','sw,df',...
		'position',[205,60,275,90])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],[90,30;120,30;120,65;140,65])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],[85,85;140,85])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],[180,75;200,75])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],[280,75;315,75])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],...
		'Mask Display','Switch\nbox',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],...
		'Mask Dialogue','The output distribution pattern follows the ith row of the switch box, where i is the input from the second port.|Switch box (column number equals block output length):|Default value:')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],...
		'Mask Translate','sw=@1;df=@2;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],...
		'Mask Help','This block follows the switch pattern of ith row in the switch box when the second input port has value i.  When the value in the second input is larger than the switch box row number or less than 1, the block outputs the defualt value.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],...
		'Mask Entries','[1:16]''\/0\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Signal switch']],...
		'hide name',0,...
		'position',[360,63,440,107])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],'Location',[128,50,722,374])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],'Location',[303,485,692,659])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/one1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Memory1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/in_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[35,25;130,25])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[45,25;45,95;120,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[170,95;195,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[170,30;260,30])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],[300,35;335,35])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],...
		'Mask Entries','thld\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector1']],...
		'ForeGround',4,...
		'position',[375,53,435,87])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/in_3']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/in_3']],...
		'Port','3',...
		'position',[315,60,335,80])

add_block('built-in/Memory',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Memory3']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Memory3']],...
		'orientation',2,...
		'ForeGround',3,...
		'position',[400,205,440,235])

add_block('built-in/Switch',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Switch3']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Switch3']],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[470,139,495,171])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/out_1']],...
		'position',[550,145,570,165])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],'Location',[303,485,692,659])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],...
		'Mask Display','Edge\ndetector',...
		'Mask Type','Edge Detection')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],...
		'Mask Dialogue','Rising edge detection:|Threshold:',...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],...
		'Mask Entries','thld\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Rising edge',13,'detector']],...
		'ForeGround',4,...
		'position',[80,148,140,182])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/in_2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/in_2']],...
		'Port','2',...
		'position',[15,155,35,175])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/in_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/in_1']],...
		'position',[15,50,35,70])

add_block('built-in/Switch',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Switch2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Switch2']],...
		'ForeGround',3,...
		'Threshold','eps',...
		'position',[345,149,370,181])

add_block('built-in/Sum',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Sum']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Sum']],...
		'ForeGround',3,...
		'position',[295,100,315,120])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Relational',13,'Operator1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Relational',13,'Operator1']],...
		'ForeGround',2,...
		'Operator','>',...
		'position',[225,53,255,77])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Constant']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter/Constant']],...
		'ForeGround',3,...
		'Value','thld',...
		'position',[105,100,135,120])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[500,155;545,155])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[520,155;520,220;445,220])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[375,165;465,165])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[340,70;370,70])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[40,165;75,165])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[40,60;220,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[320,110;330,110;340,155])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[140,110;190,110;190,70;220,70])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[260,65;275,65;275,105;290,105])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[145,165;340,165])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[395,220;275,220;275,175;340,175])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[275,175;275,115;290,115])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],[440,70;450,70;450,155;465,155])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Counter',...
		'Mask Type','Resettable number counter')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],...
		'Mask Dialogue','If the 1st inport value is larger than the threshold, the counter increases one at the rising edge of the 2nd inport pulse.|Threshold:')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(0,20,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],...
		'Mask Help','If the signal at the 1st inport is larger than or equal to the given threshold at the rising edge of the 2nd inport, the counter increases by one. The rising edge of the 3rd port resets the counter to zero.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],...
		'Mask Entries','.2\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Counter']],...
		'hide name',0,...
		'position',[235,88,315,132])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Bit inversion patterns']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Bit inversion patterns']],...
		'Value','[0 1 1 1 0 1 1 1 1 1 1 1 1 0 1 0]',...
		'position',[90,31,280,59])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Vo(m)']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern/Vo(m)']],...
		'position',[470,75,490,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern']],[445,85;465,85])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern']],[320,110;340,110;340,95;355,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern']],[285,45;305,45;305,75;355,75])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern']],[185,125;230,125])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern']],[125,110;230,110])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern']],[70,95;230,95])


%     Finished composite block ['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Bit inversion',13,'pattern']],...
		'position',[145,230,185,285])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/k-pulse']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/k-pulse']],...
		'Port','4',...
		'position',[95,235,115,255])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/frame pulse']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/frame pulse']],...
		'Port','5',...
		'position',[55,260,75,280])


%     Subsystem  ['Answer modem/Trellis',13,'decode/K-step',13,'delay1'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],'Location',[12,432,357,702])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/Relational',13,'Operator']],...
		'position',[150,168,180,192])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/Constant1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/Constant']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Switch',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/Switch']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Filter',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/K-step',13,'delay']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/in_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Digital Clock',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/Digital Clock']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],[185,180;220,180;220,130;265,130])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],[45,90;55,90])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],[300,130;320,130])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],...
		'Mask Entries','x*2\/.28/j/p/4/2\/0\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/K-step',13,'delay1'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay1']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[285,243,365,277])

add_block('built-in/Note',[sys,'/',['Answer modem/Trellis',13,'decode/Co(m)']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Co(m)']],...
		'position',[200,170,205,175])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Modulo',13,'encoder'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder']],'Location',[41,243,622,357])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Co(m)']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Co(m)']],...
		'position',[480,50,500,70])

add_block('built-in/Logical Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Logical',13,'Operator1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Logical',13,'Operator1']],...
		'hide name',0,...
		'Operator','NOT',...
		'Number of Input Ports','1',...
		'position',[415,48,445,72])

add_block('built-in/Logical Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Logical',13,'Operator']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Logical',13,'Operator']],...
		'hide name',0,...
		'Operator','XOR',...
		'position',[355,48,385,72])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Modulo',13,'operation2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Modulo',13,'operation2']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Modulo',13,'operation2']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Modulo',13,'operation2']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Modulo',13,'operation2']],...
		'Mask Entries','2\/',...
		'position',[185,41,245,69])

add_block('built-in/Unit Delay',[sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Unit Delay']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Unit Delay']],...
		'hide name',0,...
		'Sample time','.28/j/p/4/2',...
		'position',[275,67,325,83])

add_block('built-in/Sum',[sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Sum']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Sum']],...
		'hide name',0,...
		'inputs','+',...
		'position',[130,45,150,65])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/c(m)']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/c(m)']],...
		'position',[60,45,80,65])

add_block('built-in/Note',[sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Modulo encoder']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder/Modulo encoder']],...
		'position',[310,5,315,10])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder']],[450,60;475,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder']],[390,60;410,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder']],[250,55;350,55])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder']],[330,75;335,75;335,65;350,65])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder']],[155,55;180,55])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder']],[85,55;125,55])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder']],[250,55;255,55;255,75;270,75])


%     Finished composite block ['Answer modem/Trellis',13,'decode/Modulo',13,'encoder'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Modulo',13,'encoder']],...
		'position',[130,142,170,198])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/c(m)']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/c(m)']],...
		'Port','3',...
		'position',[70,160,90,180])

add_block('built-in/Logical Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Logical',13,'Operator']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Logical',13,'Operator']],...
		'hide name',0,...
		'Operator','XOR',...
		'Number of Input Ports','3',...
		'position',[285,117,315,153])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Trellis',13,'decode/Integer scalar',13,'to vector']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Integer scalar',13,'to vector']],...
		'hide name',0,...
		'function name','simde2bi',...
		'parameters','len, p',...
		'Mask Display','Sca to vec\nconverter')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Integer scalar',13,'to vector']],...
		'Mask Type','Decimal to base M vector')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Integer scalar',13,'to vector']],...
		'Mask Dialogue','Convert decimal integer input to base M\ninteger and output each position of the\nconverted integer using output vector.|Output vector length:|Conversion base M:')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Integer scalar',13,'to vector']],...
		'Mask Translate','len=@1;p=@2;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Integer scalar',13,'to vector']],...
		'Mask Help','This block converts decimal integer scalar input to a base M integer. M must be a\npositive integer. The block outputs the base M integer using a vector. The 1st element in the output vector contains the 1''s position. The 2nd element in the output vector contains the M''s position, and so on. The output vector length is given by setting the parameter entry.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Integer scalar',13,'to vector']],...
		'Mask Entries','4\/2\/',...
		'position',[175,18,255,62])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Uo(m)',13,'before TCM']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Uo(m)',13,'before TCM']],...
		'position',[45,100,65,120])

add_block('built-in/Note',[sys,'/',['Answer modem/Trellis',13,'decode/Y1(m) -- Y4(m)']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Y1(m) -- Y4(m)']],...
		'position',[300,35,305,40])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Constant']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Constant']],...
		'position',[285,60,305,80])

add_block('built-in/Mux',[sys,'/',['Answer modem/Trellis',13,'decode/Mux']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Mux']],...
		'hide name',0,...
		'inputs','2',...
		'position',[365,31,400,64])

add_block('built-in/Demux',[sys,'/',['Answer modem/Trellis',13,'decode/Demux']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Demux']],...
		'hide name',0,...
		'outputs','[tf(2,size(tf,2)), 5-tf(2,size(tf,2))]',...
		'position',[415,30,455,65])

add_block('built-in/Mux',[sys,'/',['Answer modem/Trellis',13,'decode/Mux1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Mux1']],...
		'hide name',0,...
		'inputs','2',...
		'position',[490,55,520,95])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/(m+1) pulse']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/(m+1) pulse']],...
		'Port','6',...
		'position',[495,125,515,145])


%     Subsystem  ['Answer modem/Trellis',13,'decode/K-step',13,'delay'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],'Location',[12,432,357,702])

add_block('built-in/Digital Clock',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/Digital Clock']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/in_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Filter',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/K-step',13,'delay']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Switch',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/Switch']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/Constant']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/Constant1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay/Relational',13,'Operator']],...
		'position',[150,168,180,192])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],[300,130;320,130])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],[45,90;55,90])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],[185,180;220,180;220,130;265,130])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],...
		'Mask Entries','x*2\/.28/j/p/4/2\/0\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/K-step',13,'delay'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/K-step',13,'delay']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[565,153,645,187])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],'Location',[214,496,617,630])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/in_2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/in_2']],...
		'Port','2',...
		'position',[40,65,60,85])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/in_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/in_1']],...
		'position',[40,20,60,40])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],...
		'Mask Entries','thd\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Rising edge',13,'detector']],...
		'position',[90,57,145,93])

add_block('built-in/Mux',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Mux']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Mux']],...
		'inputs','2',...
		'Mask Display','',...
		'position',[190,21,225,54])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Modulo',13,'operation1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/Modulo',13,'operation1']],...
		'function name','sconvenc',...
		'parameters','tf',...
		'position',[255,25,315,55])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1/out_1']],...
		'position',[350,30,370,50])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],[320,40;345,40])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],[65,30;185,30])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],[65,75;85,75])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],[150,75;160,75;160,45;185,45])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],[230,40;250,40])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl en',...
		'Mask Type','Vector I/O convolution encode')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],...
		'Mask Dialogue','Convolution encode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Trigger signal threshold:')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],...
		'Mask Translate','tf=@1;tf=simviter(tf);thd=@2;[x,y]=codeicon(1);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],...
		'Mask Help','This block encodes length K binary vector message input into length N binary vector codeword output using convolution code. The block refreshes its register memory and output at the rising edge of the second inport pulse. You can also use a SIMULINK block diagram to define the convolution code transfer function.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],...
		'Mask Entries','tf\/.5\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol encode1']],...
		'hide name',0,...
		'position',[670,63,750,107])

add_block('built-in/Demux',[sys,'/',['Answer modem/Trellis',13,'decode/Demux2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Demux2']],...
		'hide name',0,...
		'outputs','[tf(2,size(tf,2)), 1]',...
		'position',[770,64,815,106])

add_block('built-in/Logical Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Logical',13,'Operator1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Logical',13,'Operator1']],...
		'hide name',0,...
		'Operator','XOR',...
		'Number of Input Ports','3',...
		'position',[730,152,760,188])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Uo(m)',13,'after TCM']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Uo(m)',13,'after TCM']],...
		'position',[835,160,855,180])

add_block('built-in/Note',[sys,'/',['Answer modem/Trellis',13,'decode/Yo(m)']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Yo(m)']],...
		'position',[445,80,450,85])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],'Location',[53,297,561,483])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/in_2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/in_2']],...
		'Port','2',...
		'position',[30,120,50,140])

add_block('built-in/Demux',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Demux']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Demux']],...
		'outputs','[tf(2,size(tf,2)), 1]',...
		'position',[305,35,345,70])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/out_1']],...
		'position',[405,35,425,55])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/out_2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/out_2']],...
		'Port','2',...
		'position',[445,65,465,85])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/S-fun']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/S-fun']],...
		'function name','sviterba',...
		'parameters','tf, leng, tran_prob, plot_flag',...
		'position',[235,40,280,70])

add_block('built-in/Mux',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Mux']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Mux']],...
		'inputs','[tf(1,size(tf,2)), 1]',...
		'Mask Display','',...
		'position',[170,36,205,69])


%     Subsystem  ['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector'].

new_system([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Outport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Constant',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Memory',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],[45,25;45,95;120,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],[300,35;335,35])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'Mask Display','Edge\nDetector',...
		'Mask Type','Edge Detection',...
		'Mask Dialogue','Rising edge detection:|Threshold:')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'Mask Help','When the input signal rising edge passed the given shreshold, this block outputs one, otherwise outputs zero.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'Mask Entries','thd\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/Rising edge',13,'detector']],...
		'position',[75,112,130,148])

add_block('built-in/Inport',[sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/in_1']])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1/in_1']],...
		'position',[65,35,85,55])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],[135,130;140,130;140,60;165,60])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],[90,45;165,45])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],[210,55;230,55])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],[350,60;375,60;375,75;440,75])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],[350,45;400,45])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],[285,55;300,55])
add_line([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],[55,130;70,130])
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Convl de',...
		'Mask Type','Vector I/O convolution decode')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],...
		'Mask Dialogue','Convolution decode with codeword length\nN and message length K. Transfer function\nmatrix is a K-by-N matrix.|Transfer function (or SIMULINK diagram):|Path memory length (delay=path_length*K*T_out):|Transfer probability (3 row matrix, 0 for hard decision):|Trellis figure plot length (0 for no plot):|Trigger signal threshold:')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],...
		'Mask Translate','gen=@1;leng=@2;tran_prob=@3;plot_flag=@4;thd=@5;tf=simviter(gen);[x,y]=codeicon(2);[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],...
		'Mask Help','This block decodes length N binary vector convolution code codeword into length K binary vector message using Viterbi algorithm. The block refreshes its register memory and decoding output at the rising edge of the second inport pulse. The second outport outputs the metric value for soft decision or the accumulative distance for hard\ndecision.')
set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],...
		'Mask Entries','tf\/x\/0\/0\/.5\/')


%     Finished composite block ['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode/Binary vector',13,'convol decode1']],...
		'hide name',0,...
		'position',[565,63,645,107])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[70,110;245,110;245,125;280,125])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[95,170;125,170])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[80,270;140,270])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[120,245;140,245])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[80,40;105,40])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[155,40;170,40])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[320,135;330,135;330,85;485,85])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[525,75;560,75])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[520,135;545,135;545,95;560,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[650,75;665,75])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[545,135;655,135;665,95])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[755,85;765,85])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[820,95;835,95;835,110;715,150;725,160])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[650,170;725,170])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[175,170;560,170])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[370,260;710,260;710,180;725,180])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[765,170;830,170])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[310,70;350,70;360,55])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[260,40;360,40])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[405,50;410,50])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[460,40;470,40;470,65;485,65])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[190,260;280,260])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[245,260;245,145;280,145])
add_line([sys,'/',['Answer modem/Trellis',13,'decode']],[220,170;220,135;280,135])


%     Finished composite block ['Answer modem/Trellis',13,'decode'].

set_param([sys,'/',['Answer modem/Trellis',13,'decode']],...
		'ForeGround',2,...
		'position',[480,76,520,194])

add_block('built-in/Note',[sys,'/','Answer modem/Uo(m) before'])
set_param([sys,'/','Answer modem/Uo(m) before'],...
		'position',[425,70,430,75])

add_block('built-in/Note',[sys,'/','Answer modem/y(n)'])
set_param([sys,'/','Answer modem/y(n)'],...
		'position',[430,95,435,100])

add_block('built-in/Note',[sys,'/','Answer modem/c(n)'])
set_param([sys,'/','Answer modem/c(n)'],...
		'position',[425,120,430,125])


%     Subsystem  'Answer modem/Rotation2'.

new_system([sys,'/','Answer modem/Rotation2'])
set_param([sys,'/','Answer modem/Rotation2'],'Location',[11,87,518,273])

add_block('built-in/Outport',[sys,'/',['Answer modem/Rotation2/rotation angle',13,'0,1,2,3 for',13,'0,90,180,270 degrees']])
set_param([sys,'/',['Answer modem/Rotation2/rotation angle',13,'0,1,2,3 for',13,'0,90,180,270 degrees']],...
		'position',[420,50,440,70])

add_block('built-in/Inport',[sys,'/','Answer modem/Rotation2/switch'])
set_param([sys,'/','Answer modem/Rotation2/switch'],...
		'ForeGround',2,...
		'Port','4',...
		'position',[130,40,150,60])

add_block('built-in/Inport',[sys,'/','Answer modem/Rotation2/Z(m)'])
set_param([sys,'/','Answer modem/Rotation2/Z(m)'],...
		'Port','2',...
		'position',[45,25,65,45])

add_block('built-in/Switch',[sys,'/','Answer modem/Rotation2/Switch'])
set_param([sys,'/','Answer modem/Rotation2/Switch'],...
		'hide name',0,...
		'Threshold','.5',...
		'position',[180,29,210,71])

add_block('built-in/Inport',[sys,'/','Answer modem/Rotation2/I1'])
set_param([sys,'/','Answer modem/Rotation2/I1'],...
		'position',[45,95,65,115])

add_block('built-in/Gain',[sys,'/','Answer modem/Rotation2/Gain'])
set_param([sys,'/','Answer modem/Rotation2/Gain'],...
		'hide name',0,...
		'Gain','2',...
		'position',[85,95,105,115])

add_block('built-in/Sum',[sys,'/','Answer modem/Rotation2/Sum'])
set_param([sys,'/','Answer modem/Rotation2/Sum'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[135,87,155,123])

add_block('built-in/Constant',[sys,'/','Answer modem/Rotation2/Constant'])
set_param([sys,'/','Answer modem/Rotation2/Constant'],...
		'position',[290,95,310,115])

add_block('built-in/Sum',[sys,'/','Answer modem/Rotation2/Sum1'])
set_param([sys,'/','Answer modem/Rotation2/Sum1'],...
		'hide name',0,...
		'position',[335,42,355,78])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Rotation2/Modulo',13,'operation']])
set_param([sys,'/',['Answer modem/Rotation2/Modulo',13,'operation']],...
		'hide name',0,...
		'function name','arymodu',...
		'parameters','md',...
		'Mask Display','Modulo',...
		'Mask Type','Modulo')
set_param([sys,'/',['Answer modem/Rotation2/Modulo',13,'operation']],...
		'Mask Dialogue','Output the remainder of the input value divided by the modulo base.|Modulo base:',...
		'Mask Translate','md = @1;')
set_param([sys,'/',['Answer modem/Rotation2/Modulo',13,'operation']],...
		'Mask Help','This block outputs the remainder of the input value divided by the modulo base. The length of the output vector is the same as the input vector.')
set_param([sys,'/',['Answer modem/Rotation2/Modulo',13,'operation']],...
		'Mask Entries','4\/',...
		'position',[245,31,310,69])

add_block('built-in/Inport',[sys,'/','Answer modem/Rotation2/U0(m)'])
set_param([sys,'/','Answer modem/Rotation2/U0(m)'],...
		'Port','3',...
		'position',[40,125,60,145])
add_line([sys,'/','Answer modem/Rotation2'],[315,50;330,50])
add_line([sys,'/','Answer modem/Rotation2'],[215,50;240,50])
add_line([sys,'/','Answer modem/Rotation2'],[315,105;320,105;330,70])
add_line([sys,'/','Answer modem/Rotation2'],[160,105;165,105;175,65])
add_line([sys,'/','Answer modem/Rotation2'],[65,135;120,135;130,115])
add_line([sys,'/','Answer modem/Rotation2'],[70,35;175,35])
add_line([sys,'/','Answer modem/Rotation2'],[120,35;130,95])
add_line([sys,'/','Answer modem/Rotation2'],[110,105;130,105])
add_line([sys,'/','Answer modem/Rotation2'],[70,105;80,105])
add_line([sys,'/','Answer modem/Rotation2'],[155,50;175,50])
add_line([sys,'/','Answer modem/Rotation2'],[360,60;415,60])


%     Finished composite block 'Answer modem/Rotation2'.

set_param([sys,'/','Answer modem/Rotation2'],...
		'position',[605,61,645,179])

add_block('built-in/Note',[sys,'/','Answer modem/Uo(m) after'])
set_param([sys,'/','Answer modem/Uo(m) after'],...
		'ForeGround',2,...
		'position',[565,130,570,135])

add_block('built-in/Inport',[sys,'/','Answer modem/in_1'])
set_param([sys,'/','Answer modem/in_1'],...
		'position',[45,65,65,85])


%     Subsystem  ['Answer modem/QADM',13,'baseband2'].

new_system([sys,'/',['Answer modem/QADM',13,'baseband2']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2']],'Location',[283,122,827,417])

add_block('built-in/Inport',[sys,'/',['Answer modem/QADM',13,'baseband2/in_1']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/in_1']],...
		'position',[55,115,75,135])

add_block('built-in/Constant',[sys,'/',['Answer modem/QADM',13,'baseband2/Constant1']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Constant1']],...
		'ForeGround',6,...
		'Value','x2',...
		'position',[160,245,180,265])

add_block('built-in/Sum',[sys,'/',['Answer modem/QADM',13,'baseband2/Sum1']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Sum1']],...
		'position',[340,220,360,240])

add_block('built-in/Outport',[sys,'/',['Answer modem/QADM',13,'baseband2/out_2']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/out_2']],...
		'Port','2',...
		'position',[485,220,505,240])

add_block('built-in/Filter',[sys,'/',['Answer modem/QADM',13,'baseband2/Filter1']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Filter1']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[395,211,450,249])

add_block('built-in/Product',[sys,'/',['Answer modem/QADM',13,'baseband2/Product1']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Product1']],...
		'position',[260,123,290,147])

add_block('built-in/Demux',[sys,'/',['Answer modem/QADM',13,'baseband2/Demux']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Demux']],...
		'outputs','2',...
		'position',[120,105,160,140])

add_block('built-in/Constant',[sys,'/',['Answer modem/QADM',13,'baseband2/Constant']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Constant']],...
		'ForeGround',3,...
		'Value','x1',...
		'position',[155,40,175,60])

add_block('built-in/Product',[sys,'/',['Answer modem/QADM',13,'baseband2/Product2']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Product2']],...
		'position',[270,238,300,262])

add_block('built-in/Product',[sys,'/',['Answer modem/QADM',13,'baseband2/Product3']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Product3']],...
		'position',[270,193,300,217])

add_block('built-in/Sum',[sys,'/',['Answer modem/QADM',13,'baseband2/Sum']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Sum']],...
		'inputs','+-',...
		'position',[335,70,355,90])

add_block('built-in/Product',[sys,'/',['Answer modem/QADM',13,'baseband2/Product']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Product']],...
		'position',[260,43,290,67])

add_block('built-in/Filter',[sys,'/',['Answer modem/QADM',13,'baseband2/Filter']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Filter']],...
		'Numerator','num',...
		'Denominator','den',...
		'Sample time','ts',...
		'position',[390,61,445,99])

add_block('built-in/Outport',[sys,'/',['Answer modem/QADM',13,'baseband2/out_1']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/out_1']],...
		'position',[480,70,500,90])

add_block('built-in/Note',[sys,'/',['Answer modem/QADM',13,'baseband2/Ref: Hambley: An Intro to Comm. Systems. pp72']])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2/Ref: Hambley: An Intro to Comm. Systems. pp72']],...
		'position',[275,310,280,315])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[165,115;230,115;230,60;255,60])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[230,115;230,245;265,245])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[185,255;200,255;200,140;255,140])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[200,255;265,255])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[165,130;255,130])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[180,130;180,210;265,210])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[180,50;255,50])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[215,50;215,200;265,200])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[295,55;305,55;305,75;330,75])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[295,135;305,135;305,85;330,85])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[305,205;315,205;315,225;335,225])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[305,250;315,250;315,235;335,235])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[80,125;115,125])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[360,80;385,80])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[450,80;475,80])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[365,230;390,230])
add_line([sys,'/',['Answer modem/QADM',13,'baseband2']],[455,230;480,230])
set_param([sys,'/',['Answer modem/QADM',13,'baseband2']],...
		'Mask Display','plot(0,0,100,100,x,y,u,v);QADM',...
		'Mask Type','QM DSB-SC ADM CE')
set_param([sys,'/',['Answer modem/QADM',13,'baseband2']],...
		'Mask Dialogue','Demodulate the complex envelope of a\nQAM modulated signal into in-phase and\nquadrature components into 1st and 2nd\nout ports.|Lowpass filter numerator:|Lowpass filter denominator:|Initial phase (rad):|Sample time (sec):')
set_param([sys,'/',['Answer modem/QADM',13,'baseband2']],...
		'Mask Translate','num=@1;den=@2;Ph=@3;ts=@4;x1=cos(-Ph);x2=sin(-Ph);[x,y]=moduicon(2);[u,v]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Answer modem/QADM',13,'baseband2']],...
		'Mask Help','This block demodulates the quadratic multiplexed double-sideband suppressed-carrier amplitude modulation modulated signal using the QAM method. The filter to be specified is a lowpass filter that passes the signal message and eliminates the carrier signal.')
set_param([sys,'/',['Answer modem/QADM',13,'baseband2']],...
		'Mask Entries','1\/1\/0\/.28/j/p/4/2/2\/')


%     Finished composite block ['Answer modem/QADM',13,'baseband2'].

set_param([sys,'/',['Answer modem/QADM',13,'baseband2']],...
		'ForeGround',4,...
		'hide name',0,...
		'position',[80,55,160,95])

add_block('built-in/Mux',[sys,'/','Answer modem/Mux'])
set_param([sys,'/','Answer modem/Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[175,55,205,95])


%     Subsystem  ['Answer modem/Non-linear',13,'decoder'].

new_system([sys,'/',['Answer modem/Non-linear',13,'decoder']])
set_param([sys,'/',['Answer modem/Non-linear',13,'decoder']],'Location',[313,87,639,216])

add_block('built-in/Inport',[sys,'/',['Answer modem/Non-linear',13,'decoder/x''(n)']])
set_param([sys,'/',['Answer modem/Non-linear',13,'decoder/x''(n)']],...
		'position',[75,70,95,90])

add_block('built-in/Outport',[sys,'/',['Answer modem/Non-linear',13,'decoder/x(n)']])
set_param([sys,'/',['Answer modem/Non-linear',13,'decoder/x(n)']],...
		'position',[215,70,235,90])

add_block('built-in/Note',[sys,'/',['Answer modem/Non-linear',13,'decoder/This example assume Theta = 0']])
set_param([sys,'/',['Answer modem/Non-linear',13,'decoder/This example assume Theta = 0']],...
		'position',[150,25,155,30])
add_line([sys,'/',['Answer modem/Non-linear',13,'decoder']],[100,80;210,80])


%     Finished composite block ['Answer modem/Non-linear',13,'decoder'].

set_param([sys,'/',['Answer modem/Non-linear',13,'decoder']],...
		'position',[220,43,255,107])


%     Subsystem  ['Answer modem/Precoder',13,'decoding'].

new_system([sys,'/',['Answer modem/Precoder',13,'decoding']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding']],'Location',[58,81,748,398])

add_block('built-in/Note',[sys,'/',['Answer modem/Precoder',13,'decoding/h(1), h(2) and h(3) are the precoder filter complex coeficients in Eq.(9-28//V.34)']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/h(1), h(2) and h(3) are the precoder filter complex coeficients in Eq.(9-28//V.34)']],...
		'position',[305,250,310,255])

add_block('built-in/Gain',[sys,'/',['Answer modem/Precoder',13,'decoding/Gain']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Gain']],...
		'orientation',1,...
		'hide name',0,...
		'Gain','1.e7',...
		'position',[185,165,205,185])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Precoder',13,'decoding/Array',13,'function']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Array',13,'function']],...
		'hide name',0,...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nfunction',...
		'Mask Type','Array function')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Array',13,'function']],...
		'Mask Dialogue','Array function block for sin, cos, tan, exp, asin, acos, ln, log10, sgn, abs,\nfloor, ceil, and round.|Operation (string):')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Array',13,'function']],...
		'Mask Translate','opr=@1;',...
		'Mask Help','This block calculates the given function value. The vector length of the output is the same as the input.')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Array',13,'function']],...
		'Mask Entries','''round''\/',...
		'position',[210,180,290,220])

add_block('built-in/Gain',[sys,'/',['Answer modem/Precoder',13,'decoding/Gain1']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Gain1']],...
		'hide name',0,...
		'Gain','1.e-7',...
		'position',[310,190,330,210])

add_block('built-in/Gain',[sys,'/',['Answer modem/Precoder',13,'decoding/Gain2']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Gain2']],...
		'hide name',0,...
		'Gain','1/2/(1+(b>=56))',...
		'position',[350,190,370,210])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Precoder',13,'decoding/Array',13,'function1']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Array',13,'function1']],...
		'hide name',0,...
		'function name','arysin',...
		'parameters','opr',...
		'Mask Display','Array\nfunction',...
		'Mask Type','Array function')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Array',13,'function1']],...
		'Mask Dialogue','Array function block for sin, cos, tan, exp, asin, acos, ln, log10, sgn, abs,\nfloor, ceil, and round.|Operation (string):')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Array',13,'function1']],...
		'Mask Translate','opr=@1;',...
		'Mask Help','This block calculates the given function value. The vector length of the output is the same as the input.')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Array',13,'function1']],...
		'Mask Entries','''round''\/',...
		'position',[385,180,465,220])

add_block('built-in/Gain',[sys,'/',['Answer modem/Precoder',13,'decoding/Gain3']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Gain3']],...
		'orientation',3,...
		'hide name',0,...
		'Gain','2*(1+(b>=56))',...
		'position',[463,140,487,160])

add_block('built-in/Note',[sys,'/',['Answer modem/Precoder',13,'decoding/The input to this block is the QADM demapping result x(n) in Eq. (9-27//V.34)']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/The input to this block is the QADM demapping result x(n) in Eq. (9-27//V.34)']],...
		'position',[300,270,305,275])

add_block('built-in/Sum',[sys,'/',['Answer modem/Precoder',13,'decoding/Sum1']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[495,72,515,108])

add_block('built-in/Sum',[sys,'/',['Answer modem/Precoder',13,'decoding/Sum']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Sum']],...
		'hide name',0,...
		'position',[355,62,375,98])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Precoder',13,'decoding/Complex filter']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Complex filter']],...
		'orientation',1,...
		'hide name',0,...
		'function name','cmplxflt',...
		'parameters','num, den, ts',...
		'Mask Display','plot(0,0,100,100,x,y,u,v);Filter')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Complex filter']],...
		'Mask Type','Complex filter')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Complex filter']],...
		'Mask Dialogue','Vector expression for numerator and\ndenominator. Complex coefficients are in ascending power of 1/z.|Numerator:|Denominator:|Sample time:')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Complex filter']],...
		'Mask Translate','num=@1;den=@2;ts=@3;num=[real(num(:))'';imag(num(:))''];den=[real(den(:))'';imag(den(:))''];if max(abs(den(2,:))) <=0, den=den(1,:); end;if max(abs(num(2,:))) <=0, num=num(1,:); end;[u,v]=cmplxicn(1,50,get_param(gcb,''orientation''));[x,y]=cmplxicn(0,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Complex filter']],...
		'Mask Help','This block takes real or complex signal input and outputs complex signal. The numerator can be a real or a complex vector with the coeficient ordered in ascending power of 1/z. Same for the denominator.')
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/Complex filter']],...
		'Mask Entries','[0 h(1) h(2) h(3)]\/1\/.28/p/j/4/2\/',...
		'position',[155,100,235,140])

add_block('built-in/Note',[sys,'/',['Answer modem/Precoder',13,'decoding/This block implements the reverse of precode in Figure 7//V.34']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/This block implements the reverse of precode in Figure 7//V.34']],...
		'position',[240,10,245,15])

add_block('built-in/Inport',[sys,'/',['Answer modem/Precoder',13,'decoding/x(n)']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/x(n)']],...
		'position',[105,60,125,80])

add_block('built-in/Outport',[sys,'/',['Answer modem/Precoder',13,'decoding/c(n)']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/c(n)']],...
		'Port','3',...
		'position',[555,115,575,135])

add_block('built-in/Outport',[sys,'/',['Answer modem/Precoder',13,'decoding/u(n)']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/u(n)']],...
		'position',[580,80,600,100])

add_block('built-in/Outport',[sys,'/',['Answer modem/Precoder',13,'decoding/y(n)']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/y(n)']],...
		'Port','2',...
		'position',[615,50,635,70])

add_block('built-in/Note',[sys,'/',['Answer modem/Precoder',13,'decoding/b is  the number of bit in high mapping frame in Table 8//V.34']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/b is  the number of bit in high mapping frame in Table 8//V.34']],...
		'position',[255,230,260,235])

add_block('built-in/Note',[sys,'/',['Answer modem/Precoder',13,'decoding/The output of this block is u(n), y(n), and c(n) variable described  in section 9.6.1//V.34 ']])
set_param([sys,'/',['Answer modem/Precoder',13,'decoding/The output of this block is u(n), y(n), and c(n) variable described  in section 9.6.1//V.34 ']],...
		'position',[325,290,330,295])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[195,190;205,200])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[195,145;195,160])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[295,200;305,200])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[335,200;345,200])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[375,200;380,200])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[470,200;475,200;475,165])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[130,70;195,70;195,95])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[195,70;350,70])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[335,200;335,90;350,90])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[520,90;575,90])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[380,80;490,80])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[475,135;475,100;490,100])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[415,80;415,60;610,60])
add_line([sys,'/',['Answer modem/Precoder',13,'decoding']],[475,125;550,125])


%     Finished composite block ['Answer modem/Precoder',13,'decoding'].

set_param([sys,'/',['Answer modem/Precoder',13,'decoding']],...
		'position',[280,43,315,107])

add_block('built-in/Inport',[sys,'/','Answer modem/Inport'])
set_param([sys,'/','Answer modem/Inport'],...
		'Port','2',...
		'position',[165,270,185,290])


%     Subsystem  ['Answer modem/Triggered',13,'signal switch'].

new_system([sys,'/',['Answer modem/Triggered',13,'signal switch']])
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch']],'Location',[624,516,1004,680])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Triggered',13,'signal switch/S-function']])
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch/S-function']],...
		'function name','stdmamux',...
		'parameters','sw,ke,in,tt',...
		'position',[205,60,275,90])

add_block('built-in/Inport',[sys,'/',['Answer modem/Triggered',13,'signal switch/in_2']])
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch/in_2']],...
		'Port','2',...
		'position',[60,75,80,95])

add_block('built-in/Outport',[sys,'/',['Answer modem/Triggered',13,'signal switch/out_1']])
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch/out_1']],...
		'position',[320,65,340,85])

add_block('built-in/Mux',[sys,'/',['Answer modem/Triggered',13,'signal switch/Mux']])
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch/Mux']],...
		'inputs','2',...
		'position',[145,54,175,96])

add_block('built-in/Inport',[sys,'/',['Answer modem/Triggered',13,'signal switch/in_1']])
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch/in_1']],...
		'position',[65,20,85,40])
add_line([sys,'/',['Answer modem/Triggered',13,'signal switch']],[280,75;315,75])
add_line([sys,'/',['Answer modem/Triggered',13,'signal switch']],[180,75;200,75])
add_line([sys,'/',['Answer modem/Triggered',13,'signal switch']],[85,85;140,85])
add_line([sys,'/',['Answer modem/Triggered',13,'signal switch']],[90,30;120,30;120,65;140,65])
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch']],...
		'Mask Display','plot(0,0,100,100,v,w);Vct re-arr',...
		'Mask Type','Vector signal re-distribution')
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch']],...
		'Mask Dialogue','The rising edge from the 2nd inport\ntriggers the output of this block to follow the rule of the next row in the switch box.|Switch box (column number equals block output length):|Keeping value (flag 0 element in switch box):|Initial value (before the 1st trigger is detected):|Trigger threshold:')
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch']],...
		'Mask Translate','sw=@1;ke=@2;in=@3;tt=@4;[v,w]=trigicon(0,25,get_param(gcb,''orientation''),2);')
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch']],...
		'Mask Help','When the ith element in the current row of the switch box is j, the ith element in the output vector equals jth input element. When j=0, the output keeps the last output value if keep_value >= 0; it equals ini_val otherwise. The switch box column number must be same as the lengths of output, keep_value, and init_value. The rising edge of the 2nd inport triggers the distribution pattern to follow the next row of the switch box.')
set_param([sys,'/',['Answer modem/Triggered',13,'signal switch']],...
		'Mask Entries','vec2mat([1:b],ceil(b/4))\/zeros(1,ceil(b/4))\/zeros(1,ceil(b/4))\/.1\/')


%     Finished composite block ['Answer modem/Triggered',13,'signal switch'].

set_param([sys,'/',['Answer modem/Triggered',13,'signal switch']],...
		'hide name',0,...
		'position',[645,313,725,357])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Integer vector',13,'to scalar']])
set_param([sys,'/',['Answer modem/Integer vector',13,'to scalar']],...
		'hide name',0,...
		'function name','simbi2de',...
		'parameters','p',...
		'Mask Display','Vec to sca\nconverter',...
		'Mask Type','Base M vector to decimal integer')
set_param([sys,'/',['Answer modem/Integer vector',13,'to scalar']],...
		'Mask Dialogue','Convert base M integer with each\nposition in the input vector into scalar decimal output.|Input integer base M:',...
		'Mask Translate','p=@1;')
set_param([sys,'/',['Answer modem/Integer vector',13,'to scalar']],...
		'Mask Help','This block convert the base M vector into scalar decimal integer output. Each element of the input vector is one position of the digit of the base M integer. The 1st element in the input vector contains the 1''s position. The 2nd element in the input vector contains the M''s position.')
set_param([sys,'/',['Answer modem/Integer vector',13,'to scalar']],...
		'Mask Entries','2\/',...
		'position',[745,313,825,357])

add_block('built-in/Outport',[sys,'/','Answer modem/out_1'])
set_param([sys,'/','Answer modem/out_1'],...
		'position',[845,325,865,345])


%     Subsystem  ['Answer modem/K-step',13,'delay3'].

new_system([sys,'/',['Answer modem/K-step',13,'delay3']])
set_param([sys,'/',['Answer modem/K-step',13,'delay3']],'Location',[12,432,357,702])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/K-step',13,'delay3/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/K-step',13,'delay3/Relational',13,'Operator']],...
		'position',[150,168,180,192])

add_block('built-in/Constant',[sys,'/',['Answer modem/K-step',13,'delay3/Constant1']])
set_param([sys,'/',['Answer modem/K-step',13,'delay3/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Constant',[sys,'/',['Answer modem/K-step',13,'delay3/Constant']])
set_param([sys,'/',['Answer modem/K-step',13,'delay3/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Switch',[sys,'/',['Answer modem/K-step',13,'delay3/Switch']])
set_param([sys,'/',['Answer modem/K-step',13,'delay3/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Filter',[sys,'/',['Answer modem/K-step',13,'delay3/K-step',13,'delay']])
set_param([sys,'/',['Answer modem/K-step',13,'delay3/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Outport',[sys,'/',['Answer modem/K-step',13,'delay3/out_1']])
set_param([sys,'/',['Answer modem/K-step',13,'delay3/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Inport',[sys,'/',['Answer modem/K-step',13,'delay3/in_1']])
set_param([sys,'/',['Answer modem/K-step',13,'delay3/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Digital Clock',[sys,'/',['Answer modem/K-step',13,'delay3/Digital Clock']])
set_param([sys,'/',['Answer modem/K-step',13,'delay3/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])
add_line([sys,'/',['Answer modem/K-step',13,'delay3']],[185,180;220,180;220,130;265,130])
add_line([sys,'/',['Answer modem/K-step',13,'delay3']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['Answer modem/K-step',13,'delay3']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['Answer modem/K-step',13,'delay3']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['Answer modem/K-step',13,'delay3']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['Answer modem/K-step',13,'delay3']],[45,90;55,90])
add_line([sys,'/',['Answer modem/K-step',13,'delay3']],[300,130;320,130])
set_param([sys,'/',['Answer modem/K-step',13,'delay3']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay')
set_param([sys,'/',['Answer modem/K-step',13,'delay3']],...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['Answer modem/K-step',13,'delay3']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['Answer modem/K-step',13,'delay3']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.')
set_param([sys,'/',['Answer modem/K-step',13,'delay3']],...
		'Mask Entries','x*2+7\/.28/j/p/4/2\/0\/')


%     Finished composite block ['Answer modem/K-step',13,'delay3'].

set_param([sys,'/',['Answer modem/K-step',13,'delay3']],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[535,328,615,362])

add_block('built-in/Note',[sys,'/','Answer modem/k signal'])
set_param([sys,'/','Answer modem/k signal'],...
		'ForeGround',6,...
		'position',[300,295,305,300])

add_block('built-in/Note',[sys,'/','Answer modem/j signal'])
set_param([sys,'/','Answer modem/j signal'],...
		'ForeGround',6,...
		'position',[300,280,305,285])

add_block('built-in/Note',[sys,'/','Answer modem/Data ready'])
set_param([sys,'/','Answer modem/Data ready'],...
		'ForeGround',6,...
		'position',[305,265,310,270])

add_block('built-in/Note',[sys,'/','Answer modem/Frame begin'])
set_param([sys,'/','Answer modem/Frame begin'],...
		'ForeGround',6,...
		'position',[305,250,310,255])


%     Subsystem  ['Answer modem/K-step',13,'delay1'].

new_system([sys,'/',['Answer modem/K-step',13,'delay1']])
set_param([sys,'/',['Answer modem/K-step',13,'delay1']],'Location',[12,432,357,702])

add_block('built-in/Digital Clock',[sys,'/',['Answer modem/K-step',13,'delay1/Digital Clock']])
set_param([sys,'/',['Answer modem/K-step',13,'delay1/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])

add_block('built-in/Inport',[sys,'/',['Answer modem/K-step',13,'delay1/in_1']])
set_param([sys,'/',['Answer modem/K-step',13,'delay1/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Outport',[sys,'/',['Answer modem/K-step',13,'delay1/out_1']])
set_param([sys,'/',['Answer modem/K-step',13,'delay1/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Filter',[sys,'/',['Answer modem/K-step',13,'delay1/K-step',13,'delay']])
set_param([sys,'/',['Answer modem/K-step',13,'delay1/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Switch',[sys,'/',['Answer modem/K-step',13,'delay1/Switch']])
set_param([sys,'/',['Answer modem/K-step',13,'delay1/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Constant',[sys,'/',['Answer modem/K-step',13,'delay1/Constant']])
set_param([sys,'/',['Answer modem/K-step',13,'delay1/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Constant',[sys,'/',['Answer modem/K-step',13,'delay1/Constant1']])
set_param([sys,'/',['Answer modem/K-step',13,'delay1/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/K-step',13,'delay1/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/K-step',13,'delay1/Relational',13,'Operator']],...
		'position',[150,168,180,192])
add_line([sys,'/',['Answer modem/K-step',13,'delay1']],[300,130;320,130])
add_line([sys,'/',['Answer modem/K-step',13,'delay1']],[45,90;55,90])
add_line([sys,'/',['Answer modem/K-step',13,'delay1']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['Answer modem/K-step',13,'delay1']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['Answer modem/K-step',13,'delay1']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['Answer modem/K-step',13,'delay1']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['Answer modem/K-step',13,'delay1']],[185,180;220,180;220,130;265,130])
set_param([sys,'/',['Answer modem/K-step',13,'delay1']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay')
set_param([sys,'/',['Answer modem/K-step',13,'delay1']],...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['Answer modem/K-step',13,'delay1']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['Answer modem/K-step',13,'delay1']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.')
set_param([sys,'/',['Answer modem/K-step',13,'delay1']],...
		'Mask Entries','x*2*2\/.28/j/p/4/2/2\/0\/')


%     Finished composite block ['Answer modem/K-step',13,'delay1'].

set_param([sys,'/',['Answer modem/K-step',13,'delay1']],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[535,283,615,317])


%     Subsystem  ['Answer modem/K-step',13,'delay2'].

new_system([sys,'/',['Answer modem/K-step',13,'delay2']])
set_param([sys,'/',['Answer modem/K-step',13,'delay2']],'Location',[12,432,357,702])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/K-step',13,'delay2/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/K-step',13,'delay2/Relational',13,'Operator']],...
		'position',[150,168,180,192])

add_block('built-in/Constant',[sys,'/',['Answer modem/K-step',13,'delay2/Constant1']])
set_param([sys,'/',['Answer modem/K-step',13,'delay2/Constant1']],...
		'Value','n*ts(1)+ts(2)',...
		'position',[15,194,100,216])

add_block('built-in/Constant',[sys,'/',['Answer modem/K-step',13,'delay2/Constant']])
set_param([sys,'/',['Answer modem/K-step',13,'delay2/Constant']],...
		'Value','ini',...
		'position',[120,230,140,250])

add_block('built-in/Switch',[sys,'/',['Answer modem/K-step',13,'delay2/Switch']])
set_param([sys,'/',['Answer modem/K-step',13,'delay2/Switch']],...
		'Threshold','.1',...
		'position',[270,114,295,146])

add_block('built-in/Filter',[sys,'/',['Answer modem/K-step',13,'delay2/K-step',13,'delay']])
set_param([sys,'/',['Answer modem/K-step',13,'delay2/K-step',13,'delay']],...
		'Numerator','[zeros(1,n), 1]',...
		'Denominator','1',...
		'Sample time','ts',...
		'position',[60,70,185,110])

add_block('built-in/Outport',[sys,'/',['Answer modem/K-step',13,'delay2/out_1']])
set_param([sys,'/',['Answer modem/K-step',13,'delay2/out_1']],...
		'position',[325,120,345,140])

add_block('built-in/Inport',[sys,'/',['Answer modem/K-step',13,'delay2/in_1']])
set_param([sys,'/',['Answer modem/K-step',13,'delay2/in_1']],...
		'position',[20,80,40,100])

add_block('built-in/Digital Clock',[sys,'/',['Answer modem/K-step',13,'delay2/Digital Clock']])
set_param([sys,'/',['Answer modem/K-step',13,'delay2/Digital Clock']],...
		'Sample time','ts',...
		'position',[60,140,95,170])
add_line([sys,'/',['Answer modem/K-step',13,'delay2']],[185,180;220,180;220,130;265,130])
add_line([sys,'/',['Answer modem/K-step',13,'delay2']],[105,205;115,205;115,185;145,185])
add_line([sys,'/',['Answer modem/K-step',13,'delay2']],[100,155;115,155;115,175;145,175])
add_line([sys,'/',['Answer modem/K-step',13,'delay2']],[145,240;240,240;240,140;265,140])
add_line([sys,'/',['Answer modem/K-step',13,'delay2']],[190,90;195,90;195,120;265,120])
add_line([sys,'/',['Answer modem/K-step',13,'delay2']],[45,90;55,90])
add_line([sys,'/',['Answer modem/K-step',13,'delay2']],[300,130;320,130])
set_param([sys,'/',['Answer modem/K-step',13,'delay2']],...
		'Mask Display','    -k\nz   ',...
		'Mask Type','Multi-step delay')
set_param([sys,'/',['Answer modem/K-step',13,'delay2']],...
		'Mask Dialogue','Output is K-step delay of the input signal.|Delay steps (integer):|Sample time (sec):|Initial output:')
set_param([sys,'/',['Answer modem/K-step',13,'delay2']],...
		'Mask Translate','n=@1;ts=@2;if length(ts)<2, ts=[ts 0];end;ini=@3;')
set_param([sys,'/',['Answer modem/K-step',13,'delay2']],...
		'Mask Help','This block holds the input signal for K steps and then outputs the signal. The delay step cannot be changed during the simulation.')
set_param([sys,'/',['Answer modem/K-step',13,'delay2']],...
		'Mask Entries','x*2\/.28/j/p/4/2\/0\/')


%     Finished composite block ['Answer modem/K-step',13,'delay2'].

set_param([sys,'/',['Answer modem/K-step',13,'delay2']],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[620,253,700,287])

add_block('built-in/Logical Operator',[sys,'/',['Answer modem/Logical',13,'Operator']])
set_param([sys,'/',['Answer modem/Logical',13,'Operator']],...
		'orientation',3,...
		'ForeGround',6,...
		'hide name',0,...
		'Operator','NOT',...
		'Number of Input Ports','1',...
		'position',[425,215,465,245])


%     Subsystem  ['Answer modem/Synchronization',13,'pulses'].

new_system([sys,'/',['Answer modem/Synchronization',13,'pulses']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses']],'Location',[112,576,905,720])

add_block('built-in/Outport',[sys,'/',['Answer modem/Synchronization',13,'pulses/data ready',13,'frame pulse']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/data ready',13,'frame pulse']],...
		'Port','2',...
		'position',[735,65,755,85])

add_block('built-in/Inport',[sys,'/',['Answer modem/Synchronization',13,'pulses/enable signal']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/enable signal']],...
		'position',[230,20,250,40])

add_block('built-in/Outport',[sys,'/',['Answer modem/Synchronization',13,'pulses/frame begin signal']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/frame begin signal']],...
		'position',[490,25,510,45])

add_block('built-in/Product',[sys,'/',['Answer modem/Synchronization',13,'pulses/Product2']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Product2']],...
		'hide name',0,...
		'position',[440,25,465,45])


%     Subsystem  ['Answer modem/Synchronization',13,'pulses/D flip-flop'].

new_system([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],'Location',[144,208,694,397])

add_block('built-in/Memory',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Memory1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Memory1']],...
		'position',[90,10,130,40])

add_block('built-in/Memory',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Memory']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Memory']],...
		'orientation',2,...
		'position',[365,115,405,145])

add_block('built-in/Fcn',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Fcn1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Fcn1']],...
		'Expr','u[1]<.2',...
		'position',[150,13,180,37])

add_block('built-in/Fcn',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Fcn']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Fcn']],...
		'orientation',2,...
		'Expr','u[1]>.2',...
		'position',[280,118,325,142])

add_block('built-in/Outport',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/out_2']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/out_2']],...
		'Port','2',...
		'position',[515,65,535,85])

add_block('built-in/Outport',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/out_1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/out_1']],...
		'position',[485,50,505,70])

add_block('built-in/Combinatorial Logic',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Logic']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Logic']],...
		'Truth Table','[0 1;1 0;0 1;1 0;0 1;0 1;1 0;1 0]',...
		'position',[325,50,380,90])

add_block('built-in/Demux',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Demux']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Demux']],...
		'outputs','2',...
		'position',[405,50,445,85])

add_block('built-in/Mux',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Mux1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/Mux1']],...
		'inputs','3',...
		'position',[275,47,305,93])

add_block('built-in/Inport',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/in_2']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/in_2']],...
		'position',[160,60,180,80])


%     Subsystem  ['Answer modem/Synchronization',13,'pulses/D flip-flop/AND'].

new_system([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND']],'Location',[59,237,323,377])

add_block('built-in/Inport',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND/in_2']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND/in_2']],...
		'Port','2',...
		'position',[15,70,35,90])

add_block('built-in/Inport',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND/in_1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND/in_1']],...
		'position',[15,55,35,75])

add_block('built-in/Mux',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND/Mux']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND/Mux']],...
		'inputs','2',...
		'position',[65,55,95,90])

add_block('built-in/Combinatorial Logic',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND/AND']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND/AND']],...
		'Truth Table','[0;0;0;1]',...
		'position',[130,55,185,95])

add_block('built-in/Outport',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND/out_1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND/out_1']],...
		'position',[215,65,235,85])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND']],[190,75;210,75])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND']],[40,80;60,80])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND']],[40,65;60,65])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND']],[100,75;125,75])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND']],...
		'Mask Display','AND',...
		'Mask Type','AND',...
		'Mask Dialogue','AND Gate',...
		'Mask Help','Calculates the logical AND of the two inputs.')


%     Finished composite block ['Answer modem/Synchronization',13,'pulses/D flip-flop/AND'].

set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/AND']],...
		'position',[215,39,250,66])

add_block('built-in/Inport',[sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/in_1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop/in_1']],...
		'Port','2',...
		'position',[20,50,40,70])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[275,130;250,130;250,85;270,85])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[360,130;330,130])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[255,55;270,55])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[45,60;60,60;60,25;85,25])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[45,60;210,60])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[185,25;200,25;210,45])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[135,25;145,25])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[450,75;510,75])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[450,60;480,60])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[185,70;270,70])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[450,60;460,60;460,130;410,130])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[385,70;400,70])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],[310,70;320,70])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],...
		'Mask Display','D   1\n\n>   0',...
		'Mask Type','D flip-flop',...
		'Mask Dialogue','D flip-flop|Initial State for Output "1":')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],...
		'Mask Translate','ini=(@1~=0);')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],...
		'Mask Help','While the clock signal is high, the output will be the same as the input signal.  The flip-flop then latches to the value of the input at the trailing edge of the clock pulse for the remainder of the clock cycle.')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],...
		'Mask Entries','0\/')


%     Finished composite block ['Answer modem/Synchronization',13,'pulses/D flip-flop'].

set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/D flip-flop']],...
		'hide name',0,...
		'position',[315,16,350,69])

add_block('built-in/Outport',[sys,'/',['Answer modem/Synchronization',13,'pulses/k signal']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/k signal']],...
		'Port','4',...
		'position',[600,95,620,115])

add_block('built-in/Demux',[sys,'/',['Answer modem/Synchronization',13,'pulses/Demux2']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Demux2']],...
		'hide name',0,...
		'outputs','3',...
		'position',[500,68,550,112])

add_block('built-in/Outport',[sys,'/',['Answer modem/Synchronization',13,'pulses/j signal']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/j signal']],...
		'Port','3',...
		'position',[655,80,675,100])


%     Subsystem  ['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time'].

new_system([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],'Location',[55,192,283,286])

add_block('built-in/Outport',[sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time/Outport']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time/Outport']],...
		'position',[160,35,180,55])

add_block('built-in/S-Function',[sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time/S-function1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time/S-function1']],...
		'function name','homopuls',...
		'parameters','samp_time, out_divid, offset',...
		'position',[40,31,105,59])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],[110,45;155,45])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'Mask Display','plot(0,0,100,100,x,y);Pulse',...
		'Mask Type','Pulse generator')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'Mask Dialogue','Vector pulses with sample rate of each pulse as Sample_time / Divider.|Sample time (scalar, sec):|Divider (integer vector):|Offset (same length as Divider):')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'Mask Translate','samp_time=@1;out_divid=@2;offset=@3;[x,y]=srcsicon(2);')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'Mask Help','This block generates a vector pulse. The output length is the same as the divider vector length. The ith element of the output has the sample time Sample_time/Divider(i). All elements in divider must be integers.')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'Mask Entries','.28/j/p\/[1 1 4 8]\/[0 7*.28/j/p/8 0 0]\/')


%     Finished composite block ['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time'].

set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Pulses divide',13,'same sample time']],...
		'hide name',0,...
		'position',[20,63,100,107])

add_block('built-in/Demux',[sys,'/',['Answer modem/Synchronization',13,'pulses/Demux1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Demux1']],...
		'hide name',0,...
		'outputs','[1 3]',...
		'position',[120,67,170,103])

add_block('built-in/Product',[sys,'/',['Answer modem/Synchronization',13,'pulses/Product1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Product1']],...
		'hide name',0,...
		'position',[440,80,465,100])


%     Subsystem  ['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector'].

new_system([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],'Location',[282,116,671,290])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator']],...
		'position',[135,18,165,42])

add_block('built-in/Inport',[sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/in_1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/in_1']],...
		'position',[10,15,30,35])

add_block('built-in/Memory',[sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/Memory1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/Memory1']],...
		'position',[125,80,165,110])

add_block('built-in/Constant',[sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/one1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/one1']],...
		'Value','thld',...
		'position',[30,135,60,155])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator2']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator2']],...
		'Operator','>',...
		'position',[265,23,295,47])

add_block('built-in/Relational Operator',[sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/Relational',13,'Operator1']],...
		'position',[200,88,230,112])

add_block('built-in/Outport',[sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/out_1']])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector/out_1']],...
		'position',[340,25,360,45])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[300,35;335,35])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[235,100;240,100;240,40;260,40])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[170,30;260,30])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[65,145;100,145;100,35;130,35])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[100,145;180,145;180,105;195,105])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[170,95;195,95])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[35,25;130,25])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],[45,25;45,95;120,95])
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w);Edge det.',...
		'Mask Type','Edge detection')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'Mask Dialogue','Detect the rising edge of the input\nsignal. Output one when the rising\nedge is detected.|Threshold:')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'Mask Translate','thld=@1;[v,w]=trigicon(0,50,get_param(gcb,''orientation''),2);[x,y]=trigicon(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'Mask Help','This block outputs one when the input signal reaches a value larger than or equal to the given threshold value at the current time and the value was below the threshold one time step before. Otherwise, the block outputs zero.')
set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'Mask Entries','0.5\/')


%     Finished composite block ['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector'].

set_param([sys,'/',['Answer modem/Synchronization',13,'pulses/Rising edge',13,'detector']],...
		'hide name',0,...
		'position',[190,58,270,92])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[175,75;185,75])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[105,85;115,85])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[255,30;310,30])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[355,30;385,30;385,85;435,85])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[275,75;295,75;295,55;310,55])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[175,95;435,95])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[470,90;495,90])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[555,105;595,105])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[555,90;650,90])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[555,75;730,75])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[295,75;425,75;435,40])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[385,30;435,30])
add_line([sys,'/',['Answer modem/Synchronization',13,'pulses']],[470,35;485,35])


%     Finished composite block ['Answer modem/Synchronization',13,'pulses'].

set_param([sys,'/',['Answer modem/Synchronization',13,'pulses']],...
		'ForeGround',6,...
		'position',[215,245,250,310])
add_line([sys,'/','Answer modem'],[70,75;75,75])
add_line([sys,'/','Answer modem'],[190,280;210,280])
add_line([sys,'/','Answer modem'],[165,65;170,65])
add_line([sys,'/','Answer modem'],[165,85;170,85])
add_line([sys,'/','Answer modem'],[210,75;215,75])
add_line([sys,'/','Answer modem'],[260,75;275,75])
add_line([sys,'/','Answer modem'],[715,200;750,200])
add_line([sys,'/','Answer modem'],[600,210;675,210])
add_line([sys,'/','Answer modem'],[320,55;350,55])
add_line([sys,'/','Answer modem'],[445,210;445,185;475,185])
add_line([sys,'/','Answer modem'],[320,95;340,95;340,125;475,125])
add_line([sys,'/','Answer modem'],[320,75;345,75;345,105;475,105])
add_line([sys,'/','Answer modem'],[705,270;715,270;715,215;750,215])
add_line([sys,'/','Answer modem'],[620,300;725,300;725,230;750,230])
add_line([sys,'/','Answer modem'],[730,105;740,105;750,185])
add_line([sys,'/','Answer modem'],[395,75;465,75;475,85])
add_line([sys,'/','Answer modem'],[320,55;320,15;675,15;685,90])
add_line([sys,'/','Answer modem'],[525,135;600,135])
add_line([sys,'/','Answer modem'],[650,120;685,120])
add_line([sys,'/','Answer modem'],[395,55;665,55;675,190])
add_line([sys,'/','Answer modem'],[255,285;445,285;445,250])
add_line([sys,'/','Answer modem'],[255,300;530,300])
add_line([sys,'/','Answer modem'],[395,35;535,35;535,210;555,210])
add_line([sys,'/','Answer modem'],[395,300;395,145;475,145])
add_line([sys,'/','Answer modem'],[255,270;615,270])
add_line([sys,'/','Answer modem'],[255,255;380,255;380,165;475,165])
add_line([sys,'/','Answer modem'],[445,285;525,285;525,165;600,165])
add_line([sys,'/','Answer modem'],[580,55;580,75;600,75])
add_line([sys,'/','Answer modem'],[535,105;600,105])
add_line([sys,'/','Answer modem'],[795,210;830,210;830,305;625,305;625,325;640,325])
add_line([sys,'/','Answer modem'],[445,285;445,345;530,345])
add_line([sys,'/','Answer modem'],[620,345;640,345])
add_line([sys,'/','Answer modem'],[730,335;740,335])
add_line([sys,'/','Answer modem'],[830,335;840,335])
set_param([sys,'/','Answer modem'],...
		'Mask Display','Answer\nmodem',...
		'Mask Type','Data received modem')
set_param([sys,'/','Answer modem'],...
		'Mask Dialogue','The input signal enable the block to\ntransfer data.|Symbol rate, S (2400, 2800, 3000, 3200):|Data rate, R (2400, 4800, 9600, 14400, 28800):|Convolution encoder (1:16 state; 2:32 state; 3:64 state):|Precode filter coefficient (1x3 vector):|Convolution decoder delay steps:')
set_param([sys,'/','Answer modem'],...
		'Mask Translate','[rt,sm,tf,v34r,v34i]=v34param(@1,@2,@3,0);h=@4;j=rt(3);p=rt(4);b=rt(6);q=rt(7);K=rt(8);M=rt(9);x=@5;')
set_param([sys,'/','Answer modem'],...
		'Mask Help','This block simulate the data translation period of calling modem after modem phase 4 training. Unmask this block for details. ')
set_param([sys,'/','Answer modem'],...
		'Mask Entries','SRATE\/BRATE\/CON_CODE\/[1 .8 .4]+sqrt(-1)*[1 .5 .2]\/10\/')


%     Finished composite block 'Answer modem'.

set_param([sys,'/','Answer modem'],...
		'hide name',0,...
		'position',[425,93,505,137])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','50.000000',...
		'Hgain','0.030000',...
		'Vmax','100.000000',...
		'Hmax','0.060000',...
		'Window',[603,151,925,531])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[535,57,555,83])


%     Subsystem  'Error rate'.

new_system([sys,'/','Error rate'])
set_param([sys,'/','Error rate'],'Location',[255,368,509,510])

add_block('built-in/S-Function',[sys,'/','Error rate/S-function'])
set_param([sys,'/','Error rate/S-function'],...
		'function name','sbiterr',...
		'parameters','num_lin, K, TDelay, Sample',...
		'position',[130,52,195,78])

add_block('built-in/Mux',[sys,'/','Error rate/Mux'])
set_param([sys,'/','Error rate/Mux'],...
		'inputs','2',...
		'position',[65,46,100,79])

add_block('built-in/Inport',[sys,'/','Error rate/in_1'])
set_param([sys,'/','Error rate/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','Error rate/in_2'])
set_param([sys,'/','Error rate/in_2'],...
		'Port','2',...
		'position',[15,60,35,80])
add_line([sys,'/','Error rate'],[105,65;125,65])
add_line([sys,'/','Error rate'],[40,55;60,55])
add_line([sys,'/','Error rate'],[40,70;60,70])
set_param([sys,'/','Error rate'],...
		'Mask Display','Error\nmeter',...
		'Mask Type','Symbol/bit error counter')
set_param([sys,'/','Error rate'],...
		'Mask Dialogue','Use the input data from the 1st port as the reference signal to detect the number of errors and error rate of the 2nd port inputted signal.|Bit per symbol:|Number of digits on display:|Delay between input (1st port) and output (2nd port):|Sampling time (sec):')
set_param([sys,'/','Error rate'],...
		'Mask Translate','K=@1;num_lin=@2;TDelay=@3;Sample=@4;')
set_param([sys,'/','Error rate'],...
		'Mask Help','The signal from the first port must be a scalar. The second input port can be a vector with a same-time delay to the input signal. The comparison happens only at the sampling point.')
set_param([sys,'/','Error rate'],...
		'Mask Entries','ceil(v34_rate_b/4)\/20\/13*.28/v34_rate_p/v34_rate_j/4\/.28/v34_rate_p/v34_rate_j/4\/')


%     Finished composite block 'Error rate'.

set_param([sys,'/','Error rate'],...
		'orientation',1,...
		'hide name',0,...
		'position',[225,180,305,220])


%     Subsystem  ['Vector',13,'redistributor2'].

new_system([sys,'/',['Vector',13,'redistributor2']])
set_param([sys,'/',['Vector',13,'redistributor2']],'Location',[175,552,335,697])
set_param([sys,'/',['Vector',13,'redistributor2']],...
		'Mask Display','Display\nparameters',...
		'Mask Dialogue','eval(''[v34_rate_b, v34_rate_p, v34_rate_j]=v34prep(SRATE,BRATE,CON_CODE,1);'')')


%     Finished composite block ['Vector',13,'redistributor2'].

set_param([sys,'/',['Vector',13,'redistributor2']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[475,195,555,239])


%     Subsystem  'Utility1'.

new_system([sys,'/','Utility1'])
set_param([sys,'/','Utility1'],'Location',[136,230,381,439])
set_param([sys,'/','Utility1'],...
		'Mask Display','Reload\ndata',...
		'Mask Dialogue','eval(''v34cod16;BRATE=28800;SRATE=3200;CON_CODE=1;v34_plot_flag=0;v34_rate_b = 72; v34_rate_p=7;v34_rate_j=16;'')')


%     Finished composite block 'Utility1'.

set_param([sys,'/','Utility1'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[380,195,460,239])


%     Subsystem  'information'.

new_system([sys,'/','information'])
set_param([sys,'/','information'],'Location',[202,215,661,518])


%     Subsystem  'information/information1'.

new_system([sys,'/','information/information1'])
set_param([sys,'/','information/information1'],'Location',[4,60,788,251])

add_block('built-in/Note',[sys,'/',['information/information1/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']])
set_param([sys,'/',['information/information1/This library contains transmitter and receiver. The receiving part is almost reverse of the transmitting part. For a clear',13,'relationshipe, when a transmitter block is clicked, the function for the receiving will also be shown up and vice verse.            ']],...
		'position',[380,40,385,45])

add_block('built-in/Note',[sys,'/',['information/information1/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']])
set_param([sys,'/',['information/information1/black+blue blocks => typical ANALOG communication system.                          ',13,'',13,'black+green blocks => minimum configuration of a DIGITAL communication system.',13,'',13,'black+green+red blocks => maximum configuration of a DIGITAL communication system.      ']],...
		'position',[335,115,340,120])

add_block('built-in/Note',[sys,'/','information/information1/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'])
set_param([sys,'/','information/information1/The transmitting blocks has orientation from left to right. The receiving blocks has orientation from right to left.'],...
		'position',[350,80,355,85])
set_param([sys,'/','information/information1'],...
		'Mask Display','?')


%     Finished composite block 'information/information1'.

set_param([sys,'/','information/information1'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[485,220,530,261])

add_block('built-in/Note',[sys,'/',['information/This example implements the data translation part of the V.34 modem.',13,'The data is translated from the Call Modem to Answer Modem.']])
set_param([sys,'/',['information/This example implements the data translation part of the V.34 modem.',13,'The data is translated from the Call Modem to Answer Modem.']],...
		'position',[225,40,230,45])

add_block('built-in/Note',[sys,'/',['information/The Call Modem begins to transfer data when the signal to its input',13,'has positive value. The call modem reads a random binary signal.',13,'The first output port outputs baseband QASK modulated signal.']])
set_param([sys,'/',['information/The Call Modem begins to transfer data when the signal to its input',13,'has positive value. The call modem reads a random binary signal.',13,'The first output port outputs baseband QASK modulated signal.']],...
		'position',[215,75,220,80])

add_block('built-in/Note',[sys,'/',['information/The second output port outputs the transfered signal. This signal breaks',13,'the bits transferred in a map frame into four sections. The four sets of',13,'binary bits are converted into integerand are outputs in time sequence..']])
set_param([sys,'/',['information/The second output port outputs the transfered signal. This signal breaks',13,'the bits transferred in a map frame into four sections. The four sets of',13,'binary bits are converted into integerand are outputs in time sequence..']],...
		'position',[220,120,225,125])

add_block('built-in/Note',[sys,'/',['information/The first inport of the answer modem takes the transmitted signal. The',13,'answer modem begins to process the received signal when the signal',13,'to its second inport has a positive value. ']])
set_param([sys,'/',['information/The first inport of the answer modem takes the transmitted signal. The',13,'answer modem begins to process the received signal when the signal',13,'to its second inport has a positive value. ']],...
		'position',[220,170,225,175])

add_block('built-in/Note',[sys,'/',['information/The output of the answer modem has the same format with the second',13,'output of the Call Modem. There is a time delay for the Answer Modem',13,'to process its data.']])
set_param([sys,'/',['information/The output of the answer modem has the same format with the second',13,'output of the Call Modem. There is a time delay for the Answer Modem',13,'to process its data.']],...
		'position',[225,215,230,220])

add_block('built-in/Note',[sys,'/','information/Please read the manual for the limitation of the implementation.'])
set_param([sys,'/','information/Please read the manual for the limitation of the implementation.'],...
		'position',[205,270,210,275])
set_param([sys,'/','information'],...
		'Mask Display','?')


%     Finished composite block 'information'.

set_param([sys,'/','information'],...
		'ForeGround',6,...
		'hide name',0,...
		'position',[320,195,365,236])


%     Subsystem  ['Rayleigh noise',13,'channel CE'].

new_system([sys,'/',['Rayleigh noise',13,'channel CE']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],'Location',[496,318,758,464])

add_block('built-in/Inport',[sys,'/',['Rayleigh noise',13,'channel CE/in_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/in_1']],...
		'position',[45,10,65,30])


%     Subsystem  ['Rayleigh noise',13,'channel CE/Gaussian',13,'noise'].

new_system([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],'Location',[371,386,719,591])

add_block('built-in/White Noise',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Random',13,'Number']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Random',13,'Number']],...
		'Seed','s',...
		'position',[45,102,90,138])

add_block('built-in/Constant',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Constant']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Constant']],...
		'Value','m',...
		'position',[55,55,75,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Sum']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Sum']],...
		'position',[140,85,160,105])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/out_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/out_1']],...
		'position',[295,85,315,105])

add_block('built-in/State-Space',[sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','d\/')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise/Matrix',13,'Gain']],...
		'position',[210,81,235,109])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[80,65;110,65;110,90;135,90])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[95,120;110,120;110,100;135,100])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[165,95;205,95])
add_line([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],[240,95;290,95])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Display','Gaussian\nnoise',...
		'Mask Type','Gaussian noise.')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Dialogue','Gaussian distribution noise.|Mean value:|Standard deviation:|Initial Seed(s):',...
		'Mask Translate','m=@1;d=@2;s=@3;[m,d,s]=gwnoise(m,d,s);')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Help','When the mean value, seed are vectors, the output of this block is a vector with the length of the vector same as the length of mean value vector or that of the seed.')
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'Mask Entries','m\/d\/s\/')


%     Finished composite block ['Rayleigh noise',13,'channel CE/Gaussian',13,'noise'].

set_param([sys,'/',['Rayleigh noise',13,'channel CE/Gaussian',13,'noise']],...
		'position',[10,50,85,90])

add_block('built-in/Outport',[sys,'/',['Rayleigh noise',13,'channel CE/out_1']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/out_1']],...
		'position',[200,55,220,75])

add_block('built-in/Sum',[sys,'/',['Rayleigh noise',13,'channel CE/Sum']])
set_param([sys,'/',['Rayleigh noise',13,'channel CE/Sum']],...
		'position',[150,55,170,75])
add_line([sys,'/',['Rayleigh noise',13,'channel CE']],[175,65;195,65])
add_line([sys,'/',['Rayleigh noise',13,'channel CE']],[70,20;115,20;115,60;145,60])
add_line([sys,'/',['Rayleigh noise',13,'channel CE']],[90,70;145,70])
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Display','plot(0,0,100,100,x,y,v,w,u,z);Rayl N',...
		'Mask Type','Rayleigh noise channel, fixed parameter')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Dialogue','Additive Rayleigh noise channel for\nbaseband signal simulation. Input\nand output signals are complex.|sigma:|Seeds (1x2 vector):')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Translate','m=0;d=@1;d=d^2;s=@2;if length(s)<2,s=[s s+s];end;[x,y]=chanicon;[v,w]=cmplxicn(0,50,get_param(gcb,''orientation''));[u,z]=cmplxicn(1,50,get_param(gcb,''orientation''));')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Help','This block adds Rayleigh noise to the transmitting signal. The input and output of this block are complex data. The Rayleigh noise is composed with two independant zero mean Gaussian noise. These two Gaussian components have the same standard deviation sigma.')
set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'Mask Entries','.00001\/[12345 54321]\/')


%     Finished composite block ['Rayleigh noise',13,'channel CE'].

set_param([sys,'/',['Rayleigh noise',13,'channel CE']],...
		'hide name',0,...
		'position',[235,83,315,127])
add_line(sys,[70,115;110,115])
add_line(sys,[195,105;230,105])
add_line(sys,[320,105;420,105])
add_line(sys,[375,125;420,125])
add_line(sys,[195,125;205,125;205,160;245,160;245,175])
add_line(sys,[510,115;520,115;520,160;285,160;285,175])
add_line(sys,[360,105;360,70;530,70])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
